(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[         0,          0]
NotebookDataLength[    355277,       7822]
NotebookOptionsPosition[    347149,       7559]
NotebookOutlinePosition[    347486,       7574]
CellTagsIndexPosition[    347443,       7571]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["ClosureBSAx2.nb", "Title",
 CellChangeTimes->{{3.683902871124304*^9, 3.68390290606082*^9}, {
  3.6839498343279467`*^9, 3.683949835151998*^9}, {3.684141648169284*^9, 
  3.684141649737145*^9}, {3.6841417156830883`*^9, 3.684141717706863*^9}}],

Cell["\<\
Description: 
We compute a type A structure for closing a tangle from a planar Heegaard \
diagram. The underlying bordered sutured manifold has an additional pair of \
meridional sutures. As one might expect, the type A structure splits into two \
identical components.\
\>", "Text",
 CellChangeTimes->{{3.683950109886711*^9, 3.68395027867488*^9}, {
  3.683950357452958*^9, 3.683950446367662*^9}}],

Cell[CellGroupData[{

Cell["Load package BSFH.m", "Section",
 CellChangeTimes->{{3.683902406280332*^9, 3.683902411992662*^9}, {
  3.6839024516165123`*^9, 3.683902475521956*^9}, {3.68390335323253*^9, 
  3.683903371168364*^9}, {3.683949830312366*^9, 3.683949830550836*^9}, {
  3.685186908447523*^9, 3.6851869085320377`*^9}, {3.685198191575903*^9, 
  3.685198207056624*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "BSFH.m"}]], "Input",
 CellChangeTimes->{{3.683896286022256*^9, 3.683896288299066*^9}, {
  3.6839021785176077`*^9, 3.6839021860575857`*^9}, {3.6839491778963013`*^9, 
  3.6839491783118887`*^9}, {3.685186971048904*^9, 3.685186973487808*^9}, {
  3.685187264296172*^9, 3.685187267583693*^9}, {3.685203668910954*^9, 
  3.685203670179483*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"This is BSFH.m, version 1.0, \\na tool for computing bordered \
sutured Heegaard Floer homology,\\nbased on an algorithm due to Rumen \
Zarev,\\nwritten in Mathematica 10.3.1.0 for Linux x86 (64-bit). \\nA manual \
for this Mathematica package can be found in appendix D of\\n\\n   C.B. \
Zibrowius, \"\>", "\[InvisibleSpace]", 
   StyleBox["\<\"On a Heegaard Floer theory for tangles\"\>",
    StripOnInput->False,
    FontSlant->Italic], 
   "\[InvisibleSpace]", "\<\", PhD thesis (2016), Cambridge. \\n\\nFor more \
background on bordered sutured Floer theory, see\\n\\n   R. Zarev, \"\>", 
   "\[InvisibleSpace]", 
   StyleBox["\<\"Bordered Floer homology for sutured manifolds\"\>",
    StripOnInput->False,
    FontSlant->Italic], 
   "\[InvisibleSpace]", "\<\", arXiv: 0908.1106v2.\\n\\nFor questions, \
suggestions or comments, please email claudius.zibrowius\"\>", 
   "\[InvisibleSpace]", "\<\"@\"\>", 
   "\[InvisibleSpace]", "\<\"gmail.com. \\n\\n    Copyright (C) 2015-2016 \
Claudius Zibrowius\\n\\n    This program is free software: you can \
redistribute it and/or modify\\n    it under the terms of the GNU Affero \
General Public License as published by\\n    the Free Software Foundation, \
either version 3 of the License, or\\n    (at your option) any later version.\
\\n\\n    This program is distributed in the hope that it will be useful,\\n  \
  but WITHOUT ANY WARRANTY; without even the implied warranty of\\n    \
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\\n    GNU \
Affero General Public License for more details.\\n\\n    You should have \
received a copy of the GNU Affero General Public License\\n    along with \
this program.  If not, see <http://www.gnu.org/licenses/>.\"\>"}],
  SequenceForm[
  "This is BSFH.m, version 1.0, \na tool for computing bordered sutured \
Heegaard Floer homology,\nbased on an algorithm due to Rumen Zarev,\nwritten \
in Mathematica 10.3.1.0 for Linux x86 (64-bit). \nA manual for this \
Mathematica package can be found in appendix D of\n\n   C.B. Zibrowius, ", 
   Style["On a Heegaard Floer theory for tangles", Italic], 
   ", PhD thesis (2016), Cambridge. \n\nFor more background on bordered \
sutured Floer theory, see\n\n   R. Zarev, ", 
   Style["Bordered Floer homology for sutured manifolds", Italic], 
   ", arXiv: 0908.1106v2.\n\nFor questions, suggestions or comments, please \
email claudius.zibrowius", "@", 
   "gmail.com. \n\n    Copyright (C) 2015-2016 Claudius Zibrowius\n\n    This \
program is free software: you can redistribute it and/or modify\n    it under \
the terms of the GNU Affero General Public License as published by\n    the \
Free Software Foundation, either version 3 of the License, or\n    (at your \
option) any later version.\n\n    This program is distributed in the hope \
that it will be useful,\n    but WITHOUT ANY WARRANTY; without even the \
implied warranty of\n    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. \
 See the\n    GNU Affero General Public License for more details.\n\n    You \
should have received a copy of the GNU Affero General Public License\n    \
along with this program.  If not, see <http://www.gnu.org/licenses/>."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.685203698151988*^9, 3.685203705067401*^9}, 
   3.6852037817068872`*^9, 3.6852038625098257`*^9, 3.685246622224927*^9, 
   3.6852477466607237`*^9, 3.685248986779213*^9, 3.6852491665949183`*^9, 
   3.685254474431779*^9, {3.6852587902608347`*^9, 3.685258792835278*^9}, 
   3.68525890264445*^9, 3.68569631512576*^9, 3.685696390769709*^9, 
   3.6856967870706177`*^9, {3.685697053247446*^9, 3.68569712335627*^9}, 
   3.685697159326499*^9, 3.685697193749625*^9, 3.685697311945281*^9, 
   3.685699411414978*^9, 3.6857060379482727`*^9, 3.685711666174616*^9, 
   3.685712330216119*^9, 3.685712543738003*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input data from nice Heegaard diagram", "Section",
 CellChangeTimes->{{3.683902406280332*^9, 3.683902411992662*^9}, {
  3.6839024516165123`*^9, 3.683902475521956*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"regionsInput", "=", " ", 
   TagBox[
    RowBox[{"(", GridBox[{
       {"1", "13", "3", "\[Placeholder]", "\[Placeholder]"},
       {"2", "3", "2", "\[Placeholder]", "\[Placeholder]"},
       {"3", "2", "10", "\[Placeholder]", "\[Placeholder]"},
       {"4", "17", "9", "\[Placeholder]", "\[Placeholder]"},
       {"5", "9", "8", "\[Placeholder]", "\[Placeholder]"},
       {"6", "8", "14", "\[Placeholder]", "\[Placeholder]"},
       {"7", "11", "10", "13", "12"},
       {"8", "12", "13", "3", "4"},
       {"9", "11", "12", "4", "5"},
       {"10", "5", "4", "7", "6"},
       {"11", "6", "7", "15", "16"},
       {"12", "7", "8", "14", "15"},
       {"13", "15", "14", "17", "16"},
       {"14", "6", "5", "\[Placeholder]", "\[Placeholder]"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}, "Items" -> {}, 
        "ItemsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}, "Items" -> {}, 
        "ItemsIndexed" -> {}}], ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"alphaarcsInput", "=", 
   RowBox[{"(", GridBox[{
      {"1", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]},
      {"2", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4", ",", "5", ",", "6", ",", "7", ",", "8"}], 
        "}"}]},
      {"3", 
       RowBox[{"{", "9", "}"}]},
      {"4", 
       RowBox[{"{", 
        RowBox[{"10", ",", "11", ",", "12", ",", "13"}], "}"}]},
      {"5", 
       RowBox[{"{", 
        RowBox[{"14", ",", "15", ",", "16", ",", "17"}], "}"}]}
     }], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"alphacurvesInput", "=", 
    RowBox[{"{", "}"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"If", " ", "there", " ", "were", " ", "any", " ", "\[Alpha]"}], 
     "-", 
     RowBox[{
     "curves", " ", "we", " ", "would", " ", "start", " ", "counting", " ", 
      "at", " ", 
      RowBox[{"Length", "[", "alphaarcsInput", "]"}]}], "+", "1"}], "=", 
    "6."}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"betacurvesInput", "=", 
   RowBox[{"(", GridBox[{
      {"1", 
       RowBox[{"{", "1", "}"}]},
      {"2", 
       RowBox[{"{", 
        RowBox[{"10", ",", "13", ",", "2", ",", "3"}], "}"}]},
      {"3", 
       RowBox[{"{", 
        RowBox[{"8", ",", "9", ",", "14", ",", "17"}], "}"}]},
      {"4", 
       RowBox[{"{", 
        RowBox[{
        "11", ",", "12", ",", "4", ",", "7", ",", "15", ",", "16", ",", "6", 
         ",", "5"}], "}"}]}
     }], ")"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CancellationSortListInput", "=", 
   TagBox[
    RowBox[{"(", GridBox[{
       {"6", "5"},
       {"7", "4"}
      }], ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"RelevantGeneratorQ", "[", "v_", "]"}], ":=", 
    RowBox[{
     RowBox[{"Count", "[", 
      RowBox[{"v", ",", 
       RowBox[{"entry_", "/;", 
        RowBox[{
         RowBox[{"WhichAlphaQ", "[", "entry", "]"}], ">", "3"}]}]}], "]"}], 
     "\[Equal]", "2"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "This", " ", "means", " ", "we", " ", "only", " ", "consider", " ", 
      "those", " ", "generators", " ", "relevant", " ", "which", " ", 
      "occupy", " ", "exactly", " ", "2", " ", "\[Alpha]"}], "-", 
     RowBox[{
     "curves", " ", "with", " ", "index", " ", "greater", " ", "than", " ", 
      "3.", " ", "Here"}]}], ",", " ", 
    RowBox[{
    "we", " ", "want", " ", "the", " ", "silly", " ", "arcs", " ", "to", " ", 
     "be", " ", "always", " ", 
     RowBox[{"occupied", "."}]}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"RelevantGeneratorGenerationQ", "[", "listOfAlphas_", "]"}], ":=", 
   "True"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"S1BoundaryInput", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "2", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "5", ",", "4"}], "}"}], ",", 
     RowBox[{"{", "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"TypeS1", "=", "TypeA"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"S2BoundaryInput", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"TypeS2", "=", "TypeA"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ArcDiagram1MatchingsInput", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "9"}], "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ArcDiagram2MatchingsInput", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"S1AlwaysOccupiedAlphaArcs", "=", 
   RowBox[{"{", 
    RowBox[{"4", ",", "5"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"S2AlwaysOccupiedAlphaArcs", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"S1PotentiallyOccupiedAlphaArcs", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"S2PotentiallyOccupiedAlphaArcs", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"S1NeverOccupiedAlphaArcs", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"S2NeverOccupiedAlphaArcs", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"NS1oaa", "=", "4"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"NS2oaa", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NR", "=", "14"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NI", "=", "17"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Step0Preparation", ";"}]}], "Input",
 CellChangeTimes->{{3.6497530722503233`*^9, 3.6497531640105715`*^9}, {
   3.649753200182641*^9, 3.6497532306203814`*^9}, {3.649753295437089*^9, 
   3.6497537205584044`*^9}, {3.649753809663501*^9, 3.6497540947948093`*^9}, {
   3.64975417591745*^9, 3.6497544232615967`*^9}, {3.649754582102682*^9, 
   3.6497546193148108`*^9}, {3.6497597447969356`*^9, 3.649759820857286*^9}, {
   3.6497598739923253`*^9, 3.6497600406208553`*^9}, {3.6498348056844025`*^9, 
   3.649834809398615*^9}, {3.6500118158196554`*^9, 3.6500119552486305`*^9}, {
   3.6500120907763824`*^9, 3.650012100424934*^9}, {3.6500121318167295`*^9, 
   3.6500121752402134`*^9}, {3.650012235023633*^9, 3.6500124904712434`*^9}, {
   3.6500125549099293`*^9, 3.6500135229893*^9}, {3.6500137752877307`*^9, 
   3.6500137980100307`*^9}, {3.650014346297391*^9, 3.6500144942018504`*^9}, {
   3.651649531551473*^9, 3.651649715648744*^9}, {3.651649748025792*^9, 
   3.651650111090334*^9}, {3.651650146439418*^9, 3.6516501589804354`*^9}, {
   3.651650192001482*^9, 3.651650433735837*^9}, {3.6516504753718996`*^9, 
   3.6516519704441*^9}, {3.651652054997223*^9, 3.651652060628233*^9}, {
   3.6519345605327864`*^9, 3.6519345810648155`*^9}, {3.6519358757890897`*^9, 
   3.6519358917171125`*^9}, {3.6519359368331766`*^9, 
   3.6519359370731773`*^9}, {3.651935978236236*^9, 3.6519360167562904`*^9}, {
   3.651936124565445*^9, 3.651936172629513*^9}, {3.651936220229581*^9, 
   3.6519362497016225`*^9}, {3.651936345052758*^9, 3.651937012110732*^9}, {
   3.6519370562627954`*^9, 3.651937314038168*^9}, {3.651937665336673*^9, 
   3.651937669427678*^9}, {3.6519377101977406`*^9, 3.651937863584965*^9}, {
   3.651937897214015*^9, 3.6519381861784363`*^9}, {3.6519382217124863`*^9, 
   3.6519384265657835`*^9}, {3.6519384666458426`*^9, 3.651938520239919*^9}, {
   3.6519385515209646`*^9, 3.6519388240813603`*^9}, {3.651938855954406*^9, 
   3.6519388862824492`*^9}, {3.6519392745537353`*^9, 
   3.6519392799437428`*^9}, {3.6519393372788243`*^9, 
   3.6519393914219007`*^9}, {3.651939423092946*^9, 3.6519395761171694`*^9}, {
   3.651939612384222*^9, 3.651939714064367*^9}, {3.65193975111042*^9, 
   3.6519399760747414`*^9}, {3.651941430807907*^9, 3.6519414332769117`*^9}, {
   3.651945362054637*^9, 3.651945363210703*^9}, {3.6519454225397882`*^9, 
   3.6519455694779973`*^9}, {3.651945720107213*^9, 3.6519457916863155`*^9}, {
   3.6519458487563953`*^9, 3.651945862358415*^9}, {3.651945927406509*^9, 
   3.651946006478621*^9}, {3.6519460579536943`*^9, 3.6519461737618604`*^9}, {
   3.651946204178903*^9, 3.651946227686937*^9}, {3.651946265880993*^9, 
   3.6519466589295626`*^9}, {3.651946690234609*^9, 3.6519467289476686`*^9}, {
   3.6519467600477147`*^9, 3.651946934603969*^9}, {3.6519469707200203`*^9, 
   3.6519470228180943`*^9}, {3.6519472390614033`*^9, 
   3.6519472412114067`*^9}, {3.6519472854534683`*^9, 
   3.6519473691605873`*^9}, {3.651948557668288*^9, 3.651948558138289*^9}, {
   3.6523417291331387`*^9, 3.652341766577015*^9}, {3.652343691754648*^9, 
   3.652343701715831*^9}, {3.65234386740432*^9, 3.6523439446431303`*^9}, {
   3.652344032687261*^9, 3.6523440596433907`*^9}, {3.652358747272119*^9, 
   3.652358986818255*^9}, {3.6523590916238422`*^9, 3.652359092089066*^9}, {
   3.652378686654628*^9, 3.652378730052348*^9}, {3.652378811671297*^9, 
   3.652378858709206*^9}, {3.6523789541849403`*^9, 3.65237921139062*^9}, 
   3.652379257576953*^9, {3.652507866916305*^9, 3.652507867239162*^9}, {
   3.6527159962477207`*^9, 3.652716042325199*^9}, {3.652716363312395*^9, 
   3.65271680328963*^9}, {3.6527169177729797`*^9, 3.652716918059433*^9}, {
   3.652717303055015*^9, 3.65271730330694*^9}, {3.652790736845571*^9, 
   3.65279074215808*^9}, {3.652790774966799*^9, 3.652790789743931*^9}, 
   3.653124165618794*^9, 3.653125890605195*^9, {3.6534471181783257`*^9, 
   3.653447122852326*^9}, {3.6534471620035152`*^9, 3.653447327499275*^9}, {
   3.653447448194496*^9, 3.6534478276643457`*^9}, {3.653447881673066*^9, 
   3.6534480504974194`*^9}, {3.653448089596459*^9, 3.653448208613467*^9}, {
   3.653448239094824*^9, 3.653449345615569*^9}, {3.653449384296937*^9, 
   3.653449507080082*^9}, {3.653449554328115*^9, 3.653449742551841*^9}, {
   3.653449805976263*^9, 3.653449861005069*^9}, {3.653449898022132*^9, 
   3.653450094006476*^9}, {3.653450148433264*^9, 3.653450416688586*^9}, {
   3.653450457907782*^9, 3.6534505694720583`*^9}, {3.653450608674986*^9, 
   3.653450773591426*^9}, {3.653450808496027*^9, 3.653450926856135*^9}, {
   3.6534509667392807`*^9, 3.653451123128397*^9}, {3.6534511645267897`*^9, 
   3.653451624907023*^9}, {3.653451768110091*^9, 3.653451773589279*^9}, {
   3.653645392293866*^9, 3.653645459559637*^9}, {3.653645700349249*^9, 
   3.6536458264115257`*^9}, {3.653645860138418*^9, 3.653646117204277*^9}, {
   3.6536462030397873`*^9, 3.653646512275378*^9}, {3.6536491677669697`*^9, 
   3.6536491695033207`*^9}, {3.653649648307026*^9, 3.653649650931691*^9}, {
   3.6539023990312862`*^9, 3.6539024120716743`*^9}, {3.654001721429076*^9, 
   3.654001725411331*^9}, {3.654001834747726*^9, 3.654001838677055*^9}, {
   3.654001886392312*^9, 3.6540018902218723`*^9}, {3.654001924972046*^9, 
   3.6540019274664392`*^9}, {3.654002021825857*^9, 3.654002050814403*^9}, {
   3.6540020837955217`*^9, 3.654002209262237*^9}, {3.654080975998732*^9, 
   3.654080986792881*^9}, {3.6540841797305727`*^9, 3.654084580791286*^9}, {
   3.654084647424561*^9, 3.654084938895278*^9}, {3.654084975695881*^9, 
   3.654085188005872*^9}, {3.654189112984047*^9, 3.6541891306026983`*^9}, {
   3.654279101274822*^9, 3.654279110214291*^9}, 3.670226470106555*^9, 
   3.672564778125291*^9, {3.6736107144428673`*^9, 3.67361071673802*^9}, {
   3.673610785955585*^9, 3.67361135996733*^9}, {3.673773958449003*^9, 
   3.67377396487294*^9}, {3.673886685926611*^9, 3.6738866862138453`*^9}, {
   3.6738885485791597`*^9, 3.673888548784831*^9}, 3.67532364078561*^9, 
   3.675510019026894*^9, 3.675510051233177*^9, 3.6755754684527073`*^9, {
   3.675580786025653*^9, 3.67558086913097*^9}, {3.675591097902276*^9, 
   3.675591098195758*^9}, {3.67559116628647*^9, 3.6755911669263783`*^9}, {
   3.6755911999068737`*^9, 3.675591200173562*^9}, {3.6755915244292*^9, 
   3.6755918989747963`*^9}, {3.675592002522607*^9, 3.675592022435896*^9}, {
   3.675592089113963*^9, 3.675592089701181*^9}, {3.675593425511962*^9, 
   3.675593429599656*^9}, {3.675593470474856*^9, 3.6755935621622753`*^9}, {
   3.675595252252369*^9, 3.675595317034992*^9}, {3.675681759366687*^9, 
   3.675681806490787*^9}, {3.675851569617619*^9, 3.675851637197174*^9}, {
   3.6759226733014708`*^9, 3.675922683031599*^9}, {3.675924874544126*^9, 
   3.6759250783099422`*^9}, {3.675925765316263*^9, 3.675925853845504*^9}, {
   3.6759386639242983`*^9, 3.6759387209604273`*^9}, {3.6759584239651003`*^9, 
   3.6759585214012747`*^9}, {3.675958553821933*^9, 3.675958570771214*^9}, {
   3.6759600153765717`*^9, 3.675960057712853*^9}, {3.6759602372898693`*^9, 
   3.675960242562107*^9}, {3.6759602873497257`*^9, 3.6759603900916567`*^9}, {
   3.6759604399252377`*^9, 3.675960446607627*^9}, 3.676005272937895*^9, 
   3.6760053240393467`*^9, 3.676021482545515*^9, {3.676021560052281*^9, 
   3.676022127436892*^9}, {3.676022216512494*^9, 3.6760229843015423`*^9}, {
   3.676023177212393*^9, 3.676023546449527*^9}, {3.676024271478404*^9, 
   3.676024603324912*^9}, {3.676024665484136*^9, 3.676024782787224*^9}, {
   3.676024854119236*^9, 3.6760248640841513`*^9}, {3.6760250088069153`*^9, 
   3.676025057439742*^9}, {3.676025249390964*^9, 3.6760253009161587`*^9}, {
   3.676025343840477*^9, 3.676025454046672*^9}, {3.676119221103794*^9, 
   3.676119228237918*^9}, {3.6761193013380613`*^9, 3.676119510407556*^9}, {
   3.676119543752206*^9, 3.676119727419374*^9}, {3.676119761094864*^9, 
   3.676119890665061*^9}, {3.676120078015214*^9, 3.676120083406232*^9}, {
   3.676121221198847*^9, 3.676121921702248*^9}, {3.6761219691023912`*^9, 
   3.676122334365264*^9}, {3.676122380870414*^9, 3.676122406798971*^9}, {
   3.67612244311215*^9, 3.6761225221941767`*^9}, {3.676122639453322*^9, 
   3.676122939279006*^9}, {3.676123227018145*^9, 3.676123257096648*^9}, {
   3.6761237135454493`*^9, 3.676123734364585*^9}, {3.6761250122199507`*^9, 
   3.676125012376691*^9}, {3.676125176189796*^9, 3.67612517638523*^9}, {
   3.677676312748744*^9, 3.677676327903968*^9}, {3.677676991863443*^9, 
   3.67767729526375*^9}, {3.677677333016506*^9, 3.677677490646119*^9}, {
   3.677677523157702*^9, 3.677677667586739*^9}, {3.677677718868541*^9, 
   3.6776778204809504`*^9}, {3.677677873168643*^9, 3.677677927030601*^9}, {
   3.67767796875508*^9, 3.6776780297813463`*^9}, {3.677678064052412*^9, 
   3.677678451162526*^9}, {3.677678660504642*^9, 3.677678916339388*^9}, {
   3.67767894672374*^9, 3.6776792507558193`*^9}, {3.6776793205431004`*^9, 
   3.677679488099471*^9}, {3.677679533149323*^9, 3.677679754394271*^9}, 
   3.677681168910832*^9, {3.678722500020762*^9, 3.678722518955509*^9}, {
   3.6787230661747*^9, 3.678723242930275*^9}, {3.678723283137291*^9, 
   3.67872332957576*^9}, {3.678723365853586*^9, 3.67872383272751*^9}, {
   3.6787238948014593`*^9, 3.6787239608564997`*^9}, {3.678724796691175*^9, 
   3.678724820003809*^9}, {3.67872485860867*^9, 3.678724868788558*^9}, {
   3.678729313739044*^9, 3.67872933221128*^9}, {3.6787294763543367`*^9, 
   3.6787299065469646`*^9}, {3.6787300710280848`*^9, 3.678730071422598*^9}, {
   3.678730322495199*^9, 3.678730323785355*^9}, {3.6787303950068274`*^9, 
   3.678730395674675*^9}, {3.678765758197289*^9, 3.678766381340143*^9}, {
   3.67876643099756*^9, 3.6787665616908283`*^9}, {3.678768317890379*^9, 
   3.678768318508003*^9}, {3.678768423156954*^9, 3.6787684278849363`*^9}, {
   3.678768509959207*^9, 3.6787685197194843`*^9}, {3.678768553818428*^9, 
   3.678768554569421*^9}, {3.678768589208424*^9, 3.678769290619643*^9}, {
   3.678769326536812*^9, 3.678769428639135*^9}, {3.678769493829928*^9, 
   3.678769509433446*^9}, {3.678769549578459*^9, 3.678769590779674*^9}, {
   3.6787704361854763`*^9, 3.678770641273473*^9}, {3.678773223101853*^9, 
   3.678773239704031*^9}, 3.679373090029645*^9, {3.683894359412177*^9, 
   3.683894407306477*^9}, {3.6838945110481052`*^9, 3.6838945173890753`*^9}, 
   3.68389683590415*^9, {3.683901863456834*^9, 3.683901890387862*^9}, 
   3.6839019752670717`*^9, {3.683902018178482*^9, 3.683902048968762*^9}, {
   3.683902118716179*^9, 3.6839021222572412`*^9}, {3.683902287755432*^9, 
   3.683902287917288*^9}, {3.683906644387364*^9, 3.6839066446741962`*^9}, {
   3.68390670210072*^9, 3.68390670236974*^9}, {3.68398447852845*^9, 
   3.6839844790536222`*^9}, {3.684038701674336*^9, 3.684038706669203*^9}, {
   3.685188570586812*^9, 3.685188599093625*^9}, {3.685189608057357*^9, 
   3.685189623863472*^9}, {3.6851900509380713`*^9, 3.685190072082631*^9}, {
   3.685190109244026*^9, 3.685190247420245*^9}, {3.685190334233671*^9, 
   3.685190360919217*^9}, {3.685197303680831*^9, 3.6851973889965363`*^9}, {
   3.685197420990172*^9, 3.685197617340919*^9}, {3.6851976971770067`*^9, 
   3.685197772978985*^9}, {3.685197845150587*^9, 3.685197845392006*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"CHECK THE FOLLOWING FEEDBACK CAREFULLY! \"\>"], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991513033`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"#{regions}=\"\>", "\[InvisibleSpace]", "14"}],
  SequenceForm["#{regions}=", 14],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.685711699153081*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"#{intersection points}=\"\>", "\[InvisibleSpace]", "17"}],
  SequenceForm["#{intersection points}=", 17],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991556377`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\" 0 vertices = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "9"}], "}"}]}],
  SequenceForm[" 0 vertices = ", {1, 2, 9}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991561823`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"+1 vertices = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3", ",", "6", ",", "7", ",", "13", ",", "15"}], "}"}]}],
  SequenceForm["+1 vertices = ", {3, 6, 7, 13, 15}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.685711699156582*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"-1 vertices = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "5", ",", "8", ",", "12", ",", "14"}], "}"}]}],
  SequenceForm["-1 vertices = ", {4, 5, 8, 12, 14}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.685711699157143*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"+2 vertices = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"11", ",", "17"}], "}"}]}],
  SequenceForm["+2 vertices = ", {11, 17}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.685711699157563*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"-2 vertices = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"10", ",", "16"}], "}"}]}],
  SequenceForm["-2 vertices = ", {10, 16}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991579742`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"bigon regions = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "14"}], 
    "}"}]}],
  SequenceForm["bigon regions = ", {1, 2, 3, 4, 5, 6, 14}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991584053`*^9}],

Cell[BoxData["\<\"No multiple cancellation. Good! \"\>"], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.685711699158772*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Intersection points whose cancellation will be attempted last: \
\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "3", ",", "8", ",", "9", ",", "10", ",", "11", ",", 
     "12", ",", "13", ",", "14", ",", "15", ",", "16", ",", "17"}], "}"}]}],
  SequenceForm[
  "Intersection points whose cancellation will be attempted last: ", {1, 2, 3,
    8, 9, 10, 11, 12, 13, 14, 15, 16, 17}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.685711699159183*^9}],

Cell[BoxData["\<\"Cancelling pairs belong to same \[Alpha]s. Good!\"\>"], \
"Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.685711699159577*^9}],

Cell[BoxData["\<\"Cancelling pairs belong to same \[Beta]s. Good!\"\>"], \
"Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.685711699160153*^9}],

Cell[BoxData["\<\"All intersection points lie on exactly one \[Alpha]-curve. \
Good!\"\>"], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991606617`*^9}],

Cell[BoxData["\<\"All intersection points lie on exactly one \[Beta]-curve. \
Good!\"\>"], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.685711699161067*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"NAC=#{\[Alpha]-circles}=\"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["NAC=#{\[Alpha]-circles}=", 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.685711699161504*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"NAA=#{\[Alpha]-arcs}=\"\>", "\[InvisibleSpace]", "5"}],
  SequenceForm["NAA=#{\[Alpha]-arcs}=", 5],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.68571169916193*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"NA=#{\[Alpha]-curves}=\"\>", "\[InvisibleSpace]", "5"}],
  SequenceForm["NA=#{\[Alpha]-curves}=", 5],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.685711699162348*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"NB=#{\[Beta]-circles}=\"\>", "\[InvisibleSpace]", "4"}],
  SequenceForm["NB=#{\[Beta]-circles}=", 4],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991627703`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Surface 1 (\"\>", "\[InvisibleSpace]", "TypeA", 
   "\[InvisibleSpace]", "\<\"): #occupied \[Alpha]-arcs = \"\>", 
   "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\", #moving strands = \"\>", "\[InvisibleSpace]", 
   "4"}],
  SequenceForm[
  "Surface 1 (", $CellContext`TypeA, "): #occupied \[Alpha]-arcs = ", 4, 
   ", #moving strands = ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991631804`*^9}],

Cell[BoxData["\<\"There is only one glueing surface.\"\>"], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991636*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Setup for backups", "Section",
 CellChangeTimes->{{3.683902406280332*^9, 3.683902411992662*^9}, {
   3.6839024516165123`*^9, 3.683902475521956*^9}, {3.68390335323253*^9, 
   3.683903371168364*^9}, {3.683949830312366*^9, 3.683949830550836*^9}, {
   3.685186908447523*^9, 3.6851869085320377`*^9}, {3.685187100587757*^9, 
   3.685187104979512*^9}, {3.685187153661024*^9, 3.68518716342925*^9}, {
   3.685198090550712*^9, 3.6851980924296083`*^9}, 3.68519813049438*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"BackupFilePath", "=", 
      RowBox[{"<", 
       RowBox[{"path", " ", "for", " ", "backup"}], ">"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"To", " ", "save", " ", "all", " ", "variables"}]}], ",", " ", 
    RowBox[{
     RowBox[{"use", ":", " ", 
      RowBox[{"DumpSave", "[", 
       RowBox[{
        RowBox[{"BackupFilePath", "<>", "\"\<.mx\>\""}], ",", 
        "\"\<Global`\>\""}], "]"}]}], ";", "\n", 
     RowBox[{
     "To", " ", "load", " ", "all", " ", "variables", " ", "from", " ", 
      "this", " ", "file"}]}], ",", " ", 
    RowBox[{
     RowBox[{"use", ":", " ", 
      RowBox[{"<<", 
       RowBox[{"(", 
        RowBox[{"BackupFilePath", "<>", "\"\<.mx\>\""}], ")"}]}]}], ";"}]}], 
   "\[IndentingNewLine]", "*)"}], "\n", 
  RowBox[{"BackupFilePath", "=", 
   RowBox[{
    RowBox[{"NotebookDirectory", "[", "]"}], "<>", "\"\<Backups/\>\"", "<>", 
    RowBox[{"StringDrop", "[", 
     RowBox[{
      RowBox[{"FileNameTake", "[", 
       RowBox[{"NotebookFileName", "[", "]"}], "]"}], ",", 
      RowBox[{"-", "3"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.685187085220419*^9, 3.685187085619646*^9}, {
  3.685187115996806*^9, 3.685187117420495*^9}, {3.685187180166778*^9, 
  3.685187271160758*^9}, {3.6851876607312403`*^9, 3.685187679762589*^9}, {
  3.6851877211005583`*^9, 3.6851878014470453`*^9}, {3.685188020564032*^9, 
  3.685188024022112*^9}, {3.6851880573745403`*^9, 3.6851882124099407`*^9}, {
  3.685188243804207*^9, 3.6851882507369843`*^9}, {3.685202300849607*^9, 
  3.68520234868612*^9}}],

Cell[BoxData["\<\"/mhome/dpmms/c/cbz20/Documents/PhD/Research/thesis/BSFH/\
Backups/ClosureBSAx2\"\>"], "Output",
 CellChangeTimes->{3.685202350065628*^9, 3.6852477522167463`*^9, 
  3.685248991231922*^9, 3.685258909150461*^9, 3.685692740393689*^9, 
  3.685706229642539*^9, 3.685711702345194*^9, 3.68571233346281*^9, 
  3.685712547769155*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculation of bordered sutured algebra", "Section",
 CellChangeTimes->{{3.683902406280332*^9, 3.683902411992662*^9}, {
   3.6839024516165123`*^9, 3.683902475521956*^9}, {3.683902509419033*^9, 
   3.683902551851089*^9}, {3.683902843994619*^9, 3.6839028464994917`*^9}, {
   3.683903880670438*^9, 3.683903893160449*^9}, 3.6851906152290363`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Step1x1Algebra", ";"}]], "Input",
 CellChangeTimes->{{3.683894564398328*^9, 3.683894567470285*^9}, 
   3.6838968494193707`*^9, {3.6851903740240927`*^9, 3.685190396536707*^9}, {
   3.6851904896752787`*^9, 3.68519049325898*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Idempotents for S1 (occupied arcs in strands diagram):\\n \
\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "2", "3"},
       {
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "4", ",", "5"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"1", ",", "3", ",", "4", ",", "5"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"2", ",", "3", ",", "4", ",", "5"}], "}"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Idempotents for S1 (occupied arcs in strands diagram):\n ", 
   MatrixForm[{{1, 2, 3}, {{1, 2, 4, 5}, {1, 3, 4, 5}, {2, 3, 4, 5}}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.68389456864986*^9, 3.6838946234736547`*^9, 3.6838968500122004`*^9, 
   3.683899172980453*^9, 3.6838995524215097`*^9, 3.683903578791626*^9, {
   3.683903796738854*^9, 3.683903821259932*^9}, 3.6839039858898287`*^9, 
   3.683904596171867*^9, 3.683904668575684*^9, 3.68390546967093*^9, 
   3.68390623088945*^9, 3.683906649950728*^9, 3.683906712317583*^9, 
   3.68394927827203*^9, 3.683949850668906*^9, 3.683952373169733*^9, 
   3.683955118254199*^9, 3.683958897086561*^9, 3.685190833502232*^9, 
   3.685191535214994*^9, 3.685191885507491*^9, 3.6851920442229223`*^9, 
   3.6851922073521833`*^9, 3.685193111648541*^9, 3.685193836139495*^9, 
   3.685247754578397*^9, 3.685248996142511*^9, 3.685254501259327*^9, 
   3.685258911078904*^9, 3.685706232058814*^9, 3.6857117035769053`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Idempotents for S2 (occupied arcs in strands diagram):\\n \
\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1"},
       {
        RowBox[{"{", "}"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Idempotents for S2 (occupied arcs in strands diagram):\n ", 
   MatrixForm[{{1}, {{}}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.68389456864986*^9, 3.6838946234736547`*^9, 3.6838968500122004`*^9, 
   3.683899172980453*^9, 3.6838995524215097`*^9, 3.683903578791626*^9, {
   3.683903796738854*^9, 3.683903821259932*^9}, 3.6839039858898287`*^9, 
   3.683904596171867*^9, 3.683904668575684*^9, 3.68390546967093*^9, 
   3.68390623088945*^9, 3.683906649950728*^9, 3.683906712317583*^9, 
   3.68394927827203*^9, 3.683949850668906*^9, 3.683952373169733*^9, 
   3.683955118254199*^9, 3.683958897086561*^9, 3.685190833502232*^9, 
   3.685191535214994*^9, 3.685191885507491*^9, 3.6851920442229223`*^9, 
   3.6851922073521833`*^9, 3.685193111648541*^9, 3.685193836139495*^9, 
   3.685247754578397*^9, 3.685248996142511*^9, 3.685254501259327*^9, 
   3.685258911078904*^9, 3.685706232058814*^9, 3.685711703577753*^9}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Naming", " ", "idempotents", " ", 
     RowBox[{"(", 
      RowBox[{
      "choose", " ", "any", " ", "variable", " ", "you", " ", "find", " ", 
       "appropriate"}], ")"}]}], ";"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"S1IdemNames", "=", 
     RowBox[{"{", 
      RowBox[{"b", ",", "a", ",", "d"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"S2IdemNames", "=", 
     RowBox[{"{", "x", "}"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.677558847878817*^9, 3.6775588977945127`*^9}, {
   3.677558930459526*^9, 3.677559079416768*^9}, {3.6775591141377296`*^9, 
   3.6775591232809258`*^9}, {3.6775591673069763`*^9, 
   3.6775591708097677`*^9}, {3.677559237909267*^9, 3.677559274365768*^9}, {
   3.678365462544454*^9, 3.678365463974029*^9}, 3.679373264719275*^9, {
   3.679373345409265*^9, 3.679373355329522*^9}, 3.679373416779231*^9, {
   3.6793786869009542`*^9, 3.679378710833679*^9}, {3.679379554595536*^9, 
   3.679379638336299*^9}, {3.679380115539069*^9, 3.679380246150484*^9}, {
   3.6793803137773333`*^9, 3.679380320299905*^9}, {3.679381504792593*^9, 
   3.679381625229982*^9}, {3.6793817347272243`*^9, 3.679381738256918*^9}, {
   3.679381830811235*^9, 3.679381831562584*^9}, {3.6793818653461313`*^9, 
   3.6793819321950274`*^9}, {3.683897311350361*^9, 3.683897324687079*^9}, {
   3.68519155465518*^9, 3.6851915949356947`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"SANITY", " ", 
      RowBox[{"CHECK", ":", " ", 
       RowBox[{
       "test", " ", "for", " ", "multiplication", " ", "in", " ", "strands", 
        " ", "algebra"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"S1Reeb", "[", "z__", "]"}], " ", "takes", " ", "a", " ", 
      "sequence", " ", 
      SubscriptBox["z", "1"]}]}], ",", 
    SubscriptBox["z", "2"], ",", 
    RowBox[{
     RowBox[{
     "...", " ", "of", " ", "an", " ", "even", " ", "number", " ", "of", " ", 
      "integers", " ", "and", " ", "computes", " ", "the", " ", "element", 
      " ", "in", " ", "the", " ", "strands", " ", "algebra", " ", "for", " ", 
      "the", " ", "surface", " ", "S1", " ", "which", " ", "has", " ", "a", 
      " ", "moving", " ", "strand", " ", "from", " ", "the", " ", 
      SubscriptBox["z", 
       RowBox[{
        RowBox[{"2", "i"}], "+", "1"}]], "st", " ", "to", " ", "the", " ", 
      SubscriptBox["z", 
       RowBox[{
        RowBox[{"2", "i"}], "+", "2"}]], "nd", " ", "level"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"MorH1AlgComp", "[", 
       RowBox[{"a_", ",", "b_"}], "]"}], " ", "computes", " ", 
      SubscriptBox["\[Mu]", "2"], " ", "of", " ", "two", " ", "elements", " ",
       "a", " ", "and", " ", "b", " ", "in", " ", "the", " ", "strands", " ", 
      "algebra", " ", "and", " ", "displays", " ", "the", " ", "result", " ", 
      "using", " ", "the", " ", 
      RowBox[{"function", " ", "'"}], 
      RowBox[{"S1H", "'"}]}]}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"see", " ", "'"}], "Step", " ", "5"}], ":", " ", 
      RowBox[{"Basic", " ", "graphical", " ", 
       RowBox[{"outputs", "'"}], " ", "in", " ", "manual"}]}], ";"}]}], 
   "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"MorH1AlgComp", "[", 
    RowBox[{
     RowBox[{"S1Reeb", "[", 
      RowBox[{"2", ",", "3", ",", "4", ",", "5"}], "]"}], ",", 
     RowBox[{"S1Reeb", "[", 
      RowBox[{"3", ",", "4", ",", "6", ",", "9"}], "]"}]}], "]"}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.675148960735221*^9, 3.6751491156688137`*^9}, {
   3.675149153653947*^9, 3.675149183454502*^9}, {3.6751492167671957`*^9, 
   3.675149401938579*^9}, {3.675149486456636*^9, 3.6751494869367847`*^9}, 
   3.67514954451958*^9, {3.6751564533370657`*^9, 3.67515645413692*^9}, {
   3.675156524722777*^9, 3.675156560242648*^9}, {3.675156616520442*^9, 
   3.6751568101289454`*^9}, {3.675163957259375*^9, 3.675163970832073*^9}, {
   3.6751668771042137`*^9, 3.675166877110574*^9}, {3.675240959486168*^9, 
   3.6752410690644703`*^9}, {3.675326768492325*^9, 3.6753267702114143`*^9}, {
   3.675488784994639*^9, 3.675488800599482*^9}, {3.683892446779804*^9, 
   3.683892568970303*^9}, {3.6838946292210503`*^9, 3.683894629403434*^9}, {
   3.685190847044396*^9, 3.685191102313513*^9}, {3.6851911472048492`*^9, 
   3.685191271326366*^9}, {3.685204837861514*^9, 3.685204856946199*^9}, {
   3.685256088953251*^9, 3.685256135520506*^9}, {3.685697400552388*^9, 
   3.685697476866653*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Mu]\\), \\(2\\)]\\)(\"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    TagBox[GridBox[{
       {"8", "8"},
       {"6", "6"},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"9", "9"},
       {"8", "8"},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"10", "10"},
       {"6", "6"},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"10", "10"},
       {"9", "9"},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"]}], "\[InvisibleSpace]", "\<\" ,\\n\"\>", "\[InvisibleSpace]", 
   RowBox[{
    TagBox[GridBox[{
       {"8", "8"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {"5", "5"},
       {
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"8", "8"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {"2", "2"}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"10", "10"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {"5", "5"},
       {
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"10", "10"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {"2", "2"}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"]}], "\[InvisibleSpace]", "\<\") =\\n\"\>", "\[InvisibleSpace]", 
   RowBox[{
    TagBox[GridBox[{
       {"8", "8"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"10", "10"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"]}]}],
  SequenceForm[
  "\!\(\*SubscriptBox[\(\[Mu]\), \(2\)]\)(", Grid[{{8, 8}, {6, 6}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{9, 9}, {8, 8}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{10, 10}, {6, 6}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{10, 10}, {9, 9}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True], 
   " ,\n", Grid[{{8, 8}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {5, 5}, {
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{8, 8}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}, {2, 2}}, Frame -> 
     True] + Grid[{{10, 10}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {5, 5}, {
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{10, 10}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}, {2, 2}}, Frame -> 
     True], ") =\n", Grid[{{8, 8}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{10, 10}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.68389462471453*^9, 3.683894630193058*^9}, 
   3.68389685177421*^9, 3.683899175650861*^9, 3.683899554426527*^9, 
   3.683903987712611*^9, 3.6839045977182837`*^9, 3.68390467072602*^9, 
   3.683905472148747*^9, 3.68390623716576*^9, 3.683906653805142*^9, 
   3.683906715689011*^9, 3.683949288745957*^9, 3.68394985342809*^9, 
   3.683955122156901*^9, 3.683958901081587*^9, {3.685190970573328*^9, 
   3.685190974038107*^9}, {3.685191261596065*^9, 3.6851912779095592`*^9}, 
   3.685191543035482*^9, {3.68519160095391*^9, 3.6851916098629713`*^9}, 
   3.685191888757268*^9, 3.685192047642233*^9, 3.685192209052795*^9, 
   3.685193115844283*^9, 3.6851938395359707`*^9, 3.685248999275526*^9, 
   3.685254505324308*^9, 3.685258914455195*^9, 3.6857062357713823`*^9, {
   3.68571171641415*^9, 3.685711718848358*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Step1x2Algebra", ";"}]], "Input",
 CellChangeTimes->{{3.683894573809146*^9, 3.68389457569536*^9}, 
   3.683896854916707*^9, {3.685190544973094*^9, 3.685190547812798*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"S1: Idempotents (occupied \[Alpha]-arcs) and their names (from \
'S1IdemNames'):\\n \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "4", ",", "5"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"1", ",", "3", ",", "4", ",", "5"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"2", ",", "3", ",", "4", ",", "5"}], "}"}]},
       {"b", "a", "d"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm[
  "S1: Idempotents (occupied \[Alpha]-arcs) and their names (from \
'S1IdemNames'):\n ", 
   MatrixForm[{{{1, 2, 4, 5}, {1, 3, 4, 5}, {2, 3, 4, 
     5}}, {$CellContext`b, $CellContext`a, $CellContext`d}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894576291297*^9, 3.683894636939271*^9, 3.683896855963625*^9, 
   3.6838991777417603`*^9, 3.6838995563130627`*^9, {3.683903823955768*^9, 
   3.6839038446720753`*^9}, 3.683903990836575*^9, 3.683904600824422*^9, 
   3.683904673542452*^9, 3.683905474795196*^9, 3.683906239958479*^9, 
   3.683906674640527*^9, 3.6839067191536303`*^9, 3.683949293301263*^9, 
   3.683949855362233*^9, 3.683952376069016*^9, 3.683955123852866*^9, 
   3.683958902943614*^9, {3.68519145850126*^9, 3.685191480352109*^9}, 
   3.685191612181581*^9, 3.685191720422462*^9, 3.685191890702222*^9, 
   3.685191929102725*^9, 3.685192049265316*^9, 3.685192212772407*^9, 
   3.685192286439252*^9, 3.68519311765595*^9, 3.6851938427894278`*^9, 
   3.685249008374435*^9, 3.6852545068160353`*^9, 3.685258967957315*^9, 
   3.685706237906004*^9, 3.685711720394435*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"S2: Idempotents (occupied \[Alpha]-arcs) and their names (from \
'S2IdemNames'):\\n \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"{", "}"}]},
       {"x"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm[
  "S2: Idempotents (occupied \[Alpha]-arcs) and their names (from \
'S2IdemNames'):\n ", 
   MatrixForm[{{{}}, {$CellContext`x}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894576291297*^9, 3.683894636939271*^9, 3.683896855963625*^9, 
   3.6838991777417603`*^9, 3.6838995563130627`*^9, {3.683903823955768*^9, 
   3.6839038446720753`*^9}, 3.683903990836575*^9, 3.683904600824422*^9, 
   3.683904673542452*^9, 3.683905474795196*^9, 3.683906239958479*^9, 
   3.683906674640527*^9, 3.6839067191536303`*^9, 3.683949293301263*^9, 
   3.683949855362233*^9, 3.683952376069016*^9, 3.683955123852866*^9, 
   3.683958902943614*^9, {3.68519145850126*^9, 3.685191480352109*^9}, 
   3.685191612181581*^9, 3.685191720422462*^9, 3.685191890702222*^9, 
   3.685191929102725*^9, 3.685192049265316*^9, 3.685192212772407*^9, 
   3.685192286439252*^9, 3.68519311765595*^9, 3.6851938427894278`*^9, 
   3.685249008374435*^9, 3.6852545068160353`*^9, 3.685258967957315*^9, 
   3.685706237906004*^9, 3.685711720395455*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"S1: number of algebra elements for each pair of idempotents = \
\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"13", "9", "9"},
       {"3", "9", "9"},
       {"1", "3", "13"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm[
  "S1: number of algebra elements for each pair of idempotents = ", 
   MatrixForm[{{13, 9, 9}, {3, 9, 9}, {1, 3, 13}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894576291297*^9, 3.683894636939271*^9, 3.683896855963625*^9, 
   3.6838991777417603`*^9, 3.6838995563130627`*^9, {3.683903823955768*^9, 
   3.6839038446720753`*^9}, 3.683903990836575*^9, 3.683904600824422*^9, 
   3.683904673542452*^9, 3.683905474795196*^9, 3.683906239958479*^9, 
   3.683906674640527*^9, 3.6839067191536303`*^9, 3.683949293301263*^9, 
   3.683949855362233*^9, 3.683952376069016*^9, 3.683955123852866*^9, 
   3.683958902943614*^9, {3.68519145850126*^9, 3.685191480352109*^9}, 
   3.685191612181581*^9, 3.685191720422462*^9, 3.685191890702222*^9, 
   3.685191929102725*^9, 3.685192049265316*^9, 3.685192212772407*^9, 
   3.685192286439252*^9, 3.68519311765595*^9, 3.6851938427894278`*^9, 
   3.685249008374435*^9, 3.6852545068160353`*^9, 3.685258967957315*^9, 
   3.685706237906004*^9, 3.685711721859675*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"S2: number of algebra elements for each pair of idempotents = \
\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm[
  "S2: number of algebra elements for each pair of idempotents = ", 
   MatrixForm[{{1}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894576291297*^9, 3.683894636939271*^9, 3.683896855963625*^9, 
   3.6838991777417603`*^9, 3.6838995563130627`*^9, {3.683903823955768*^9, 
   3.6839038446720753`*^9}, 3.683903990836575*^9, 3.683904600824422*^9, 
   3.683904673542452*^9, 3.683905474795196*^9, 3.683906239958479*^9, 
   3.683906674640527*^9, 3.6839067191536303`*^9, 3.683949293301263*^9, 
   3.683949855362233*^9, 3.683952376069016*^9, 3.683955123852866*^9, 
   3.683958902943614*^9, {3.68519145850126*^9, 3.685191480352109*^9}, 
   3.685191612181581*^9, 3.685191720422462*^9, 3.685191890702222*^9, 
   3.685191929102725*^9, 3.685192049265316*^9, 3.685192212772407*^9, 
   3.685192286439252*^9, 3.68519311765595*^9, 3.6851938427894278`*^9, 
   3.685249008374435*^9, 3.6852545068160353`*^9, 3.685258967957315*^9, 
   3.685706237906004*^9, 3.68571172189222*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Sanity checks for algebra basis: \"\>", 
   "\[InvisibleSpace]", "\<\"S1 ok\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", "\<\"S2 ok\"\>"}],
  SequenceForm["Sanity checks for algebra basis: ", "S1 ok", ", ", "S2 ok"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894576291297*^9, 3.683894636939271*^9, 3.683896855963625*^9, 
   3.6838991777417603`*^9, 3.6838995563130627`*^9, {3.683903823955768*^9, 
   3.6839038446720753`*^9}, 3.683903990836575*^9, 3.683904600824422*^9, 
   3.683904673542452*^9, 3.683905474795196*^9, 3.683906239958479*^9, 
   3.683906674640527*^9, 3.6839067191536303`*^9, 3.683949293301263*^9, 
   3.683949855362233*^9, 3.683952376069016*^9, 3.683955123852866*^9, 
   3.683958902943614*^9, {3.68519145850126*^9, 3.685191480352109*^9}, 
   3.685191612181581*^9, 3.685191720422462*^9, 3.685191890702222*^9, 
   3.685191929102725*^9, 3.685192049265316*^9, 3.685192212772407*^9, 
   3.685192286439252*^9, 3.68519311765595*^9, 3.6851938427894278`*^9, 
   3.685249008374435*^9, 3.6852545068160353`*^9, 3.685258967957315*^9, 
   3.685706237906004*^9, 3.685711721892775*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There\"\>", 
   "\[InvisibleSpace]", "\<\" are 69 basis elements \"\>", 
   "\[InvisibleSpace]", "\<\"in the algebra for S1. The multiplication table \
looks like this: \"\>", "\[InvisibleSpace]", 
   GraphicsBox[
    RasterBox[SparseArray[
     Automatic, {69, 69}, 1., {
      1, {{0, 4, 9, 13, 14, 16, 19, 20, 22, 23, 24, 25, 26, 33, 35, 37, 40, 
        53, 57, 60, 63, 67, 68, 69, 70, 71, 77, 84, 90, 92, 99, 101, 103, 105,
         114, 117, 120, 133, 137, 141, 144, 147, 148, 149, 150, 151, 172, 178,
         184, 191, 193, 195, 202, 204, 206, 217, 226, 229, 238, 240, 249, 250,
         253, 256, 258, 259, 262, 279, 300, 331}, CompressedData["
1:eJxTTMoPSmJiYGDwZmRgACIGZksHF2Y7R2dXMIPZhRnIApJAwKSipWNoYsoE
hIwSisxm5haW1rb2Dk7OLhC1QIUwXUDFGtpGxqYwLRCOKZIJQDO4+IREJWTl
FIGGYTUPYSbIPCVlFVU1dQ1NLW0dXT19A0MjY7i5KFahWsPIxsUNs4aHX0xc
Ql4BbB/cbn6EMMQdQBGYa6ysbWzt7B0cQS7Caj8jCysbOwcnFzcPLx+/gKCQ
sIgo0CxJKWkZWTmgiQBOoy5J
        "]}, CompressedData["
1:eJxTTMoPSmVkYGDwBhGjYBSMglEwCkbBKBgFo2AUUAEAAGcjAfc=
       "]}], {{0, 0}, {69, 69}}, {0, 1}],
    Frame->Automatic,
    FrameLabel->{None, None},
    FrameTicks->{{None, None}, {None, None}},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{
     "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> Automatic}]}],
  SequenceForm[
  "There", " are 69 basis elements ", 
   "in the algebra for S1. The multiplication table looks like this: ", 
   Graphics[
    Raster[
    SparseArray[
     Automatic, {69, 69}, 1., {
      1, {{0, 4, 9, 13, 14, 16, 19, 20, 22, 23, 24, 25, 26, 33, 35, 37, 40, 
        53, 57, 60, 63, 67, 68, 69, 70, 71, 77, 84, 90, 92, 99, 101, 103, 105,
         114, 117, 120, 133, 137, 141, 144, 147, 148, 149, 150, 151, 172, 178,
         184, 191, 193, 195, 202, 204, 206, 217, 226, 229, 238, 240, 249, 250,
         253, 256, 258, 259, 262, 279, 300, 331}, CompressedData["
1:eJxTTMoPSmJiYGDwZmRgACIGZksHF2Y7R2dXMIPZhRnIApJAwKSipWNoYsoE
hIwSisxm5haW1rb2Dk7OLhC1QIUwXUDFGtpGxqYwLRCOKZIJQDO4+IREJWTl
FIGGYTUPYSbIPCVlFVU1dQ1NLW0dXT19A0MjY7i5KFahWsPIxsUNs4aHX0xc
Ql4BbB/cbn6EMMQdQBGYa6ysbWzt7B0cQS7Caj8jCysbOwcnFzcPLx+/gKCQ
sIgo0CxJKWkZWTmgiQBOoy5J
        "]}, CompressedData["
1:eJxTTMoPSmVkYGDwBhGjYBSMglEwCkbBKBgFo2AUUAEAAGcjAfc=
       "]}], {{0, 0}, {69, 69}}, {0, 1}], Frame -> Automatic, 
    FrameLabel -> {None, None}, FrameTicks -> {{None, None}, {None, None}}, 
    GridLinesStyle -> Directive[
      GrayLevel[0.5, 0.4]], 
    Method -> {
     "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> Automatic}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894576291297*^9, 3.683894636939271*^9, 3.683896855963625*^9, 
   3.6838991777417603`*^9, 3.6838995563130627`*^9, {3.683903823955768*^9, 
   3.6839038446720753`*^9}, 3.683903990836575*^9, 3.683904600824422*^9, 
   3.683904673542452*^9, 3.683905474795196*^9, 3.683906239958479*^9, 
   3.683906674640527*^9, 3.6839067191536303`*^9, 3.683949293301263*^9, 
   3.683949855362233*^9, 3.683952376069016*^9, 3.683955123852866*^9, 
   3.683958902943614*^9, {3.68519145850126*^9, 3.685191480352109*^9}, 
   3.685191612181581*^9, 3.685191720422462*^9, 3.685191890702222*^9, 
   3.685191929102725*^9, 3.685192049265316*^9, 3.685192212772407*^9, 
   3.685192286439252*^9, 3.68519311765595*^9, 3.6851938427894278`*^9, 
   3.685249008374435*^9, 3.6852545068160353`*^9, 3.685258967957315*^9, 
   3.685706237906004*^9, 3.685711722281117*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There\"\>", 
   "\[InvisibleSpace]", "\<\" is one basis element \"\>", 
   "\[InvisibleSpace]", "\<\"in the algebra for S2. The multiplication table \
looks like this: \"\>", "\[InvisibleSpace]", 
   GraphicsBox[RasterBox[{{{0., 0., 0.}}}, {{0, 0}, {1, 1}}, {0, 1}],
    Frame->Automatic,
    FrameLabel->{None, None},
    FrameTicks->{{None, None}, {None, None}},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{
     "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> Automatic}]}],
  SequenceForm[
  "There", " is one basis element ", 
   "in the algebra for S2. The multiplication table looks like this: ", 
   Graphics[
    Raster[{{{0., 0., 0.}}}, {{0, 0}, {1, 1}}, {0, 1}], Frame -> Automatic, 
    FrameLabel -> {None, None}, FrameTicks -> {{None, None}, {None, None}}, 
    GridLinesStyle -> Directive[
      GrayLevel[0.5, 0.4]], 
    Method -> {
     "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> Automatic}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894576291297*^9, 3.683894636939271*^9, 3.683896855963625*^9, 
   3.6838991777417603`*^9, 3.6838995563130627`*^9, {3.683903823955768*^9, 
   3.6839038446720753`*^9}, 3.683903990836575*^9, 3.683904600824422*^9, 
   3.683904673542452*^9, 3.683905474795196*^9, 3.683906239958479*^9, 
   3.683906674640527*^9, 3.6839067191536303`*^9, 3.683949293301263*^9, 
   3.683949855362233*^9, 3.683952376069016*^9, 3.683955123852866*^9, 
   3.683958902943614*^9, {3.68519145850126*^9, 3.685191480352109*^9}, 
   3.685191612181581*^9, 3.685191720422462*^9, 3.685191890702222*^9, 
   3.685191929102725*^9, 3.685192049265316*^9, 3.685192212772407*^9, 
   3.685192286439252*^9, 3.68519311765595*^9, 3.6851938427894278`*^9, 
   3.685249008374435*^9, 3.6852545068160353`*^9, 3.685258967957315*^9, 
   3.685706237906004*^9, 3.685711722320058*^9}],

Cell[BoxData["\<\"Sanity check for the differential on S1 algebra: ok.\"\>"], \
"Print",
 CellChangeTimes->{
  3.683894576291297*^9, 3.683894636939271*^9, 3.683896855963625*^9, 
   3.6838991777417603`*^9, 3.6838995563130627`*^9, {3.683903823955768*^9, 
   3.6839038446720753`*^9}, 3.683903990836575*^9, 3.683904600824422*^9, 
   3.683904673542452*^9, 3.683905474795196*^9, 3.683906239958479*^9, 
   3.683906674640527*^9, 3.6839067191536303`*^9, 3.683949293301263*^9, 
   3.683949855362233*^9, 3.683952376069016*^9, 3.683955123852866*^9, 
   3.683958902943614*^9, {3.68519145850126*^9, 3.685191480352109*^9}, 
   3.685191612181581*^9, 3.685191720422462*^9, 3.685191890702222*^9, 
   3.685191929102725*^9, 3.685192049265316*^9, 3.685192212772407*^9, 
   3.685192286439252*^9, 3.68519311765595*^9, 3.6851938427894278`*^9, 
   3.685249008374435*^9, 3.6852545068160353`*^9, 3.685258967957315*^9, 
   3.685706237906004*^9, 3.6857117225039463`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There\"\>", 
   "\[InvisibleSpace]", "\<\" are 38 basis elements \"\>", 
   "\[InvisibleSpace]", "\<\"in the algebra for S1 whose differential is \
non-vanishing.\"\>"}],
  SequenceForm[
  "There", " are 38 basis elements ", 
   "in the algebra for S1 whose differential is non-vanishing."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894576291297*^9, 3.683894636939271*^9, 3.683896855963625*^9, 
   3.6838991777417603`*^9, 3.6838995563130627`*^9, {3.683903823955768*^9, 
   3.6839038446720753`*^9}, 3.683903990836575*^9, 3.683904600824422*^9, 
   3.683904673542452*^9, 3.683905474795196*^9, 3.683906239958479*^9, 
   3.683906674640527*^9, 3.6839067191536303`*^9, 3.683949293301263*^9, 
   3.683949855362233*^9, 3.683952376069016*^9, 3.683955123852866*^9, 
   3.683958902943614*^9, {3.68519145850126*^9, 3.685191480352109*^9}, 
   3.685191612181581*^9, 3.685191720422462*^9, 3.685191890702222*^9, 
   3.685191929102725*^9, 3.685192049265316*^9, 3.685192212772407*^9, 
   3.685192286439252*^9, 3.68519311765595*^9, 3.6851938427894278`*^9, 
   3.685249008374435*^9, 3.6852545068160353`*^9, 3.685258967957315*^9, 
   3.685706237906004*^9, 3.68571172250447*^9}],

Cell[BoxData["\<\"Sanity check for the differential on S2 algebra: ok.\"\>"], \
"Print",
 CellChangeTimes->{
  3.683894576291297*^9, 3.683894636939271*^9, 3.683896855963625*^9, 
   3.6838991777417603`*^9, 3.6838995563130627`*^9, {3.683903823955768*^9, 
   3.6839038446720753`*^9}, 3.683903990836575*^9, 3.683904600824422*^9, 
   3.683904673542452*^9, 3.683905474795196*^9, 3.683906239958479*^9, 
   3.683906674640527*^9, 3.6839067191536303`*^9, 3.683949293301263*^9, 
   3.683949855362233*^9, 3.683952376069016*^9, 3.683955123852866*^9, 
   3.683958902943614*^9, {3.68519145850126*^9, 3.685191480352109*^9}, 
   3.685191612181581*^9, 3.685191720422462*^9, 3.685191890702222*^9, 
   3.685191929102725*^9, 3.685192049265316*^9, 3.685192212772407*^9, 
   3.685192286439252*^9, 3.68519311765595*^9, 3.6851938427894278`*^9, 
   3.685249008374435*^9, 3.6852545068160353`*^9, 3.685258967957315*^9, 
   3.685706237906004*^9, 3.685711722533017*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There\"\>", 
   "\[InvisibleSpace]", "\<\" are 0 basis elements \"\>", 
   "\[InvisibleSpace]", "\<\"in the algebra for S2 whose differential is \
non-vanishing.\"\>"}],
  SequenceForm[
  "There", " are 0 basis elements ", 
   "in the algebra for S2 whose differential is non-vanishing."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894576291297*^9, 3.683894636939271*^9, 3.683896855963625*^9, 
   3.6838991777417603`*^9, 3.6838995563130627`*^9, {3.683903823955768*^9, 
   3.6839038446720753`*^9}, 3.683903990836575*^9, 3.683904600824422*^9, 
   3.683904673542452*^9, 3.683905474795196*^9, 3.683906239958479*^9, 
   3.683906674640527*^9, 3.6839067191536303`*^9, 3.683949293301263*^9, 
   3.683949855362233*^9, 3.683952376069016*^9, 3.683955123852866*^9, 
   3.683958902943614*^9, {3.68519145850126*^9, 3.685191480352109*^9}, 
   3.685191612181581*^9, 3.685191720422462*^9, 3.685191890702222*^9, 
   3.685191929102725*^9, 3.685192049265316*^9, 3.685192212772407*^9, 
   3.685192286439252*^9, 3.68519311765595*^9, 3.6851938427894278`*^9, 
   3.685249008374435*^9, 3.6852545068160353`*^9, 3.685258967957315*^9, 
   3.685706237906004*^9, 3.685711722534697*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Define", " ", "subalgebra", " ", "of", " ", "glueing", " ", "algebras"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"S1SubalgebraGensInput", "=", 
     TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"\"\<\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)\>\"", 
          "\"\<\\\\tau_{2}\>\"", "3", 
          RowBox[{"{", 
           RowBox[{"3", ",", "4"}], "}"}], "2"},
         {"\"\<\!\(\*SubscriptBox[\(\[Tau]\), \(13\)]\)\>\"", 
          "\"\<\\\\tau_{13}\>\"", "2", 
          RowBox[{"{", 
           RowBox[{"2", ",", "3", ",", "4", ",", "5"}], "}"}], "3"},
         {"\"\<\!\(\*SubscriptBox[\(\[Delta]\), \(2\)]\)\>\"", 
          "\"\<\\\\delta_{2}\>\"", "2", 
          RowBox[{"{", 
           RowBox[{"7", ",", "8"}], "}"}], "1"},
         {"\"\<\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)\>\"", 
          "\"\<\\\\delta_{13}\>\"", "1", 
          RowBox[{"{", 
           RowBox[{"6", ",", "7", ",", "8", ",", "9"}], "}"}], "2"}
        },
        GridBoxAlignment->{
         "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.7]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
      Function[BoxForm`e$, 
       MatrixForm[BoxForm`e$]]]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"S2SubalgebraGensInput", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Step1x3Algebra", ";"}]}]}]], "Input",
 CellChangeTimes->{{3.67541670490312*^9, 3.675416943706355*^9}, {
   3.6754170205791273`*^9, 3.675417160207923*^9}, {3.6754171988645773`*^9, 
   3.6754172047285013`*^9}, {3.67541726389194*^9, 3.675417411421652*^9}, {
   3.675417504592208*^9, 3.675417671756445*^9}, {3.675417702455329*^9, 
   3.6754177955677443`*^9}, {3.675417857795292*^9, 3.6754180486165743`*^9}, {
   3.6754181200985603`*^9, 3.675418156692951*^9}, {3.6754182097573767`*^9, 
   3.675418233939465*^9}, {3.675418578868428*^9, 3.675418585533842*^9}, {
   3.6754187853257713`*^9, 3.6754191790874443`*^9}, {3.6754196050117188`*^9, 
   3.6754196402749863`*^9}, {3.6754197357439947`*^9, 3.675419766438498*^9}, {
   3.675419986525477*^9, 3.675420009644898*^9}, {3.675420050158463*^9, 
   3.675420079462613*^9}, {3.6754201403113937`*^9, 3.6754201888257*^9}, {
   3.675420232067382*^9, 3.675420386424735*^9}, {3.675420417032227*^9, 
   3.675420509776697*^9}, {3.675420545939254*^9, 3.6754205864055357`*^9}, {
   3.675420722813902*^9, 3.675420723408658*^9}, {3.675421190651394*^9, 
   3.675421195333506*^9}, {3.675421884925761*^9, 3.675421885037178*^9}, {
   3.675422070693953*^9, 3.675422191917118*^9}, {3.675422236953292*^9, 
   3.675422449285512*^9}, {3.675422489267954*^9, 3.675422509463949*^9}, {
   3.675422635165626*^9, 3.675422640045535*^9}, {3.675422685645858*^9, 
   3.675422750348567*^9}, {3.675422785240765*^9, 3.67542280706288*^9}, {
   3.675422855020863*^9, 3.675422859344832*^9}, {3.675424215280971*^9, 
   3.675424221070169*^9}, {3.6754242919296637`*^9, 3.6754243212187567`*^9}, {
   3.67542602176145*^9, 3.67542602609664*^9}, {3.6754260603369637`*^9, 
   3.675426068589275*^9}, {3.675429232464768*^9, 3.675429323920988*^9}, {
   3.6754293690262938`*^9, 3.675429369521201*^9}, {3.6754294085392933`*^9, 
   3.675429435698406*^9}, {3.675489570048691*^9, 3.6754895887810993`*^9}, {
   3.6754896880190897`*^9, 3.6754896937036343`*^9}, {3.6754897259876423`*^9, 
   3.675489738120859*^9}, {3.675489801566051*^9, 3.675489826478066*^9}, {
   3.6754904308821793`*^9, 3.675490455156652*^9}, {3.675490489672057*^9, 
   3.675490502896306*^9}, {3.67549062825817*^9, 3.675490980950973*^9}, {
   3.675491047466683*^9, 3.675491089193486*^9}, {3.67549121466953*^9, 
   3.6754913164714518`*^9}, 3.675491391767598*^9, {3.6754914249514227`*^9, 
   3.675491472388465*^9}, {3.675491506053948*^9, 3.675491507522543*^9}, {
   3.675491616142733*^9, 3.6754916228800497`*^9}, {3.675491766836528*^9, 
   3.6754917910789957`*^9}, {3.675492000529435*^9, 3.6754920619598293`*^9}, 
   3.675493085052888*^9, {3.675496723655764*^9, 3.675496774348954*^9}, {
   3.6754968300053883`*^9, 3.675496890103347*^9}, {3.675496958064917*^9, 
   3.675496980749998*^9}, {3.675497027081711*^9, 3.675497072937887*^9}, {
   3.675500494000929*^9, 3.6755005190493*^9}, {3.675501434290371*^9, 
   3.6755014406626368`*^9}, {3.6755022859449368`*^9, 3.67550231374466*^9}, {
   3.675576639058669*^9, 3.6755766395736933`*^9}, {3.675576695541645*^9, 
   3.675576860809417*^9}, {3.67557704449465*^9, 3.675577357618638*^9}, {
   3.6755953877500257`*^9, 3.675595392298416*^9}, {3.6756818427121563`*^9, 
   3.6756818487330112`*^9}, {3.675927638493026*^9, 3.6759276689603777`*^9}, {
   3.6759586354724283`*^9, 3.675958645259203*^9}, {3.6759605315291443`*^9, 
   3.675960760207101*^9}, 3.6760053846449127`*^9, {3.676026462041202*^9, 
   3.6760265881084013`*^9}, {3.676026684200674*^9, 3.676026815068563*^9}, {
   3.6760269150023746`*^9, 3.676026993126997*^9}, {3.6761254946040907`*^9, 
   3.676125552395556*^9}, {3.676125606553938*^9, 3.676125711299168*^9}, {
   3.676125753429627*^9, 3.676125773481463*^9}, {3.676265137067075*^9, 
   3.676265220549065*^9}, {3.676288128022416*^9, 3.676288201806101*^9}, {
   3.677681981601057*^9, 3.677682107280738*^9}, {3.677682137522174*^9, 
   3.677682265999445*^9}, {3.677682307394906*^9, 3.6776823431857147`*^9}, {
   3.677682379758047*^9, 3.677682403763871*^9}, {3.677682492007575*^9, 
   3.6776826007343893`*^9}, {3.6787715125583973`*^9, 
   3.6787715614795017`*^9}, {3.678771609093541*^9, 3.6787717536203117`*^9}, {
   3.678771805742807*^9, 3.678771868759883*^9}, {3.678772027332717*^9, 
   3.678772034436185*^9}, {3.6787722605150347`*^9, 3.678772283682819*^9}, {
   3.678772373965992*^9, 3.678772449903233*^9}, {3.678772529785922*^9, 
   3.678772531905593*^9}, {3.678772824890971*^9, 3.678772827481413*^9}, {
   3.6787728690995407`*^9, 3.678772871578577*^9}, {3.678774431296946*^9, 
   3.678774434324017*^9}, {3.679373140304928*^9, 3.679373144800671*^9}, {
   3.6838946851494904`*^9, 3.683894703205244*^9}, {3.685190554574445*^9, 
   3.685190556892708*^9}, {3.685192961281529*^9, 3.685192987809022*^9}, {
   3.685207421645051*^9, 3.685207426225121*^9}, 3.685207467365735*^9, 
   3.685697492274362*^9}],

Cell[CellGroupData[{

Cell[BoxData["\<\"Note: If this step produces an error message, double-check \
'S1SubalgebraGensInput' and 'S2SubalgebraGensInput'.\\n If some of the \
entries of the lists below are empty, you have probably only mixed up the \
starting/ending idempotents.\"\>"], "Print",
 CellChangeTimes->{
  3.675577358840218*^9, 3.67557784106756*^9, 3.675581579650231*^9, 
   3.675595500289331*^9, 3.675613125973466*^9, 3.675656236601492*^9, 
   3.675681856180417*^9, 3.675682207840516*^9, 3.6756824475633097`*^9, 
   3.675852729718355*^9, 3.6758617463689203`*^9, {3.675927619547714*^9, 
   3.675927651329775*^9}, 3.675938927383788*^9, 3.67595865191124*^9, 
   3.675960603697714*^9, 3.6759606522289267`*^9, {3.675960729708458*^9, 
   3.675960760646541*^9}, 3.675961789029345*^9, 3.676004009504449*^9, {
   3.6760053876838408`*^9, 3.676005391390046*^9}, {3.6760267460268908`*^9, 
   3.67602677066754*^9}, 3.676026818467801*^9, {3.67602691981961*^9, 
   3.676026955021439*^9}, {3.676026993767375*^9, 3.6760270089952517`*^9}, {
   3.6761255821669617`*^9, 3.676125713077436*^9}, 3.676125774688211*^9, 
   3.676265293611487*^9, 3.676288224107232*^9, 3.6763477949276323`*^9, 
   3.676388666448176*^9, 3.676440141917055*^9, 3.67644206113505*^9, 
   3.6764734260760403`*^9, 3.677484677351678*^9, 3.67750386490447*^9, 
   3.677682252521587*^9, 3.677682344242956*^9, 3.677682405799204*^9, {
   3.677682559314039*^9, 3.677682601748749*^9}, 3.678771755603828*^9, 
   3.6787718704111567`*^9, 3.6787720354712553`*^9, {3.678772266822555*^9, 
   3.678772284607242*^9}, {3.678772375092311*^9, 3.678772409154812*^9}, {
   3.678772441192569*^9, 3.67877245072477*^9}, 3.678772532795595*^9, {
   3.678772817801484*^9, 3.678772828460821*^9}, 3.678772872535182*^9, 
   3.678774475451853*^9, 3.678775839601779*^9, 3.679373148388205*^9, 
   3.6838947043272953`*^9, 3.68389686364214*^9, 3.683899190547463*^9, 
   3.683899560122406*^9, 3.6839038492626743`*^9, 3.683903995232173*^9, 
   3.683904603740594*^9, 3.6839046780311937`*^9, 3.6839054787572117`*^9, 
   3.683906251985915*^9, 3.68390668065705*^9, 3.683906723095969*^9, 
   3.683949302957801*^9, 3.683949860524699*^9, 3.6839523804559183`*^9, 
   3.6839551294524803`*^9, 3.683958906704781*^9, {3.685192867733756*^9, 
   3.6851928832382393`*^9}, {3.6851929468598423`*^9, 3.6851929884163*^9}, 
   3.685193122696867*^9, 3.685193849822316*^9, 3.6852490140941887`*^9, 
   3.6852545093644657`*^9, 3.685258976314921*^9, 3.685706242225347*^9, 
   3.685711724459684*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"S1 algebra indices of the subalgebra generators = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "3", ",", "53", ",", "57", ",", "24", ",", "36"}], 
    "}"}]}],
  SequenceForm[
  "S1 algebra indices of the subalgebra generators = ", {1, 2, 3, 53, 57, 24, 
   36}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.675577358840218*^9, 3.67557784106756*^9, 3.675581579650231*^9, 
   3.675595500289331*^9, 3.675613125973466*^9, 3.675656236601492*^9, 
   3.675681856180417*^9, 3.675682207840516*^9, 3.6756824475633097`*^9, 
   3.675852729718355*^9, 3.6758617463689203`*^9, {3.675927619547714*^9, 
   3.675927651329775*^9}, 3.675938927383788*^9, 3.67595865191124*^9, 
   3.675960603697714*^9, 3.6759606522289267`*^9, {3.675960729708458*^9, 
   3.675960760646541*^9}, 3.675961789029345*^9, 3.676004009504449*^9, {
   3.6760053876838408`*^9, 3.676005391390046*^9}, {3.6760267460268908`*^9, 
   3.67602677066754*^9}, 3.676026818467801*^9, {3.67602691981961*^9, 
   3.676026955021439*^9}, {3.676026993767375*^9, 3.6760270089952517`*^9}, {
   3.6761255821669617`*^9, 3.676125713077436*^9}, 3.676125774688211*^9, 
   3.676265293611487*^9, 3.676288224107232*^9, 3.6763477949276323`*^9, 
   3.676388666448176*^9, 3.676440141917055*^9, 3.67644206113505*^9, 
   3.6764734260760403`*^9, 3.677484677351678*^9, 3.67750386490447*^9, 
   3.677682252521587*^9, 3.677682344242956*^9, 3.677682405799204*^9, {
   3.677682559314039*^9, 3.677682601748749*^9}, 3.678771755603828*^9, 
   3.6787718704111567`*^9, 3.6787720354712553`*^9, {3.678772266822555*^9, 
   3.678772284607242*^9}, {3.678772375092311*^9, 3.678772409154812*^9}, {
   3.678772441192569*^9, 3.67877245072477*^9}, 3.678772532795595*^9, {
   3.678772817801484*^9, 3.678772828460821*^9}, 3.678772872535182*^9, 
   3.678774475451853*^9, 3.678775839601779*^9, 3.679373148388205*^9, 
   3.6838947043272953`*^9, 3.68389686364214*^9, 3.683899190547463*^9, 
   3.683899560122406*^9, 3.6839038492626743`*^9, 3.683903995232173*^9, 
   3.683904603740594*^9, 3.6839046780311937`*^9, 3.6839054787572117`*^9, 
   3.683906251985915*^9, 3.68390668065705*^9, 3.683906723095969*^9, 
   3.683949302957801*^9, 3.683949860524699*^9, 3.6839523804559183`*^9, 
   3.6839551294524803`*^9, 3.683958906704781*^9, {3.685192867733756*^9, 
   3.6851928832382393`*^9}, {3.6851929468598423`*^9, 3.6851929884163*^9}, 
   3.685193122696867*^9, 3.685193849822316*^9, 3.6852490140941887`*^9, 
   3.6852545093644657`*^9, 3.685258976314921*^9, 3.685706242225347*^9, 
   3.685711724477165*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"S2 algebra indices of the subalgebra generators = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", "1", "}"}]}],
  SequenceForm["S2 algebra indices of the subalgebra generators = ", {1}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.675577358840218*^9, 3.67557784106756*^9, 3.675581579650231*^9, 
   3.675595500289331*^9, 3.675613125973466*^9, 3.675656236601492*^9, 
   3.675681856180417*^9, 3.675682207840516*^9, 3.6756824475633097`*^9, 
   3.675852729718355*^9, 3.6758617463689203`*^9, {3.675927619547714*^9, 
   3.675927651329775*^9}, 3.675938927383788*^9, 3.67595865191124*^9, 
   3.675960603697714*^9, 3.6759606522289267`*^9, {3.675960729708458*^9, 
   3.675960760646541*^9}, 3.675961789029345*^9, 3.676004009504449*^9, {
   3.6760053876838408`*^9, 3.676005391390046*^9}, {3.6760267460268908`*^9, 
   3.67602677066754*^9}, 3.676026818467801*^9, {3.67602691981961*^9, 
   3.676026955021439*^9}, {3.676026993767375*^9, 3.6760270089952517`*^9}, {
   3.6761255821669617`*^9, 3.676125713077436*^9}, 3.676125774688211*^9, 
   3.676265293611487*^9, 3.676288224107232*^9, 3.6763477949276323`*^9, 
   3.676388666448176*^9, 3.676440141917055*^9, 3.67644206113505*^9, 
   3.6764734260760403`*^9, 3.677484677351678*^9, 3.67750386490447*^9, 
   3.677682252521587*^9, 3.677682344242956*^9, 3.677682405799204*^9, {
   3.677682559314039*^9, 3.677682601748749*^9}, 3.678771755603828*^9, 
   3.6787718704111567`*^9, 3.6787720354712553`*^9, {3.678772266822555*^9, 
   3.678772284607242*^9}, {3.678772375092311*^9, 3.678772409154812*^9}, {
   3.678772441192569*^9, 3.67877245072477*^9}, 3.678772532795595*^9, {
   3.678772817801484*^9, 3.678772828460821*^9}, 3.678772872535182*^9, 
   3.678774475451853*^9, 3.678775839601779*^9, 3.679373148388205*^9, 
   3.6838947043272953`*^9, 3.68389686364214*^9, 3.683899190547463*^9, 
   3.683899560122406*^9, 3.6839038492626743`*^9, 3.683903995232173*^9, 
   3.683904603740594*^9, 3.6839046780311937`*^9, 3.6839054787572117`*^9, 
   3.683906251985915*^9, 3.68390668065705*^9, 3.683906723095969*^9, 
   3.683949302957801*^9, 3.683949860524699*^9, 3.6839523804559183`*^9, 
   3.6839551294524803`*^9, 3.683958906704781*^9, {3.685192867733756*^9, 
   3.6851928832382393`*^9}, {3.6851929468598423`*^9, 3.6851929884163*^9}, 
   3.685193122696867*^9, 3.685193849822316*^9, 3.6852490140941887`*^9, 
   3.6852545093644657`*^9, 3.685258976314921*^9, 3.685706242225347*^9, 
   3.685711724477647*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Step1x4Algebra", ";"}]], "Input",
 CellChangeTimes->{{3.6851905751101*^9, 3.6851905772932377`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"S1Subalgebra=\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1"},
            {
             SubscriptBox["\[Iota]", "1"]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"2"},
            {
             SubscriptBox["\[Iota]", "2"]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"3"},
            {
             SubscriptBox["\[Iota]", "3"]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"4"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"12"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"16"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"18"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"22"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"24"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"25"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]]},
       {
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"29"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"31"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"33"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"34"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"36"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(13\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"37"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"40"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"42"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(13\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"45"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"49"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(13\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]]},
       {
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"50"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"53"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"54"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(13\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"55"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(13\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"57"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(13\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"59"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(13\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"64"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(13\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox["\<\"\"\>",
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox["\<\"\"\>",
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox["\<\"\"\>",
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["S1Subalgebra=", 
   MatrixForm[{{
      MatrixForm[{{1}, {
         Subscript[$CellContext`\[Iota], 1]}}], 
      MatrixForm[{{2}, {
         Subscript[$CellContext`\[Iota], 2]}}], 
      MatrixForm[{{3}, {
         Subscript[$CellContext`\[Iota], 3]}}], 
      MatrixForm[{{4}, {
        "\!\(\*SubscriptBox[\(\[Delta]\), \
\(13\)]\)\!\(\*SubscriptBox[\(\[Tau]\), \
\(13\)]\)\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)\!\(\*SubscriptBox[\(\[Delta]\
\), \(2\)]\)"}}], 
      MatrixForm[{{12}, {
        "\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)\!\(\*SubscriptBox[\(\
\[Delta]\), \(2\)]\)"}}], 
      MatrixForm[{{16}, {
        "\!\(\*SubscriptBox[\(\[Delta]\), \(2\)]\)\!\(\*SubscriptBox[\(\
\[Delta]\), \(13\)]\)\!\(\*SubscriptBox[\(\[Tau]\), \
\(13\)]\)\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)\!\(\*SubscriptBox[\(\[Delta]\
\), \(2\)]\)"}}], 
      MatrixForm[{{18}, {
        "\!\(\*SubscriptBox[\(\[Tau]\), \
\(13\)]\)\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)\!\(\*SubscriptBox[\(\[Delta]\
\), \(2\)]\)"}}], 
      MatrixForm[{{22}, {
        "\!\(\*SubscriptBox[\(\[Delta]\), \(2\)]\)\!\(\*SubscriptBox[\(\
\[Delta]\), \(13\)]\)\!\(\*SubscriptBox[\(\[Delta]\), \(2\)]\)"}}], 
      MatrixForm[{{24}, {"\!\(\*SubscriptBox[\(\[Delta]\), \(2\)]\)"}}], 
      MatrixForm[{{25}, {
        "\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)\!\(\*SubscriptBox[\(\[Delta]\
\), \(2\)]\)\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)\!\(\*SubscriptBox[\(\
\[Tau]\), \(13\)]\)\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)\!\(\*SubscriptBox[\
\(\[Delta]\), \(2\)]\)"}}]}, {
      MatrixForm[{{29}, {
        "\!\(\*SubscriptBox[\(\[Tau]\), \
\(2\)]\)\!\(\*SubscriptBox[\(\[Tau]\), \
\(13\)]\)\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)\!\(\*SubscriptBox[\(\[Delta]\
\), \(2\)]\)"}}], 
      MatrixForm[{{31}, {
        "\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)\!\(\*SubscriptBox[\(\[Delta]\
\), \(2\)]\)\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)\!\(\*SubscriptBox[\(\
\[Delta]\), \(2\)]\)"}}], 
      MatrixForm[{{33}, {
        "\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)\!\(\*SubscriptBox[\(\[Delta]\
\), \(2\)]\)"}}], 
      MatrixForm[{{34}, {
        "\!\(\*SubscriptBox[\(\[Delta]\), \
\(13\)]\)\!\(\*SubscriptBox[\(\[Tau]\), \
\(13\)]\)\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)"}}], 
      MatrixForm[{{36}, {"\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)"}}], 
      MatrixForm[{{37}, {
        "\!\(\*SubscriptBox[\(\[Delta]\), \(2\)]\)\!\(\*SubscriptBox[\(\
\[Delta]\), \(13\)]\)\!\(\*SubscriptBox[\(\[Tau]\), \
\(13\)]\)\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)"}}], 
      MatrixForm[{{40}, {
        "\!\(\*SubscriptBox[\(\[Tau]\), \
\(13\)]\)\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)"}}], 
      MatrixForm[{{42}, {
        "\!\(\*SubscriptBox[\(\[Delta]\), \(2\)]\)\!\(\*SubscriptBox[\(\
\[Delta]\), \(13\)]\)"}}], 
      MatrixForm[{{45}, {
        "\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)\!\(\*SubscriptBox[\(\[Delta]\
\), \(2\)]\)\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)\!\(\*SubscriptBox[\(\
\[Tau]\), \(13\)]\)\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)"}}], 
      MatrixForm[{{49}, {
        "\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)\!\(\*SubscriptBox[\(\[Delta]\
\), \(2\)]\)\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)"}}]}, {
      MatrixForm[{{50}, {
        "\!\(\*SubscriptBox[\(\[Tau]\), \
\(2\)]\)\!\(\*SubscriptBox[\(\[Tau]\), \
\(13\)]\)\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)"}}], 
      MatrixForm[{{53}, {"\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)"}}], 
      MatrixForm[{{54}, {
        "\!\(\*SubscriptBox[\(\[Delta]\), \
\(13\)]\)\!\(\*SubscriptBox[\(\[Tau]\), \(13\)]\)"}}], 
      MatrixForm[{{55}, {
        "\!\(\*SubscriptBox[\(\[Delta]\), \(2\)]\)\!\(\*SubscriptBox[\(\
\[Delta]\), \(13\)]\)\!\(\*SubscriptBox[\(\[Tau]\), \(13\)]\)"}}], 
      MatrixForm[{{57}, {"\!\(\*SubscriptBox[\(\[Tau]\), \(13\)]\)"}}], 
      MatrixForm[{{59}, {
        "\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)\!\(\*SubscriptBox[\(\[Delta]\
\), \(2\)]\)\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)\!\(\*SubscriptBox[\(\
\[Tau]\), \(13\)]\)"}}], 
      MatrixForm[{{64}, {
        "\!\(\*SubscriptBox[\(\[Tau]\), \
\(2\)]\)\!\(\*SubscriptBox[\(\[Tau]\), \(13\)]\)"}}], 
      MatrixForm[""], 
      MatrixForm[""], 
      MatrixForm[""]}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.683894720447112*^9, 3.6838968668468018`*^9, 
  3.683899198805331*^9, 3.683899562039463*^9, 3.683903850917775*^9, 
  3.683903999315219*^9, 3.683904605899776*^9, 3.683904680346571*^9, 
  3.6839054808932447`*^9, 3.683906254214137*^9, 3.683906688799885*^9, 
  3.6839067255501547`*^9, 3.683949307746722*^9, 3.6839498623762913`*^9, 
  3.6839523828028383`*^9, 3.683955131153241*^9, 3.683958910291017*^9, 
  3.6851931255300837`*^9, 3.6851938653373003`*^9, 3.685254511106864*^9, 
  3.685258992752664*^9, 3.685706244525*^9, 3.685711726494656*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"S2Subalgebra=\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1"},
            {
             SubscriptBox["\[Iota]", "1"]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["S2Subalgebra=", 
   MatrixForm[{{
      MatrixForm[{{1}, {
         Subscript[$CellContext`\[Iota], 1]}}]}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.683894720447112*^9, 3.6838968668468018`*^9, 
  3.683899198805331*^9, 3.683899562039463*^9, 3.683903850917775*^9, 
  3.683903999315219*^9, 3.683904605899776*^9, 3.683904680346571*^9, 
  3.6839054808932447`*^9, 3.683906254214137*^9, 3.683906688799885*^9, 
  3.6839067255501547`*^9, 3.683949307746722*^9, 3.6839498623762913`*^9, 
  3.6839523828028383`*^9, 3.683955131153241*^9, 3.683958910291017*^9, 
  3.6851931255300837`*^9, 3.6851938653373003`*^9, 3.685254511106864*^9, 
  3.685258992752664*^9, 3.685706244525*^9, 3.68571172650064*^9}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Step1x5Algebra", ";"}]], "Input",
 CellChangeTimes->{
  3.683894830461444*^9, {3.6851905801180687`*^9, 3.685190585509602*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculation of generators", "Section",
 CellChangeTimes->{{3.683902406280332*^9, 3.683902411992662*^9}, {
  3.6839024516165123`*^9, 3.683902475521956*^9}, {3.683902509419033*^9, 
  3.683902551851089*^9}, {3.683902843994619*^9, 3.6839028464994917`*^9}, {
  3.683903880670438*^9, 3.683903893160449*^9}, {3.6851906152290363`*^9, 
  3.6851906281173563`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Step2Generators", ";"}]], "Input",
 CellChangeTimes->{{3.683894537461843*^9, 3.6838945431879177`*^9}, 
   3.683896844267519*^9, {3.685190630579959*^9, 3.685190640942966*^9}, {
   3.685248875406439*^9, 3.6852488757824078`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Number of prefiltered (RelevantGeneratorGenerationQ) \
generators = \"\>", "\[InvisibleSpace]", "40"}],
  SequenceForm[
  "Number of prefiltered (RelevantGeneratorGenerationQ) generators = ", 40],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894543869298*^9, 3.683896846407238*^9, 3.683899171636959*^9, 
   3.683899550999612*^9, 3.68390341308134*^9, 3.683903487359417*^9, {
   3.683903575170375*^9, 3.683903580924982*^9}, {3.683903794785561*^9, 
   3.683903798387924*^9}, 3.6839038692686567`*^9, 3.6839040053230257`*^9, 
   3.683904191184215*^9, 3.6839042879017773`*^9, 3.683904612034918*^9, {
   3.6839046848598967`*^9, 3.683904691479237*^9}, 3.683905484692594*^9, 
   3.683906258270974*^9, 3.683906729250897*^9, 3.683949311284865*^9, 
   3.683949866022407*^9, 3.683952386424906*^9, 3.683955134941909*^9, 
   3.6839589138886127`*^9, 3.685193073719002*^9, 3.685193129928636*^9, 
   3.6851931966453743`*^9, 3.6851938896178083`*^9, {3.685249057025475*^9, 
   3.68524907850462*^9}, 3.685259002990913*^9, 3.685706249520693*^9, 
   3.685711735967304*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Final number of generators = \"\>", "\[InvisibleSpace]", "28", 
   "\[InvisibleSpace]", "\<\". The first (up to) 10 generators are = \"\>", 
   "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {
       TagBox[
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"1"},
            {"10"},
            {"14"},
            {"5"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}],
        Function[BoxForm`e$, 
         MatrixForm[BoxForm`e$]]], 
       TagBox[
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"1"},
            {"10"},
            {"14"},
            {"6"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}],
        Function[BoxForm`e$, 
         MatrixForm[BoxForm`e$]]], 
       TagBox[
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"1"},
            {"10"},
            {"17"},
            {"5"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}],
        Function[BoxForm`e$, 
         MatrixForm[BoxForm`e$]]], 
       TagBox[
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"1"},
            {"10"},
            {"17"},
            {"6"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}],
        Function[BoxForm`e$, 
         MatrixForm[BoxForm`e$]]], 
       TagBox[
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"1"},
            {"13"},
            {"14"},
            {"5"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}],
        Function[BoxForm`e$, 
         MatrixForm[BoxForm`e$]]], 
       TagBox[
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"1"},
            {"13"},
            {"14"},
            {"6"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}],
        Function[BoxForm`e$, 
         MatrixForm[BoxForm`e$]]], 
       TagBox[
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"1"},
            {"13"},
            {"17"},
            {"5"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}],
        Function[BoxForm`e$, 
         MatrixForm[BoxForm`e$]]], 
       TagBox[
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"1"},
            {"13"},
            {"17"},
            {"6"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}],
        Function[BoxForm`e$, 
         MatrixForm[BoxForm`e$]]], 
       TagBox[
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"1"},
            {"10"},
            {"14"},
            {"4"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}],
        Function[BoxForm`e$, 
         MatrixForm[BoxForm`e$]]], 
       TagBox[
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"1"},
            {"10"},
            {"14"},
            {"7"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}],
        Function[BoxForm`e$, 
         MatrixForm[BoxForm`e$]]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]]}],
  SequenceForm[
  "Final number of generators = ", 28, 
   ". The first (up to) 10 generators are = ", 
   TableForm[{{
      MatrixForm[{1, 10, 14, 5}], 
      MatrixForm[{1, 10, 14, 6}], 
      MatrixForm[{1, 10, 17, 5}], 
      MatrixForm[{1, 10, 17, 6}], 
      MatrixForm[{1, 13, 14, 5}], 
      MatrixForm[{1, 13, 14, 6}], 
      MatrixForm[{1, 13, 17, 5}], 
      MatrixForm[{1, 13, 17, 6}], 
      MatrixForm[{1, 10, 14, 4}], 
      MatrixForm[{1, 10, 14, 7}]}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894543869298*^9, 3.683896846407238*^9, 3.683899171636959*^9, 
   3.683899550999612*^9, 3.68390341308134*^9, 3.683903487359417*^9, {
   3.683903575170375*^9, 3.683903580924982*^9}, {3.683903794785561*^9, 
   3.683903798387924*^9}, 3.6839038692686567`*^9, 3.6839040053230257`*^9, 
   3.683904191184215*^9, 3.6839042879017773`*^9, 3.683904612034918*^9, {
   3.6839046848598967`*^9, 3.683904691479237*^9}, 3.683905484692594*^9, 
   3.683906258270974*^9, 3.683906729250897*^9, 3.683949311284865*^9, 
   3.683949866022407*^9, 3.683952386424906*^9, 3.683955134941909*^9, 
   3.6839589138886127`*^9, 3.685193073719002*^9, 3.685193129928636*^9, 
   3.6851931966453743`*^9, 3.6851938896178083`*^9, {3.685249057025475*^9, 
   3.68524907850462*^9}, 3.685259002990913*^9, 3.685706249520693*^9, 
   3.68571173596953*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"After the initial cancellation (de-niceification), we expect \
to have \"\>", "\[InvisibleSpace]", "12", 
   "\[InvisibleSpace]", "\<\" generators left.\"\>"}],
  SequenceForm[
  "After the initial cancellation (de-niceification), we expect to have ", 12,
    " generators left."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894543869298*^9, 3.683896846407238*^9, 3.683899171636959*^9, 
   3.683899550999612*^9, 3.68390341308134*^9, 3.683903487359417*^9, {
   3.683903575170375*^9, 3.683903580924982*^9}, {3.683903794785561*^9, 
   3.683903798387924*^9}, 3.6839038692686567`*^9, 3.6839040053230257`*^9, 
   3.683904191184215*^9, 3.6839042879017773`*^9, 3.683904612034918*^9, {
   3.6839046848598967`*^9, 3.683904691479237*^9}, 3.683905484692594*^9, 
   3.683906258270974*^9, 3.683906729250897*^9, 3.683949311284865*^9, 
   3.683949866022407*^9, 3.683952386424906*^9, 3.683955134941909*^9, 
   3.6839589138886127`*^9, 3.685193073719002*^9, 3.685193129928636*^9, 
   3.6851931966453743`*^9, 3.6851938896178083`*^9, {3.685249057025475*^9, 
   3.68524907850462*^9}, 3.685259002990913*^9, 3.685706249520693*^9, 
   3.685711735970048*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"They will lie in the following idempotents:\\n\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"\<\"idempotents\"\>", "\<\"#{generators}\"\>"},
       {
        RowBox[{"{", 
         RowBox[{"\<\"b\"\>", ",", "\<\"x\"\>"}], "}"}], "8"},
       {
        RowBox[{"{", 
         RowBox[{"\<\"a\"\>", ",", "\<\"x\"\>"}], "}"}], "4"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["They will lie in the following idempotents:\n", 
   MatrixForm[{{
     "idempotents", "#{generators}"}, {{"b", "x"}, 8}, {{"a", "x"}, 4}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894543869298*^9, 3.683896846407238*^9, 3.683899171636959*^9, 
   3.683899550999612*^9, 3.68390341308134*^9, 3.683903487359417*^9, {
   3.683903575170375*^9, 3.683903580924982*^9}, {3.683903794785561*^9, 
   3.683903798387924*^9}, 3.6839038692686567`*^9, 3.6839040053230257`*^9, 
   3.683904191184215*^9, 3.6839042879017773`*^9, 3.683904612034918*^9, {
   3.6839046848598967`*^9, 3.683904691479237*^9}, 3.683905484692594*^9, 
   3.683906258270974*^9, 3.683906729250897*^9, 3.683949311284865*^9, 
   3.683949866022407*^9, 3.683952386424906*^9, 3.683955134941909*^9, 
   3.6839589138886127`*^9, 3.685193073719002*^9, 3.685193129928636*^9, 
   3.6851931966453743`*^9, 3.6851938896178083`*^9, {3.685249057025475*^9, 
   3.68524907850462*^9}, 3.685259002990913*^9, 3.685706249520693*^9, 
   3.68571173597075*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculation of domains and structure maps", "Section",
 CellChangeTimes->{{3.683902406280332*^9, 3.683902411992662*^9}, {
  3.6839024516165123`*^9, 3.683902475521956*^9}, {3.683902509419033*^9, 
  3.6839025833159637`*^9}, {3.683902614317812*^9, 3.683902621444993*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Step3x1Domains", ";"}]], "Input",
 CellChangeTimes->{{3.6838947269387207`*^9, 3.6838947298832827`*^9}, 
   3.6838947755524597`*^9, {3.68519067320802*^9, 3.685190679928112*^9}, {
   3.685248878742404*^9, 3.685248878886519*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There are \"\>", "\[InvisibleSpace]", "32", 
   "\[InvisibleSpace]", "\<\" rectangles, bigons or boundary rectangles. Here \
is a random selection of up to 10 of these:\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"24", "25", "21", "28", "29", "26", "12", "10", "15", "20"},
       {
        RowBox[{"{", 
         RowBox[{"10", ",", "9"}], "}"}], 
        RowBox[{"{", "9", "}"}], 
        RowBox[{"{", 
         RowBox[{"9", ",", "8"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"12", ",", "11"}], "}"}], 
        RowBox[{"{", "11", "}"}], 
        RowBox[{"{", 
         RowBox[{"11", ",", "10"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"5", ",", "4"}], "}"}], 
        RowBox[{"{", "3", "}"}], 
        RowBox[{"{", "5", "}"}], 
        RowBox[{"{", "7", "}"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm[
  "There are ", 32, 
   " rectangles, bigons or boundary rectangles. Here is a random selection of \
up to 10 of these:", 
   MatrixForm[{{24, 25, 21, 28, 29, 26, 12, 10, 15, 
     20}, {{10, 9}, {9}, {9, 8}, {12, 11}, {11}, {11, 10}, {5, 4}, {3}, {5}, {
      7}}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.683894730955065*^9, 3.6838947783069363`*^9, 
  3.683894849892799*^9, 3.683896385425003*^9, 3.683896875241727*^9, 
  3.6838992152472486`*^9, 3.683899568257552*^9, 3.683904569129693*^9, 
  3.683904615298397*^9, 3.683904696135613*^9, 3.6839054921439457`*^9, 
  3.6839062640974073`*^9, 3.68390673333317*^9, 3.6839072142815037`*^9, 
  3.6839493213703203`*^9, 3.683949878004867*^9, 3.683952394631023*^9, 
  3.6839551403057747`*^9, 3.683958924101*^9, 3.685193337800858*^9, 
  3.6851938971431427`*^9, 3.685202311684525*^9, 3.685249082427041*^9, 
  3.6852590077462797`*^9, 3.685706253568079*^9, 3.685711740102295*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There are \"\>", "\[InvisibleSpace]", "164", 
   "\[InvisibleSpace]", "\<\" domains with boundary on S1, \"\>", 
   "\[InvisibleSpace]", "0", "\[InvisibleSpace]", "\<\" on S2 and \"\>", 
   "\[InvisibleSpace]", "16", 
   "\[InvisibleSpace]", "\<\" without any boundary.\"\>"}],
  SequenceForm[
  "There are ", 164, " domains with boundary on S1, ", 0, " on S2 and ", 16, 
   " without any boundary."],
  Editable->False]], "Print",
 CellChangeTimes->{3.683894730955065*^9, 3.6838947783069363`*^9, 
  3.683894849892799*^9, 3.683896385425003*^9, 3.683896875241727*^9, 
  3.6838992152472486`*^9, 3.683899568257552*^9, 3.683904569129693*^9, 
  3.683904615298397*^9, 3.683904696135613*^9, 3.6839054921439457`*^9, 
  3.6839062640974073`*^9, 3.68390673333317*^9, 3.6839072142815037`*^9, 
  3.6839493213703203`*^9, 3.683949878004867*^9, 3.683952394631023*^9, 
  3.6839551403057747`*^9, 3.683958924101*^9, 3.685193337800858*^9, 
  3.6851938971431427`*^9, 3.685202311684525*^9, 3.685249082427041*^9, 
  3.6852590077462797`*^9, 3.685706253568079*^9, 3.685711741783766*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\" << backup saved at: \"\>", 
   "\[InvisibleSpace]", \
"\<\"/mhome/dpmms/c/cbz20/Documents/PhD/Research/thesis/BSFH/Backups/\
ClosureBSAx2_AfterDomains1.mx >>\"\>"}],
  SequenceForm[
  " << backup saved at: ", 
   "/mhome/dpmms/c/cbz20/Documents/PhD/Research/thesis/BSFH/Backups/\
ClosureBSAx2_AfterDomains1.mx >>"],
  Editable->False]], "Print",
 CellChangeTimes->{3.683894730955065*^9, 3.6838947783069363`*^9, 
  3.683894849892799*^9, 3.683896385425003*^9, 3.683896875241727*^9, 
  3.6838992152472486`*^9, 3.683899568257552*^9, 3.683904569129693*^9, 
  3.683904615298397*^9, 3.683904696135613*^9, 3.6839054921439457`*^9, 
  3.6839062640974073`*^9, 3.68390673333317*^9, 3.6839072142815037`*^9, 
  3.6839493213703203`*^9, 3.683949878004867*^9, 3.683952394631023*^9, 
  3.6839551403057747`*^9, 3.683958924101*^9, 3.685193337800858*^9, 
  3.6851938971431427`*^9, 3.685202311684525*^9, 3.685249082427041*^9, 
  3.6852590077462797`*^9, 3.685706253568079*^9, 3.685711741826297*^9}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"<<", 
  RowBox[{"(", 
   RowBox[{"BackupFilePath", "<>", "\"\<_AfterDomains1.mx\>\""}], 
   ")"}]}]], "Input",
 CellChangeTimes->{{3.67401554637004*^9, 3.674015550954636*^9}, 
   3.674027617098591*^9, {3.683907168603799*^9, 3.6839071704999237`*^9}}],

Cell["\<\
The next two steps can take quite a while for large diagrams, for 250 000 \
generators up to a week or more. Parallel processing is possible, so consider \
using a computer with multiple kernels to speed up.\
\>", "Text",
 CellChangeTimes->{{3.683904487701765*^9, 3.683904540055222*^9}, {
  3.6839067513604193`*^9, 3.6839067871764097`*^9}, {3.683907238892846*^9, 
  3.6839072757256117`*^9}, {3.6839073161515713`*^9, 3.683907319646093*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Step3x2Domains", ";"}]], "Input",
 CellChangeTimes->{{3.68389561766648*^9, 3.683895623768882*^9}, {
  3.685190703361431*^9, 3.685190705639604*^9}, {3.685248881614497*^9, 
  3.685248881790359*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"Computed indices for domains.\"\>"], "Print",
 CellChangeTimes->{3.6838956246100893`*^9, 3.683895684554982*^9, 
  3.683896099063699*^9, 3.6838961508419447`*^9, 3.68389639107202*^9, 
  3.683896615873249*^9, 3.6838968837250547`*^9, 3.6838992386609*^9, 
  3.683899573469658*^9, 3.683901250664845*^9, 3.683904706146625*^9, 
  3.6839056527730093`*^9, 3.6839062695679092`*^9, 3.683949330866878*^9, 
  3.6839498827606487`*^9, 3.683952400833411*^9, 3.68395892921129*^9, 
  3.6851937142246103`*^9, 3.685193906917478*^9, 3.685249092025691*^9, 
  3.685259023392149*^9, 3.685259056942852*^9, 3.685706258821162*^9, 
  3.6857117468757668`*^9}],

Cell[BoxData["\<\"Computed starting intersection points of domains.\"\>"], \
"Print",
 CellChangeTimes->{3.6838956246100893`*^9, 3.683895684554982*^9, 
  3.683896099063699*^9, 3.6838961508419447`*^9, 3.68389639107202*^9, 
  3.683896615873249*^9, 3.6838968837250547`*^9, 3.6838992386609*^9, 
  3.683899573469658*^9, 3.683901250664845*^9, 3.683904706146625*^9, 
  3.6839056527730093`*^9, 3.6839062695679092`*^9, 3.683949330866878*^9, 
  3.6839498827606487`*^9, 3.683952400833411*^9, 3.68395892921129*^9, 
  3.6851937142246103`*^9, 3.685193906917478*^9, 3.685249092025691*^9, 
  3.685259023392149*^9, 3.685259056942852*^9, 3.685706258821162*^9, 
  3.685711746909234*^9}],

Cell[BoxData[
 TemplateBox[{RowBox[{"\"Mon 17 Oct 2016 17:49:06\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", "1.`"}], FontColor -> 
      GrayLevel[0.5]]}],RowBox[{"DateObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"2016", ",", "10", ",", "17"}], "}"}], ",", 
       RowBox[{"TimeObject", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"17", ",", "49", ",", "6.888753`"}], "}"}], ",", 
           RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}], ",", 
       RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}]},
  "DateObject",
  Editable->False]], "Print",
 CellChangeTimes->{3.6838956246100893`*^9, 3.683895684554982*^9, 
  3.683896099063699*^9, 3.6838961508419447`*^9, 3.68389639107202*^9, 
  3.683896615873249*^9, 3.6838968837250547`*^9, 3.6838992386609*^9, 
  3.683899573469658*^9, 3.683901250664845*^9, 3.683904706146625*^9, 
  3.6839056527730093`*^9, 3.6839062695679092`*^9, 3.683949330866878*^9, 
  3.6839498827606487`*^9, 3.683952400833411*^9, 3.68395892921129*^9, 
  3.6851937142246103`*^9, 3.685193906917478*^9, 3.685249092025691*^9, 
  3.685259023392149*^9, 3.685259056942852*^9, 3.685706258821162*^9, 
  3.6857117469135447`*^9}],

Cell[BoxData["\<\"There are 180 domains that I need to look at.\"\>"], "Print",
 CellChangeTimes->{3.6838956246100893`*^9, 3.683895684554982*^9, 
  3.683896099063699*^9, 3.6838961508419447`*^9, 3.68389639107202*^9, 
  3.683896615873249*^9, 3.6838968837250547`*^9, 3.6838992386609*^9, 
  3.683899573469658*^9, 3.683901250664845*^9, 3.683904706146625*^9, 
  3.6839056527730093`*^9, 3.6839062695679092`*^9, 3.683949330866878*^9, 
  3.6839498827606487`*^9, 3.683952400833411*^9, 3.68395892921129*^9, 
  3.6851937142246103`*^9, 3.685193906917478*^9, 3.685249092025691*^9, 
  3.685259023392149*^9, 3.685259056942852*^9, 3.685706258821162*^9, 
  3.685711746914707*^9}],

Cell[BoxData["\<\"Computed starting generators for all domains.\"\>"], "Print",
 CellChangeTimes->{3.6838956246100893`*^9, 3.683895684554982*^9, 
  3.683896099063699*^9, 3.6838961508419447`*^9, 3.68389639107202*^9, 
  3.683896615873249*^9, 3.6838968837250547`*^9, 3.6838992386609*^9, 
  3.683899573469658*^9, 3.683901250664845*^9, 3.683904706146625*^9, 
  3.6839056527730093`*^9, 3.6839062695679092`*^9, 3.683949330866878*^9, 
  3.6839498827606487`*^9, 3.683952400833411*^9, 3.68395892921129*^9, 
  3.6851937142246103`*^9, 3.685193906917478*^9, 3.685249092025691*^9, 
  3.685259023392149*^9, 3.685259056942852*^9, 3.685706258821162*^9, 
  3.685711746991214*^9}],

Cell[BoxData[
 TemplateBox[{RowBox[{"\"Mon 17 Oct 2016 17:49:06\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", "1.`"}], FontColor -> 
      GrayLevel[0.5]]}],RowBox[{"DateObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"2016", ",", "10", ",", "17"}], "}"}], ",", 
       RowBox[{"TimeObject", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"17", ",", "49", ",", "6.990864`"}], "}"}], ",", 
           RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}], ",", 
       RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}]},
  "DateObject",
  Editable->False]], "Print",
 CellChangeTimes->{3.6838956246100893`*^9, 3.683895684554982*^9, 
  3.683896099063699*^9, 3.6838961508419447`*^9, 3.68389639107202*^9, 
  3.683896615873249*^9, 3.6838968837250547`*^9, 3.6838992386609*^9, 
  3.683899573469658*^9, 3.683901250664845*^9, 3.683904706146625*^9, 
  3.6839056527730093`*^9, 3.6839062695679092`*^9, 3.683949330866878*^9, 
  3.6839498827606487`*^9, 3.683952400833411*^9, 3.68395892921129*^9, 
  3.6851937142246103`*^9, 3.685193906917478*^9, 3.685249092025691*^9, 
  3.685259023392149*^9, 3.685259056942852*^9, 3.685706258821162*^9, 
  3.685711746994487*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Step3x3Domains", ";"}]], "Input",
 CellChangeTimes->{{3.68389606856364*^9, 3.683896070573711*^9}, {
  3.685190710440928*^9, 3.685190712688836*^9}, {3.685249107324833*^9, 
  3.6852491074910917`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 TemplateBox[{RowBox[{"\"Mon 17 Oct 2016 17:49:08\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", "1.`"}], FontColor -> 
      GrayLevel[0.5]]}],RowBox[{"DateObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"2016", ",", "10", ",", "17"}], "}"}], ",", 
       RowBox[{"TimeObject", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"17", ",", "49", ",", "8.917059`"}], "}"}], ",", 
           RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}], ",", 
       RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}]},
  "DateObject",
  Editable->False]], "Print",
 CellChangeTimes->{3.685249109994158*^9, 3.685259025303008*^9, 
  3.6852590586172037`*^9, 3.6857062612414713`*^9, 3.685711748953321*^9}],

Cell[BoxData["\<\"Calculation of the structure map. There are 28 \
generators.\"\>"], "Print",
 CellChangeTimes->{3.685249109994158*^9, 3.685259025303008*^9, 
  3.6852590586172037`*^9, 3.6857062612414713`*^9, 3.685711748955715*^9}],

Cell[BoxData["\<\"Good: There are no multiple labels in the structure!\"\>"], \
"Print",
 CellChangeTimes->{3.685249109994158*^9, 3.685259025303008*^9, 
  3.6852590586172037`*^9, 3.6857062612414713`*^9, 3.685711749021747*^9}],

Cell[BoxData[
 TemplateBox[{RowBox[{"\"Mon 17 Oct 2016 17:49:08\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", "1.`"}], FontColor -> 
      GrayLevel[0.5]]}],RowBox[{"DateObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"2016", ",", "10", ",", "17"}], "}"}], ",", 
       RowBox[{"TimeObject", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"17", ",", "49", ",", "8.966998`"}], "}"}], ",", 
           RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}], ",", 
       RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}]},
  "DateObject",
  Editable->False]], "Print",
 CellChangeTimes->{3.685249109994158*^9, 3.685259025303008*^9, 
  3.6852590586172037`*^9, 3.6857062612414713`*^9, 3.685711749025097*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Step3x4Domains", ";"}]], "Input",
 CellChangeTimes->{{3.683896075892415*^9, 3.683896076077523*^9}, {
  3.68519071569775*^9, 3.685190717729068*^9}, {3.685248883862629*^9, 
  3.685248884014323*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There are \"\>", "\[InvisibleSpace]", "25", 
   "\[InvisibleSpace]", "\<\" domains that contribute to the structure \
maps.\"\>"}],
  SequenceForm[
  "There are ", 25, " domains that contribute to the structure maps."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.68571175160121*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There are \"\>", "\[InvisibleSpace]", "8", 
   "\[InvisibleSpace]", "\<\" domains that contribute an honest differential \
to the structure maps, e.g. \\n\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"{", "8", "}"}], 
        RowBox[{"{", "12", "}"}], 
        RowBox[{"{", "14", "}"}], 
        RowBox[{"{", 
         RowBox[{"8", ",", "7"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"9", ",", "8"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"10", ",", "14"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"12", ",", "11"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"13", ",", "12"}], "}"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm[
  "There are ", 8, 
   " domains that contribute an honest differential to the structure maps, \
e.g. \n", 
   MatrixForm[{{{8}, {12}, {14}, {8, 7}, {9, 8}, {10, 14}, {12, 11}, {13, 
      12}}}]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.68571175160283*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There are \"\>", "\[InvisibleSpace]", "17", 
   "\[InvisibleSpace]", "\<\" domains that contribute an S1 algebra element \
to the structure maps, e.g. \\n\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"\<\"Regions\"\>", 
        RowBox[{"{", "5", "}"}], 
        RowBox[{"{", 
         RowBox[{"3", ",", "2", ",", "8", ",", "1"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"4", ",", "12", ",", "6"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"5", ",", "4", ",", "12", ",", "6"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"3", ",", "2", ",", "1"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"5", ",", "3", ",", "2", ",", "1"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"4", ",", "12", ",", "6", ",", "3", ",", "2", ",", "1"}], 
         "}"}]},
       {"\<\"moving strands\"\>", 
        RowBox[{"{", 
         RowBox[{"3", ",", "4"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"6", ",", "7", ",", "7", ",", "9"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"2", ",", "3", ",", "4", ",", "5"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"2", ",", "4", ",", "4", ",", "5"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"6", ",", "9"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"3", ",", "4", ",", "6", ",", "9"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "9"}], 
         "}"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm[
  "There are ", 17, 
   " domains that contribute an S1 algebra element to the structure maps, \
e.g. \n", 
   MatrixForm[{{
     "Regions", {5}, {3, 2, 8, 1}, {4, 12, 6}, {5, 4, 12, 6}, {3, 2, 1}, {5, 
      3, 2, 1}, {4, 12, 6, 3, 2, 1}}, {
     "moving strands", {3, 4}, {6, 7, 7, 9}, {2, 3, 4, 5}, {2, 4, 4, 5}, {6, 
      9}, {3, 4, 6, 9}, {2, 3, 4, 5, 6, 9}}}]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.685711751603689*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There are \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\" domains that contribute an S2 algebra element \
to the structure maps, e.g. \\n\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"\<\"Regions\"\>"},
       {"\<\"moving strands\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm[
  "There are ", 0, 
   " domains that contribute an S2 algebra element to the structure maps, \
e.g. \n", 
   MatrixForm[{{"Regions"}, {"moving strands"}}]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.685711751604446*^9}],

Cell[BoxData["\<\"Note: If this calculation gives an error message 'Part 1 of \
{} does not exist', there are some algebra elements generated by domains, \
that do not show up in the glueing algebra. This should not happen. If it \
does, check your algebra input data.\"\>"], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.685711751664555*^9}],

Cell[BoxData["\<\"OK. All domains for S1 can contribute.\"\>"], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.685711751749946*^9}],

Cell[BoxData["\<\"OK. All domains for S2 can contribute.\"\>"], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.6857117518017397`*^9}],

Cell[BoxData[
 TemplateBox[{RowBox[{"\"Mon 17 Oct 2016 17:49:11\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", "1.`"}], FontColor -> 
      GrayLevel[0.5]]}],RowBox[{"DateObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"2016", ",", "10", ",", "17"}], "}"}], ",", 
       RowBox[{"TimeObject", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"17", ",", "49", ",", "11.750393`"}], "}"}], ",", 
           RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}], ",", 
       RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}]},
  "DateObject",
  Editable->False]], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.685711751804019*^9}],

Cell[BoxData["\<\"Calculation of StructureMapsSparse.\"\>"], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.685711751804461*^9}],

Cell[BoxData[
 TemplateBox[{RowBox[{"\"Mon 17 Oct 2016 17:49:11\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", "1.`"}], FontColor -> 
      GrayLevel[0.5]]}],RowBox[{"DateObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"2016", ",", "10", ",", "17"}], "}"}], ",", 
       RowBox[{"TimeObject", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"17", ",", "49", ",", "11.753567`"}], "}"}], ",", 
           RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}], ",", 
       RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}]},
  "DateObject",
  Editable->False]], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.685711751806404*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"This is what the upper left corner of \
'StructureMapsWith1Action' looks like:\\n\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"\<\"{{{1}, 1}}\"\>", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \\\"1\\\"}], \\\"}\\\"}], \\\
\"}\\\"}]\\)\"\>", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", \\\"15\\\", \\\"}\\\"}], \\\",\\\", \\\"1\\\"}], \
\\\"}\\\"}], \\\"}\\\"}]\\)\"\>", 
        "0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", \\\"14\\\", \\\"}\\\"}], \\\",\\\", \\\"1\\\"}], \
\\\"}\\\"}], \\\"}\\\"}]\\)\"\>", 
        "0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", \\\"13\\\", \\\"}\\\"}], \\\",\\\", \\\"1\\\"}], \
\\\"}\\\"}], \\\"}\\\"}]\\)\"\>", "0", "0", "0"},
       {"0", "\<\"{{{1}, 1}}\"\>", 
        "0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", \\\"15\\\", \\\"}\\\"}], \\\",\\\", \\\"1\\\"}], \
\\\"}\\\"}], \\\"}\\\"}]\\)\"\>", 
        "0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", \\\"14\\\", \\\"}\\\"}], \\\",\\\", \\\"1\\\"}], \
\\\"}\\\"}], \\\"}\\\"}]\\)\"\>", 
        "0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", \\\"13\\\", \\\"}\\\"}], \\\",\\\", \\\"1\\\"}], \
\\\"}\\\"}], \\\"}\\\"}]\\)\"\>", "0", "0"},
       {"0", 
        "0", "\<\"{{{1}, 1}}\"\>", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \\\"1\\\"}], \\\"}\\\"}], \\\
\"}\\\"}]\\)\"\>", "0", 
        "0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", \\\"14\\\", \\\"}\\\"}], \\\",\\\", \\\"1\\\"}], \
\\\"}\\\"}], \\\"}\\\"}]\\)\"\>", "0", "0", "0"},
       {"0", "0", "0", "\<\"{{{1}, 1}}\"\>", "0", "0", 
        "0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", \\\"14\\\", \\\"}\\\"}], \\\",\\\", \\\"1\\\"}], \
\\\"}\\\"}], \\\"}\\\"}]\\)\"\>", "0", "0"},
       {"0", "0", "0", 
        "0", "\<\"{{{1}, 1}}\"\>", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \\\"1\\\"}], \\\"}\\\"}], \\\
\"}\\\"}]\\)\"\>", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", \\\"15\\\", \\\"}\\\"}], \\\",\\\", \\\"1\\\"}], \
\\\"}\\\"}], \\\"}\\\"}]\\)\"\>", "0", "0", "0"},
       {"0", "0", "0", "0", "0", "\<\"{{{1}, 1}}\"\>", 
        "0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", \\\"15\\\", \\\"}\\\"}], \\\",\\\", \\\"1\\\"}], \
\\\"}\\\"}], \\\"}\\\"}]\\)\"\>", "0", "0"},
       {"0", "0", "0", "0", "0", 
        "0", "\<\"{{{1}, 1}}\"\>", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \\\"1\\\"}], \\\"}\\\"}], \\\
\"}\\\"}]\\)\"\>", "0", "0"},
       {"0", "0", "0", "0", "0", "0", "0", "\<\"{{{1}, 1}}\"\>", "0", "0"},
       {"0", "0", "0", "0", "0", "0", "0", 
        "0", "\<\"{{{1}, 1}}\"\>", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{\\\"{\\\", RowBox[{\\\"1\\\", \\\",\\\", \\\"1\\\"}], \\\"}\\\"}], \\\
\"}\\\"}]\\)\"\>"},
       {"0", "0", "0", "0", "0", "0", "0", "0", "0", "\<\"{{{1}, 1}}\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {10, 10}, 0, {
       1, {{0, 5, 9, 12, 14, 17, 19, 21, 22, 24, 25}, {{1}, {2}, {3}, {5}, {
         7}, {2}, {4}, {6}, {8}, {3}, {4}, {7}, {4}, {8}, {5}, {6}, {7}, {
         6}, {8}, {7}, {8}, {8}, {9}, {10}, {10}}}, {
        "{{{1}, 1}}", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"1\", \",\", \"1\"}], \
\"}\"}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{RowBox[{\"{\", \"15\", \
\"}\"}], \",\", \"1\"}], \"}\"}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{RowBox[{\"{\", \"14\", \
\"}\"}], \",\", \"1\"}], \"}\"}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{RowBox[{\"{\", \"13\", \
\"}\"}], \",\", \"1\"}], \"}\"}], \"}\"}]\)", "{{{1}, 1}}", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{RowBox[{\"{\", \"15\", \
\"}\"}], \",\", \"1\"}], \"}\"}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{RowBox[{\"{\", \"14\", \
\"}\"}], \",\", \"1\"}], \"}\"}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{RowBox[{\"{\", \"13\", \
\"}\"}], \",\", \"1\"}], \"}\"}], \"}\"}]\)", "{{{1}, 1}}", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"1\", \",\", \"1\"}], \
\"}\"}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{RowBox[{\"{\", \"14\", \
\"}\"}], \",\", \"1\"}], \"}\"}], \"}\"}]\)", "{{{1}, 1}}", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{RowBox[{\"{\", \"14\", \
\"}\"}], \",\", \"1\"}], \"}\"}], \"}\"}]\)", "{{{1}, 1}}", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"1\", \",\", \"1\"}], \
\"}\"}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{RowBox[{\"{\", \"15\", \
\"}\"}], \",\", \"1\"}], \"}\"}], \"}\"}]\)", "{{{1}, 1}}", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{RowBox[{\"{\", \"15\", \
\"}\"}], \",\", \"1\"}], \"}\"}], \"}\"}]\)", "{{{1}, 1}}", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"1\", \",\", \"1\"}], \
\"}\"}], \"}\"}]\)", "{{{1}, 1}}", "{{{1}, 1}}", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"1\", \",\", \"1\"}], \
\"}\"}], \"}\"}]\)", "{{{1}, 1}}"}}]]]]}],
  SequenceForm[
  "This is what the upper left corner of 'StructureMapsWith1Action' looks \
like:\n", 
   MatrixForm[
   SparseArray[
    Automatic, {10, 10}, 0, {
     1, {{0, 5, 9, 12, 14, 17, 19, 21, 22, 24, 25}, {{1}, {2}, {3}, {5}, {
       7}, {2}, {4}, {6}, {8}, {3}, {4}, {7}, {4}, {8}, {5}, {6}, {7}, {6}, {
       8}, {7}, {8}, {8}, {9}, {10}, {10}}}, {
      "{{{1}, 1}}", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"1\", \",\", \"1\"}], \
\"}\"}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{RowBox[{\"{\", \"15\", \
\"}\"}], \",\", \"1\"}], \"}\"}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{RowBox[{\"{\", \"14\", \
\"}\"}], \",\", \"1\"}], \"}\"}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{RowBox[{\"{\", \"13\", \
\"}\"}], \",\", \"1\"}], \"}\"}], \"}\"}]\)", "{{{1}, 1}}", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{RowBox[{\"{\", \"15\", \
\"}\"}], \",\", \"1\"}], \"}\"}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{RowBox[{\"{\", \"14\", \
\"}\"}], \",\", \"1\"}], \"}\"}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{RowBox[{\"{\", \"13\", \
\"}\"}], \",\", \"1\"}], \"}\"}], \"}\"}]\)", "{{{1}, 1}}", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"1\", \",\", \"1\"}], \
\"}\"}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{RowBox[{\"{\", \"14\", \
\"}\"}], \",\", \"1\"}], \"}\"}], \"}\"}]\)", "{{{1}, 1}}", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{RowBox[{\"{\", \"14\", \
\"}\"}], \",\", \"1\"}], \"}\"}], \"}\"}]\)", "{{{1}, 1}}", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"1\", \",\", \"1\"}], \
\"}\"}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{RowBox[{\"{\", \"15\", \
\"}\"}], \",\", \"1\"}], \"}\"}], \"}\"}]\)", "{{{1}, 1}}", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{RowBox[{\"{\", \"15\", \
\"}\"}], \",\", \"1\"}], \"}\"}], \"}\"}]\)", "{{{1}, 1}}", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"1\", \",\", \"1\"}], \
\"}\"}], \"}\"}]\)", "{{{1}, 1}}", "{{{1}, 1}}", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"1\", \",\", \"1\"}], \
\"}\"}], \"}\"}]\)", "{{{1}, 1}}"}}]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.685711751945591*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\" << backup saved at: \"\>", 
   "\[InvisibleSpace]", \
"\<\"/mhome/dpmms/c/cbz20/Documents/PhD/Research/thesis/BSFH/Backups/\
ClosureBSAx2_BeforeCancellation.mx >>\"\>"}],
  SequenceForm[
  " << backup saved at: ", 
   "/mhome/dpmms/c/cbz20/Documents/PhD/Research/thesis/BSFH/Backups/\
ClosureBSAx2_BeforeCancellation.mx >>"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.685711751946681*^9}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"<<", 
   RowBox[{"(", 
    RowBox[{"BackupFilePath", "<>", "\"\<_BeforeCancellation.mx\>\""}], 
    ")"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.676092257232688*^9, 3.676092257977479*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"SANITY", " ", "CHECK"}], ";", " ", 
    RowBox[{
    "you", " ", "might", " ", "want", " ", "to", " ", "check", " ", "if", " ",
      "you", " ", "can", " ", "find", " ", "some", " ", "differentials", " ", 
     "computed", " ", "here", " ", "in", " ", "your", " ", "nice", " ", 
     "Heegaard", " ", "diagram"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SparseNiceFindAllArrowsStartingAt", "[", "n_", "]"}], " ", 
     "lists", " ", "all", " ", "arrows", " ", "that", " ", "start", " ", "at",
      " ", "generator", " ", "of", " ", 
     RowBox[{"index", " ", "'"}], 
     RowBox[{"n", "'"}], " ", "in", " ", "the", " ", 
     RowBox[{"list", " ", "'"}], 
     RowBox[{"generators", "'"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SparseNiceFindAllArrowsStartingAt", "[", "n_", "]"}], " ", 
     "lists", " ", "all", " ", "arrows", " ", "that", " ", "end", " ", "at", 
     " ", "generator", " ", "of", " ", 
     RowBox[{"index", " ", "'"}], 
     RowBox[{"n", "'"}], " ", "in", " ", "the", " ", 
     RowBox[{"list", " ", "'"}], 
     RowBox[{"generators", "'"}]}], ";"}], "\[IndentingNewLine]", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"SparseNiceFindAllArrowsStartingAt", "[", "2", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"SparseNiceFindAllArrowsEndingAt", "[", "3", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.674104304443412*^9, 3.674104307474148*^9}, 
   3.674104966443514*^9, {3.674105085853196*^9, 3.6741050869424877`*^9}, {
   3.674228773456483*^9, 3.6742287789948273`*^9}, {3.674268634047946*^9, 
   3.674268635627301*^9}, {3.674268790102474*^9, 3.6742688117888603`*^9}, {
   3.674269107233716*^9, 3.6742691076093807`*^9}, {3.6742765544263973`*^9, 
   3.67427655485629*^9}, 3.675245199212315*^9, {3.675245268803441*^9, 
   3.675245294940248*^9}, {3.675245613734436*^9, 3.675245614036627*^9}, {
   3.675935426998316*^9, 3.675935427252965*^9}, {3.676441741691539*^9, 
   3.67644175022666*^9}, {3.6838969940205708`*^9, 3.683896994204054*^9}, {
   3.6851939440098352`*^9, 3.685193977665649*^9}, {3.685194036684403*^9, 
   3.6851941015901117`*^9}, {3.685194137103114*^9, 3.685194258090046*^9}, {
   3.68519429023514*^9, 3.685194382196105*^9}, {3.685194417518076*^9, 
   3.685194417725258*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"From 2=(1|10|14|6)      {regions} = Relevant Domain Index (Old \
Index)\"\>", 
   "\[InvisibleSpace]", "\<\"\\n To  1=(1|10|14|5) via (14) = 3 (8), label \
=((1|1))\"\>", 
   "\[InvisibleSpace]", "\<\"\\n To  22=(1|10|8|16) via (12|11) = 7 (14), \
label =((1|1))\"\>"}],
  SequenceForm[
  "From 2=(1|10|14|6)      {regions} = Relevant Domain Index (Old Index)", 
   "\n To  1=(1|10|14|5) via (14) = 3 (8), label =((1|1))", 
   "\n To  22=(1|10|8|16) via (12|11) = 7 (14), label =((1|1))"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.674149533028758*^9, 3.674149613295639*^9, {3.67422875015836*^9, 
   3.6742287793379374`*^9}, 3.674268636201438*^9, {3.674268790888933*^9, 
   3.674268812213994*^9}, 3.674269108319046*^9, 3.674276555521348*^9, 
   3.674278431214143*^9, 3.674279561803392*^9, 3.675240304731463*^9, 
   3.67524055059062*^9, 3.675242328123254*^9, 3.67524519978808*^9, {
   3.675245270088979*^9, 3.6752452952635193`*^9}, {3.6752455965712852`*^9, 
   3.675245614489789*^9}, 3.675272485838872*^9, {3.675272601160602*^9, 
   3.67527271885688*^9}, 3.675272793273382*^9, 3.675272846678245*^9, 
   3.675503699806039*^9, {3.675507867971129*^9, 3.6755078958091373`*^9}, 
   3.67550935516679*^9, 3.675509425533766*^9, {3.6759354173925447`*^9, 
   3.67593542778658*^9}, 3.675935534043977*^9, {3.6759356389280024`*^9, 
   3.6759356598173847`*^9}, {3.675935749004092*^9, 3.6759357720758543`*^9}, 
   3.6759421296376123`*^9, 3.675958787663187*^9, 3.675962599266767*^9, 
   3.6760054406677027`*^9, 3.676389732279505*^9, {3.67644174352247*^9, 
   3.676441751092914*^9}, 3.676475067922023*^9, 3.677558347572921*^9, 
   3.6789371436314898`*^9, 3.6789382478871098`*^9, 3.683896779420425*^9, 
   3.683896904192246*^9, 3.6838969947649813`*^9, 3.6838992605164824`*^9, 
   3.683899622598269*^9, 3.683899819133437*^9, 3.683906280399602*^9, 
   3.6839068019023046`*^9, 3.683949355652266*^9, 3.6839498914696693`*^9, 
   3.683952408955373*^9, 3.683958936989856*^9, 3.6851944185927553`*^9, 
   3.685194582335441*^9, 3.6852590806499767`*^9, 3.685706267130395*^9, 
   3.685711755199422*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"From 3=(1|10|17|5)      {regions} = Relevant Domain Index (Old \
Index)\"\>", 
   "\[InvisibleSpace]", "\<\"\\n From 4=(1|10|17|6) via (14) = 3 (8), label \
=((1|1))\"\>", 
   "\[InvisibleSpace]", "\<\"\\n From 7=(1|13|17|5) via (3|2|1) = 13 (104), \
label =(((14)|1))\"\>", 
   "\[InvisibleSpace]", "\<\"\\n From 19=(1|3|17|11) via (3|2|9|8|1) = 20 \
(139), label =(((11)|1))\"\>"}],
  SequenceForm[
  "From 3=(1|10|17|5)      {regions} = Relevant Domain Index (Old Index)", 
   "\n From 4=(1|10|17|6) via (14) = 3 (8), label =((1|1))", 
   "\n From 7=(1|13|17|5) via (3|2|1) = 13 (104), label =(((14)|1))", 
   "\n From 19=(1|3|17|11) via (3|2|9|8|1) = 20 (139), label =(((11)|1))"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.674149533028758*^9, 3.674149613295639*^9, {3.67422875015836*^9, 
   3.6742287793379374`*^9}, 3.674268636201438*^9, {3.674268790888933*^9, 
   3.674268812213994*^9}, 3.674269108319046*^9, 3.674276555521348*^9, 
   3.674278431214143*^9, 3.674279561803392*^9, 3.675240304731463*^9, 
   3.67524055059062*^9, 3.675242328123254*^9, 3.67524519978808*^9, {
   3.675245270088979*^9, 3.6752452952635193`*^9}, {3.6752455965712852`*^9, 
   3.675245614489789*^9}, 3.675272485838872*^9, {3.675272601160602*^9, 
   3.67527271885688*^9}, 3.675272793273382*^9, 3.675272846678245*^9, 
   3.675503699806039*^9, {3.675507867971129*^9, 3.6755078958091373`*^9}, 
   3.67550935516679*^9, 3.675509425533766*^9, {3.6759354173925447`*^9, 
   3.67593542778658*^9}, 3.675935534043977*^9, {3.6759356389280024`*^9, 
   3.6759356598173847`*^9}, {3.675935749004092*^9, 3.6759357720758543`*^9}, 
   3.6759421296376123`*^9, 3.675958787663187*^9, 3.675962599266767*^9, 
   3.6760054406677027`*^9, 3.676389732279505*^9, {3.67644174352247*^9, 
   3.676441751092914*^9}, 3.676475067922023*^9, 3.677558347572921*^9, 
   3.6789371436314898`*^9, 3.6789382478871098`*^9, 3.683896779420425*^9, 
   3.683896904192246*^9, 3.6838969947649813`*^9, 3.6838992605164824`*^9, 
   3.683899622598269*^9, 3.683899819133437*^9, 3.683906280399602*^9, 
   3.6839068019023046`*^9, 3.683949355652266*^9, 3.6839498914696693`*^9, 
   3.683952408955373*^9, 3.683958936989856*^9, 3.6851944185927553`*^9, 
   3.685194582335441*^9, 3.6852590806499767`*^9, 3.685706267130395*^9, 
   3.685711755200629*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Initial cancellation (de-niceification)", "Section",
 CellChangeTimes->{{3.683902406280332*^9, 3.683902411992662*^9}, {
  3.6839024516165123`*^9, 3.683902475521956*^9}, {3.683902509419033*^9, 
  3.6839025833159637`*^9}, {3.683902614317812*^9, 3.683902621444993*^9}, {
  3.6839026606787653`*^9, 3.683902706656199*^9}, {3.683902768385414*^9, 
  3.6839028035945807`*^9}}],

Cell[BoxData[
 RowBox[{"Step4CancellationPreparation", ";"}]], "Input",
 CellChangeTimes->{{3.6838972567262897`*^9, 3.6838972613485126`*^9}, 
   3.685194519470417*^9, {3.68524888962287*^9, 3.685248890046817*^9}}],

Cell["\<\
The next step can take quite a while for large diagrams. Consider using a \
computer with a single fast kernel to speed up, as no parallel evaluation is \
possible.\
\>", "Text",
 CellChangeTimes->{{3.683904487701765*^9, 3.683904540055222*^9}, {
  3.683906443512352*^9, 3.6839064977306423`*^9}, {3.683907404281674*^9, 
  3.683907411497081*^9}, {3.683907443442786*^9, 3.683907445257428*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"BackToStart", "=", 
   RowBox[{"CancellationSparse", "[", 
    RowBox[{"StructureMapsSparse", ",", "generators"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MMit", "=", 
   RowBox[{"BackToStart", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"generatorsit", "=", 
    RowBox[{"BackToStart", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", "backup", " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{
    RowBox[{"BackupFilePath", "<>", "\"\<_AfterCancellation.mx\>\""}], ",", 
    "\"\<Global`\>\""}], "]"}], ";", 
  RowBox[{"Print", "[", 
   RowBox[{"\"\< << backup saved at: \>\"", " ", ",", 
    RowBox[{"BackupFilePath", "<>", "\"\<_AfterCancellation.mx >>\>\""}]}], 
   "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.675529652739524*^9, 3.675529692839591*^9}, {
   3.675533781109782*^9, 3.675533788559823*^9}, {3.6755339029195147`*^9, 
   3.6755339057155733`*^9}, {3.675534517304041*^9, 3.67553451981328*^9}, {
   3.6755354813960943`*^9, 3.6755354971737413`*^9}, {3.675535640875539*^9, 
   3.6755356519778547`*^9}, {3.6755359652661943`*^9, 3.675535976345201*^9}, {
   3.6755360643622417`*^9, 3.675536064611867*^9}, {3.6755361393965387`*^9, 
   3.6755361396533003`*^9}, {3.6755709179569883`*^9, 3.675570929236774*^9}, {
   3.675571665947143*^9, 3.675571678890936*^9}, 3.675571917736599*^9, {
   3.675571979826198*^9, 3.6755720109772253`*^9}, 3.675573257411477*^9, {
   3.675574565159875*^9, 3.6755745664054403`*^9}, {3.6755823477349453`*^9, 
   3.6755823483031054`*^9}, {3.6755900229971848`*^9, 3.675590024322789*^9}, {
   3.675595572936466*^9, 3.675595573174676*^9}, {3.675599437786158*^9, 
   3.6755994407980137`*^9}, {3.675682262423912*^9, 3.675682263327428*^9}, {
   3.675683187529191*^9, 3.675683212504593*^9}, {3.6756905066294813`*^9, 
   3.6756905090293922`*^9}, {3.675865338794071*^9, 3.6758653399670467`*^9}, {
   3.675867831309825*^9, 3.675867832071665*^9}, {3.675936856885241*^9, 
   3.675936857843165*^9}, 3.675942144804379*^9, {3.6851946075638866`*^9, 
   3.6851946736934967`*^9}, {3.6851958500589848`*^9, 3.685195851450302*^9}, {
   3.6856928016572037`*^9, 3.68569280207942*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 TemplateBox[{RowBox[{"\"17:50:17\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", "1.`"}], FontColor -> 
      GrayLevel[0.5]]}],RowBox[{"TimeObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"17", ",", "50", ",", "17.334792`"}], "}"}], ",", 
       RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}]},
  "TimeObject",
  Editable->False]], "Print",
 CellChangeTimes->{{3.675572006401083*^9, 3.6755720142676477`*^9}, {
   3.6755724810671797`*^9, 3.6755725163027477`*^9}, {3.6755726014468203`*^9, 
   3.6755726042007113`*^9}, 3.675572832423069*^9, {3.6755731727076263`*^9, 
   3.675573260843977*^9}, 3.675573532159712*^9, {3.675573721837899*^9, 
   3.675573752056282*^9}, {3.675573782652417*^9, 3.6755738066460943`*^9}, {
   3.675573898552917*^9, 3.6755739274110928`*^9}, {3.675574004200198*^9, 
   3.675574008538425*^9}, 3.675574053034545*^9, {3.675574280711363*^9, 
   3.675574297288308*^9}, 3.675574462790161*^9, 3.675574586089883*^9, 
   3.675574637476365*^9, 3.675574839226425*^9, {3.675574890495219*^9, 
   3.675574899961628*^9}, {3.6755750577441473`*^9, 3.6755750653479033`*^9}, {
   3.67557536517969*^9, 3.675575374622838*^9}, 3.67558241864917*^9, 
   3.675595561804577*^9, 3.675595598189539*^9, 3.675596941501546*^9, {
   3.6755969799136963`*^9, 3.675596981891532*^9}, {3.6755985390385427`*^9, 
   3.6755985603346*^9}, 3.675598655784644*^9, 3.675598710761747*^9, 
   3.675598772277358*^9, 3.675598982611813*^9, 3.6755990365712214`*^9, 
   3.675599124714926*^9, 3.675599190525057*^9, 3.6755992265054293`*^9, 
   3.6755993517965727`*^9, 3.675599384154059*^9, 3.675599441691959*^9, 
   3.6755995793084993`*^9, 3.675600493810341*^9, 3.675601419908771*^9, 
   3.6756020555122337`*^9, 3.6756023632210083`*^9, 3.675602807876725*^9, 
   3.675602897602737*^9, {3.6756033421530533`*^9, 3.675603380919065*^9}, 
   3.675613375417395*^9, 3.675613494839464*^9, 3.675656390071207*^9, 
   3.6756832342389383`*^9, 3.675683357975985*^9, 3.675857704474587*^9, 
   3.675862632474606*^9, 3.6758648822207727`*^9, 3.675865049216236*^9, 
   3.67586513788349*^9, {3.675865233131024*^9, 3.675865257251742*^9}, {
   3.6758653420784893`*^9, 3.675865356836982*^9}, 3.6758656228927298`*^9, 
   3.675865747362034*^9, {3.675865818783901*^9, 3.675865835891333*^9}, {
   3.6758658670111237`*^9, 3.675865896860029*^9}, 3.675865958760379*^9, 
   3.6758676158396473`*^9, {3.675867824560811*^9, 3.675867834230739*^9}, {
   3.675936848949038*^9, 3.675936860094269*^9}, 3.675942150157858*^9, 
   3.6759589153553867`*^9, 3.675959692249486*^9, 3.675959749337008*^9, 
   3.675959793505755*^9, {3.675962726520094*^9, 3.675962732940042*^9}, 
   3.6759631992326183`*^9, 3.676005076509894*^9, 3.6760054510397987`*^9, 
   3.6760922799521914`*^9, 3.676145031860186*^9, 3.67752770975972*^9, 
   3.6781944003152027`*^9, 3.678938324033092*^9, 3.678938762397016*^9, 
   3.678938841034732*^9, 3.678938888097413*^9, 3.679373237470869*^9, 
   3.679379242564719*^9, 3.679379516825293*^9, 3.679381106126199*^9, 
   3.679381156825899*^9, 3.6793821749785*^9, 3.6793823448314533`*^9, 
   3.679382425135206*^9, 3.683899292519908*^9, 3.683899851402754*^9, 
   3.6839027549793243`*^9, 3.683906415792178*^9, 3.683906819144183*^9, 
   3.683949372390581*^9, 3.6839498985827827`*^9, 3.6839524145676823`*^9, 
   3.683958943103503*^9, 3.6851945867973022`*^9, 3.685194616981819*^9, 
   3.68519478292586*^9, 3.685195855352476*^9, 3.685195900536501*^9, 
   3.685195987695903*^9, 3.685249178033299*^9, 3.685259097524781*^9, 
   3.685706272015841*^9, 3.685711817356892*^9}],

Cell[BoxData["\<\"Finished calculation after 8 iterations.\"\>"], "Print",
 CellChangeTimes->{{3.675572006401083*^9, 3.6755720142676477`*^9}, {
   3.6755724810671797`*^9, 3.6755725163027477`*^9}, {3.6755726014468203`*^9, 
   3.6755726042007113`*^9}, 3.675572832423069*^9, {3.6755731727076263`*^9, 
   3.675573260843977*^9}, 3.675573532159712*^9, {3.675573721837899*^9, 
   3.675573752056282*^9}, {3.675573782652417*^9, 3.6755738066460943`*^9}, {
   3.675573898552917*^9, 3.6755739274110928`*^9}, {3.675574004200198*^9, 
   3.675574008538425*^9}, 3.675574053034545*^9, {3.675574280711363*^9, 
   3.675574297288308*^9}, 3.675574462790161*^9, 3.675574586089883*^9, 
   3.675574637476365*^9, 3.675574839226425*^9, {3.675574890495219*^9, 
   3.675574899961628*^9}, {3.6755750577441473`*^9, 3.6755750653479033`*^9}, {
   3.67557536517969*^9, 3.675575374622838*^9}, 3.67558241864917*^9, 
   3.675595561804577*^9, 3.675595598189539*^9, 3.675596941501546*^9, {
   3.6755969799136963`*^9, 3.675596981891532*^9}, {3.6755985390385427`*^9, 
   3.6755985603346*^9}, 3.675598655784644*^9, 3.675598710761747*^9, 
   3.675598772277358*^9, 3.675598982611813*^9, 3.6755990365712214`*^9, 
   3.675599124714926*^9, 3.675599190525057*^9, 3.6755992265054293`*^9, 
   3.6755993517965727`*^9, 3.675599384154059*^9, 3.675599441691959*^9, 
   3.6755995793084993`*^9, 3.675600493810341*^9, 3.675601419908771*^9, 
   3.6756020555122337`*^9, 3.6756023632210083`*^9, 3.675602807876725*^9, 
   3.675602897602737*^9, {3.6756033421530533`*^9, 3.675603380919065*^9}, 
   3.675613375417395*^9, 3.675613494839464*^9, 3.675656390071207*^9, 
   3.6756832342389383`*^9, 3.675683357975985*^9, 3.675857704474587*^9, 
   3.675862632474606*^9, 3.6758648822207727`*^9, 3.675865049216236*^9, 
   3.67586513788349*^9, {3.675865233131024*^9, 3.675865257251742*^9}, {
   3.6758653420784893`*^9, 3.675865356836982*^9}, 3.6758656228927298`*^9, 
   3.675865747362034*^9, {3.675865818783901*^9, 3.675865835891333*^9}, {
   3.6758658670111237`*^9, 3.675865896860029*^9}, 3.675865958760379*^9, 
   3.6758676158396473`*^9, {3.675867824560811*^9, 3.675867834230739*^9}, {
   3.675936848949038*^9, 3.675936860094269*^9}, 3.675942150157858*^9, 
   3.6759589153553867`*^9, 3.675959692249486*^9, 3.675959749337008*^9, 
   3.675959793505755*^9, {3.675962726520094*^9, 3.675962732940042*^9}, 
   3.6759631992326183`*^9, 3.676005076509894*^9, 3.6760054510397987`*^9, 
   3.6760922799521914`*^9, 3.676145031860186*^9, 3.67752770975972*^9, 
   3.6781944003152027`*^9, 3.678938324033092*^9, 3.678938762397016*^9, 
   3.678938841034732*^9, 3.678938888097413*^9, 3.679373237470869*^9, 
   3.679379242564719*^9, 3.679379516825293*^9, 3.679381106126199*^9, 
   3.679381156825899*^9, 3.6793821749785*^9, 3.6793823448314533`*^9, 
   3.679382425135206*^9, 3.683899292519908*^9, 3.683899851402754*^9, 
   3.6839027549793243`*^9, 3.683906415792178*^9, 3.683906819144183*^9, 
   3.683949372390581*^9, 3.6839498985827827`*^9, 3.6839524145676823`*^9, 
   3.683958943103503*^9, 3.6851945867973022`*^9, 3.685194616981819*^9, 
   3.68519478292586*^9, 3.685195855352476*^9, 3.685195900536501*^9, 
   3.685195987695903*^9, 3.685249178033299*^9, 3.685259097524781*^9, 
   3.685706272015841*^9, 3.685711817433503*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There are \"\>", "\[InvisibleSpace]", "12", 
   "\[InvisibleSpace]", "\<\" generators left.\"\>"}],
  SequenceForm["There are ", 12, " generators left."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.675572006401083*^9, 3.6755720142676477`*^9}, {
   3.6755724810671797`*^9, 3.6755725163027477`*^9}, {3.6755726014468203`*^9, 
   3.6755726042007113`*^9}, 3.675572832423069*^9, {3.6755731727076263`*^9, 
   3.675573260843977*^9}, 3.675573532159712*^9, {3.675573721837899*^9, 
   3.675573752056282*^9}, {3.675573782652417*^9, 3.6755738066460943`*^9}, {
   3.675573898552917*^9, 3.6755739274110928`*^9}, {3.675574004200198*^9, 
   3.675574008538425*^9}, 3.675574053034545*^9, {3.675574280711363*^9, 
   3.675574297288308*^9}, 3.675574462790161*^9, 3.675574586089883*^9, 
   3.675574637476365*^9, 3.675574839226425*^9, {3.675574890495219*^9, 
   3.675574899961628*^9}, {3.6755750577441473`*^9, 3.6755750653479033`*^9}, {
   3.67557536517969*^9, 3.675575374622838*^9}, 3.67558241864917*^9, 
   3.675595561804577*^9, 3.675595598189539*^9, 3.675596941501546*^9, {
   3.6755969799136963`*^9, 3.675596981891532*^9}, {3.6755985390385427`*^9, 
   3.6755985603346*^9}, 3.675598655784644*^9, 3.675598710761747*^9, 
   3.675598772277358*^9, 3.675598982611813*^9, 3.6755990365712214`*^9, 
   3.675599124714926*^9, 3.675599190525057*^9, 3.6755992265054293`*^9, 
   3.6755993517965727`*^9, 3.675599384154059*^9, 3.675599441691959*^9, 
   3.6755995793084993`*^9, 3.675600493810341*^9, 3.675601419908771*^9, 
   3.6756020555122337`*^9, 3.6756023632210083`*^9, 3.675602807876725*^9, 
   3.675602897602737*^9, {3.6756033421530533`*^9, 3.675603380919065*^9}, 
   3.675613375417395*^9, 3.675613494839464*^9, 3.675656390071207*^9, 
   3.6756832342389383`*^9, 3.675683357975985*^9, 3.675857704474587*^9, 
   3.675862632474606*^9, 3.6758648822207727`*^9, 3.675865049216236*^9, 
   3.67586513788349*^9, {3.675865233131024*^9, 3.675865257251742*^9}, {
   3.6758653420784893`*^9, 3.675865356836982*^9}, 3.6758656228927298`*^9, 
   3.675865747362034*^9, {3.675865818783901*^9, 3.675865835891333*^9}, {
   3.6758658670111237`*^9, 3.675865896860029*^9}, 3.675865958760379*^9, 
   3.6758676158396473`*^9, {3.675867824560811*^9, 3.675867834230739*^9}, {
   3.675936848949038*^9, 3.675936860094269*^9}, 3.675942150157858*^9, 
   3.6759589153553867`*^9, 3.675959692249486*^9, 3.675959749337008*^9, 
   3.675959793505755*^9, {3.675962726520094*^9, 3.675962732940042*^9}, 
   3.6759631992326183`*^9, 3.676005076509894*^9, 3.6760054510397987`*^9, 
   3.6760922799521914`*^9, 3.676145031860186*^9, 3.67752770975972*^9, 
   3.6781944003152027`*^9, 3.678938324033092*^9, 3.678938762397016*^9, 
   3.678938841034732*^9, 3.678938888097413*^9, 3.679373237470869*^9, 
   3.679379242564719*^9, 3.679379516825293*^9, 3.679381106126199*^9, 
   3.679381156825899*^9, 3.6793821749785*^9, 3.6793823448314533`*^9, 
   3.679382425135206*^9, 3.683899292519908*^9, 3.683899851402754*^9, 
   3.6839027549793243`*^9, 3.683906415792178*^9, 3.683906819144183*^9, 
   3.683949372390581*^9, 3.6839498985827827`*^9, 3.6839524145676823`*^9, 
   3.683958943103503*^9, 3.6851945867973022`*^9, 3.685194616981819*^9, 
   3.68519478292586*^9, 3.685195855352476*^9, 3.685195900536501*^9, 
   3.685195987695903*^9, 3.685249178033299*^9, 3.685259097524781*^9, 
   3.685706272015841*^9, 3.68571181743423*^9}],

Cell[BoxData[
 TemplateBox[{RowBox[{"\"17:50:17\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", "1.`"}], FontColor -> 
      GrayLevel[0.5]]}],RowBox[{"TimeObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"17", ",", "50", ",", "17.425519`"}], "}"}], ",", 
       RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}]},
  "TimeObject",
  Editable->False]], "Print",
 CellChangeTimes->{{3.675572006401083*^9, 3.6755720142676477`*^9}, {
   3.6755724810671797`*^9, 3.6755725163027477`*^9}, {3.6755726014468203`*^9, 
   3.6755726042007113`*^9}, 3.675572832423069*^9, {3.6755731727076263`*^9, 
   3.675573260843977*^9}, 3.675573532159712*^9, {3.675573721837899*^9, 
   3.675573752056282*^9}, {3.675573782652417*^9, 3.6755738066460943`*^9}, {
   3.675573898552917*^9, 3.6755739274110928`*^9}, {3.675574004200198*^9, 
   3.675574008538425*^9}, 3.675574053034545*^9, {3.675574280711363*^9, 
   3.675574297288308*^9}, 3.675574462790161*^9, 3.675574586089883*^9, 
   3.675574637476365*^9, 3.675574839226425*^9, {3.675574890495219*^9, 
   3.675574899961628*^9}, {3.6755750577441473`*^9, 3.6755750653479033`*^9}, {
   3.67557536517969*^9, 3.675575374622838*^9}, 3.67558241864917*^9, 
   3.675595561804577*^9, 3.675595598189539*^9, 3.675596941501546*^9, {
   3.6755969799136963`*^9, 3.675596981891532*^9}, {3.6755985390385427`*^9, 
   3.6755985603346*^9}, 3.675598655784644*^9, 3.675598710761747*^9, 
   3.675598772277358*^9, 3.675598982611813*^9, 3.6755990365712214`*^9, 
   3.675599124714926*^9, 3.675599190525057*^9, 3.6755992265054293`*^9, 
   3.6755993517965727`*^9, 3.675599384154059*^9, 3.675599441691959*^9, 
   3.6755995793084993`*^9, 3.675600493810341*^9, 3.675601419908771*^9, 
   3.6756020555122337`*^9, 3.6756023632210083`*^9, 3.675602807876725*^9, 
   3.675602897602737*^9, {3.6756033421530533`*^9, 3.675603380919065*^9}, 
   3.675613375417395*^9, 3.675613494839464*^9, 3.675656390071207*^9, 
   3.6756832342389383`*^9, 3.675683357975985*^9, 3.675857704474587*^9, 
   3.675862632474606*^9, 3.6758648822207727`*^9, 3.675865049216236*^9, 
   3.67586513788349*^9, {3.675865233131024*^9, 3.675865257251742*^9}, {
   3.6758653420784893`*^9, 3.675865356836982*^9}, 3.6758656228927298`*^9, 
   3.675865747362034*^9, {3.675865818783901*^9, 3.675865835891333*^9}, {
   3.6758658670111237`*^9, 3.675865896860029*^9}, 3.675865958760379*^9, 
   3.6758676158396473`*^9, {3.675867824560811*^9, 3.675867834230739*^9}, {
   3.675936848949038*^9, 3.675936860094269*^9}, 3.675942150157858*^9, 
   3.6759589153553867`*^9, 3.675959692249486*^9, 3.675959749337008*^9, 
   3.675959793505755*^9, {3.675962726520094*^9, 3.675962732940042*^9}, 
   3.6759631992326183`*^9, 3.676005076509894*^9, 3.6760054510397987`*^9, 
   3.6760922799521914`*^9, 3.676145031860186*^9, 3.67752770975972*^9, 
   3.6781944003152027`*^9, 3.678938324033092*^9, 3.678938762397016*^9, 
   3.678938841034732*^9, 3.678938888097413*^9, 3.679373237470869*^9, 
   3.679379242564719*^9, 3.679379516825293*^9, 3.679381106126199*^9, 
   3.679381156825899*^9, 3.6793821749785*^9, 3.6793823448314533`*^9, 
   3.679382425135206*^9, 3.683899292519908*^9, 3.683899851402754*^9, 
   3.6839027549793243`*^9, 3.683906415792178*^9, 3.683906819144183*^9, 
   3.683949372390581*^9, 3.6839498985827827`*^9, 3.6839524145676823`*^9, 
   3.683958943103503*^9, 3.6851945867973022`*^9, 3.685194616981819*^9, 
   3.68519478292586*^9, 3.685195855352476*^9, 3.685195900536501*^9, 
   3.685195987695903*^9, 3.685249178033299*^9, 3.685259097524781*^9, 
   3.685706272015841*^9, 3.685711817436151*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\" << backup saved at: \"\>", 
   "\[InvisibleSpace]", \
"\<\"/mhome/dpmms/c/cbz20/Documents/PhD/Research/thesis/BSFH/Backups/\
ClosureBSAx2_AfterCancellation.mx >>\"\>"}],
  SequenceForm[
  " << backup saved at: ", 
   "/mhome/dpmms/c/cbz20/Documents/PhD/Research/thesis/BSFH/Backups/\
ClosureBSAx2_AfterCancellation.mx >>"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.675572006401083*^9, 3.6755720142676477`*^9}, {
   3.6755724810671797`*^9, 3.6755725163027477`*^9}, {3.6755726014468203`*^9, 
   3.6755726042007113`*^9}, 3.675572832423069*^9, {3.6755731727076263`*^9, 
   3.675573260843977*^9}, 3.675573532159712*^9, {3.675573721837899*^9, 
   3.675573752056282*^9}, {3.675573782652417*^9, 3.6755738066460943`*^9}, {
   3.675573898552917*^9, 3.6755739274110928`*^9}, {3.675574004200198*^9, 
   3.675574008538425*^9}, 3.675574053034545*^9, {3.675574280711363*^9, 
   3.675574297288308*^9}, 3.675574462790161*^9, 3.675574586089883*^9, 
   3.675574637476365*^9, 3.675574839226425*^9, {3.675574890495219*^9, 
   3.675574899961628*^9}, {3.6755750577441473`*^9, 3.6755750653479033`*^9}, {
   3.67557536517969*^9, 3.675575374622838*^9}, 3.67558241864917*^9, 
   3.675595561804577*^9, 3.675595598189539*^9, 3.675596941501546*^9, {
   3.6755969799136963`*^9, 3.675596981891532*^9}, {3.6755985390385427`*^9, 
   3.6755985603346*^9}, 3.675598655784644*^9, 3.675598710761747*^9, 
   3.675598772277358*^9, 3.675598982611813*^9, 3.6755990365712214`*^9, 
   3.675599124714926*^9, 3.675599190525057*^9, 3.6755992265054293`*^9, 
   3.6755993517965727`*^9, 3.675599384154059*^9, 3.675599441691959*^9, 
   3.6755995793084993`*^9, 3.675600493810341*^9, 3.675601419908771*^9, 
   3.6756020555122337`*^9, 3.6756023632210083`*^9, 3.675602807876725*^9, 
   3.675602897602737*^9, {3.6756033421530533`*^9, 3.675603380919065*^9}, 
   3.675613375417395*^9, 3.675613494839464*^9, 3.675656390071207*^9, 
   3.6756832342389383`*^9, 3.675683357975985*^9, 3.675857704474587*^9, 
   3.675862632474606*^9, 3.6758648822207727`*^9, 3.675865049216236*^9, 
   3.67586513788349*^9, {3.675865233131024*^9, 3.675865257251742*^9}, {
   3.6758653420784893`*^9, 3.675865356836982*^9}, 3.6758656228927298`*^9, 
   3.675865747362034*^9, {3.675865818783901*^9, 3.675865835891333*^9}, {
   3.6758658670111237`*^9, 3.675865896860029*^9}, 3.675865958760379*^9, 
   3.6758676158396473`*^9, {3.675867824560811*^9, 3.675867834230739*^9}, {
   3.675936848949038*^9, 3.675936860094269*^9}, 3.675942150157858*^9, 
   3.6759589153553867`*^9, 3.675959692249486*^9, 3.675959749337008*^9, 
   3.675959793505755*^9, {3.675962726520094*^9, 3.675962732940042*^9}, 
   3.6759631992326183`*^9, 3.676005076509894*^9, 3.6760054510397987`*^9, 
   3.6760922799521914`*^9, 3.676145031860186*^9, 3.67752770975972*^9, 
   3.6781944003152027`*^9, 3.678938324033092*^9, 3.678938762397016*^9, 
   3.678938841034732*^9, 3.678938888097413*^9, 3.679373237470869*^9, 
   3.679379242564719*^9, 3.679379516825293*^9, 3.679381106126199*^9, 
   3.679381156825899*^9, 3.6793821749785*^9, 3.6793823448314533`*^9, 
   3.679382425135206*^9, 3.683899292519908*^9, 3.683899851402754*^9, 
   3.6839027549793243`*^9, 3.683906415792178*^9, 3.683906819144183*^9, 
   3.683949372390581*^9, 3.6839498985827827`*^9, 3.6839524145676823`*^9, 
   3.683958943103503*^9, 3.6851945867973022`*^9, 3.685194616981819*^9, 
   3.68519478292586*^9, 3.685195855352476*^9, 3.685195900536501*^9, 
   3.685195987695903*^9, 3.685249178033299*^9, 3.685259097524781*^9, 
   3.685706272015841*^9, 3.68571181746557*^9}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"<<", 
   RowBox[{"(", 
    RowBox[{"BackupFilePath", "<>", "\"\<_AfterCancellation.mx\>\""}], 
    ")"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.675682414716271*^9, 3.675682416691991*^9}, 
   3.675683195825262*^9, {3.675747922268229*^9, 3.675747929553258*^9}, {
   3.676175514307502*^9, 3.676175515721424*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Post-processing: Further cancellations and homotopies", "Section",
 CellChangeTimes->{{3.683902406280332*^9, 3.683902411992662*^9}, {
  3.6839024516165123`*^9, 3.683902475521956*^9}, {3.683902509419033*^9, 
  3.6839025833159637`*^9}, {3.683902614317812*^9, 3.683902621444993*^9}, {
  3.6839026606787653`*^9, 3.683902706656199*^9}, {3.683902768385414*^9, 
  3.6839028035945807`*^9}, {3.683906361254035*^9, 3.683906397535213*^9}}],

Cell[BoxData[
 RowBox[{"Step5PostProcessing", ";"}]], "Input",
 CellChangeTimes->{
  3.683897532395102*^9, {3.6839058148344393`*^9, 3.683905815122682*^9}, {
   3.683905991192045*^9, 3.6839059922611847`*^9}, {3.685194541520829*^9, 
   3.685194543848864*^9}, {3.685248894086935*^9, 3.6852488943255787`*^9}, {
   3.685693093120482*^9, 3.685693117431604*^9}, {3.685695524119947*^9, 
   3.685695530703979*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"PlotGraph", "[", "MMit", "]"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"GenTableWithIdems", "[", "gens_", "]"}], " ", "displays", " ", 
     "a", " ", "list", " ", "of", " ", "idempotents", " ", "and", " ", 
     "their", " ", "generators"}], ";"}], "\[IndentingNewLine]", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"GenTableWithIdems", "[", "generatorsit", "]"}]}], "Input",
 CellChangeTimes->{{3.6761773820432796`*^9, 3.676177384954527*^9}, 
   3.676177617306233*^9, 3.6761786321171417`*^9, {3.6839495373610287`*^9, 
   3.683949538281969*^9}, {3.685693132401354*^9, 3.6856931784270372`*^9}, {
   3.6856955535368137`*^9, 3.6856955843935833`*^9}, {3.685697559716579*^9, 
   3.685697559947776*^9}, 3.685706283228877*^9}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDggWIQGxV8sMcQwir+wh47Tao5g02c1v4aKuFGqjuppX6w
hc9AhQO11FNLfLC584E9dppa5uMSHyrlAy5zqBVugy0cyHUPOhhs+ZfW5Sqp
9AUc9FAJB1zqqSU+2OqvgRIfDQcIGCrpltbio+GASxwAr48FkA==
   "], {{0, 0}, {12, 12}}, {0, 1}],
  Frame->Automatic,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
    Automatic}]], "Print",
 CellChangeTimes->{{3.685706277430007*^9, 3.685706283816469*^9}, 
   3.685711824375615*^9, 3.685712345087315*^9, 3.685712558558536*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"{", 
       RowBox[{"\<\"b\"\>", ",", "\<\"x\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "9", ",", 
        "10"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"a\"\>", ",", "\<\"x\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{"7", ",", "8", ",", "11", ",", "12"}], "}"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.685706283820657*^9, 3.6857118243768883`*^9, 
  3.68571234512143*^9, 3.685712558590065*^9}]
}, Open  ]],

Cell["\<\
Evaluate the next function only if the result above is reasonably small, i.e. \
if it has fewer than 50 generators, say. Otherwise, this can take quite a \
while and might use a lot of memory.\
\>", "Text",
 CellChangeTimes->{{3.683904487701765*^9, 3.683904540055222*^9}, {
  3.683906511938468*^9, 3.68390661591635*^9}, {3.6839074670110493`*^9, 
  3.683907472234708*^9}, {3.685256305636306*^9, 3.685256306532284*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"SANITY", " ", "CHECK"}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"AInftyQ", "[", "mat_", "]"}], " ", "checks", " ", "that", " ", 
      "the", " ", "structure", " ", 
      RowBox[{"map", " ", "'"}], 
      RowBox[{"mat", "'"}], " ", "satisfy", " ", 
      RowBox[{"\"\<D^2=0\>\"", ".", " ", "If"}], " ", "it", " ", "does", " ", 
      "not", " ", 
      RowBox[{"return", " ", "'"}], 
      RowBox[{"True", "'"}]}]}], ",", " ", 
    RowBox[{
     RowBox[{"something", " ", "went", " ", "wrong"}], ";"}]}], 
   "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"AInftyQ", "[", "MMit", "]"}]}]], "Input",
 CellChangeTimes->{{3.683906626525436*^9, 3.683906629868657*^9}, {
  3.6839068283227663`*^9, 3.683906828467052*^9}, {3.6839513252538433`*^9, 
  3.683951325939283*^9}, {3.685194797671068*^9, 3.685194797799234*^9}, {
  3.685196004810017*^9, 3.685196039684505*^9}, {3.685196143798833*^9, 
  3.685196196664261*^9}, {3.685196239041091*^9, 3.68519625860972*^9}, {
  3.6851963564678707`*^9, 3.6851965517146797`*^9}, {3.68525768917494*^9, 
  3.685257706608857*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.685196552085421*^9, 3.685259122716757*^9, 
  3.685706298226635*^9, 3.685711827449998*^9, 3.68571234877267*^9, 
  3.68571256206706*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"CarefulCancel1", "=", 
   RowBox[{"CarefulCancellation", "[", 
    RowBox[{"MMit", ",", "generatorsit"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MM1", "=", 
   RowBox[{"CarefulCancel1", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GG1", "=", 
   RowBox[{"CarefulCancel1", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.6761752543259783`*^9, 3.676175337459744*^9}, {
   3.676175408702016*^9, 3.6761754091734247`*^9}, {3.6761754586476603`*^9, 
   3.676175483863119*^9}, {3.6761756365504932`*^9, 3.6761756366932783`*^9}, {
   3.676181697923071*^9, 3.67618170080893*^9}, {3.676181786491774*^9, 
   3.676181803043103*^9}, {3.676181845699214*^9, 3.676181850899927*^9}, {
   3.6761819942660027`*^9, 3.676182005800435*^9}, {3.676182125581752*^9, 
   3.676182180341146*^9}, {3.678365601919386*^9, 3.678365642786083*^9}, {
   3.679100821763163*^9, 3.67910105888132*^9}, 3.679101231862932*^9, {
   3.6793734417653027`*^9, 3.679373463948657*^9}, {3.6793812277833776`*^9, 
   3.679381285144319*^9}, {3.679381341196933*^9, 3.679381343026075*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 TemplateBox[{RowBox[{"\"18:02:43\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", "1.`"}], FontColor -> 
      GrayLevel[0.5]]}],RowBox[{"TimeObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"18", ",", "2", ",", "43.365666`"}], "}"}], ",", 
       RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}]},
  "TimeObject",
  Editable->False]], "Print",
 CellChangeTimes->{{3.676175630167898*^9, 3.6761756432051477`*^9}, 
   3.676177633238863*^9, 3.676181718282309*^9, 3.676181805218286*^9, 
   3.676181851823415*^9, 3.676182006495245*^9, 3.676182181420231*^9, 
   3.676221922288815*^9, 3.6762219998584948`*^9, 3.676259911566552*^9, 
   3.676347690195682*^9, 3.676365991397257*^9, 3.6763879252666597`*^9, 
   3.676392629800563*^9, 3.676440169293993*^9, 3.676473474391552*^9, 
   3.677558391444075*^9, 3.67755939315864*^9, 3.677561474804204*^9, {
   3.678365630463592*^9, 3.678365643154956*^9}, 3.678438841809287*^9, 
   3.67910106886849*^9, 3.679101233304977*^9, {3.679228828213192*^9, 
   3.679228845187958*^9}, 3.6792292430359297`*^9, 3.679235213978156*^9, 
   3.679373465879586*^9, 3.679379276205572*^9, 3.679379653711396*^9, 
   3.679381175254533*^9, 3.679381220446678*^9, {3.679381278310419*^9, 
   3.679381286237536*^9}, 3.679381363721024*^9, 3.679382113895825*^9, 
   3.6793821789474087`*^9, {3.679382351073333*^9, 3.6793823563180857`*^9}, 
   3.679382428774447*^9, 3.6839008031636467`*^9, 3.683906842872005*^9, {
   3.683907938656304*^9, 3.683907945517867*^9}, 3.6839496031815987`*^9, 
   3.683949916694581*^9, 3.683952428309697*^9, 3.6839589662501383`*^9, 
   3.684043336180006*^9, 3.684043390906584*^9, 3.685196556483519*^9, 
   3.685257710349473*^9, 3.6852591238576803`*^9, 3.685706310640483*^9, 
   3.685711829094784*^9, 3.6857123501278343`*^9, 3.685712563375325*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {"\<\"Finished calculation\"\>"},
      {"\<\"after 2 iterations.\"\>"},
      {
       GraphicsBox[RasterBox[CompressedData["
1:eJxTTMoPSmVmYGDggGIQe9ZMEHhpj04zoIAPaHz6i5PqzoHyF23sxQWoHz7G
YPAYgyZVPWX+pX544jKHWv6itTuJM4cwIDUcqBVuQyX/kio+VNyJSxwATeNZ
QA==
         "], {{0, 0}, {8, 8}}, {0, 1}],
        Frame->Automatic,
        FrameLabel->{None, None},
        FrameTicks->{{None, None}, {None, None}},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
          Automatic}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{{3.676175630167898*^9, 3.6761756432051477`*^9}, 
   3.676177633238863*^9, 3.676181718282309*^9, 3.676181805218286*^9, 
   3.676181851823415*^9, 3.676182006495245*^9, 3.676182181420231*^9, 
   3.676221922288815*^9, 3.6762219998584948`*^9, 3.676259911566552*^9, 
   3.676347690195682*^9, 3.676365991397257*^9, 3.6763879252666597`*^9, 
   3.676392629800563*^9, 3.676440169293993*^9, 3.676473474391552*^9, 
   3.677558391444075*^9, 3.67755939315864*^9, 3.677561474804204*^9, {
   3.678365630463592*^9, 3.678365643154956*^9}, 3.678438841809287*^9, 
   3.67910106886849*^9, 3.679101233304977*^9, {3.679228828213192*^9, 
   3.679228845187958*^9}, 3.6792292430359297`*^9, 3.679235213978156*^9, 
   3.679373465879586*^9, 3.679379276205572*^9, 3.679379653711396*^9, 
   3.679381175254533*^9, 3.679381220446678*^9, {3.679381278310419*^9, 
   3.679381286237536*^9}, 3.679381363721024*^9, 3.679382113895825*^9, 
   3.6793821789474087`*^9, {3.679382351073333*^9, 3.6793823563180857`*^9}, 
   3.679382428774447*^9, 3.6839008031636467`*^9, 3.683906842872005*^9, {
   3.683907938656304*^9, 3.683907945517867*^9}, 3.6839496031815987`*^9, 
   3.683949916694581*^9, 3.683952428309697*^9, 3.6839589662501383`*^9, 
   3.684043336180006*^9, 3.684043390906584*^9, 3.685196556483519*^9, 
   3.685257710349473*^9, 3.6852591238576803`*^9, 3.685706310640483*^9, 
   3.685711829094784*^9, 3.6857123501278343`*^9, 3.685712563590261*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There are \"\>", "\[InvisibleSpace]", "8", 
   "\[InvisibleSpace]", "\<\" generators left.\"\>"}],
  SequenceForm["There are ", 8, " generators left."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.676175630167898*^9, 3.6761756432051477`*^9}, 
   3.676177633238863*^9, 3.676181718282309*^9, 3.676181805218286*^9, 
   3.676181851823415*^9, 3.676182006495245*^9, 3.676182181420231*^9, 
   3.676221922288815*^9, 3.6762219998584948`*^9, 3.676259911566552*^9, 
   3.676347690195682*^9, 3.676365991397257*^9, 3.6763879252666597`*^9, 
   3.676392629800563*^9, 3.676440169293993*^9, 3.676473474391552*^9, 
   3.677558391444075*^9, 3.67755939315864*^9, 3.677561474804204*^9, {
   3.678365630463592*^9, 3.678365643154956*^9}, 3.678438841809287*^9, 
   3.67910106886849*^9, 3.679101233304977*^9, {3.679228828213192*^9, 
   3.679228845187958*^9}, 3.6792292430359297`*^9, 3.679235213978156*^9, 
   3.679373465879586*^9, 3.679379276205572*^9, 3.679379653711396*^9, 
   3.679381175254533*^9, 3.679381220446678*^9, {3.679381278310419*^9, 
   3.679381286237536*^9}, 3.679381363721024*^9, 3.679382113895825*^9, 
   3.6793821789474087`*^9, {3.679382351073333*^9, 3.6793823563180857`*^9}, 
   3.679382428774447*^9, 3.6839008031636467`*^9, 3.683906842872005*^9, {
   3.683907938656304*^9, 3.683907945517867*^9}, 3.6839496031815987`*^9, 
   3.683949916694581*^9, 3.683952428309697*^9, 3.6839589662501383`*^9, 
   3.684043336180006*^9, 3.684043390906584*^9, 3.685196556483519*^9, 
   3.685257710349473*^9, 3.6852591238576803`*^9, 3.685706310640483*^9, 
   3.685711829094784*^9, 3.6857123501278343`*^9, 3.685712563591331*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The cancelled generators were \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"\<\"(1)\"\>", "\<\"(1)\"\>"},
       {"\<\"1\"\>", "\<\"2\"\>"},
       {"\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>"},
       {"\<\"5\"\>", "\<\"9\"\>"},
       {"\<\"(5)\"\>", "\<\"(7)\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["The cancelled generators were ", 
   MatrixForm[{{"(1)", "(1)"}, {"1", "2"}, {"\[DownArrow]", "\[DownArrow]"}, {
     "5", "9"}, {"(5)", "(7)"}}]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.676175630167898*^9, 3.6761756432051477`*^9}, 
   3.676177633238863*^9, 3.676181718282309*^9, 3.676181805218286*^9, 
   3.676181851823415*^9, 3.676182006495245*^9, 3.676182181420231*^9, 
   3.676221922288815*^9, 3.6762219998584948`*^9, 3.676259911566552*^9, 
   3.676347690195682*^9, 3.676365991397257*^9, 3.6763879252666597`*^9, 
   3.676392629800563*^9, 3.676440169293993*^9, 3.676473474391552*^9, 
   3.677558391444075*^9, 3.67755939315864*^9, 3.677561474804204*^9, {
   3.678365630463592*^9, 3.678365643154956*^9}, 3.678438841809287*^9, 
   3.67910106886849*^9, 3.679101233304977*^9, {3.679228828213192*^9, 
   3.679228845187958*^9}, 3.6792292430359297`*^9, 3.679235213978156*^9, 
   3.679373465879586*^9, 3.679379276205572*^9, 3.679379653711396*^9, 
   3.679381175254533*^9, 3.679381220446678*^9, {3.679381278310419*^9, 
   3.679381286237536*^9}, 3.679381363721024*^9, 3.679382113895825*^9, 
   3.6793821789474087`*^9, {3.679382351073333*^9, 3.6793823563180857`*^9}, 
   3.679382428774447*^9, 3.6839008031636467`*^9, 3.683906842872005*^9, {
   3.683907938656304*^9, 3.683907945517867*^9}, 3.6839496031815987`*^9, 
   3.683949916694581*^9, 3.683952428309697*^9, 3.6839589662501383`*^9, 
   3.684043336180006*^9, 3.684043390906584*^9, 3.685196556483519*^9, 
   3.685257710349473*^9, 3.6852591238576803`*^9, 3.685706310640483*^9, 
   3.685711829094784*^9, 3.6857123501278343`*^9, 3.685712563592352*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ShowGraph", "[", 
  RowBox[{"MM1", ",", "GG1"}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8}, {
       SparseArray[
       Automatic, {8, 8}, 0, {
        1, {{0, 4, 8, 8, 10, 11, 12, 15, 18}, {{3}, {4}, {5}, {8}, {3}, {4}, {
          6}, {7}, {3}, {6}, {3}, {3}, {3}, {4}, {6}, {3}, {5}, {6}}}, 
         Pattern}], Null}, {EdgeLabels -> {DirectedEdge[8, 5] -> {{{43}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          1, 4] -> {{{"\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          5, 3] -> {{{"\!\(\*SubscriptBox[\(\[Delta]\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[2, 4] -> {{{35}, 
            Subscript[$CellContext`\[Iota], 1]}, {{
            11, "\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[6, 3] -> {{{14}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[7, 3] -> {{{21, 11}, 
            Subscript[$CellContext`\[Iota], 1]}, {{
            "\!\(\*SubscriptBox[\(\[Delta]\), \(2\)]\)", 11, 11}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          1, 8] -> {{{"\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[2, 6] -> {{
            Subscript[$CellContext`\[Iota], 1], 
            Subscript[$CellContext`\[Iota], 1]}, {{7}, 
            Subscript[$CellContext`\[Iota], 1]}, {{9}, 
            Subscript[$CellContext`\[Iota], 1]}, {{
            11, "\!\(\*SubscriptBox[\(\[Delta]\), \
\(13\)]\)\!\(\*SubscriptBox[\(\[Delta]\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}, {{
            "\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)\!\(\*SubscriptBox[\(\
\[Delta]\), \(2\)]\)", 11}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[7, 6] -> {{{21}, 
            Subscript[$CellContext`\[Iota], 1]}, {{
            "\!\(\*SubscriptBox[\(\[Delta]\), \(2\)]\)", 11}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[2, 3] -> {{{11}, 
            Subscript[$CellContext`\[Iota], 1]}, {{7, 11}, 
            Subscript[$CellContext`\[Iota], 1]}, {{9, 11}, 
            Subscript[$CellContext`\[Iota], 1]}, {{
            11, "\!\(\*SubscriptBox[\(\[Delta]\), \
\(13\)]\)\!\(\*SubscriptBox[\(\[Delta]\), \(2\)]\)", 11}, 
            Subscript[$CellContext`\[Iota], 1]}, {{
            "\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)\!\(\*SubscriptBox[\(\
\[Delta]\), \(2\)]\)", 11, 11}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[1, 3] -> {{
            Subscript[$CellContext`\[Iota], 1], 
            Subscript[$CellContext`\[Iota], 1]}, {{7}, 
            Subscript[$CellContext`\[Iota], 1]}, {{9}, 
            Subscript[$CellContext`\[Iota], 1]}, {{
            11, "\!\(\*SubscriptBox[\(\[Delta]\), \
\(13\)]\)\!\(\*SubscriptBox[\(\[Delta]\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}, {{
            "\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)\!\(\*SubscriptBox[\(\
\[Delta]\), \(2\)]\)", 11}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          4, 3] -> {{{"\!\(\*SubscriptBox[\(\[Delta]\), \(2\)]\)", 11}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[7, 4] -> {{{43}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[1, 5] -> {{{35}, 
            Subscript[$CellContext`\[Iota], 1]}, {{
            11, "\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          4, 6] -> {{{"\!\(\*SubscriptBox[\(\[Delta]\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          2, 7] -> {{{"\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[8, 3] -> {{{21}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          8, 6] -> {{{"\!\(\*SubscriptBox[\(\[Delta]\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}}, 
       VertexLabels -> {
        6 -> Placed["6:(bx)", Above], 3 -> Placed["3:(bx)", Above], 5 -> 
         Placed["5:(ax)", Above], 8 -> Placed["8:(ax)", Above], 7 -> 
         Placed["7:(ax)", Above], 4 -> Placed["4:(ax)", Above], 2 -> 
         Placed["2:(bx)", Above], 1 -> Placed["1:(bx)", Above]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
        Medium], {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQjQo4HH5qnenkY11hH3L+xtHX89kd7r+89meDx077
TR6SFbtM2R2m2L2cbPfysL14zkGxnINsDivT3zz6ev60fZvlxYUMzmwOIFX2
Opfs/24AaWB1EAOru2Zfd0m99pI6q8M5/u4pjctv23PMyzvL383iMG9j93X7
/Af2M4VluQyeMDsYg8FjexMwzeywNYF7WwL3M/srIO21TA4WfY+B6IV9ocxx
IGJ02LMbBF7bCwmCAKMD2HmT39lvZI3ewBrN4ADWvu2D/YIvnvO/eP63VwKD
T/b37oLAX/vHYAM/28uCjCv8Y7/U/9cS/19f7GM2gAz4bT9rJgj8tE8Dg2/2
0VDxxVB1MlB9MHMeQM1VhtozH2pvItQdMHfZQ90JczfMH0VQf1lC/XkZ6u9t
0HCAhQssnGDhBgtHWLjCwhkW7uLQeIDFCyyeYPG2AhqPsHiFxfNGaLw/gKYD
WLr4B00nsHQDS0EAFRAB6w==
          "]], 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "1"], 
              SubscriptBox["\[Iota]", "1"]},
             {
              RowBox[{"{", "7", "}"}], 
              SubscriptBox["\[Iota]", "1"]},
             {
              RowBox[{"{", "9", "}"}], 
              SubscriptBox["\[Iota]", "1"]},
             {
              RowBox[{"{", 
               RowBox[{
               "11", ",", "\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]},
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>", ",", 
                "11"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.4999999999999998`, 1.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0., 3.}, {4., 2.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\"\>", "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {2., 2.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQjQo4HH5qnenkY12xP+T8jaOv57M73H957c8Gj537
N3lIVuwyZXeYYvdyst3Lw/vFcw6K5Rxkc1iZ/ubR1/On97dZXlzI4MzmAFJl
r3Np/98NIA2sDmJgddf2111Sr72kzupwjr97SuPy2/s55uWd5e9mcZi3sfu6
ff6D/TOFZbkMnjA7GIPB4/0mYJrZ4Q/YnKf7r4C01zI5QNz1fH+hzHEgYnSw
7Hts0ff4xX4hQRBgdFj1NqMovvXl/o2s0RtYoxkcVkP5C754zv/i+d/eCqr+
3l0Q+GsPM08WZFzhH/u/UPtiNoAM+G0Pc8+smSDw0x7mXrA28x/2MP98PqyU
+uDlN3txqH/ZQdZv+GoPCw92sH+/2K+AhtfXntg9/yo/28PCExw8tZ/sH0DD
G6x8ykf7f9D4iEj0K9E48MEeNb4+2AMANfDctg==
          "]], 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", "35", "}"}], 
              SubscriptBox["\[Iota]", "1"]},
             {
              RowBox[{"{", 
               RowBox[{
               "11", ",", "\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-0.7975308641975307, 2.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0., 3.}, {0., 2.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\"\>", "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0., 2.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGDQA2IQDQEcDhBawKHArnvTbxNOB73XavmMM/kdFl/nWnFm
I5eD/I5AWUEpfofpp+seFJXxOFxIa+DSb+Zz8JB6Hv2uic/B7vsms+grvA73
Hir2zs8WcMjNfLlwKi+vw4/kU72bdgo6xOxV9rmnx+NQKPxWf4O2sAPX50RT
UwtuB58PncUzDoo4VHEtiZ2lyeXQ9mtBRHa1mMMK5ldHeJk5HRgDp2r+PCPm
sEmORW3SIQ4HlqBrh9+JiDuUF+666VjC4TDpb7K6T7C4w4ffPA9kJDgclgbb
hQh2iDso7PttobyO3cEhJNXLbrO4A8eOtichZuwOKf9vcF6+Iu6w7OXaRxs3
sDkIhM6cdP6NuMOfoEJjK1k2B5fQZU+Mf4s7cH65cO1tNSs0XCQcTIxBgNnh
PxiIO1xRr72kXssEly+UOQ5EjA6MUL6QIAgwwuU3skZvYI1mgPMXfPGc/8Xz
vz2Mf+8uCPyF82VBxhX+gfNjNoAM+A3np4HBN3tnqHvfiMcFqXB8tReE+oc9
SnZm99HP9qlQ/27RWWI1Z94ne1h4fOz/ZBY2+aP9Emh4HWjm6Nu5+IM9LDyd
Bc7U98x/b88GDW8tK7GZP/Te2TNB48Os9X369q9v7GHxlfIx/M2Jz6/tvaHx
KXstv3Na5HN7WHzfMK7Q0pZ/bA9LDxqij+bxdt6zh6WXOVu2fAiafN0elp5E
3DK81GIv2k+DpjfpyT/D+c8et18CTY8Kf06E3tm7x74Iml7lTFzNluxfaY+a
nhkYACJrGu8=
          "]], 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", "11", "}"}], 
              SubscriptBox["\[Iota]", "1"]},
             {
              RowBox[{"{", 
               RowBox[{"7", ",", "11"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]},
             {
              RowBox[{"{", 
               RowBox[{"9", ",", "11"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]},
             {
              RowBox[{"{", 
               RowBox[{
               "11", ",", "\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>", ",", 
                "11"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]},
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>", ",", "11",
                 ",", "11"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {6., 1.999955098875899},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEcDhBawMHszpUermQOhxPK2sVf5/A7VKbOvSR3
jcOhfVaS7kNNfocTsyMv2kRyOlilLNM7vIzPQameszPlDafDvYZvZbOF+Ry6
+Nf+nNrP5VD2IYgtq4DX4a+Pi/JFJ24Hls277+jt5XGoMT/PKsbG49BywuDX
y5/cDhznfRem3ORx+GmwKW62GrfDfOEDX/fs4XVIfGPP5ezM5XAtJfSovxmf
g6GrkPrk/ZwOJomiwlMX8jm8d+uc982U02EXB8P9nn98DjM+LinIXcbhkBwt
qmnuy++g5Zo697sAh4NpZOjHyb38DssdT6lMLWV30Gc6YL54P7+DwPPLbG5X
2Bz8wkL/pDzmd0gxbXLm0mVzmBIqan/zB7/DYp2rtx7Ws8LD5QwYsMD5aW8e
fT0vjeD/Spxo9KGE2YERym/RvdGke4MJLs/iv/1ZuyuCX3VML+7/HkY4/9Vk
u5eT7RB8sPJTDHD+GgN1K5EEBB8acQ4AB9KSaw==
          "]], 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", "35", "}"}], 
              SubscriptBox["\[Iota]", "1"]},
             {
              RowBox[{"{", 
               RowBox[{
               "11", ",", "\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {3.828852714152939, 3.151406900260565},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQDQEcDhBawOGksnbx1znsDifANL9Dx6wk3Yea7A7t
YJrfwTJlmd7hZWwOVmCaz+Few7ey2cJsUJrPoexDEFtWASuU5nVg2bz7jt5e
FijN49BywuDXy5/MUJrb4afBprjZasxQmtsh8Y09l7MzE5TmctCcvcpqw0lG
B0NXIfXJ+zkdzsx79SYrjtHhvVvnvG+mnA4e3/8rFDMyOsz4uKQgdxmHw5wl
r66d2MTgoOWaOve7AIfDqWWr+HKKGByWO55SmVrK7nDpr/2JGAcGB4Hnl9nc
rrA5bFq5inm2DINDimmTM5cum0PuqlcH1NgZHBbrXL31sJ4VGi4MDibGIMDs
kAOVj7uspSrXwOSwGap/9qnaPV8vMTpchpr/QULn505tRrj9EftMb2d1McDd
t6bU9KjAvf/2MPdfktkmp7r5nz3Mf0pFbw8JTflrrwX1/+zS2xtvNvyxh4WP
nXrD68rK3/Y/oOHHN2+208lNP+1h4fszbx63Ds8Pe1Zo+P+e2eG2qPWbPSx+
hOWjPmvLf7WHxZ/rPyGhkzc+28Pid4L55kWVmz7Zw+L/0ymrpbZrPtqfgqaP
3B0rJUWPfbBHTT8f7AFHWvWn
          "]], 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "1"], 
              SubscriptBox["\[Iota]", "1"]},
             {
              RowBox[{"{", "7", "}"}], 
              SubscriptBox["\[Iota]", "1"]},
             {
              RowBox[{"{", "9", "}"}], 
              SubscriptBox["\[Iota]", "1"]},
             {
              RowBox[{"{", 
               RowBox[{
               "11", ",", "\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]},
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>", ",", 
                "11"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {2.001214427658658, 2.4999683814188636`},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3., 4.}, {3., 3.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\"\>", "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {3., 3.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQECDlCGA4y/fN7G7uv2/+1h/KSJRh9Ksv/ZM0L5
ejeadG80/YXL8xQvcmZs+wPn/0oEafiN4C/xByGEepu7s+TFfsL5hupWIgkn
vsP5aWDwzX5yqKj9zR/8DjuWhXrZMHy19wsL/ZPymN/BfOrvitdLP9sbMB0w
X7yf3+GBYcSn4vBP9maRoR8n9/I7bKjJ3nZV5KN9SrSoprkvv0PE66wuxT3v
7XdwMNzv+cfnsMgyx9Yr7a29SaKo8NSFfA5OT261qmq8tr+WEnrU34zPwfT1
tuTNjC/t5wsf+LpnD69DtR/D9c+fntmznfddmHKTx0HGxrx1Uupj+xrz86xi
bDwO7+/aiEdIPLD/5+OifNGJ2+FZupJUp9gt+y7+tT+n9nM5+NRknF1fc8Ve
uZ6zM+UNp4P6p+kTPI6dsz8xO/KiTSSnQ/WemaJnJx+1r0yde0nuGoeD3Po1
wbcO77I3v3OlhyuZw2Eer7np4kMroOHDAYsvBgADLqKJ
          "]], 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\
\"\>", ",", "11"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {3.828852714152939, 0.8485930997394352},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4., 2.}, {3., 1.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(2\\)]\\)\"\>", "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {3.5, 1.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0., 1.}, {3., 0.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(2\\)]\\)\"\>", "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.5, 0.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3., 1.}, {3., 0.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", "14", "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {3., 0.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQDQEcDjD6gtuHu2GnORym32GfGDKL3aGVJXSby0FO
h/21V5fEyrM7SFjqdZ58yOVQ+jjDWrqfzaHnSXXYUx0eh928h0J6X7I6PGKz
k5uxiNeh/8+DD5v1WB0kF5Q8eOjE7/Bl/VH+/jgWB4kb/X4P2wQcXqgXbJSr
ZHaYOltea26joENOyoOrSXVMDk2zXjYtmSjkUJcqVhudx+iQbKju13FPyGFZ
hcO8KHFGhwuM16ITlIQdgpedCNXeyuBwgvvbap1YYYeOd+sWn3VncPD2b7d7
2yfs0LroGX/zvP/2kWc6hRdtF3bgmKvNyjf9n/2npr9a3teFHWad0VG3qfxr
L1b8qOXFW2EHc8NXpbyuf+yPzbFQrPot7PDoVPLHxl+/7CHhIuKQBgbf7I9C
5WVN5/DVsX6F6z9xTrTr067P9p+h5mcYX75xuO0T3P7vSVd+fcz4aA9zX3Ws
5IeaxA/2MPc/dHUpPPngnT3Mf1vS7q4I0n5rnwL1f7bsv7api17bw8KHI2sZ
9yS3V/aw8AvKq1tRwvbMXhIavokJ9lat0o/sYeGf0nCpsZ37rv1jaPy0Sf+o
SOi6Zg+LP/1J7yOnbr5gD4vfXScKPX34jtu3QOPf0iMg1Vtkj/0laPrQvsWx
73bWSnvU9MPAAADHivor
          "]], 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               RowBox[{"21", ",", "11"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]},
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\
\"\>", ",", "11", ",", "11"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {4.998457273264699, 1.49994856657929},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3., 3.}, {4., 2.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", "43", "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {3.5, 2.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEcDjD6PxiwO4Scv3H09Xx2uPgmD8mKXabsDoxQ
vnjOQbGcg2xw+TbLiwsZnBH8vxtAGljh/LpL6rWX1BF8jnl5Z/m7WeD8mcKy
XAZPmOF8E2MQYIa75wpIey0TXL5Q5jgQMcLdIyQIAoxw+Y2s0RtYoxng/AVf
POd/8fxvD+PfuwsCf+F8WZBxhX/g/JgNIAN+w/mzZoLAT3uYe8DBY/4DLv/5
sFLqg5ff7GHuYQdZv+ErXJ4d7N8vcP7Xntg9/yo/w/ng4Kn9BOeDlU/5COdH
JPqVaBz4AOdD6A/2AHCxels=
          "]], 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", "21", "}"}], 
              SubscriptBox["\[Iota]", "1"]},
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\
\"\>", ",", "11"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {3., 2.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQjQYcfmqd6eRjXWG/fN7G7uv2/+3vv7z2Z4PHTvuk
iUYfSrL/2U+xeznZ7uVhe70bTbo3mv7ar0x/8+jr+dP2PMWLnBnb/thLVuwy
tde5ZP8rEaTht71YzkEgumb/a4k/CNmf4++e0rj8tj2Pzd1Z8mI/7cHW5D+w
N1S3Ekk48d3eGAwe26eBwTd7ZjVBMwmxZ/buJhNv7GP8al+w+JdFDt9L+6LT
Lzd+Xf3ZvnL1e2t9mTf2T7QLPnGlfrKXsftgl2j/3n5OqMqsfzof7dfp/lNg
tPloP9uDbeUF5g/2cxi7lDgff7I/wqljx3T5rf2NWdJLTkz5Yv9AZPkP+T2v
7ZN+blpqH/jNvndTbeOvQy/tLWUD1PMkftgfe7T+xsTnz+27/zDGqt38bV/M
/G/RTbUn9oUfv5WuDf5v38/H2RW05oH991rxnYwujA6aHIukf76/Zf+P96qG
yG4mB84Tq2PWC1+1v6hhwsXHz+JQtzNuXX/7efvccyax7+1ZHeb2RIq1Mhyz
v/LvmuIOXzaHU0ITHtWq7LZn3SUVkWHB7lC8f8WfL59W2EOiicMBFmEAQ37M
qg==
          "]], 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", "21", "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.3735385270268532`, 0.8171537190705848},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0., 2.}, {0., 1.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", "43", "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0., 1.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0., 2.}, {3., 1.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(2\\)]\\)\"\>", "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.5, 1.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {DiskBox[{0., 3.}, 0.03700564971751412], 
         InsetBox["\<\"1:(bx)\"\>", Offset[{0, 2}, {0., 3.037005649717514}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{3., 4.}, 0.03700564971751412], 
         InsetBox["\<\"2:(bx)\"\>", Offset[{0, 2}, {3., 4.037005649717514}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{3., 0.}, 0.03700564971751412], 
         InsetBox["\<\"3:(bx)\"\>", Offset[{0, 2}, {3., 0.03700564971751412}],
           ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{4., 2.}, 0.03700564971751412], 
         InsetBox["\<\"4:(ax)\"\>", Offset[{0, 2}, {4., 2.037005649717514}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{0., 1.}, 0.03700564971751412], 
         InsetBox["\<\"5:(ax)\"\>", Offset[{0, 2}, {0., 1.0370056497175142`}],
           ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{3., 1.}, 0.03700564971751412], 
         InsetBox["\<\"6:(bx)\"\>", Offset[{0, 2}, {3., 1.0370056497175142`}],
           ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{3., 3.}, 0.03700564971751412], 
         InsetBox["\<\"7:(ax)\"\>", Offset[{0, 2}, {3., 3.037005649717514}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{0., 2.}, 0.03700564971751412], 
         InsetBox["\<\"8:(ax)\"\>", Offset[{0, 2}, {0., 2.037005649717514}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None,
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{827., Automatic}]], "Output",
 CellChangeTimes->{{3.685706314619673*^9, 3.685706324726777*^9}, 
   3.6857118309603443`*^9, 3.685712352449057*^9, 3.685712565270421*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"AutoCleanPosns1", "=", " ", 
   RowBox[{"AutoCleanPosns", "[", 
    RowBox[{"MM1", ",", "GG1", ",", 
     RowBox[{"Tuples", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", "8", "]"}], ",", 
        RowBox[{"Range", "[", "8", "]"}]}], "}"}], "]"}], ",", "50"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MM2", "=", 
   RowBox[{"AutoCleanPosns1", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GG2", "=", "GG1"}], ";"}]}], "Input",
 CellChangeTimes->{{3.679237416285112*^9, 3.679237474026512*^9}, 
   3.6792375781449423`*^9, {3.6793735860487337`*^9, 3.679373609456627*^9}, {
   3.679376263071794*^9, 3.679376264565131*^9}, {3.679377331889419*^9, 
   3.679377346917666*^9}, {3.67938132383418*^9, 3.6793813873714037`*^9}, {
   3.684046367595406*^9, 3.6840463777905207`*^9}, 3.685196574589794*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 TemplateBox[{RowBox[{"\"Mon 17 Oct 2016 18:02:46\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", "1.`"}], FontColor -> 
      GrayLevel[0.5]]}],RowBox[{"DateObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"2016", ",", "10", ",", "17"}], "}"}], ",", 
       RowBox[{"TimeObject", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"18", ",", "2", ",", "46.961655`"}], "}"}], ",", 
           RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}], ",", 
       RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}]},
  "DateObject",
  Editable->False]], "Print",
 CellChangeTimes->{
  3.67923749399505*^9, {3.679237554188056*^9, 3.679237578996296*^9}, 
   3.679373577896247*^9, 3.6793736123420973`*^9, 3.6793737431066933`*^9, 
   3.679374389938847*^9, 3.679376156726047*^9, {3.679376264950897*^9, 
   3.679376273491117*^9}, 3.679376317366557*^9, 3.6793766700712423`*^9, 
   3.679377121603821*^9, {3.679377334237754*^9, 3.679377347772024*^9}, 
   3.6793774519499073`*^9, 3.679377568407089*^9, {3.679377616539229*^9, 
   3.679377620450218*^9}, {3.6793797155906467`*^9, 3.679379741564639*^9}, 
   3.679379850575164*^9, 3.679381296995924*^9, 3.6793813900711946`*^9, 
   3.679382119943206*^9, {3.6793821840834923`*^9, 3.679382213235279*^9}, {
   3.6793824332874613`*^9, 3.679382442447735*^9}, 3.679382613951873*^9, 
   3.6839008095567617`*^9, 3.683906849037881*^9, 3.683907950675561*^9, 
   3.683949619412546*^9, 3.683949921760997*^9, 3.683952433208049*^9, 
   3.683958971667571*^9, 3.68404339444049*^9, {3.684046369466941*^9, 
   3.684046395836597*^9}, {3.68519656186138*^9, 3.6851965766272507`*^9}, 
   3.685257716092029*^9, 3.685259128092087*^9, 3.685706326678438*^9, 
   3.685711832824519*^9, 3.6857123545769997`*^9, 3.6857125669822807`*^9}],

Cell[BoxData["\<\"Aborted after iteration 18\"\>"], "Print",
 CellChangeTimes->{
  3.67923749399505*^9, {3.679237554188056*^9, 3.679237578996296*^9}, 
   3.679373577896247*^9, 3.6793736123420973`*^9, 3.6793737431066933`*^9, 
   3.679374389938847*^9, 3.679376156726047*^9, {3.679376264950897*^9, 
   3.679376273491117*^9}, 3.679376317366557*^9, 3.6793766700712423`*^9, 
   3.679377121603821*^9, {3.679377334237754*^9, 3.679377347772024*^9}, 
   3.6793774519499073`*^9, 3.679377568407089*^9, {3.679377616539229*^9, 
   3.679377620450218*^9}, {3.6793797155906467`*^9, 3.679379741564639*^9}, 
   3.679379850575164*^9, 3.679381296995924*^9, 3.6793813900711946`*^9, 
   3.679382119943206*^9, {3.6793821840834923`*^9, 3.679382213235279*^9}, {
   3.6793824332874613`*^9, 3.679382442447735*^9}, 3.679382613951873*^9, 
   3.6839008095567617`*^9, 3.683906849037881*^9, 3.683907950675561*^9, 
   3.683949619412546*^9, 3.683949921760997*^9, 3.683952433208049*^9, 
   3.683958971667571*^9, 3.68404339444049*^9, {3.684046369466941*^9, 
   3.684046395836597*^9}, {3.68519656186138*^9, 3.6851965766272507`*^9}, 
   3.685257716092029*^9, 3.685259128092087*^9, 3.685706326678438*^9, 
   3.685711832824519*^9, 3.6857123545769997`*^9, 3.685712567377269*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"I increased complexity \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\" times.\"\>"}],
  SequenceForm["I increased complexity ", 0, " times."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.67923749399505*^9, {3.679237554188056*^9, 3.679237578996296*^9}, 
   3.679373577896247*^9, 3.6793736123420973`*^9, 3.6793737431066933`*^9, 
   3.679374389938847*^9, 3.679376156726047*^9, {3.679376264950897*^9, 
   3.679376273491117*^9}, 3.679376317366557*^9, 3.6793766700712423`*^9, 
   3.679377121603821*^9, {3.679377334237754*^9, 3.679377347772024*^9}, 
   3.6793774519499073`*^9, 3.679377568407089*^9, {3.679377616539229*^9, 
   3.679377620450218*^9}, {3.6793797155906467`*^9, 3.679379741564639*^9}, 
   3.679379850575164*^9, 3.679381296995924*^9, 3.6793813900711946`*^9, 
   3.679382119943206*^9, {3.6793821840834923`*^9, 3.679382213235279*^9}, {
   3.6793824332874613`*^9, 3.679382442447735*^9}, 3.679382613951873*^9, 
   3.6839008095567617`*^9, 3.683906849037881*^9, 3.683907950675561*^9, 
   3.683949619412546*^9, 3.683949921760997*^9, 3.683952433208049*^9, 
   3.683958971667571*^9, 3.68404339444049*^9, {3.684046369466941*^9, 
   3.684046395836597*^9}, {3.68519656186138*^9, 3.6851965766272507`*^9}, 
   3.685257716092029*^9, 3.685259128092087*^9, 3.685706326678438*^9, 
   3.685711832824519*^9, 3.6857123545769997`*^9, 3.685712567428396*^9}],

Cell[BoxData[
 TemplateBox[{RowBox[{"\"Mon 17 Oct 2016 18:02:47\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", "1.`"}], FontColor -> 
      GrayLevel[0.5]]}],RowBox[{"DateObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"2016", ",", "10", ",", "17"}], "}"}], ",", 
       RowBox[{"TimeObject", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"18", ",", "2", ",", "47.382145`"}], "}"}], ",", 
           RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}], ",", 
       RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}]},
  "DateObject",
  Editable->False]], "Print",
 CellChangeTimes->{
  3.67923749399505*^9, {3.679237554188056*^9, 3.679237578996296*^9}, 
   3.679373577896247*^9, 3.6793736123420973`*^9, 3.6793737431066933`*^9, 
   3.679374389938847*^9, 3.679376156726047*^9, {3.679376264950897*^9, 
   3.679376273491117*^9}, 3.679376317366557*^9, 3.6793766700712423`*^9, 
   3.679377121603821*^9, {3.679377334237754*^9, 3.679377347772024*^9}, 
   3.6793774519499073`*^9, 3.679377568407089*^9, {3.679377616539229*^9, 
   3.679377620450218*^9}, {3.6793797155906467`*^9, 3.679379741564639*^9}, 
   3.679379850575164*^9, 3.679381296995924*^9, 3.6793813900711946`*^9, 
   3.679382119943206*^9, {3.6793821840834923`*^9, 3.679382213235279*^9}, {
   3.6793824332874613`*^9, 3.679382442447735*^9}, 3.679382613951873*^9, 
   3.6839008095567617`*^9, 3.683906849037881*^9, 3.683907950675561*^9, 
   3.683949619412546*^9, 3.683949921760997*^9, 3.683952433208049*^9, 
   3.683958971667571*^9, 3.68404339444049*^9, {3.684046369466941*^9, 
   3.684046395836597*^9}, {3.68519656186138*^9, 3.6851965766272507`*^9}, 
   3.685257716092029*^9, 3.685259128092087*^9, 3.685706326678438*^9, 
   3.685711832824519*^9, 3.6857123545769997`*^9, 3.685712567433095*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
List of homotopies performed automatically in the previous step:\
\>", "Text",
 CellChangeTimes->{{3.6840632401672707`*^9, 3.684063256646521*^9}, 
   3.684064046259367*^9, {3.6857123738456507`*^9, 3.6857124039102716`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AutoCleanPosns1", "[", 
  RowBox[{"[", "2", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.684063176485009*^9, 3.6840632313340693`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "11", "}"}], ",", "1"}], "}"}], ",", "6", ",", "3"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "40", "}"}], ",", "1"}], "}"}], ",", "7", ",", "4"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "34", "}"}], ",", "1"}], "}"}], ",", "1", ",", "5"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "18", "}"}], ",", "1"}], "}"}], ",", "8", ",", "3"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"6", ",", "36"}], "}"}], ",", "1"}], "}"}], ",", "1", ",", 
     "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "34", "}"}], ",", "1"}], "}"}], ",", "2", ",", "4"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"6", ",", "36"}], "}"}], ",", "1"}], "}"}], ",", "2", ",", 
     "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "18", "}"}], ",", "1"}], "}"}], ",", "7", ",", "6"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"24", ",", "6"}], "}"}], ",", "1"}], "}"}], ",", "8", ",", 
     "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}], ",", "8", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"24", ",", "6"}], "}"}], ",", "1"}], "}"}], ",", "7", ",", 
     "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "40", "}"}], ",", "1"}], "}"}], ",", "8", ",", "5"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "4", "}"}], ",", "1"}], "}"}], ",", "1", ",", "3"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "5", "}"}], ",", "1"}], "}"}], ",", "1", ",", "3"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"12", ",", "6"}], "}"}], ",", "1"}], "}"}], ",", "1", ",", 
     "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"6", ",", "12"}], "}"}], ",", "1"}], "}"}], ",", "1", ",", 
     "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "4", "}"}], ",", "1"}], "}"}], ",", "2", ",", "6"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "5", "}"}], ",", "1"}], "}"}], ",", "2", ",", "6"}], 
      "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"12", ",", "6"}], "}"}], ",", "1"}], "}"}], ",", "2", ",", 
     "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"6", ",", "12"}], "}"}], ",", "1"}], "}"}], ",", "2", ",", 
     "6"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.685712304853888*^9, 3.68571236113675*^9, 
  3.6857124133897142`*^9, 3.6857125694030247`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ShowGraph", "[", 
  RowBox[{"MM2", ",", "GG2"}], "]"}]], "Input",
 CellChangeTimes->{{3.679373622636108*^9, 3.67937362953642*^9}, {
  3.679381400662393*^9, 3.6793814023397007`*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8}, {
       SparseArray[
       Automatic, {8, 8}, 0, {
        1, {{0, 3, 6, 6, 7, 8, 8, 10, 12}, {{3}, {5}, {8}, {4}, {6}, {7}, {
          6}, {3}, {4}, {6}, {3}, {5}}}, Pattern}], Null}, {
      EdgeLabels -> {
        DirectedEdge[
          8, 5] -> {{{
            "\!\(\*SubscriptBox[\(\[Tau]\), \(13\)]\)", 
             "\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          5, 3] -> {{{"\!\(\*SubscriptBox[\(\[Delta]\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          2, 4] -> {{{
            "\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)\!\(\*SubscriptBox[\(\
\[Tau]\), \(13\)]\)", "\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          1, 8] -> {{{"\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[2, 6] -> {{
            Subscript[$CellContext`\[Iota], 1], 
            Subscript[$CellContext`\[Iota], 1]}, {{
            "\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)\!\(\*SubscriptBox[\(\
\[Tau]\), \(13\)]\)", 
             "\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)\!\(\*SubscriptBox[\(\
\[Delta]\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          7, 6] -> {{{
            "\!\(\*SubscriptBox[\(\[Tau]\), \(13\)]\)", 
             "\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)\!\(\*SubscriptBox[\(\
\[Delta]\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[1, 3] -> {{
            Subscript[$CellContext`\[Iota], 1], 
            Subscript[$CellContext`\[Iota], 1]}, {{
            "\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)\!\(\*SubscriptBox[\(\
\[Tau]\), \(13\)]\)", 
             "\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)\!\(\*SubscriptBox[\(\
\[Delta]\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          7, 
           4] -> {{{
            "\!\(\*SubscriptBox[\(\[Tau]\), \(13\)]\)", 
             "\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          1, 5] -> {{{
            "\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)\!\(\*SubscriptBox[\(\
\[Tau]\), \(13\)]\)", "\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          4, 6] -> {{{"\!\(\*SubscriptBox[\(\[Delta]\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          2, 7] -> {{{"\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          8, 3] -> {{{
            "\!\(\*SubscriptBox[\(\[Tau]\), \(13\)]\)", 
             "\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)\!\(\*SubscriptBox[\(\
\[Delta]\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}}, 
       VertexLabels -> {
        6 -> Placed["6:(bx)", Above], 3 -> Placed["3:(bx)", Above], 5 -> 
         Placed["5:(ax)", Above], 8 -> Placed["8:(ax)", Above], 7 -> 
         Placed["7:(ax)", Above], 4 -> Placed["4:(ax)", Above], 2 -> 
         Placed["2:(bx)", Above], 1 -> Placed["1:(bx)", Above]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
        Medium], {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQXXQkqoaL4Zf9k46tP0QYnuy/V8MyTf7YL/u9Pzl0
7Hue7k/un6rosea3/Qk5becJEc/3M/3hlW/Z9Mee+Ye0HUfqy/3bDuX2Xb7x
1z6v9bbM8o2v97c+3pJvJv/fnut45v0cu3f7TdcXJl5zYnDIiXt8aE3rh/1b
Z/5xlmZjdMgy/tluxvNpv4Nh9f3Mm4wOjUnf9l3e9Hn/jdK3xof2MDlseH0r
vaXy637+403MoWbMDjxWZnpPGr7tzz3sFDhrIbPDFDMPe9kp3/d/ytKVnfSP
2cHlocBs/c0/9s/d65Ru48viIGc1wVH63s/9+bub9Gf2sjgoOx4zeiDye39G
ytvSFftZHAK/bcqrC/+zv21Hk1XWYxaHVZFhX78u/bv/zHan2ns/WBx0sjcc
c2P4v98ySdeOlYHVgU3/F9elM4wHTkPl7/QxST6vZzoA0z93+vpGfl3mA+lQ
8708GV29rzAfyIPa/3Dx96RZpSwH5kDdl7x80u0/AqwHYO6/EHxpXdEy1gM5
UP9prNx257cp2wGY/3OW26fO2M92ABY+s/xyPTyc2Q/YQ8PPcPL9OQvUOA5s
gYbvXq04i/c/OQ6YQcPfVvSllMlezgMt0PjZENTgkl/AdWA7NP7EHitvXSDM
fQAWv4XHLuecWMZ9IAUa/wf+9Gc/0+Q5cB+aPpjbIjb+msNzAJZ+IOHEewAA
T7Qb6g==
          "]], 0.03857951133202078], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "1"], 
              SubscriptBox["\[Iota]", "1"]},
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(13\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {2.623795572341342, -2.125041618581136},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQXXQkqoaL4Zf9k46tP0QYnuxn5dmY9NXyp/3enxw6
9j1P9zf8lL9+JviH/Qk5becJEc/3P+5ZfnOC73d75h/SdhypL/frHHPPclT/
Zp/Xeltm+cbX+xOWMnTee/DFnut45v0cu3f7K7UumWZUfbbPiXt8aE3rh/1V
oXsK7n3+aJ9l/LPdjOfT/hS1/ZaOvh/sG5O+7bu86fP+TKutioq8b+03vL6V
3lL5dX/P1/jHV9Ve2/NYmek9afi2X5QlYc2Bypf2U8w87GWnfN/PnLa15iHr
C3uXhwKz9Tf/2B8mnRBicfqZvZzVBEfpez/386kkGB89+dRe2fGY0QOR3/t1
GrZKdjA+tQ/8timvLvzP/nX6CeyNRU/sV0WGff269O/+6UYJf9bLPLHXyd5w
zI3h/35ouNjnTE0otDBmOPAYyr9Y6uVh+oThAEzegWEOt2g344GnUP52k9Dd
19WZ4PJmwmXhtbsQ/H2z/91ndWaG8wPOvQspPIjgv1rltm2/KQuc32fIxvJx
PoJvmaRrx8rAegAADXfkCw==
          "]], 0.03857951133202078], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(13\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0.7961572858470616, -1.4736030997394352`},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.62501, -0.6250100000000001}, {1.62501, -1.62501}}, 
          0.03857951133202078], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\"\>", "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.62501, -1.12501},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQHSrscpe9QdjhScfWHyIMT/ZbLb05rclP2GHvTw4d
+56n+2cmfC3+ISLscEJO23lCxPP9Ra7TSzIvCzkw/5C240h9uf9w8P4ZVzuF
HPJab8ss3/h6/4Tu3Ac2FkIOXMcz7+fYvdt//c1C7/n3BB1y4h4fWtP6Yf+M
8phbf2oEHbKMf7ab8Xzaf0l7bk+osKBDY9K3fZc3fd7fxpmStHKhgMOG17fS
Wyq/7n+VMPPX/RQBBx4rM70nDd/2707aGWyrL+AwxczDXnbK9/2/+I7kHmQQ
cHB5KDBbf/OP/W6niybe2MTvIGc1wVH63s/9pWeNTlYX8TsoOx4zeiDye3+N
yommHAd+h8Bvm/Lqwv/sj7lgtG+VDL/Dqsiwr1+X/t0vfrGo2oyd30Ene8Mx
N4b/+1epdeziZ+B3yJmaUGhhzHBgBZR/sdTLw/QJwwGYvAPDHG7RbsYDq6H8
7Sahu6+rM8H5ZsJl4bW7EPx9s//dZ3VmhusPOPcupPAggv9qldu2/aYscH6f
IRvLx/kIvmWSrh0rA+sBAIDgybg=
          "]], 0.03857951133202078], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(13\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {4.046177285847062, -1.4736030997394352`},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQHSrscpe9QdjhScfWHyIMT/bnN65T7t0o7LD3J4eO
fc/T/ULHJrmJvxZ2OCGn7Twh4vl+q4cfXJfpiDgw/5C240h9uf/5pROKVmUi
Dnmtt2WWb3y9X3q21K1Lx0UcuI5n3s+xe7f/iuWzvAJFUYecuMeH1rR+2C+8
XvuBULOoQ5bxz3Yznk/7b/16pbvrjahDY9K3fZc3fd6vKqsSkRYn5rDh9a30
lsqv+w8cfbdff7aYA4+Vmd6Thm/73x8+l3bpgpjDFDMPe9kp3/dvEj/i4/df
zMHlocBs/c0/9rMfPFe4WE3cQc5qgqP0vZ/7P+x/d/Wim7iDsuMxowciv/fn
iKhU3owXdwj8timvLvzP/pp9edG7CsUdVkWGff269O9++X3nakpqxB10sjcc
c2P4vx8SPuIObPq/uC6dYTwgB5W/08ck+bye6QBM/9zp6xv5dZkP5ELN9/Jk
dPW+wnzgI9T+h4u/J80qZTkAc1/y8km3/wiwHoC5/0LwpXVFy1gPwPynsXLb
nd+mbAcOQv2fs9w+dcZ+tgOw8Jnll+vh4cx+4CY0/Awn35+zQI3jACx892rF
Wbz/yXHgKjT8bUVfSpns5TwgBY2fDUENLvkFXAdg8Sf2WHnrAmHuA7D4LTx2
OefEMu4DsPg/8Kc/+5kmz4ECaPpgbovY+GsOzwFY+rFM0rVjZeA9AAADCRkJ

          "]], 0.03857951133202078], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "1"], 
              SubscriptBox["\[Iota]", "1"]},
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(13\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {5.873815572341342, -2.1250416185811365`},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.87503, -0.6250100000000001}, {4.87503, -1.62501}}, 
          0.03857951133202078], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\"\>", "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {4.87503, -1.12501},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3.8750299999999998`, -2.62501}, {4.87503, -3.62501}}, 
          0.03857951133202078], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(2\\)]\\)\"\>", "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {4.37503, -3.12501},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.6250100000000001, -2.62501}, {1.62501, -3.62501}}, 
          0.03857951133202078], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(2\\)]\\)\"\>", "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.12501, -3.12501},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{4.87503, -1.62501}, {3.8750299999999998`, -2.62501}}, 
          0.03857951133202078], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(13\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {4.37503, -2.12501},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQHSrscpe9Qdih6EhUDRfDr/0w/knVlR+MDiD4/MYa
PVOn/N4fBuW7vrnuZ1T7B85PC9xhwVn1F86vSDrpKdX9D84vl+duSt3wH26e
0ZF9BV9LGA7A+Av9BEyuSjPC+Wz6v7gunUHw06w2ZN9tYoLzj7umnXlhwXwA
Zr5moIzul3cIfkfMpd7/S1jg/FfpHe+4olnhfK9iO38xQTa4eavrvqxXPI7g
c3etEtCtZYfzc6YmFFoYc8D5F0u9PEyfIPj2DHO4Rbs54ebvMAndfV2dC843
Ey4Lr92F4O+b/e8+qzM3nB9w7l1I4UFuuHmvVrlt22/KA+f3GbKxfJyP4Fsm
6dqxMvAeAAAQ06yD
          "]], 0.03857951133202078], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(13\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {4.875030000000001, -2.62501},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQXXQkqoaL4Zc9lN4P459UXfnB6ACCz2+s0TN1yu/9
JVC+65vrfka1f+DyaYE7LDir/sL5FUknPaW6/8H55fLcTakb/sP5Rkf2FXwt
YTgA4y/0EzC5Ks0I57Pp/+K6dAbBT7PakH23iQnOP+6aduaFBfMBmHs0A2V0
v7xjhst3xFzq/b+EBc5/ld7xjiuaFc73KrbzFxNkg/NX131Zr3gcwefuWiWg
W8sO5+dMTSi0MOaA8y+WenmYPkHw7RnmcIt2c8Lds8MkdPd1dS64vJlwWXjt
LgR/3+x/91mdueH8gHPvQgoPIvivVrlt22/KA+f3GbKxfJyP4Fsm6dqxMvAe
AAAnUMZN
          "]], 0.03857951133202078], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(13\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.62501, -2.62501},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.62501, -1.62501}, {0.6250100000000001, -2.62501}}, 
          0.03857951133202078], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(13\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.12501, -2.12501},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {DiskBox[{1.62501, -0.6250100000000001}, 0.03857951133202078],
          InsetBox["\<\"1:(bx)\"\>", 
          Offset[{0, 2}, {1.62501, -0.5864304886679793}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.87503, -0.6250100000000001}, 0.03857951133202078], 
         InsetBox["\<\"2:(bx)\"\>", 
          Offset[{0, 2}, {4.87503, -0.5864304886679793}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.62501, -3.62501}, 0.03857951133202078], 
         InsetBox["\<\"3:(bx)\"\>", 
          Offset[{0, 2}, {1.62501, -3.5864304886679794`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.8750299999999998`, -2.62501}, 0.03857951133202078], 
         InsetBox["\<\"4:(ax)\"\>", 
          Offset[{0, 2}, {3.8750299999999998`, -2.5864304886679794`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.6250100000000001, -2.62501}, 0.03857951133202078], 
         InsetBox["\<\"5:(ax)\"\>", 
          Offset[{0, 2}, {0.6250100000000001, -2.5864304886679794`}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.87503, -3.62501}, 0.03857951133202078], 
         InsetBox["\<\"6:(bx)\"\>", 
          Offset[{0, 2}, {4.87503, -3.5864304886679794`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.87503, -1.62501}, 0.03857951133202078], 
         InsetBox["\<\"7:(ax)\"\>", 
          Offset[{0, 2}, {4.87503, -1.5864304886679792`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.62501, -1.62501}, 0.03857951133202078], 
         InsetBox["\<\"8:(ax)\"\>", 
          Offset[{0, 2}, {1.62501, -1.5864304886679792`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None,
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{838., Automatic}]], "Output",
 CellChangeTimes->{
  3.6793736303798018`*^9, 3.6793737457045593`*^9, 3.6793743925608253`*^9, 
   3.6793761711017733`*^9, 3.679376282500206*^9, 3.679376324609407*^9, 
   3.67937667806216*^9, 3.679377130220358*^9, {3.679377341271063*^9, 
   3.679377356434741*^9}, 3.6793775741532784`*^9, 3.679377624774218*^9, {
   3.679379725325902*^9, 3.67937974553378*^9}, 3.6793798554319696`*^9, {
   3.679381302399268*^9, 3.6793813136681137`*^9}, {3.679381397624531*^9, 
   3.6793814040997562`*^9}, {3.679382189272953*^9, 3.679382216770248*^9}, 
   3.6793824375739117`*^9, 3.679382618138267*^9, 3.683900813646614*^9, 
   3.683906853171975*^9, 3.683907954425968*^9, 3.683949624270487*^9, 
   3.6839499259648857`*^9, 3.683952437082922*^9, 3.683958976451192*^9, 
   3.6840433995016336`*^9, {3.6840463724974623`*^9, 3.6840463980200443`*^9}, 
   3.68519658000334*^9, 3.6852577215338507`*^9, 3.685259130064921*^9, 
   3.685706329093967*^9, 3.6857118359365*^9, 3.685712363730589*^9, {
   3.685712414542348*^9, 3.685712451677003*^9}, 3.685712570855389*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ShowSubGraph", "[", 
  RowBox[{"MM2", ",", "GG2", ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3", ",", "5", ",", "8"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.684043308616386*^9, 3.684043318888775*^9}, {
  3.685712436416945*^9, 3.685712442023926*^9}, {3.685712580031019*^9, 
  3.68571258185157*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4}, {
       SparseArray[
       Automatic, {4, 4}, 0, {
        1, {{0, 3, 3, 4, 6}, {{2}, {3}, {4}, {2}, {2}, {3}}}, Pattern}], 
       Null}, {EdgeLabels -> {
        DirectedEdge[
          1, 4] -> {{{"\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          4, 2] -> {{{
            "\!\(\*SubscriptBox[\(\[Tau]\), \(13\)]\)", 
             "\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)\!\(\*SubscriptBox[\(\
\[Delta]\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          1, 3] -> {{{
            "\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)\!\(\*SubscriptBox[\(\
\[Tau]\), \(13\)]\)", "\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          4, 3] -> {{{
            "\!\(\*SubscriptBox[\(\[Tau]\), \(13\)]\)", 
             "\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[1, 2] -> {{
            Subscript[$CellContext`\[Iota], 1], 
            Subscript[$CellContext`\[Iota], 1]}, {{
            "\!\(\*SubscriptBox[\(\[Delta]\), \(13\)]\)\!\(\*SubscriptBox[\(\
\[Tau]\), \(13\)]\)", 
             "\!\(\*SubscriptBox[\(\[Tau]\), \(2\)]\)\!\(\*SubscriptBox[\(\
\[Delta]\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          3, 2] -> {{{"\!\(\*SubscriptBox[\(\[Delta]\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}}, 
       VertexLabels -> {
        3 -> Placed["5:(ax)", Above], 4 -> Placed["8:(ax)", Above], 2 -> 
         Placed["3:(bx)", Above], 1 -> Placed["1:(bx)", Above]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
        Medium], {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQjQo4HGbympsuPrTC/qSydvHXOewOcuvXBN86vMu+
Y1aS7kNNdoeqPTNFz04+am+Zskzv8DI2B41P0yd4HDtnf6/hW9lsYTYHn5qM
s+trrtiXfQhiyypgdXiSriTVKXbLnmXz7jt6e1kc3t+1EY+QeGDfcsLg18uf
zA6yNuatk1If2/802BQ3W43ZodqP4frnT8/sE9/Yczk7MzlETA4Vtb/5wt7I
VUh98n5Gh3MtoT4hba/s37t1zvtmyujwSImhxvjXa/sZH5cU5C5jcOjPDV1y
x+StvZZr6tzvAgwO11JCj/qbvbMPaJ7iqfX6n/1ODob7Pf/e2SudW87bs+Kv
vVlk6MfJve/tT2SxtItE/bH3Cwv9k/L4vb175Kqth///soeEywf7NDD4Zu8L
ld+xLNTLhuErXL/51N8Vr5d+tt8FNf+BYcSn4vBP9jD7N9Rkb7sq8tG+D+q+
iNdZXYp73tvD3L/IMsfWK+2t/Xmo/5ye3GpV1XhtD/O/6ettyZsZX9rDwgdG
y0DDD0bDwhdGP4OGP4yGxQ+MVofGH4yuhsYvjIbFP4yeB00fMBo9BQEAMtsN
+g==
          "]], 0.030239520958083826`], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "1"], 
              SubscriptBox["\[Iota]", "1"]},
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(13\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0.9987855723413421, 1.4999683814188636`},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQjQo4HGbympsuPrRi/0ll7eKvc9gd5NavCb51eNf+
jllJug812R2q9swUPTv56H7LlGV6h5exOWh8mj7B49i5/fcavpXNFmZz8KnJ
OLu+5sr+sg9BbFkFrA5P0pWkOsVu7WfZvPuO3l4Wh/d3bcQjJB7sbzlh8Ovl
T2YHWRvz1kmpj/f/NNgUN1uN2aHaj+H650/P9ie+sedydmZyiJgcKmp/88V+
I1ch9cn7GR3OtYT6hLS92v/erXPeN1NGh0dKDDXGv17vn/FxSUHuMgaH/tzQ
JXdM3u7Xck2d+12AweFaSuhRf7N3+wOap3hqvf5nv5OD4X7Pv3f7lc4t5+1Z
8dfeLDL04+Te9/tPZLG0i0T9sfcLC/2T8vj9fvfIVVsP//9lDwmXD/tnzQSB
n3D++RtHX883/wHnfz6slPrg5Td7RiifPXoDa/SGr3B59nl5Z/m7v8D5X3ti
9/yr/AznX1KvBaJPcD5Y+ZSPcH5Eol+JxoEPcD6UtgcA7hvDDQ==
          "]], 0.030239520958083826`], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(13\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-0.8288527141529385, 2.151406900260565},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0., 3.}, {0., 2.}}, 0.030239520958083826`], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\"\>", "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0., 2.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-1., 1.}, {0., 0.}}, 0.030239520958083826`], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(2\\)]\\)\"\>", "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-0.5, 0.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQjQYcYIzl8zZ2X7f/bw/jJ000+lCS/Q/O17vRpHuj
6S+cz1O8yJmx7Q+c/ysRpOE3gr/EH4QQ6m3uzpIX+wnnG6pbiSSc+A7np4HB
Nzh/MVj7Fzj/sUUfEH2G85WVQOATnJ/IvS2Be9sHON/+5WS7l5Pfwfl7doPA
azjfEmTc4xdwPkh3AvczON8YDB7D+eDgyX8A55/j757SuPw2nC+ec1As5+A1
OF+yYpepvc4lOH9F+ptHX8+fhvOn2IEceBjOf/Dy2p8NHjvh/H9aZzr5WFfA
+TAAAGdHa/U=
          "]], 0.030239520958083826`], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(13\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0., 0.9999999999999998},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0., 2.}, {-1., 1.}}, 0.030239520958083826`], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(13\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-0.5, 1.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {DiskBox[{0., 3.}, 0.030239520958083826`], 
         InsetBox["\<\"1:(bx)\"\>", Offset[{0, 2}, {0., 3.0302395209580837`}],
           ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{0., 0.}, 0.030239520958083826`], 
         InsetBox["\<\"3:(bx)\"\>", 
          Offset[{0, 2}, {0., 0.030239520958083826`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{-1., 1.}, 0.030239520958083826`],
          InsetBox["\<\"5:(ax)\"\>", Offset[{0, 2}, {-1., 1.030239520958084}],
           ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{0., 2.}, 0.030239520958083826`], 
         InsetBox["\<\"8:(ax)\"\>", Offset[{0, 2}, {0., 2.0302395209580837`}],
           ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None,
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]]]], "Output",
 CellChangeTimes->{
  3.684043319387128*^9, 3.684043401075367*^9, {3.684046386185759*^9, 
   3.6840464012085667`*^9}, 3.6851965822443333`*^9, 3.6852577255845346`*^9, 
   3.6852591315612*^9, 3.685706332126906*^9, 3.68571183820146*^9, {
   3.685712416109838*^9, 3.68571245347795*^9}, {3.685712572477045*^9, 
   3.68571258256175*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ListOfAllLabels", "[", "mat_", "]"}], " ", "returns", " ", "a", 
    " ", "list", " ", "of", " ", "all", " ", "labels", " ", "appearing", " ", 
    "in", " ", 
    RowBox[{"mat", "."}]}], "\[IndentingNewLine]", " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"ListOfAllLabels", "[", "MM2", "]"}]}]], "Input",
 CellChangeTimes->{{3.679237666887838*^9, 3.679237667346768*^9}, {
  3.679239191225569*^9, 3.679239191450878*^9}, {3.6792394544071093`*^9, 
  3.679239454672257*^9}, {3.6792399684612503`*^9, 3.6792399688802633`*^9}, {
  3.6793800792981243`*^9, 3.679380100506167*^9}, {3.679380264670209*^9, 
  3.679380267101907*^9}, {3.679381410516021*^9, 3.6793814106679087`*^9}, {
  3.685196601266109*^9, 3.685196606857038*^9}, {3.6852577371148367`*^9, 
  3.685257764209899*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      SubscriptBox["\[Iota]", "1"], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", "1", "1"},
     {
      RowBox[{"{", 
       SubscriptBox["\[Iota]", "1"], "}"}], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", "1", "}"}], "1"},
     {
      RowBox[{"{", 
       SubscriptBox["\[Iota]", "2"], "}"}], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", "2", "}"}], "1"},
     {
      RowBox[{
      "{", "\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>", "}"}], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", "24", "}"}], "1"},
     {
      RowBox[{
      "{", "\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(13\\)]\\)\"\>", 
       "}"}], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", "36", "}"}], "1"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(13\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"54", ",", "33"}], "}"}], "1"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \
\\(13\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(13\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(2\\)]\\)\"\>"}], 
       "}"}], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"54", ",", "53"}], "}"}], "1"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(13\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(\[Delta]\\), \\(2\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"57", ",", "33"}], "}"}], "1"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(13\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(2\\)]\\)\"\>"}], 
       "}"}], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"57", ",", "53"}], "}"}], "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.679238299497143*^9, 3.679239205140809*^9, {3.679239585409433*^9, 
   3.679239608398715*^9}, 3.679239970015602*^9, 3.679241783079337*^9, 
   3.6792425566861753`*^9, {3.679380073444624*^9, 3.679380091254319*^9}, 
   3.679380268153495*^9, 3.679380444312344*^9, {3.679381408476821*^9, 
   3.679381411370544*^9}, 3.679382230400732*^9, 3.679382626632945*^9, 
   3.6839008168762827`*^9, 3.683901513492984*^9, 3.6839068558028727`*^9, 
   3.683907956029022*^9, 3.683949626834029*^9, 3.683949930836933*^9, 
   3.683952438601931*^9, 3.683958978077808*^9, 3.684043403578092*^9, 
   3.685196584455429*^9, 3.6852577320115843`*^9, 3.6852591337127*^9, 
   3.685706334950254*^9, 3.6857118404975977`*^9, {3.685712448133966*^9, 
   3.685712455531282*^9}, 3.685712585741621*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"S1H", "/@", 
   RowBox[{"{", 
    RowBox[{"24", ",", "36", ",", "54", ",", "33", ",", "53", ",", "57"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6839525161737823`*^9, 3.683952556477257*^9}, 
   3.683952605101562*^9, 3.684063288303858*^9, {3.6857125978519173`*^9, 
   3.685712617228053*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  TagBox[GridBox[{
     {"8", "8"},
     {"6", "6"},
     {"5", "5"},
     {
      StyleBox["3",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["4",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "+", 
  TagBox[GridBox[{
     {"8", "8"},
     {"6", "6"},
     {
      StyleBox["3",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["4",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {"2", "2"}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "+", 
  TagBox[GridBox[{
     {"9", "9"},
     {"8", "8"},
     {"5", "5"},
     {
      StyleBox["3",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["4",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "+", 
  TagBox[GridBox[{
     {"9", "9"},
     {"8", "8"},
     {
      StyleBox["3",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["4",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {"2", "2"}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "+", 
  TagBox[GridBox[{
     {"10", "10"},
     {"6", "6"},
     {"5", "5"},
     {
      StyleBox["3",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["4",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "+", 
  TagBox[GridBox[{
     {"10", "10"},
     {"6", "6"},
     {
      StyleBox["3",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["4",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {"2", "2"}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "+", 
  TagBox[GridBox[{
     {"10", "10"},
     {"9", "9"},
     {"5", "5"},
     {
      StyleBox["3",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["4",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "+", 
  TagBox[GridBox[{
     {"10", "10"},
     {"9", "9"},
     {
      StyleBox["3",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["4",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {"2", "2"}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"]}]], "Print",
 CellChangeTimes->{3.685712621545664*^9}],

Cell[BoxData[
 RowBox[{
  TagBox[GridBox[{
     {"8", "8"},
     {"6", "6"},
     {
      StyleBox["4",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["5",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {
      StyleBox["2",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["3",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "+", 
  TagBox[GridBox[{
     {"9", "9"},
     {"8", "8"},
     {
      StyleBox["4",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["5",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {
      StyleBox["2",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["3",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "+", 
  TagBox[GridBox[{
     {"10", "10"},
     {"6", "6"},
     {
      StyleBox["4",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["5",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {
      StyleBox["2",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["3",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "+", 
  TagBox[GridBox[{
     {"10", "10"},
     {"9", "9"},
     {
      StyleBox["4",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["5",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {
      StyleBox["2",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["3",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"]}]], "Print",
 CellChangeTimes->{3.685712621563365*^9}],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["8",
      StripOnInput->False,
      FontWeight->Bold,
      Background->RGBColor[1, 1, 0]], 
     StyleBox["9",
      StripOnInput->False,
      FontWeight->Bold,
      Background->RGBColor[1, 1, 0]]},
    {
     StyleBox["6",
      StripOnInput->False,
      FontWeight->Bold,
      Background->RGBColor[1, 1, 0]], 
     StyleBox["7",
      StripOnInput->False,
      FontWeight->Bold,
      Background->RGBColor[1, 1, 0]]},
    {
     StyleBox["4",
      StripOnInput->False,
      FontWeight->Bold,
      Background->RGBColor[1, 1, 0]], 
     StyleBox["5",
      StripOnInput->False,
      FontWeight->Bold,
      Background->RGBColor[1, 1, 0]]},
    {
     StyleBox["2",
      StripOnInput->False,
      FontWeight->Bold,
      Background->RGBColor[1, 1, 0]], 
     StyleBox["3",
      StripOnInput->False,
      FontWeight->Bold,
      Background->RGBColor[1, 1, 0]]}
   },
   AutoDelete->False,
   GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Print",
 CellChangeTimes->{3.6857126215642843`*^9}],

Cell[BoxData[
 RowBox[{
  TagBox[GridBox[{
     {"9", "9"},
     {
      StyleBox["7",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["8",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {"5", "5"},
     {
      StyleBox["3",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["4",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "+", 
  TagBox[GridBox[{
     {"9", "9"},
     {
      StyleBox["7",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["8",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {
      StyleBox["3",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["4",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {"2", "2"}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "+", 
  TagBox[GridBox[{
     {
      StyleBox["7",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["8",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {"6", "6"},
     {"5", "5"},
     {
      StyleBox["3",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["4",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "+", 
  TagBox[GridBox[{
     {
      StyleBox["7",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["8",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {"6", "6"},
     {
      StyleBox["3",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["4",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {"2", "2"}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"]}]], "Print",
 CellChangeTimes->{3.685712621565434*^9}],

Cell[BoxData[
 RowBox[{
  TagBox[GridBox[{
     {"9", "9"},
     {
      StyleBox["7",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["8",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {"2", "2"},
     {"1", "1"}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "+", 
  TagBox[GridBox[{
     {"9", "9"},
     {
      StyleBox["7",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["8",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {"3", "3"},
     {"2", "2"}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "+", 
  TagBox[GridBox[{
     {"9", "9"},
     {
      StyleBox["7",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["8",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {"5", "5"},
     {"1", "1"}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "+", 
  TagBox[GridBox[{
     {"9", "9"},
     {
      StyleBox["7",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["8",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {"5", "5"},
     {"3", "3"}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "+", 
  TagBox[GridBox[{
     {
      StyleBox["7",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["8",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {"6", "6"},
     {"2", "2"},
     {"1", "1"}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "+", 
  TagBox[GridBox[{
     {
      StyleBox["7",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["8",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {"6", "6"},
     {"3", "3"},
     {"2", "2"}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "+", 
  TagBox[GridBox[{
     {
      StyleBox["7",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["8",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {"6", "6"},
     {"5", "5"},
     {"1", "1"}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "+", 
  TagBox[GridBox[{
     {
      StyleBox["7",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["8",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {"6", "6"},
     {"5", "5"},
     {"3", "3"}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"]}]], "Print",
 CellChangeTimes->{3.68571262156686*^9}],

Cell[BoxData[
 RowBox[{
  TagBox[GridBox[{
     {
      StyleBox["8",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["9",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {
      StyleBox["6",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["7",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {"2", "2"},
     {"1", "1"}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "+", 
  TagBox[GridBox[{
     {
      StyleBox["8",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["9",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {
      StyleBox["6",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["7",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {"3", "3"},
     {"2", "2"}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "+", 
  TagBox[GridBox[{
     {
      StyleBox["8",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["9",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {
      StyleBox["6",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["7",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {"5", "5"},
     {"1", "1"}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"], "+", 
  TagBox[GridBox[{
     {
      StyleBox["8",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["9",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {
      StyleBox["6",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]], 
      StyleBox["7",
       StripOnInput->False,
       FontWeight->Bold,
       Background->RGBColor[1, 1, 0]]},
     {"5", "5"},
     {"3", "3"}
    },
    AutoDelete->False,
    GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
   "Grid"]}]], "Print",
 CellChangeTimes->{3.6857126215681267`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1280, 974},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"10.3 for Linux x86 (64-bit) (December 10, 2015)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[422, 15, 245, 3, 93, "Title"],
Cell[670, 20, 407, 8, 71, "Text"],
Cell[CellGroupData[{
Cell[1102, 32, 349, 5, 65, "Section"],
Cell[CellGroupData[{
Cell[1476, 41, 366, 6, 32, "Input"],
Cell[1845, 49, 3880, 60, 537, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5774, 115, 173, 2, 65, "Section"],
Cell[CellGroupData[{
Cell[5972, 121, 17290, 334, 976, "Input"],
Cell[CellGroupData[{
Cell[23287, 459, 1748, 24, 23, "Print"],
Cell[25038, 485, 1832, 28, 23, "Print"],
Cell[26873, 515, 1858, 28, 23, "Print"],
Cell[28734, 545, 1905, 30, 23, "Print"],
Cell[30642, 577, 1933, 30, 23, "Print"],
Cell[32578, 609, 1933, 30, 23, "Print"],
Cell[34514, 641, 1894, 30, 23, "Print"],
Cell[36411, 673, 1896, 30, 23, "Print"],
Cell[38310, 705, 1973, 32, 23, "Print"],
Cell[40286, 739, 1738, 24, 23, "Print"],
Cell[42027, 765, 2167, 35, 23, "Print"],
Cell[44197, 802, 1756, 25, 23, "Print"],
Cell[45956, 829, 1755, 25, 23, "Print"],
Cell[47714, 856, 1774, 25, 23, "Print"],
Cell[49491, 883, 1771, 25, 23, "Print"],
Cell[51265, 910, 1856, 28, 23, "Print"],
Cell[53124, 940, 1849, 28, 23, "Print"],
Cell[54976, 970, 1852, 28, 23, "Print"],
Cell[56831, 1000, 1854, 28, 23, "Print"],
Cell[58688, 1030, 2106, 34, 23, "Print"],
Cell[60797, 1066, 1738, 24, 23, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[62596, 1097, 469, 6, 65, "Section"],
Cell[CellGroupData[{
Cell[63090, 1107, 1619, 39, 121, "Input"],
Cell[64712, 1148, 341, 5, 65, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[65102, 1159, 348, 4, 65, "Section"],
Cell[CellGroupData[{
Cell[65475, 1167, 250, 4, 32, "Input"],
Cell[CellGroupData[{
Cell[65750, 1175, 1962, 41, 58, "Print"],
Cell[67715, 1218, 1683, 36, 58, "Print"]
}, Open  ]]
}, Open  ]],
Cell[69425, 1258, 1465, 30, 77, "Input"],
Cell[CellGroupData[{
Cell[70915, 1292, 3138, 66, 165, "Input"],
Cell[74056, 1360, 12404, 350, 242, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[86497, 1715, 194, 3, 32, "Input"],
Cell[CellGroupData[{
Cell[86716, 1722, 2110, 45, 58, "Print"],
Cell[88829, 1769, 1801, 39, 58, "Print"],
Cell[90633, 1810, 1793, 38, 53, "Print"],
Cell[92429, 1850, 1702, 36, 23, "Print"],
Cell[94134, 1888, 1167, 19, 23, "Print"],
Cell[95304, 1909, 3466, 67, 100, "Print"],
Cell[98773, 1978, 1896, 37, 100, "Print"],
Cell[100672, 2017, 941, 14, 23, "Print"],
Cell[101616, 2033, 1220, 22, 23, "Print"],
Cell[102839, 2057, 939, 14, 23, "Print"],
Cell[103781, 2073, 1219, 22, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[105049, 2101, 6509, 108, 170, "Input"],
Cell[CellGroupData[{
Cell[111583, 2213, 2476, 35, 43, "Print"],
Cell[114062, 2250, 2588, 43, 23, "Print"],
Cell[116653, 2295, 2470, 38, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[119172, 2339, 123, 2, 32, "Input"],
Cell[CellGroupData[{
Cell[119320, 2345, 27999, 663, 107, "Print"],
Cell[147322, 3010, 2094, 50, 39, "Print"]
}, Open  ]]
}, Open  ]],
Cell[149443, 3064, 150, 3, 32, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[149630, 3072, 360, 5, 65, "Section"],
Cell[CellGroupData[{
Cell[150015, 3081, 250, 4, 32, "Input"],
Cell[CellGroupData[{
Cell[150290, 3089, 1110, 19, 23, "Print"],
Cell[151403, 3110, 9767, 267, 93, "Print"],
Cell[161173, 3379, 1195, 21, 23, "Print"],
Cell[162371, 3402, 1952, 42, 79, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[164384, 3451, 274, 3, 65, "Section"],
Cell[CellGroupData[{
Cell[164683, 3458, 250, 4, 32, "Input"],
Cell[CellGroupData[{
Cell[164958, 3466, 2323, 53, 58, "Print"],
Cell[167284, 3521, 1110, 19, 23, "Print"],
Cell[168397, 3542, 1025, 19, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[169449, 3565, 273, 6, 32, "Input"],
Cell[169725, 3573, 449, 7, 51, "Text"],
Cell[CellGroupData[{
Cell[170199, 3584, 220, 4, 32, "Input"],
Cell[CellGroupData[{
Cell[170444, 3592, 647, 9, 23, "Print"],
Cell[171094, 3603, 667, 10, 23, "Print"],
Cell[171764, 3615, 1204, 24, 33, "Print"],
Cell[172971, 3641, 661, 9, 23, "Print"],
Cell[173635, 3652, 661, 9, 23, "Print"],
Cell[174299, 3663, 1202, 24, 33, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[175550, 3693, 222, 4, 32, "Input"],
Cell[CellGroupData[{
Cell[175797, 3701, 757, 17, 33, "Print"],
Cell[176557, 3720, 231, 3, 23, "Print"],
Cell[176791, 3725, 225, 3, 23, "Print"],
Cell[177019, 3730, 757, 17, 33, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[177825, 3753, 220, 4, 32, "Input"],
Cell[CellGroupData[{
Cell[178070, 3761, 1108, 19, 23, "Print"],
Cell[179181, 3782, 2283, 52, 44, "Print"],
Cell[181467, 3836, 3208, 72, 59, "Print"],
Cell[184678, 3910, 1867, 39, 57, "Print"],
Cell[186548, 3951, 1095, 15, 43, "Print"],
Cell[187646, 3968, 883, 12, 23, "Print"],
Cell[188532, 3982, 885, 12, 23, "Print"],
Cell[189420, 3996, 1432, 27, 33, "Print"],
Cell[190855, 4025, 880, 12, 23, "Print"],
Cell[191738, 4039, 1432, 27, 33, "Print"],
Cell[193173, 4068, 9087, 159, 206, "Print"],
Cell[202263, 4229, 1216, 22, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[203506, 4255, 226, 6, 32, "Input"],
Cell[CellGroupData[{
Cell[203757, 4265, 2326, 43, 143, "Input"],
Cell[CellGroupData[{
Cell[206108, 4312, 2132, 35, 62, "Print"],
Cell[208243, 4349, 2328, 38, 81, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[210632, 4394, 374, 5, 65, "Section"],
Cell[211009, 4401, 212, 3, 32, "Input"],
Cell[211224, 4406, 400, 7, 31, "Text"],
Cell[CellGroupData[{
Cell[211649, 4417, 2303, 43, 143, "Input"],
Cell[CellGroupData[{
Cell[213977, 4464, 3552, 54, 33, "Print"],
Cell[217532, 4520, 3231, 44, 23, "Print"],
Cell[220766, 4566, 3389, 49, 23, "Print"],
Cell[224158, 4617, 3552, 54, 33, "Print"],
Cell[227713, 4673, 3559, 54, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[231299, 4731, 347, 8, 32, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[231683, 4744, 434, 5, 65, "Section"],
Cell[232120, 4751, 405, 7, 32, "Input"],
Cell[CellGroupData[{
Cell[232550, 4762, 846, 16, 121, "Input"],
Cell[233399, 4780, 651, 15, 367, "Print"],
Cell[234053, 4797, 1049, 29, 62, "Output"]
}, Open  ]],
Cell[235117, 4829, 427, 7, 51, "Text"],
Cell[CellGroupData[{
Cell[235569, 4840, 1178, 25, 99, "Input"],
Cell[236750, 4867, 187, 3, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[236974, 4875, 1181, 23, 77, "Input"],
Cell[CellGroupData[{
Cell[238180, 4902, 1820, 30, 33, "Print"],
Cell[240003, 4934, 2616, 53, 222, "Print"],
Cell[242622, 4989, 1657, 25, 23, "Print"],
Cell[244282, 5016, 2491, 46, 85, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[246822, 5068, 89, 2, 32, "Input"],
Cell[246914, 5072, 30909, 658, 477, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[277860, 5735, 925, 21, 77, "Input"],
Cell[CellGroupData[{
Cell[278810, 5760, 1798, 32, 33, "Print"],
Cell[280611, 5794, 1236, 17, 23, "Print"],
Cell[281850, 5813, 1413, 22, 23, "Print"],
Cell[283266, 5837, 1796, 32, 33, "Print"]
}, Open  ]]
}, Open  ]],
Cell[285089, 5873, 232, 4, 31, "Text"],
Cell[CellGroupData[{
Cell[285346, 5881, 159, 3, 32, "Input"],
Cell[285508, 5886, 3615, 134, 77, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[289160, 6025, 205, 4, 32, "Input"],
Cell[289368, 6031, 23069, 482, 482, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[312474, 6518, 334, 7, 32, "Input"],
Cell[312811, 6527, 11204, 238, 442, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[324052, 6770, 868, 16, 99, "Input"],
Cell[324923, 6788, 3719, 85, 188, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[328679, 6878, 338, 8, 89, "Input"],
Cell[CellGroupData[{
Cell[329042, 6890, 4055, 146, 76, "Print"],
Cell[333100, 7038, 2927, 106, 76, "Print"],
Cell[336030, 7146, 1164, 43, 76, "Print"],
Cell[337197, 7191, 2923, 106, 76, "Print"],
Cell[340123, 7299, 4046, 146, 76, "Print"],
Cell[344172, 7447, 2925, 106, 76, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

