(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[         0,          0]
NotebookDataLength[   1509622,      30541]
NotebookOptionsPosition[   1500529,      30254]
NotebookOutlinePosition[   1500868,      30269]
CellTagsIndexPosition[   1500825,      30266]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["GlueingBSAAx4e.nb", "Title",
 CellChangeTimes->{{3.683902871124304*^9, 3.68390290606082*^9}, {
   3.6839498343279467`*^9, 3.683949835151998*^9}, {3.684141648169284*^9, 
   3.684141649737145*^9}, {3.6841417156830883`*^9, 3.684141717706863*^9}, 
   3.685713748603252*^9}],

Cell["\<\
Description: 
We compute a type AA structure for glueing two tangles. The underlying \
3-manifold is a thickened 4-punctured sphere. We use a parametrization of the \
two glueing surfaces such that the basepoints are on diagonally opposite \
tangle ends.\
\>", "Text",
 CellChangeTimes->{{3.683950109886711*^9, 3.68395027867488*^9}, {
   3.683950357452958*^9, 3.683950446367662*^9}, 3.6857137535923758`*^9}],

Cell[CellGroupData[{

Cell["Load package BSFH.m", "Section",
 CellChangeTimes->{{3.683902406280332*^9, 3.683902411992662*^9}, {
  3.6839024516165123`*^9, 3.683902475521956*^9}, {3.68390335323253*^9, 
  3.683903371168364*^9}, {3.683949830312366*^9, 3.683949830550836*^9}, {
  3.685186908447523*^9, 3.6851869085320377`*^9}, {3.685198191575903*^9, 
  3.685198207056624*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "BSFH.m"}]], "Input",
 CellChangeTimes->{{3.683896286022256*^9, 3.683896288299066*^9}, {
  3.6839021785176077`*^9, 3.6839021860575857`*^9}, {3.6839491778963013`*^9, 
  3.6839491783118887`*^9}, {3.685186971048904*^9, 3.685186973487808*^9}, {
  3.685187264296172*^9, 3.685187267583693*^9}, {3.685203668910954*^9, 
  3.685203670179483*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"This is BSFH.m, version 1.0, \\na tool for computing bordered \
sutured Heegaard Floer homology,\\nbased on an algorithm due to Rumen \
Zarev,\\nwritten in Mathematica 10.3.1.0 for Linux x86 (64-bit). \\nA manual \
for this Mathematica package can be found in appendix D of\\n\\n   C.B. \
Zibrowius, \"\>", "\[InvisibleSpace]", 
   StyleBox["\<\"On a Heegaard Floer theory for tangles\"\>",
    StripOnInput->False,
    FontSlant->Italic], 
   "\[InvisibleSpace]", "\<\", PhD thesis (2016), Cambridge. \\n\\nFor more \
background on bordered sutured Floer theory, see\\n\\n   R. Zarev, \"\>", 
   "\[InvisibleSpace]", 
   StyleBox["\<\"Bordered Floer homology for sutured manifolds\"\>",
    StripOnInput->False,
    FontSlant->Italic], 
   "\[InvisibleSpace]", "\<\", arXiv: 0908.1106v2.\\n\\nFor questions, \
suggestions or comments, please email claudius.zibrowius\"\>", 
   "\[InvisibleSpace]", "\<\"@\"\>", 
   "\[InvisibleSpace]", "\<\"gmail.com. \\n\\n    Copyright (C) 2015-2016 \
Claudius Zibrowius\\n\\n    This program is free software: you can \
redistribute it and/or modify\\n    it under the terms of the GNU Affero \
General Public License as published by\\n    the Free Software Foundation, \
either version 3 of the License, or\\n    (at your option) any later version.\
\\n\\n    This program is distributed in the hope that it will be useful,\\n  \
  but WITHOUT ANY WARRANTY; without even the implied warranty of\\n    \
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\\n    GNU \
Affero General Public License for more details.\\n\\n    You should have \
received a copy of the GNU Affero General Public License\\n    along with \
this program.  If not, see <http://www.gnu.org/licenses/>.\"\>"}],
  SequenceForm[
  "This is BSFH.m, version 1.0, \na tool for computing bordered sutured \
Heegaard Floer homology,\nbased on an algorithm due to Rumen Zarev,\nwritten \
in Mathematica 10.3.1.0 for Linux x86 (64-bit). \nA manual for this \
Mathematica package can be found in appendix D of\n\n   C.B. Zibrowius, ", 
   Style["On a Heegaard Floer theory for tangles", Italic], 
   ", PhD thesis (2016), Cambridge. \n\nFor more background on bordered \
sutured Floer theory, see\n\n   R. Zarev, ", 
   Style["Bordered Floer homology for sutured manifolds", Italic], 
   ", arXiv: 0908.1106v2.\n\nFor questions, suggestions or comments, please \
email claudius.zibrowius", "@", 
   "gmail.com. \n\n    Copyright (C) 2015-2016 Claudius Zibrowius\n\n    This \
program is free software: you can redistribute it and/or modify\n    it under \
the terms of the GNU Affero General Public License as published by\n    the \
Free Software Foundation, either version 3 of the License, or\n    (at your \
option) any later version.\n\n    This program is distributed in the hope \
that it will be useful,\n    but WITHOUT ANY WARRANTY; without even the \
implied warranty of\n    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. \
 See the\n    GNU Affero General Public License for more details.\n\n    You \
should have received a copy of the GNU Affero General Public License\n    \
along with this program.  If not, see <http://www.gnu.org/licenses/>."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.685203698151988*^9, 3.685203705067401*^9}, 
   3.6852037817068872`*^9, 3.6852038625098257`*^9, 3.685246622224927*^9, 
   3.6852477466607237`*^9, 3.685248986779213*^9, 3.6852491665949183`*^9, 
   3.685254474431779*^9, {3.6852587902608347`*^9, 3.685258792835278*^9}, 
   3.68525890264445*^9, 3.68569631512576*^9, 3.685696390769709*^9, 
   3.6856967870706177`*^9, {3.685697053247446*^9, 3.68569712335627*^9}, 
   3.685697159326499*^9, 3.685697193749625*^9, 3.685697311945281*^9, 
   3.685699411414978*^9, 3.6857060379482727`*^9, 3.685711666174616*^9, 
   3.685712330216119*^9, 3.685712543738003*^9, 3.685713772901455*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input data from nice Heegaard diagram", "Section",
 CellChangeTimes->{{3.683902406280332*^9, 3.683902411992662*^9}, {
  3.6839024516165123`*^9, 3.683902475521956*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"regionsInput", "=", " ", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "73", "72", "25", "24"},
       {"2", "74", "73", "24", "23"},
       {"3", "75", "74", "23", "22"},
       {"4", "76", "75", "22", "21"},
       {"5", "20", "19", "68", "67"},
       {"6", "19", "18", "69", "68"},
       {"7", "18", "17", "70", "69"},
       {"8", "17", "16", "71", "70"},
       {"9", "81", "80", "35", "34"},
       {"10", "80", "79", "36", "35"},
       {"11", "79", "78", "37", "36"},
       {"12", "78", "77", "38", "37"},
       {"13", "86", "85", "40", "39"},
       {"14", "85", "84", "41", "40"},
       {"15", "84", "83", "42", "41"},
       {"16", "83", "82", "43", "42"},
       {"17", "23", "24", "3", "4"},
       {"18", "24", "25", "2", "3"},
       {"19", "25", "2", "\[Placeholder]", "\[Placeholder]"},
       {"20", "2", "1", "\[Placeholder]", "\[Placeholder]"},
       {"21", "1", "16", "\[Placeholder]", "\[Placeholder]"},
       {"22", "47", "48", "68", "69"},
       {"23", "48", "49", "67", "68"},
       {"24", "49", "67", "\[Placeholder]", "\[Placeholder]"},
       {"25", "50", "49", "\[Placeholder]", "\[Placeholder]"},
       {"26", "76", "50", "\[Placeholder]", "\[Placeholder]"},
       {"27", "11", "12", "35", "36"},
       {"28", "12", "13", "34", "35"},
       {"29", "13", "34", "\[Placeholder]", "\[Placeholder]"},
       {"30", "14", "13", "\[Placeholder]", "\[Placeholder]"},
       {"31", "43", "14", "\[Placeholder]", "\[Placeholder]"},
       {"32", "84", "85", "54", "55"},
       {"33", "85", "86", "53", "54"},
       {"34", "86", "53", "\[Placeholder]", "\[Placeholder]"},
       {"35", "53", "52", "\[Placeholder]", "\[Placeholder]"},
       {"36", "52", "77", "\[Placeholder]", "\[Placeholder]"},
       {"37", "71", "72", "\[Placeholder]", "\[Placeholder]"},
       {"38", "70", "71", "72", "73"},
       {"39", "20", "21", "\[Placeholder]", "\[Placeholder]"},
       {"40", "19", "20", "21", "22"},
       {"41", "81", "82", "\[Placeholder]", "\[Placeholder]"},
       {"42", "80", "81", "82", "83"},
       {"43", "38", "39", "\[Placeholder]", "\[Placeholder]"},
       {"44", "37", "38", "39", "40"},
       {"45", "5", "6", "27", "28"},
       {"46", "6", "7", "26", "27"},
       {"47", "7", "26", "\[Placeholder]", "\[Placeholder]"},
       {"48", "8", "7", "\[Placeholder]", "\[Placeholder]"},
       {"49", "33", "8", "\[Placeholder]", "\[Placeholder]"},
       {"50", "32", "33", "8", "9"},
       {"51", "31", "32", "9", "10"},
       {"52", "56", "57", "65", "64"},
       {"53", "57", "58", "66", "65"},
       {"54", "58", "66", "\[Placeholder]", "\[Placeholder]"},
       {"55", "44", "58", "\[Placeholder]", "\[Placeholder]"},
       {"56", "59", "44", "\[Placeholder]", "\[Placeholder]"},
       {"57", "44", "45", "60", "59"},
       {"58", "45", "46", "61", "60"},
       {"59", "5", "4", "\[Placeholder]", "\[Placeholder]"},
       {"60", "6", "5", "4", "3"},
       {"61", "11", "10", "\[Placeholder]", "\[Placeholder]"},
       {"62", "12", "11", "10", "9"},
       {"63", "56", "55", "\[Placeholder]", "\[Placeholder]"},
       {"64", "57", "56", "55", "54"},
       {"65", "47", "46", "\[Placeholder]", "\[Placeholder]"},
       {"66", "48", "47", "46", "45"},
       {"67", "27", "26", "\[Placeholder]", "\[Placeholder]"},
       {"68", "33", "32", "\[Placeholder]", "\[Placeholder]"},
       {"69", "63", "62", "\[Placeholder]", "\[Placeholder]"},
       {"70", "65", "66", "\[Placeholder]", "\[Placeholder]"},
       {"71", "59", "60", "\[Placeholder]", "\[Placeholder]"},
       {"72", "29", "30", "\[Placeholder]", "\[Placeholder]"},
       {"73", "61", "62", "17", "18"},
       {"74", "29", "28", "74", "75"},
       {"75", "31", "30", "78", "79"},
       {"76", "63", "64", "41", "42"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"alphaarcsInput", "=", 
   RowBox[{"(", GridBox[{
      {"1", 
       RowBox[{"{", "1", "}"}]},
      {"2", 
       RowBox[{"Range", "[", 
        RowBox[{"2", ",", "7"}], "]"}]},
      {"3", 
       RowBox[{"Range", "[", 
        RowBox[{"8", ",", "13"}], "]"}]},
      {"4", 
       RowBox[{"{", 
        RowBox[{"14", ",", "15"}], "}"}]},
      {"5", 
       RowBox[{"Range", "[", 
        RowBox[{"16", ",", "25"}], "]"}]},
      {"6", 
       RowBox[{"Range", "[", 
        RowBox[{"26", ",", "33"}], "]"}]},
      {"7", 
       RowBox[{"Range", "[", 
        RowBox[{"34", ",", "43"}], "]"}]},
      {"8", 
       RowBox[{"Range", "[", 
        RowBox[{"44", ",", "49"}], "]"}]},
      {"9", 
       RowBox[{"{", "50", "}"}]},
      {"10", 
       RowBox[{"{", 
        RowBox[{"51", ",", "52"}], "}"}]},
      {"11", 
       RowBox[{"Range", "[", 
        RowBox[{"53", ",", "58"}], "]"}]},
      {"12", 
       RowBox[{"Range", "[", 
        RowBox[{"59", ",", "66"}], "]"}]},
      {"13", 
       RowBox[{"Range", "[", 
        RowBox[{"67", ",", "76"}], "]"}]},
      {"14", 
       RowBox[{"Range", "[", 
        RowBox[{"77", ",", "86"}], "]"}]}
     }], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"alphacurvesInput", "=", 
    RowBox[{"{", "}"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"If", " ", "there", " ", "were", " ", "any", " ", "\[Alpha]"}], 
     "-", 
     RowBox[{
     "curves", " ", "we", " ", "would", " ", "start", " ", "counting", " ", 
      "at", " ", 
      RowBox[{"Length", "[", "alphaarcsInput", "]"}]}], "+", "1"}], "=", 
    "15."}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"betacurvesInput", "=", 
   RowBox[{"(", GridBox[{
      {"1", 
       RowBox[{"{", "15", "}"}]},
      {"2", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", "25", ",", "72", ",", "71", ",", "16"}], 
        "}"}]},
      {"3", 
       RowBox[{"{", 
        RowBox[{
        "8", ",", "33", ",", "32", ",", "9", ",", "12", ",", "35", ",", "80", 
         ",", "83", ",", "42", ",", "63", ",", "62", ",", "17", ",", "70", 
         ",", "73", ",", "24", ",", "3", ",", "6", ",", "27", ",", "26", ",", 
         "7"}], "}"}]},
      {"4", 
       RowBox[{"{", 
        RowBox[{"14", ",", "43", ",", "82", ",", "81", ",", "34", ",", "13"}],
         "}"}]},
      {"5", 
       RowBox[{"{", 
        RowBox[{
        "44", ",", "59", ",", "60", ",", "45", ",", "48", ",", "68", ",", 
         "19", ",", "22", ",", "75", ",", "29", ",", "30", ",", "78", ",", 
         "37", ",", "40", ",", "85", ",", "54", ",", "57", ",", "65", ",", 
         "66", ",", "58"}], "}"}]},
      {"6", 
       RowBox[{"{", 
        RowBox[{"50", ",", "76", ",", "21", ",", "20", ",", "67", ",", "49"}],
         "}"}]},
      {"7", 
       RowBox[{"{", "51", "}"}]},
      {"8", 
       RowBox[{"{", 
        RowBox[{"53", ",", "86", ",", "39", ",", "38", ",", "77", ",", "52"}],
         "}"}]},
      {"9", 
       RowBox[{"{", 
        RowBox[{"61", ",", "46", ",", "47", ",", "69", ",", "18"}], "}"}]},
      {"10", 
       RowBox[{"{", 
        RowBox[{"74", ",", "23", ",", "4", ",", "5", ",", "28"}], "}"}]},
      {"11", 
       RowBox[{"{", 
        RowBox[{"31", ",", "10", ",", "11", ",", "36", ",", "79"}], "}"}]},
      {"12", 
       RowBox[{"{", 
        RowBox[{"41", ",", "84", ",", "55", ",", "56", ",", "64"}], "}"}]}
     }], ")"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"CancellationSortListInput", "=", 
   TagBox[
    RowBox[{"(", GridBox[{
       {"29", "30"},
       {"63", "62"},
       {"38", "39"},
       {"20", "21"},
       {"71", "72"},
       {"81", "82"},
       {"37", "40"},
       {"19", "22"},
       {"70", "73"},
       {"80", "83"},
       {"65", "66"},
       {"59", "60"},
       {"27", "26"},
       {"33", "32"},
       {"57", "58"},
       {"44", "45"},
       {"6", "7"},
       {"8", "9"},
       {"47", "46"},
       {"56", "55"},
       {"5", "4"},
       {"11", "10"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}, "Items" -> {}, 
        "ItemsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}, "Items" -> {}, 
        "ItemsIndexed" -> {}}], ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"RelevantGeneratorQ", "[", "v_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"Count", "[", 
      RowBox[{"v", ",", 
       RowBox[{"e_", "/;", 
        RowBox[{
         RowBox[{"WhichAlphaQ", "[", "e", "]"}], "<", "8"}]}]}], "]"}], 
     "\[Equal]", "6"}], "&&", 
    RowBox[{
     RowBox[{"Count", "[", 
      RowBox[{"v", ",", 
       RowBox[{"e_", "/;", 
        RowBox[{
         RowBox[{"WhichAlphaQ", "[", "e", "]"}], ">", "7"}]}]}], "]"}], 
     "\[Equal]", "6"}], "&&", 
    RowBox[{"MemberQ", "[", 
     RowBox[{
      RowBox[{"WhichAlphaQ", "/@", "v"}], ",", "5"}], "]"}], "&&", 
    RowBox[{"MemberQ", "[", 
     RowBox[{
      RowBox[{"WhichAlphaQ", "/@", "v"}], ",", "6"}], "]"}], "&&", 
    RowBox[{"MemberQ", "[", 
     RowBox[{
      RowBox[{"WhichAlphaQ", "/@", "v"}], ",", "7"}], "]"}], "&&", 
    RowBox[{"MemberQ", "[", 
     RowBox[{
      RowBox[{"WhichAlphaQ", "/@", "v"}], ",", "12"}], "]"}], "&&", 
    RowBox[{"MemberQ", "[", 
     RowBox[{
      RowBox[{"WhichAlphaQ", "/@", "v"}], ",", "13"}], "]"}], "&&", 
    RowBox[{"MemberQ", "[", 
     RowBox[{
      RowBox[{"WhichAlphaQ", "/@", "v"}], ",", "14"}], "]"}]}]}], ";", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "This", " ", "means", " ", "we", " ", "only", " ", "consider", " ", 
      "those", " ", "generators", " ", "relevant", " ", "which", " ", 
      "occupy", " ", "exactly", " ", "2", " ", "\[Alpha]"}], "-", 
     RowBox[{
     "curves", " ", "with", " ", "index", " ", "greater", " ", "than", " ", 
      "3.", " ", "Here"}]}], ",", " ", 
    RowBox[{
    "we", " ", "want", " ", "the", " ", "silly", " ", "arcs", " ", "to", " ", 
     "be", " ", "always", " ", 
     RowBox[{"occupied", "."}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"RelevantGeneratorGenerationQ", "[", "listOfAlphas_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"Count", "[", 
      RowBox[{"listOfAlphas", ",", 
       RowBox[{"e_", "/;", 
        RowBox[{"e", "<", "8"}]}]}], "]"}], "\[LessEqual]", "6"}], "&&", 
    RowBox[{
     RowBox[{"Count", "[", 
      RowBox[{"listOfAlphas", ",", 
       RowBox[{"e_", "/;", 
        RowBox[{"e", ">", "7"}]}]}], "]"}], "\[LessEqual]", "6"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"S1BoundaryInput", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"21", ",", "20", ",", "19"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"47", ",", "48", ",", "49"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"29", ",", "30", ",", "31"}], "}"}], ",", 
     RowBox[{"{", "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"TypeS1", "=", "TypeA"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"S2BoundaryInput", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"36", ",", "35", ",", "34"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"54", ",", "55", ",", "56"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"24", ",", "25", ",", "26"}], "}"}], ",", 
     RowBox[{"{", "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"TypeS2", "=", "TypeA"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"ArcDiagram1MatchingsInput", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"12", ",", "14"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "13"}], "}"}]}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"ArcDiagram2MatchingsInput", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"8", ",", "11"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"12", ",", "14"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"4", ",", "7"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"6", ",", "9"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"10", ",", "13"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "5"}], "}"}]}], "}"}]}], ";"}], 
  "  "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"S1AlwaysOccupiedAlphaArcs", "=", 
   RowBox[{"{", 
    RowBox[{"5", ",", "6", ",", "7"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"S2AlwaysOccupiedAlphaArcs", "=", 
   RowBox[{"{", 
    RowBox[{"12", ",", "13", ",", "14"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"S1PotentiallyOccupiedAlphaArcs", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"S2PotentiallyOccupiedAlphaArcs", "=", 
   RowBox[{"{", 
    RowBox[{"8", ",", "9", ",", "10", ",", "11"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"S1NeverOccupiedAlphaArcs", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"S2NeverOccupiedAlphaArcs", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"NS1oaa", "=", "6"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"NS2oaa", "=", "6"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NR", "=", "76"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"NI", "=", "86"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Step0Preparation", ";"}]}], "Input",
 CellChangeTimes->{{3.6497530722503233`*^9, 3.6497531640105715`*^9}, {
   3.649753200182641*^9, 3.6497532306203814`*^9}, {3.649753295437089*^9, 
   3.6497537205584044`*^9}, {3.649753809663501*^9, 3.6497540947948093`*^9}, {
   3.64975417591745*^9, 3.6497544232615967`*^9}, {3.649754582102682*^9, 
   3.6497546193148108`*^9}, {3.6497597447969356`*^9, 3.649759820857286*^9}, {
   3.6497598739923253`*^9, 3.6497600406208553`*^9}, {3.6498348056844025`*^9, 
   3.649834809398615*^9}, {3.6500118158196554`*^9, 3.6500119552486305`*^9}, {
   3.6500120907763824`*^9, 3.650012100424934*^9}, {3.6500121318167295`*^9, 
   3.6500121752402134`*^9}, {3.650012235023633*^9, 3.6500124904712434`*^9}, {
   3.6500125549099293`*^9, 3.6500135229893*^9}, {3.6500137752877307`*^9, 
   3.6500137980100307`*^9}, {3.650014346297391*^9, 3.6500144942018504`*^9}, {
   3.651649531551473*^9, 3.651649715648744*^9}, {3.651649748025792*^9, 
   3.651650111090334*^9}, {3.651650146439418*^9, 3.6516501589804354`*^9}, {
   3.651650192001482*^9, 3.651650433735837*^9}, {3.6516504753718996`*^9, 
   3.6516519704441*^9}, {3.651652054997223*^9, 3.651652060628233*^9}, {
   3.6519345605327864`*^9, 3.6519345810648155`*^9}, {3.6519358757890897`*^9, 
   3.6519358917171125`*^9}, {3.6519359368331766`*^9, 
   3.6519359370731773`*^9}, {3.651935978236236*^9, 3.6519360167562904`*^9}, {
   3.651936124565445*^9, 3.651936172629513*^9}, {3.651936220229581*^9, 
   3.6519362497016225`*^9}, {3.651936345052758*^9, 3.651937012110732*^9}, {
   3.6519370562627954`*^9, 3.651937314038168*^9}, {3.651937665336673*^9, 
   3.651937669427678*^9}, {3.6519377101977406`*^9, 3.651937863584965*^9}, {
   3.651937897214015*^9, 3.6519381861784363`*^9}, {3.6519382217124863`*^9, 
   3.6519384265657835`*^9}, {3.6519384666458426`*^9, 3.651938520239919*^9}, {
   3.6519385515209646`*^9, 3.6519388240813603`*^9}, {3.651938855954406*^9, 
   3.6519388862824492`*^9}, {3.6519392745537353`*^9, 
   3.6519392799437428`*^9}, {3.6519393372788243`*^9, 
   3.6519393914219007`*^9}, {3.651939423092946*^9, 3.6519395761171694`*^9}, {
   3.651939612384222*^9, 3.651939714064367*^9}, {3.65193975111042*^9, 
   3.6519399760747414`*^9}, {3.651941430807907*^9, 3.6519414332769117`*^9}, {
   3.651945362054637*^9, 3.651945363210703*^9}, {3.6519454225397882`*^9, 
   3.6519455694779973`*^9}, {3.651945720107213*^9, 3.6519457916863155`*^9}, {
   3.6519458487563953`*^9, 3.651945862358415*^9}, {3.651945927406509*^9, 
   3.651946006478621*^9}, {3.6519460579536943`*^9, 3.6519461737618604`*^9}, {
   3.651946204178903*^9, 3.651946227686937*^9}, {3.651946265880993*^9, 
   3.6519466589295626`*^9}, {3.651946690234609*^9, 3.6519467289476686`*^9}, {
   3.6519467600477147`*^9, 3.651946934603969*^9}, {3.6519469707200203`*^9, 
   3.6519470228180943`*^9}, {3.6519472390614033`*^9, 
   3.6519472412114067`*^9}, {3.6519472854534683`*^9, 
   3.6519473691605873`*^9}, {3.651948557668288*^9, 3.651948558138289*^9}, {
   3.6523417291331387`*^9, 3.652341766577015*^9}, {3.652343691754648*^9, 
   3.652343701715831*^9}, {3.65234386740432*^9, 3.6523439446431303`*^9}, {
   3.652344032687261*^9, 3.6523440596433907`*^9}, {3.652358747272119*^9, 
   3.652358986818255*^9}, {3.6523590916238422`*^9, 3.652359092089066*^9}, {
   3.652378686654628*^9, 3.652378730052348*^9}, {3.652378811671297*^9, 
   3.652378858709206*^9}, {3.6523789541849403`*^9, 3.65237921139062*^9}, 
   3.652379257576953*^9, {3.652507866916305*^9, 3.652507867239162*^9}, {
   3.6527159962477207`*^9, 3.652716042325199*^9}, {3.652716363312395*^9, 
   3.65271680328963*^9}, {3.6527169177729797`*^9, 3.652716918059433*^9}, {
   3.652717303055015*^9, 3.65271730330694*^9}, {3.652790736845571*^9, 
   3.65279074215808*^9}, {3.652790774966799*^9, 3.652790789743931*^9}, 
   3.653124165618794*^9, 3.653125890605195*^9, {3.6534471181783257`*^9, 
   3.653447122852326*^9}, {3.6534471620035152`*^9, 3.653447327499275*^9}, {
   3.653447448194496*^9, 3.6534478276643457`*^9}, {3.653447881673066*^9, 
   3.6534480504974194`*^9}, {3.653448089596459*^9, 3.653448208613467*^9}, {
   3.653448239094824*^9, 3.653449345615569*^9}, {3.653449384296937*^9, 
   3.653449507080082*^9}, {3.653449554328115*^9, 3.653449742551841*^9}, {
   3.653449805976263*^9, 3.653449861005069*^9}, {3.653449898022132*^9, 
   3.653450094006476*^9}, {3.653450148433264*^9, 3.653450416688586*^9}, {
   3.653450457907782*^9, 3.6534505694720583`*^9}, {3.653450608674986*^9, 
   3.653450773591426*^9}, {3.653450808496027*^9, 3.653450926856135*^9}, {
   3.6534509667392807`*^9, 3.653451123128397*^9}, {3.6534511645267897`*^9, 
   3.653451624907023*^9}, {3.653451768110091*^9, 3.653451773589279*^9}, {
   3.653645392293866*^9, 3.653645459559637*^9}, {3.653645700349249*^9, 
   3.6536458264115257`*^9}, {3.653645860138418*^9, 3.653646117204277*^9}, {
   3.6536462030397873`*^9, 3.653646512275378*^9}, {3.6536491677669697`*^9, 
   3.6536491695033207`*^9}, {3.653649648307026*^9, 3.653649650931691*^9}, {
   3.6539023990312862`*^9, 3.6539024120716743`*^9}, {3.654001721429076*^9, 
   3.654001725411331*^9}, {3.654001834747726*^9, 3.654001838677055*^9}, {
   3.654001886392312*^9, 3.6540018902218723`*^9}, {3.654001924972046*^9, 
   3.6540019274664392`*^9}, {3.654002021825857*^9, 3.654002050814403*^9}, {
   3.6540020837955217`*^9, 3.654002209262237*^9}, {3.654080975998732*^9, 
   3.654080986792881*^9}, {3.6540841797305727`*^9, 3.654084580791286*^9}, {
   3.654084647424561*^9, 3.654084938895278*^9}, {3.654084975695881*^9, 
   3.654085188005872*^9}, {3.654189112984047*^9, 3.6541891306026983`*^9}, {
   3.654279101274822*^9, 3.654279110214291*^9}, 3.670226470106555*^9, 
   3.672564778125291*^9, {3.6736107144428673`*^9, 3.67361071673802*^9}, {
   3.673610785955585*^9, 3.67361135996733*^9}, {3.673773958449003*^9, 
   3.67377396487294*^9}, {3.673886685926611*^9, 3.6738866862138453`*^9}, {
   3.6738885485791597`*^9, 3.673888548784831*^9}, 3.67532364078561*^9, 
   3.675510019026894*^9, 3.675510051233177*^9, 3.6755754684527073`*^9, {
   3.675580786025653*^9, 3.67558086913097*^9}, {3.675591097902276*^9, 
   3.675591098195758*^9}, {3.67559116628647*^9, 3.6755911669263783`*^9}, {
   3.6755911999068737`*^9, 3.675591200173562*^9}, {3.6755915244292*^9, 
   3.6755918989747963`*^9}, {3.675592002522607*^9, 3.675592022435896*^9}, {
   3.675592089113963*^9, 3.675592089701181*^9}, {3.675593425511962*^9, 
   3.675593429599656*^9}, {3.675593470474856*^9, 3.6755935621622753`*^9}, {
   3.675595252252369*^9, 3.675595317034992*^9}, {3.675681759366687*^9, 
   3.675681806490787*^9}, {3.675851569617619*^9, 3.675851637197174*^9}, {
   3.6759226733014708`*^9, 3.675922683031599*^9}, {3.675924874544126*^9, 
   3.6759250783099422`*^9}, {3.675925765316263*^9, 3.675925853845504*^9}, {
   3.6759386639242983`*^9, 3.6759387209604273`*^9}, {3.6759584239651003`*^9, 
   3.6759585214012747`*^9}, {3.675958553821933*^9, 3.675958570771214*^9}, {
   3.6759600153765717`*^9, 3.675960057712853*^9}, {3.6759602372898693`*^9, 
   3.675960242562107*^9}, {3.6759602873497257`*^9, 3.6759603900916567`*^9}, {
   3.6759604399252377`*^9, 3.675960446607627*^9}, 3.676005272937895*^9, 
   3.6760053240393467`*^9, 3.676021482545515*^9, {3.676021560052281*^9, 
   3.676022127436892*^9}, {3.676022216512494*^9, 3.6760229843015423`*^9}, {
   3.676023177212393*^9, 3.676023546449527*^9}, {3.676024271478404*^9, 
   3.676024603324912*^9}, {3.676024665484136*^9, 3.676024782787224*^9}, {
   3.676024854119236*^9, 3.6760248640841513`*^9}, {3.6760250088069153`*^9, 
   3.676025057439742*^9}, {3.676025249390964*^9, 3.6760253009161587`*^9}, {
   3.676025343840477*^9, 3.676025454046672*^9}, {3.676119221103794*^9, 
   3.676119228237918*^9}, {3.6761193013380613`*^9, 3.676119510407556*^9}, {
   3.676119543752206*^9, 3.676119727419374*^9}, {3.676119761094864*^9, 
   3.676119890665061*^9}, {3.676120078015214*^9, 3.676120083406232*^9}, {
   3.676121221198847*^9, 3.676121921702248*^9}, {3.6761219691023912`*^9, 
   3.676122334365264*^9}, {3.676122380870414*^9, 3.676122406798971*^9}, {
   3.67612244311215*^9, 3.6761225221941767`*^9}, {3.676122639453322*^9, 
   3.676122939279006*^9}, {3.676123227018145*^9, 3.676123257096648*^9}, {
   3.6761237135454493`*^9, 3.676123734364585*^9}, {3.6761250122199507`*^9, 
   3.676125012376691*^9}, {3.676125176189796*^9, 3.67612517638523*^9}, {
   3.677676312748744*^9, 3.677676327903968*^9}, {3.677676991863443*^9, 
   3.67767729526375*^9}, {3.677677333016506*^9, 3.677677490646119*^9}, {
   3.677677523157702*^9, 3.677677667586739*^9}, {3.677677718868541*^9, 
   3.6776778204809504`*^9}, {3.677677873168643*^9, 3.677677927030601*^9}, {
   3.67767796875508*^9, 3.6776780297813463`*^9}, {3.677678064052412*^9, 
   3.677678451162526*^9}, {3.677678660504642*^9, 3.677678916339388*^9}, {
   3.67767894672374*^9, 3.6776792507558193`*^9}, {3.6776793205431004`*^9, 
   3.677679488099471*^9}, {3.677679533149323*^9, 3.677679754394271*^9}, 
   3.677681168910832*^9, {3.678722500020762*^9, 3.678722518955509*^9}, {
   3.6787230661747*^9, 3.678723242930275*^9}, {3.678723283137291*^9, 
   3.67872332957576*^9}, {3.678723365853586*^9, 3.67872383272751*^9}, {
   3.6787238948014593`*^9, 3.6787239608564997`*^9}, {3.678724796691175*^9, 
   3.678724820003809*^9}, {3.67872485860867*^9, 3.678724868788558*^9}, {
   3.678729313739044*^9, 3.67872933221128*^9}, {3.6787294763543367`*^9, 
   3.6787299065469646`*^9}, {3.6787300710280848`*^9, 3.678730071422598*^9}, {
   3.678730322495199*^9, 3.678730323785355*^9}, {3.6787303950068274`*^9, 
   3.678730395674675*^9}, {3.678765758197289*^9, 3.678766381340143*^9}, {
   3.67876643099756*^9, 3.6787665616908283`*^9}, {3.678768317890379*^9, 
   3.678768318508003*^9}, {3.678768423156954*^9, 3.6787684278849363`*^9}, {
   3.678768509959207*^9, 3.6787685197194843`*^9}, {3.678768553818428*^9, 
   3.678768554569421*^9}, {3.678768589208424*^9, 3.678769290619643*^9}, {
   3.678769326536812*^9, 3.678769428639135*^9}, {3.678769493829928*^9, 
   3.678769509433446*^9}, {3.678769549578459*^9, 3.678769590779674*^9}, {
   3.6787704361854763`*^9, 3.678770641273473*^9}, {3.678773223101853*^9, 
   3.678773239704031*^9}, 3.679373090029645*^9, {3.683894359412177*^9, 
   3.683894407306477*^9}, {3.6838945110481052`*^9, 3.6838945173890753`*^9}, 
   3.68389683590415*^9, {3.683901863456834*^9, 3.683901890387862*^9}, 
   3.6839019752670717`*^9, {3.683902018178482*^9, 3.683902048968762*^9}, {
   3.683902118716179*^9, 3.6839021222572412`*^9}, {3.683902287755432*^9, 
   3.683902287917288*^9}, {3.683906644387364*^9, 3.6839066446741962`*^9}, {
   3.68390670210072*^9, 3.68390670236974*^9}, {3.68398447852845*^9, 
   3.6839844790536222`*^9}, {3.684038701674336*^9, 3.684038706669203*^9}, {
   3.685188570586812*^9, 3.685188599093625*^9}, {3.685189608057357*^9, 
   3.685189623863472*^9}, {3.6851900509380713`*^9, 3.685190072082631*^9}, {
   3.685190109244026*^9, 3.685190247420245*^9}, {3.685190334233671*^9, 
   3.685190360919217*^9}, {3.685197303680831*^9, 3.6851973889965363`*^9}, {
   3.685197420990172*^9, 3.685197617340919*^9}, {3.6851976971770067`*^9, 
   3.685197772978985*^9}, {3.685197845150587*^9, 3.685197845392006*^9}, {
   3.685713782727233*^9, 3.685713833952775*^9}, {3.685713879256155*^9, 
   3.685713945014422*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"CHECK THE FOLLOWING FEEDBACK CAREFULLY! \"\>"], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991513033`*^9, 
   3.6857139520113173`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"#{regions}=\"\>", "\[InvisibleSpace]", "76"}],
  SequenceForm["#{regions}=", 76],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991513033`*^9, 
   3.685713952016631*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"#{intersection points}=\"\>", "\[InvisibleSpace]", "86"}],
  SequenceForm["#{intersection points}=", 86],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991513033`*^9, 
   3.685713952022174*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\" 0 vertices = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "14", ",", "15", ",", "24", ",", "35", ",", "50", ",", "51", 
     ",", "52", ",", "68", ",", "85"}], "}"}]}],
  SequenceForm[" 0 vertices = ", {1, 14, 15, 24, 35, 50, 51, 52, 68, 85}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991513033`*^9, 
   3.6857139520255632`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"+1 vertices = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "5", ",", "6", ",", "8", ",", "11", ",", "12", ",", "17", ",", 
     "19", ",", "20", ",", "23", ",", "25", ",", "27", ",", "33", ",", "37", 
     ",", "38", ",", "41", ",", "44", ",", "47", ",", "48", ",", "53", ",", 
     "56", ",", "57", ",", "59", ",", "65", ",", "70", ",", "71", ",", "74", 
     ",", "78", ",", "80", ",", "81", ",", "84", ",", "86"}], "}"}]}],
  SequenceForm[
  "+1 vertices = ", {2, 5, 6, 8, 11, 12, 17, 19, 20, 23, 25, 27, 33, 37, 38, 
   41, 44, 47, 48, 53, 56, 57, 59, 65, 70, 71, 74, 78, 80, 81, 84, 86}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991513033`*^9, 
   3.685713952029166*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"-1 vertices = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "3", ",", "4", ",", "7", ",", "9", ",", "10", ",", "13", ",", "18", ",", 
     "21", ",", "22", ",", "26", ",", "32", ",", "34", ",", "36", ",", "39", 
     ",", "40", ",", "42", ",", "45", ",", "46", ",", "49", ",", "54", ",", 
     "55", ",", "58", ",", "60", ",", "66", ",", "67", ",", "69", ",", "72", 
     ",", "73", ",", "75", ",", "79", ",", "82", ",", "83"}], "}"}]}],
  SequenceForm[
  "-1 vertices = ", {3, 4, 7, 9, 10, 13, 18, 21, 22, 26, 32, 34, 36, 39, 40, 
   42, 45, 46, 49, 54, 55, 58, 60, 66, 67, 69, 72, 73, 75, 79, 82, 83}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991513033`*^9, 
   3.6857139520327187`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"+2 vertices = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"29", ",", "31", ",", "43", ",", "61", ",", "63", ",", "76"}], 
    "}"}]}],
  SequenceForm["+2 vertices = ", {29, 31, 43, 61, 63, 76}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991513033`*^9, 
   3.685713952035324*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"-2 vertices = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"16", ",", "28", ",", "30", ",", "62", ",", "64", ",", "77"}], 
    "}"}]}],
  SequenceForm["-2 vertices = ", {16, 28, 30, 62, 64, 77}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991513033`*^9, 
   3.685713952038289*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"bigon regions = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "19", ",", "20", ",", "21", ",", "24", ",", "25", ",", "26", ",", "29", 
     ",", "30", ",", "31", ",", "34", ",", "35", ",", "36", ",", "37", ",", 
     "39", ",", "41", ",", "43", ",", "47", ",", "48", ",", "49", ",", "54", 
     ",", "55", ",", "56", ",", "59", ",", "61", ",", "63", ",", "65", ",", 
     "67", ",", "68", ",", "69", ",", "70", ",", "71", ",", "72"}], "}"}]}],
  SequenceForm[
  "bigon regions = ", {19, 20, 21, 24, 25, 26, 29, 30, 31, 34, 35, 36, 37, 39,
    41, 43, 47, 48, 49, 54, 55, 56, 59, 61, 63, 65, 67, 68, 69, 70, 71, 72}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991513033`*^9, 
   3.685713952042049*^9}],

Cell[BoxData["\<\"No multiple cancellation. Good! \"\>"], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991513033`*^9, 
   3.685713952045978*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Intersection points whose cancellation will be attempted last: \
\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "3", ",", "12", ",", "13", ",", "14", ",", "15", ",", 
     "16", ",", "17", ",", "18", ",", "23", ",", "24", ",", "25", ",", "28", 
     ",", "31", ",", "34", ",", "35", ",", "36", ",", "41", ",", "42", ",", 
     "43", ",", "48", ",", "49", ",", "50", ",", "51", ",", "52", ",", "53", 
     ",", "54", ",", "61", ",", "64", ",", "67", ",", "68", ",", "69", ",", 
     "74", ",", "75", ",", "76", ",", "77", ",", "78", ",", "79", ",", "84", 
     ",", "85", ",", "86"}], "}"}]}],
  SequenceForm[
  "Intersection points whose cancellation will be attempted last: ", {1, 2, 3,
    12, 13, 14, 15, 16, 17, 18, 23, 24, 25, 28, 31, 34, 35, 36, 41, 42, 43, 
   48, 49, 50, 51, 52, 53, 54, 61, 64, 67, 68, 69, 74, 75, 76, 77, 78, 79, 84,
    85, 86}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991513033`*^9, 
   3.685713952050066*^9}],

Cell[BoxData["\<\"Cancelling pairs belong to same \[Alpha]s. Good!\"\>"], \
"Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991513033`*^9, 
   3.685713952053574*^9}],

Cell[BoxData["\<\"Cancelling pairs belong to same \[Beta]s. Good!\"\>"], \
"Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991513033`*^9, 
   3.685713952056363*^9}],

Cell[BoxData["\<\"All intersection points lie on exactly one \[Alpha]-curve. \
Good!\"\>"], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991513033`*^9, 
   3.685713952059259*^9}],

Cell[BoxData["\<\"All intersection points lie on exactly one \[Beta]-curve. \
Good!\"\>"], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991513033`*^9, 
   3.685713952061799*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"NAC=#{\[Alpha]-circles}=\"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["NAC=#{\[Alpha]-circles}=", 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991513033`*^9, 
   3.685713952064587*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"NAA=#{\[Alpha]-arcs}=\"\>", "\[InvisibleSpace]", "14"}],
  SequenceForm["NAA=#{\[Alpha]-arcs}=", 14],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991513033`*^9, 
   3.6857139520671787`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"NA=#{\[Alpha]-curves}=\"\>", "\[InvisibleSpace]", "14"}],
  SequenceForm["NA=#{\[Alpha]-curves}=", 14],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991513033`*^9, 
   3.6857139520697002`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"NB=#{\[Beta]-circles}=\"\>", "\[InvisibleSpace]", "12"}],
  SequenceForm["NB=#{\[Beta]-circles}=", 12],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991513033`*^9, 
   3.6857139520721188`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Surface 1 (\"\>", "\[InvisibleSpace]", "TypeA", 
   "\[InvisibleSpace]", "\<\"): #occupied \[Alpha]-arcs = \"\>", 
   "\[InvisibleSpace]", "6", 
   "\[InvisibleSpace]", "\<\", #moving strands = \"\>", "\[InvisibleSpace]", 
   "6"}],
  SequenceForm[
  "Surface 1 (", $CellContext`TypeA, "): #occupied \[Alpha]-arcs = ", 6, 
   ", #moving strands = ", 6],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991513033`*^9, 
   3.6857139520749693`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Surface 2 (\"\>", "\[InvisibleSpace]", "TypeA", 
   "\[InvisibleSpace]", "\<\"): #occupied \[Alpha]-arcs = \"\>", 
   "\[InvisibleSpace]", "6", 
   "\[InvisibleSpace]", "\<\", #moving strands = \"\>", "\[InvisibleSpace]", 
   "6"}],
  SequenceForm[
  "Surface 2 (", $CellContext`TypeA, "): #occupied \[Alpha]-arcs = ", 6, 
   ", #moving strands = ", 6],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894485032523*^9, {3.683896827424573*^9, 3.683896840039596*^9}, 
   3.683899166818673*^9, 3.683899544658469*^9, 3.6839018760716476`*^9, 
   3.683901949545713*^9, 3.6839022009560947`*^9, 3.683902291697789*^9, 
   3.6839024273494987`*^9, 3.683903482678611*^9, 3.683903538633713*^9, 
   3.68390356971111*^9, 3.683903770491641*^9, 3.683903981173608*^9, 
   3.683904592077524*^9, 3.6839046649434423`*^9, 3.683905463221498*^9, 
   3.683906225358996*^9, 3.6839066458052187`*^9, 3.683906704795207*^9, 
   3.683949215668654*^9, 3.683949846043804*^9, 3.683952364912459*^9, 
   3.683955114841975*^9, 3.683958893334997*^9, 3.683984390577526*^9, 
   3.683984557008689*^9, 3.684038716573325*^9, {3.685188468885972*^9, 
   3.6851884768210163`*^9}, {3.685188573345351*^9, 3.6851886248647213`*^9}, 
   3.6851886634276123`*^9, 3.685188777498905*^9, {3.685189010911956*^9, 
   3.685189026657585*^9}, 3.685189116302412*^9, 3.685189198235416*^9, 
   3.6851892621681213`*^9, 3.685189348013937*^9, 3.685189419281498*^9, 
   3.685189664898436*^9, 3.685189791413233*^9, 3.685190009163664*^9, {
   3.685190046763073*^9, 3.68519007332873*^9}, 3.685190197716743*^9, {
   3.685190339393978*^9, 3.685190369322047*^9}, 3.685190823536599*^9, 
   3.685191531568097*^9, 3.685191881688471*^9, 3.685192041208709*^9, 
   3.685192204482134*^9, 3.6851922784833593`*^9, {3.6851931046983232`*^9, 
   3.685193109142747*^9}, 3.6851931913675613`*^9, 3.68519383086311*^9, {
   3.685197835388092*^9, 3.6851978469174023`*^9}, 3.685201312040641*^9, 
   3.6852477484468193`*^9, 3.685248987076124*^9, 3.6852588012863503`*^9, 
   3.685258903555644*^9, 3.685706224664885*^9, 3.6857116991513033`*^9, 
   3.685713952077862*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Setup for backups", "Section",
 CellChangeTimes->{{3.683902406280332*^9, 3.683902411992662*^9}, {
   3.6839024516165123`*^9, 3.683902475521956*^9}, {3.68390335323253*^9, 
   3.683903371168364*^9}, {3.683949830312366*^9, 3.683949830550836*^9}, {
   3.685186908447523*^9, 3.6851869085320377`*^9}, {3.685187100587757*^9, 
   3.685187104979512*^9}, {3.685187153661024*^9, 3.68518716342925*^9}, {
   3.685198090550712*^9, 3.6851980924296083`*^9}, 3.68519813049438*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"BackupFilePath", "=", 
      RowBox[{"<", 
       RowBox[{"path", " ", "for", " ", "backup"}], ">"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"To", " ", "save", " ", "all", " ", "variables"}]}], ",", " ", 
    RowBox[{
     RowBox[{"use", ":", " ", 
      RowBox[{"DumpSave", "[", 
       RowBox[{
        RowBox[{"BackupFilePath", "<>", "\"\<.mx\>\""}], ",", 
        "\"\<Global`\>\""}], "]"}]}], ";", "\n", 
     RowBox[{
     "To", " ", "load", " ", "all", " ", "variables", " ", "from", " ", 
      "this", " ", "file"}]}], ",", " ", 
    RowBox[{
     RowBox[{"use", ":", " ", 
      RowBox[{"<<", 
       RowBox[{"(", 
        RowBox[{"BackupFilePath", "<>", "\"\<.mx\>\""}], ")"}]}]}], ";"}]}], 
   "\[IndentingNewLine]", "*)"}], "\n", 
  RowBox[{"BackupFilePath", "=", 
   RowBox[{
    RowBox[{"NotebookDirectory", "[", "]"}], "<>", "\"\<Backups/\>\"", "<>", 
    RowBox[{"StringDrop", "[", 
     RowBox[{
      RowBox[{"FileNameTake", "[", 
       RowBox[{"NotebookFileName", "[", "]"}], "]"}], ",", 
      RowBox[{"-", "3"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.685187085220419*^9, 3.685187085619646*^9}, {
  3.685187115996806*^9, 3.685187117420495*^9}, {3.685187180166778*^9, 
  3.685187271160758*^9}, {3.6851876607312403`*^9, 3.685187679762589*^9}, {
  3.6851877211005583`*^9, 3.6851878014470453`*^9}, {3.685188020564032*^9, 
  3.685188024022112*^9}, {3.6851880573745403`*^9, 3.6851882124099407`*^9}, {
  3.685188243804207*^9, 3.6851882507369843`*^9}, {3.685202300849607*^9, 
  3.68520234868612*^9}}],

Cell[BoxData["\<\"/mhome/dpmms/c/cbz20/Documents/PhD/Research/thesis/BSFH/\
Backups/GlueingBSAAx4e\"\>"], "Output",
 CellChangeTimes->{3.685202350065628*^9, 3.6852477522167463`*^9, 
  3.685248991231922*^9, 3.685258909150461*^9, 3.685692740393689*^9, 
  3.685706229642539*^9, 3.685711702345194*^9, 3.68571233346281*^9, 
  3.685712547769155*^9, 3.685713974617674*^9, 3.685851749858959*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculation of bordered sutured algebra", "Section",
 CellChangeTimes->{{3.683902406280332*^9, 3.683902411992662*^9}, {
   3.6839024516165123`*^9, 3.683902475521956*^9}, {3.683902509419033*^9, 
   3.683902551851089*^9}, {3.683902843994619*^9, 3.6839028464994917`*^9}, {
   3.683903880670438*^9, 3.683903893160449*^9}, 3.6851906152290363`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Step1x1Algebra", ";"}]], "Input",
 CellChangeTimes->{{3.683894564398328*^9, 3.683894567470285*^9}, 
   3.6838968494193707`*^9, {3.6851903740240927`*^9, 3.685190396536707*^9}, {
   3.6851904896752787`*^9, 3.68519049325898*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Idempotents for S1 (occupied arcs in strands diagram):\\n \
\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "2", "3", "4"},
       {
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "3", ",", "5", ",", "6", ",", "7"}], 
         "}"}], 
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "4", ",", "5", ",", "6", ",", "7"}], 
         "}"}], 
        RowBox[{"{", 
         RowBox[{"1", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7"}], 
         "}"}], 
        RowBox[{"{", 
         RowBox[{"2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7"}], 
         "}"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Idempotents for S1 (occupied arcs in strands diagram):\n ", 
   MatrixForm[{{1, 2, 3, 4}, {{1, 2, 3, 5, 6, 7}, {1, 2, 4, 5, 6, 7}, {1, 3, 
     4, 5, 6, 7}, {2, 3, 4, 5, 6, 7}}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.68389456864986*^9, 3.6838946234736547`*^9, 3.6838968500122004`*^9, 
   3.683899172980453*^9, 3.6838995524215097`*^9, 3.683903578791626*^9, {
   3.683903796738854*^9, 3.683903821259932*^9}, 3.6839039858898287`*^9, 
   3.683904596171867*^9, 3.683904668575684*^9, 3.68390546967093*^9, 
   3.68390623088945*^9, 3.683906649950728*^9, 3.683906712317583*^9, 
   3.68394927827203*^9, 3.683949850668906*^9, 3.683952373169733*^9, 
   3.683955118254199*^9, 3.683958897086561*^9, 3.685190833502232*^9, 
   3.685191535214994*^9, 3.685191885507491*^9, 3.6851920442229223`*^9, 
   3.6851922073521833`*^9, 3.685193111648541*^9, 3.685193836139495*^9, 
   3.685247754578397*^9, 3.685248996142511*^9, 3.685254501259327*^9, 
   3.685258911078904*^9, 3.685706232058814*^9, 3.6857117035769053`*^9, 
   3.6857139790311127`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Idempotents for S2 (occupied arcs in strands diagram):\\n \
\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "2", "3", "4"},
       {
        RowBox[{"{", 
         RowBox[{"8", ",", "9", ",", "10", ",", "12", ",", "13", ",", "14"}], 
         "}"}], 
        RowBox[{"{", 
         RowBox[{"8", ",", "9", ",", "11", ",", "12", ",", "13", ",", "14"}], 
         "}"}], 
        RowBox[{"{", 
         RowBox[{"8", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14"}],
          "}"}], 
        RowBox[{"{", 
         RowBox[{"9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14"}],
          "}"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Idempotents for S2 (occupied arcs in strands diagram):\n ", 
   MatrixForm[{{1, 2, 3, 4}, {{8, 9, 10, 12, 13, 14}, {8, 9, 11, 12, 13, 
     14}, {8, 10, 11, 12, 13, 14}, {9, 10, 11, 12, 13, 14}}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.68389456864986*^9, 3.6838946234736547`*^9, 3.6838968500122004`*^9, 
   3.683899172980453*^9, 3.6838995524215097`*^9, 3.683903578791626*^9, {
   3.683903796738854*^9, 3.683903821259932*^9}, 3.6839039858898287`*^9, 
   3.683904596171867*^9, 3.683904668575684*^9, 3.68390546967093*^9, 
   3.68390623088945*^9, 3.683906649950728*^9, 3.683906712317583*^9, 
   3.68394927827203*^9, 3.683949850668906*^9, 3.683952373169733*^9, 
   3.683955118254199*^9, 3.683958897086561*^9, 3.685190833502232*^9, 
   3.685191535214994*^9, 3.685191885507491*^9, 3.6851920442229223`*^9, 
   3.6851922073521833`*^9, 3.685193111648541*^9, 3.685193836139495*^9, 
   3.685247754578397*^9, 3.685248996142511*^9, 3.685254501259327*^9, 
   3.685258911078904*^9, 3.685706232058814*^9, 3.6857117035769053`*^9, 
   3.685713979037052*^9}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Naming", " ", "idempotents", " ", 
     RowBox[{"(", 
      RowBox[{
      "choose", " ", "any", " ", "variable", " ", "you", " ", "find", " ", 
       "appropriate"}], ")"}]}], ";"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"S1IdemNames", "=", 
     RowBox[{"{", 
      RowBox[{"d", ",", "c", ",", "b", ",", "a"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"S2IdemNames", "=", 
     RowBox[{"{", 
      RowBox[{"d", ",", "c", ",", "b", ",", "a"}], "}"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.677558847878817*^9, 3.6775588977945127`*^9}, {
   3.677558930459526*^9, 3.677559079416768*^9}, {3.6775591141377296`*^9, 
   3.6775591232809258`*^9}, {3.6775591673069763`*^9, 
   3.6775591708097677`*^9}, {3.677559237909267*^9, 3.677559274365768*^9}, {
   3.678365462544454*^9, 3.678365463974029*^9}, 3.679373264719275*^9, {
   3.679373345409265*^9, 3.679373355329522*^9}, 3.679373416779231*^9, {
   3.6793786869009542`*^9, 3.679378710833679*^9}, {3.679379554595536*^9, 
   3.679379638336299*^9}, {3.679380115539069*^9, 3.679380246150484*^9}, {
   3.6793803137773333`*^9, 3.679380320299905*^9}, {3.679381504792593*^9, 
   3.679381625229982*^9}, {3.6793817347272243`*^9, 3.679381738256918*^9}, {
   3.679381830811235*^9, 3.679381831562584*^9}, {3.6793818653461313`*^9, 
   3.6793819321950274`*^9}, {3.683897311350361*^9, 3.683897324687079*^9}, {
   3.68519155465518*^9, 3.6851915949356947`*^9}, {3.685713986628358*^9, 
   3.685713992231986*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"SANITY", " ", 
      RowBox[{"CHECK", ":", " ", 
       RowBox[{
       "test", " ", "for", " ", "multiplication", " ", "in", " ", "strands", 
        " ", "algebra"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"S1Reeb", "[", "z__", "]"}], " ", "takes", " ", "a", " ", 
      "sequence", " ", 
      SubscriptBox["z", "1"]}]}], ",", 
    SubscriptBox["z", "2"], ",", 
    RowBox[{
     RowBox[{
     "...", " ", "of", " ", "an", " ", "even", " ", "number", " ", "of", " ", 
      "integers", " ", "and", " ", "computes", " ", "the", " ", "element", 
      " ", "in", " ", "the", " ", "strands", " ", "algebra", " ", "for", " ", 
      "the", " ", "surface", " ", "S1", " ", "which", " ", "has", " ", "a", 
      " ", "moving", " ", "strand", " ", "from", " ", "the", " ", 
      SubscriptBox["z", 
       RowBox[{
        RowBox[{"2", "i"}], "+", "1"}]], "st", " ", "to", " ", "the", " ", 
      SubscriptBox["z", 
       RowBox[{
        RowBox[{"2", "i"}], "+", "2"}]], "nd", " ", "level"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"MorH1AlgComp", "[", 
       RowBox[{"a_", ",", "b_"}], "]"}], " ", "computes", " ", 
      SubscriptBox["\[Mu]", "2"], " ", "of", " ", "two", " ", "elements", " ",
       "a", " ", "and", " ", "b", " ", "in", " ", "the", " ", "strands", " ", 
      "algebra", " ", "and", " ", "displays", " ", "the", " ", "result", " ", 
      "using", " ", "the", " ", 
      RowBox[{"function", " ", "'"}], 
      RowBox[{"S1H", "'"}]}]}], ",", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"see", " ", "'"}], "Step", " ", "5"}], ":", " ", 
      RowBox[{"Basic", " ", "graphical", " ", 
       RowBox[{"outputs", "'"}], " ", "in", " ", "manual"}]}], ";"}]}], 
   "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"MorH1AlgComp", "[", 
    RowBox[{
     RowBox[{"S1Reeb", "[", 
      RowBox[{"2", ",", "3", ",", "4", ",", "5"}], "]"}], ",", 
     RowBox[{"S1Reeb", "[", 
      RowBox[{"3", ",", "4", ",", "6", ",", "9"}], "]"}]}], "]"}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.675148960735221*^9, 3.6751491156688137`*^9}, {
   3.675149153653947*^9, 3.675149183454502*^9}, {3.6751492167671957`*^9, 
   3.675149401938579*^9}, {3.675149486456636*^9, 3.6751494869367847`*^9}, 
   3.67514954451958*^9, {3.6751564533370657`*^9, 3.67515645413692*^9}, {
   3.675156524722777*^9, 3.675156560242648*^9}, {3.675156616520442*^9, 
   3.6751568101289454`*^9}, {3.675163957259375*^9, 3.675163970832073*^9}, {
   3.6751668771042137`*^9, 3.675166877110574*^9}, {3.675240959486168*^9, 
   3.6752410690644703`*^9}, {3.675326768492325*^9, 3.6753267702114143`*^9}, {
   3.675488784994639*^9, 3.675488800599482*^9}, {3.683892446779804*^9, 
   3.683892568970303*^9}, {3.6838946292210503`*^9, 3.683894629403434*^9}, {
   3.685190847044396*^9, 3.685191102313513*^9}, {3.6851911472048492`*^9, 
   3.685191271326366*^9}, {3.685204837861514*^9, 3.685204856946199*^9}, {
   3.685256088953251*^9, 3.685256135520506*^9}, {3.685697400552388*^9, 
   3.685697476866653*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(\[Mu]\\), \\(2\\)]\\)(\"\>", 
   "\[InvisibleSpace]", 
   RowBox[{
    TagBox[GridBox[{
       {"12", "12"},
       {"10", "10"},
       {"8", "8"},
       {"6", "6"},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"12", "12"},
       {"10", "10"},
       {"9", "9"},
       {"8", "8"},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"12", "12"},
       {"11", "11"},
       {"10", "10"},
       {"6", "6"},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"12", "12"},
       {"11", "11"},
       {"10", "10"},
       {"9", "9"},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"13", "13"},
       {"12", "12"},
       {"8", "8"},
       {"6", "6"},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"13", "13"},
       {"12", "12"},
       {"9", "9"},
       {"8", "8"},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"13", "13"},
       {"12", "12"},
       {"11", "11"},
       {"6", "6"},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"13", "13"},
       {"12", "12"},
       {"11", "11"},
       {"9", "9"},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"14", "14"},
       {"10", "10"},
       {"8", "8"},
       {"6", "6"},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"14", "14"},
       {"10", "10"},
       {"9", "9"},
       {"8", "8"},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"14", "14"},
       {"11", "11"},
       {"10", "10"},
       {"6", "6"},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"14", "14"},
       {"11", "11"},
       {"10", "10"},
       {"9", "9"},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"14", "14"},
       {"13", "13"},
       {"8", "8"},
       {"6", "6"},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"14", "14"},
       {"13", "13"},
       {"9", "9"},
       {"8", "8"},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"14", "14"},
       {"13", "13"},
       {"11", "11"},
       {"6", "6"},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"14", "14"},
       {"13", "13"},
       {"11", "11"},
       {"9", "9"},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"]}], "\[InvisibleSpace]", "\<\" ,\\n\"\>", "\[InvisibleSpace]", 
   RowBox[{
    TagBox[GridBox[{
       {"12", "12"},
       {"10", "10"},
       {"8", "8"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {"5", "5"},
       {
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"12", "12"},
       {"10", "10"},
       {"8", "8"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {"2", "2"}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"12", "12"},
       {"11", "11"},
       {"10", "10"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {"5", "5"},
       {
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"12", "12"},
       {"11", "11"},
       {"10", "10"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {"2", "2"}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"13", "13"},
       {"12", "12"},
       {"8", "8"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {"5", "5"},
       {
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"13", "13"},
       {"12", "12"},
       {"8", "8"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {"2", "2"}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"13", "13"},
       {"12", "12"},
       {"11", "11"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {"5", "5"},
       {
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"13", "13"},
       {"12", "12"},
       {"11", "11"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {"2", "2"}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"14", "14"},
       {"10", "10"},
       {"8", "8"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {"5", "5"},
       {
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"14", "14"},
       {"10", "10"},
       {"8", "8"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {"2", "2"}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"14", "14"},
       {"11", "11"},
       {"10", "10"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {"5", "5"},
       {
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"14", "14"},
       {"11", "11"},
       {"10", "10"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {"2", "2"}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"14", "14"},
       {"13", "13"},
       {"8", "8"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {"5", "5"},
       {
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"14", "14"},
       {"13", "13"},
       {"8", "8"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {"2", "2"}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"14", "14"},
       {"13", "13"},
       {"11", "11"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {"5", "5"},
       {
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"14", "14"},
       {"13", "13"},
       {"11", "11"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["3",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {"2", "2"}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"]}], "\[InvisibleSpace]", "\<\") =\\n\"\>", "\[InvisibleSpace]", 
   RowBox[{
    TagBox[GridBox[{
       {"12", "12"},
       {"10", "10"},
       {"8", "8"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"12", "12"},
       {"11", "11"},
       {"10", "10"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"13", "13"},
       {"12", "12"},
       {"8", "8"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"13", "13"},
       {"12", "12"},
       {"11", "11"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"14", "14"},
       {"10", "10"},
       {"8", "8"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"14", "14"},
       {"11", "11"},
       {"10", "10"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"14", "14"},
       {"13", "13"},
       {"8", "8"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"], "+", 
    TagBox[GridBox[{
       {"14", "14"},
       {"13", "13"},
       {"11", "11"},
       {
        StyleBox["6",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["9",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["5",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]},
       {
        StyleBox["2",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]], 
        StyleBox["4",
         StripOnInput->False,
         FontWeight->Bold,
         Background->RGBColor[1, 1, 0]]}
      },
      AutoDelete->False,
      GridBoxFrame->{"ColumnsIndexed" -> {{{1, -1}, {1, -1}} -> True}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
     "Grid"]}]}],
  SequenceForm[
  "\!\(\*SubscriptBox[\(\[Mu]\), \(2\)]\)(", 
   Grid[{{12, 12}, {10, 10}, {8, 8}, {6, 6}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{12, 12}, {10, 10}, {9, 9}, {8, 8}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{12, 12}, {11, 11}, {10, 10}, {6, 6}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{12, 12}, {11, 11}, {10, 10}, {9, 9}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{13, 13}, {12, 12}, {8, 8}, {6, 6}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{13, 13}, {12, 12}, {9, 9}, {8, 8}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{13, 13}, {12, 12}, {11, 11}, {6, 6}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{13, 13}, {12, 12}, {11, 11}, {9, 9}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{14, 14}, {10, 10}, {8, 8}, {6, 6}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{14, 14}, {10, 10}, {9, 9}, {8, 8}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{14, 14}, {11, 11}, {10, 10}, {6, 6}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{14, 14}, {11, 11}, {10, 10}, {9, 9}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{14, 14}, {13, 13}, {8, 8}, {6, 6}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{14, 14}, {13, 13}, {9, 9}, {8, 8}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{14, 14}, {13, 13}, {11, 11}, {6, 6}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{14, 14}, {13, 13}, {11, 11}, {9, 9}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True], 
   " ,\n", Grid[{{12, 12}, {10, 10}, {8, 8}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {5, 5}, {
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{12, 12}, {10, 10}, {8, 8}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}, {2, 2}}, Frame -> 
     True] + Grid[{{12, 12}, {11, 11}, {10, 10}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {5, 5}, {
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{12, 12}, {11, 11}, {10, 10}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}, {2, 2}}, Frame -> 
     True] + Grid[{{13, 13}, {12, 12}, {8, 8}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {5, 5}, {
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{13, 13}, {12, 12}, {8, 8}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}, {2, 2}}, Frame -> 
     True] + Grid[{{13, 13}, {12, 12}, {11, 11}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {5, 5}, {
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{13, 13}, {12, 12}, {11, 11}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}, {2, 2}}, Frame -> 
     True] + Grid[{{14, 14}, {10, 10}, {8, 8}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {5, 5}, {
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{14, 14}, {10, 10}, {8, 8}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}, {2, 2}}, Frame -> 
     True] + Grid[{{14, 14}, {11, 11}, {10, 10}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {5, 5}, {
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{14, 14}, {11, 11}, {10, 10}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}, {2, 2}}, Frame -> 
     True] + Grid[{{14, 14}, {13, 13}, {8, 8}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {5, 5}, {
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{14, 14}, {13, 13}, {8, 8}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}, {2, 2}}, Frame -> 
     True] + Grid[{{14, 14}, {13, 13}, {11, 11}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {5, 5}, {
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{14, 14}, {13, 13}, {11, 11}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[3, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}, {2, 2}}, Frame -> 
     True], ") =\n", Grid[{{12, 12}, {10, 10}, {8, 8}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{12, 12}, {11, 11}, {10, 10}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{13, 13}, {12, 12}, {8, 8}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{13, 13}, {12, 12}, {11, 11}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{14, 14}, {10, 10}, {8, 8}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{14, 14}, {11, 11}, {10, 10}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{14, 14}, {13, 13}, {8, 8}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True] + 
   Grid[{{14, 14}, {13, 13}, {11, 11}, {
       Style[6, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[9, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[5, {Bold, Background -> RGBColor[1, 1, 0]}]}, {
       Style[2, {Bold, Background -> RGBColor[1, 1, 0]}], 
       Style[4, {Bold, Background -> RGBColor[1, 1, 0]}]}}, Frame -> True]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.68389462471453*^9, 3.683894630193058*^9}, 
   3.68389685177421*^9, 3.683899175650861*^9, 3.683899554426527*^9, 
   3.683903987712611*^9, 3.6839045977182837`*^9, 3.68390467072602*^9, 
   3.683905472148747*^9, 3.68390623716576*^9, 3.683906653805142*^9, 
   3.683906715689011*^9, 3.683949288745957*^9, 3.68394985342809*^9, 
   3.683955122156901*^9, 3.683958901081587*^9, {3.685190970573328*^9, 
   3.685190974038107*^9}, {3.685191261596065*^9, 3.6851912779095592`*^9}, 
   3.685191543035482*^9, {3.68519160095391*^9, 3.6851916098629713`*^9}, 
   3.685191888757268*^9, 3.685192047642233*^9, 3.685192209052795*^9, 
   3.685193115844283*^9, 3.6851938395359707`*^9, 3.685248999275526*^9, 
   3.685254505324308*^9, 3.685258914455195*^9, 3.6857062357713823`*^9, {
   3.68571171641415*^9, 3.685711718848358*^9}, 3.685713999000844*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Step1x2Algebra", ";"}]], "Input",
 CellChangeTimes->{{3.683894573809146*^9, 3.68389457569536*^9}, 
   3.683896854916707*^9, {3.685190544973094*^9, 3.685190547812798*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"S1: Idempotents (occupied \[Alpha]-arcs) and their names (from \
'S1IdemNames'):\\n \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "3", ",", "5", ",", "6", ",", "7"}], 
         "}"}], 
        RowBox[{"{", 
         RowBox[{"1", ",", "2", ",", "4", ",", "5", ",", "6", ",", "7"}], 
         "}"}], 
        RowBox[{"{", 
         RowBox[{"1", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7"}], 
         "}"}], 
        RowBox[{"{", 
         RowBox[{"2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "7"}], 
         "}"}]},
       {"d", "c", "b", "a"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm[
  "S1: Idempotents (occupied \[Alpha]-arcs) and their names (from \
'S1IdemNames'):\n ", 
   MatrixForm[{{{1, 2, 3, 5, 6, 7}, {1, 2, 4, 5, 6, 7}, {1, 3, 4, 5, 6, 7}, {
     2, 3, 4, 5, 6, 
     7}}, {$CellContext`d, $CellContext`c, $CellContext`b, $CellContext`a}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894576291297*^9, 3.683894636939271*^9, 3.683896855963625*^9, 
   3.6838991777417603`*^9, 3.6838995563130627`*^9, {3.683903823955768*^9, 
   3.6839038446720753`*^9}, 3.683903990836575*^9, 3.683904600824422*^9, 
   3.683904673542452*^9, 3.683905474795196*^9, 3.683906239958479*^9, 
   3.683906674640527*^9, 3.6839067191536303`*^9, 3.683949293301263*^9, 
   3.683949855362233*^9, 3.683952376069016*^9, 3.683955123852866*^9, 
   3.683958902943614*^9, {3.68519145850126*^9, 3.685191480352109*^9}, 
   3.685191612181581*^9, 3.685191720422462*^9, 3.685191890702222*^9, 
   3.685191929102725*^9, 3.685192049265316*^9, 3.685192212772407*^9, 
   3.685192286439252*^9, 3.68519311765595*^9, 3.6851938427894278`*^9, 
   3.685249008374435*^9, 3.6852545068160353`*^9, 3.685258967957315*^9, 
   3.685706237906004*^9, 3.685711720394435*^9, 3.6857140118934927`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"S2: Idempotents (occupied \[Alpha]-arcs) and their names (from \
'S2IdemNames'):\\n \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"{", 
         RowBox[{"8", ",", "9", ",", "10", ",", "12", ",", "13", ",", "14"}], 
         "}"}], 
        RowBox[{"{", 
         RowBox[{"8", ",", "9", ",", "11", ",", "12", ",", "13", ",", "14"}], 
         "}"}], 
        RowBox[{"{", 
         RowBox[{"8", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14"}],
          "}"}], 
        RowBox[{"{", 
         RowBox[{"9", ",", "10", ",", "11", ",", "12", ",", "13", ",", "14"}],
          "}"}]},
       {"d", "c", "b", "a"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm[
  "S2: Idempotents (occupied \[Alpha]-arcs) and their names (from \
'S2IdemNames'):\n ", 
   MatrixForm[{{{8, 9, 10, 12, 13, 14}, {8, 9, 11, 12, 13, 14}, {8, 10, 11, 
     12, 13, 14}, {9, 10, 11, 12, 13, 
     14}}, {$CellContext`d, $CellContext`c, $CellContext`b, $CellContext`a}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894576291297*^9, 3.683894636939271*^9, 3.683896855963625*^9, 
   3.6838991777417603`*^9, 3.6838995563130627`*^9, {3.683903823955768*^9, 
   3.6839038446720753`*^9}, 3.683903990836575*^9, 3.683904600824422*^9, 
   3.683904673542452*^9, 3.683905474795196*^9, 3.683906239958479*^9, 
   3.683906674640527*^9, 3.6839067191536303`*^9, 3.683949293301263*^9, 
   3.683949855362233*^9, 3.683952376069016*^9, 3.683955123852866*^9, 
   3.683958902943614*^9, {3.68519145850126*^9, 3.685191480352109*^9}, 
   3.685191612181581*^9, 3.685191720422462*^9, 3.685191890702222*^9, 
   3.685191929102725*^9, 3.685192049265316*^9, 3.685192212772407*^9, 
   3.685192286439252*^9, 3.68519311765595*^9, 3.6851938427894278`*^9, 
   3.685249008374435*^9, 3.6852545068160353`*^9, 3.685258967957315*^9, 
   3.685706237906004*^9, 3.685711720394435*^9, 3.685714011898408*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"S1: number of algebra elements for each pair of idempotents = \
\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"55", "39", "27", "27"},
       {"13", "39", "27", "27"},
       {"3", "9", "39", "39"},
       {"1", "3", "13", "55"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm[
  "S1: number of algebra elements for each pair of idempotents = ", 
   MatrixForm[{{55, 39, 27, 27}, {13, 39, 27, 27}, {3, 9, 39, 39}, {1, 3, 13, 
    55}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894576291297*^9, 3.683894636939271*^9, 3.683896855963625*^9, 
   3.6838991777417603`*^9, 3.6838995563130627`*^9, {3.683903823955768*^9, 
   3.6839038446720753`*^9}, 3.683903990836575*^9, 3.683904600824422*^9, 
   3.683904673542452*^9, 3.683905474795196*^9, 3.683906239958479*^9, 
   3.683906674640527*^9, 3.6839067191536303`*^9, 3.683949293301263*^9, 
   3.683949855362233*^9, 3.683952376069016*^9, 3.683955123852866*^9, 
   3.683958902943614*^9, {3.68519145850126*^9, 3.685191480352109*^9}, 
   3.685191612181581*^9, 3.685191720422462*^9, 3.685191890702222*^9, 
   3.685191929102725*^9, 3.685192049265316*^9, 3.685192212772407*^9, 
   3.685192286439252*^9, 3.68519311765595*^9, 3.6851938427894278`*^9, 
   3.685249008374435*^9, 3.6852545068160353`*^9, 3.685258967957315*^9, 
   3.685706237906004*^9, 3.685711720394435*^9, 3.685714058369328*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"S2: number of algebra elements for each pair of idempotents = \
\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"39", "39", "3", "9"},
       {"13", "55", "1", "3"},
       {"27", "27", "55", "39"},
       {"27", "27", "13", "39"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm[
  "S2: number of algebra elements for each pair of idempotents = ", 
   MatrixForm[{{39, 39, 3, 9}, {13, 55, 1, 3}, {27, 27, 55, 39}, {27, 27, 13, 
    39}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894576291297*^9, 3.683894636939271*^9, 3.683896855963625*^9, 
   3.6838991777417603`*^9, 3.6838995563130627`*^9, {3.683903823955768*^9, 
   3.6839038446720753`*^9}, 3.683903990836575*^9, 3.683904600824422*^9, 
   3.683904673542452*^9, 3.683905474795196*^9, 3.683906239958479*^9, 
   3.683906674640527*^9, 3.6839067191536303`*^9, 3.683949293301263*^9, 
   3.683949855362233*^9, 3.683952376069016*^9, 3.683955123852866*^9, 
   3.683958902943614*^9, {3.68519145850126*^9, 3.685191480352109*^9}, 
   3.685191612181581*^9, 3.685191720422462*^9, 3.685191890702222*^9, 
   3.685191929102725*^9, 3.685192049265316*^9, 3.685192212772407*^9, 
   3.685192286439252*^9, 3.68519311765595*^9, 3.6851938427894278`*^9, 
   3.685249008374435*^9, 3.6852545068160353`*^9, 3.685258967957315*^9, 
   3.685706237906004*^9, 3.685711720394435*^9, 3.685714089221293*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Sanity checks for algebra basis: \"\>", 
   "\[InvisibleSpace]", "\<\"S1 ok\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", "\<\"S2 ok\"\>"}],
  SequenceForm["Sanity checks for algebra basis: ", "S1 ok", ", ", "S2 ok"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894576291297*^9, 3.683894636939271*^9, 3.683896855963625*^9, 
   3.6838991777417603`*^9, 3.6838995563130627`*^9, {3.683903823955768*^9, 
   3.6839038446720753`*^9}, 3.683903990836575*^9, 3.683904600824422*^9, 
   3.683904673542452*^9, 3.683905474795196*^9, 3.683906239958479*^9, 
   3.683906674640527*^9, 3.6839067191536303`*^9, 3.683949293301263*^9, 
   3.683949855362233*^9, 3.683952376069016*^9, 3.683955123852866*^9, 
   3.683958902943614*^9, {3.68519145850126*^9, 3.685191480352109*^9}, 
   3.685191612181581*^9, 3.685191720422462*^9, 3.685191890702222*^9, 
   3.685191929102725*^9, 3.685192049265316*^9, 3.685192212772407*^9, 
   3.685192286439252*^9, 3.68519311765595*^9, 3.6851938427894278`*^9, 
   3.685249008374435*^9, 3.6852545068160353`*^9, 3.685258967957315*^9, 
   3.685706237906004*^9, 3.685711720394435*^9, 3.685714089226472*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There\"\>", 
   "\[InvisibleSpace]", "\<\" are 416 basis elements \"\>", 
   "\[InvisibleSpace]", "\<\"in the algebra for S1. The multiplication table \
looks like this: \"\>", "\[InvisibleSpace]", 
   GraphicsBox[
    RasterBox[SparseArray[Automatic, {416, 416}, 1., {1, {CompressedData["
1:eJwV0mtM1lUcB/C/KVeJoVGzYoJESJuaChWZc441S0VhTK0XzxjDDfER0a05
Ly9ctcaUMduabrKl4cwuEluzXM90Ma+zAC0uFg6lyGcoJCqk8xKjPpztc16d
ne9+lxnlm0qqJwRBcGj8cqbwIgtYThGrKCXMJrZTQy0fU88BDtLAYb7kKE18
R4QfOc0ZznGBVi7xC+100EkXv9FND738QR9/cZ0o/dxkgEH+5hZD3OYOd0lW
39Okk00Os5hPHvksYCGLWMwyVlDMKuqop4kTXKCLbnropZ8RHjA63tMngmAi
sSQzladIZRrPkUY6mWQzkxxmMYe5zGM+ueTxCq/yGvmsYAO7OcjnNPIDP9PJ
MA8YI3FiEKQwlWdJ5wVeIpfXeYMC3qaQlRRTwhpClFJGORVUEqaKaurYx2d8
RSPHiXCSZlq4RAePiZukR6STwzwWUcASllJIESWs5l1ClLGWCtZRyXrCbKCK
jVTzLef5nQH+IzXGTMhgJrPJZSlFrCZEKWWsYyPvsYWt7OR9PuQjajhCKwPE
x6qPNLJ5k0LCbGEnH1BLHfuo5zBNHCfCac7SxkV+pZPLXOE6UW4wyC2GuMsw
98iIs18sZDGFFBOilHIqCFPFZvZzhGM000InV/mTKDcY5DYj3Och/zLGhPgg
mEQMscQRTwKJTCaJlaxlG7V8yjEiNHOeVtrpppcojxllbDwjwf8kkMIzpDGd
DDLJYg9NtDEy/jYxCJ4ni5fJp4AyKqlhN5+wlwM08DWNfE+EM7TRxWW66eEa
vfQRpZ9B7nGfhzxilLmT5bKL/XxBB1e5SVKSvaWAt1jOO4QIs4MadrGHvTTw
DSc4STOnOMdPXKSda/QxxB2G+YdHxDxpfsQRTyLJpJDKNNKYTgYzyCSLHDbT
Ql6yTP4HI3jdVQ==
        "], CompressedData["
1:eJztmweUVEUWhqtcs4g5I4goiIkgKmACM2YQxaxgRgVzwgwogmIAAwZgDRt0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        "]}, CompressedData["
1:eJztwTERACAMBLDHAB5qCQncMWMTWVXBlqT2XWckeTMAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAHzSPMICgQ==
       "]}], {{0, 0}, {416, 416}}, {0, 1}],
    Frame->Automatic,
    FrameLabel->{None, None},
    FrameTicks->{{None, None}, {None, None}},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{
     "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> Automatic},
    ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzlWEtPwzAMzvraViTGQOIGqxAHThx4aBdOSDwuHEACJG4TYoIDAo39/zJn
rdNmjps+xiYxaa3nxp8dJ/6c7m40fX/7HE0/XkfRzWT0/f7x+hNdf01mKrcl
hHiBbyRAjmdicnmJZ5+Z4MI9Ho/H8BXP8prVwqgnuLaSR172ESBcwd0DyZEa
KcbpJ1U7KPFAPZBa7LgbxJOP2mUsfKlxsyEKi9BuCbMArm6xc8rWx5yVtw0s
0/lA2PKDneKASoE+slCn6FLuNl/uSzd9Kn9J3RaLckYE5OLKeJhnHuWCQPEw
PoNtEuWAtVWSi1KfsNhkfWwTFo5p5pruEK5bxUur17FCgaUI/kVd2to2XQZh
tc3fZAkFOdpOIdJ0+CjVKcdmUOoUNbXPDKXHoNhSwz6Oo0pq04oL3CyoiNjM
6A04CUMxz4EZuYuD5jlq6ygox2ltqjT0iLAoforYdK2C5fzctk+nZ9Ga7zHr
y6MZnjlO4L5ThiUy3IBzp3bmnxW6RmBaGMbKqRif2q91iEhD0ULjCWEPfu9W
qPsBOpX56BcUc5REqlG6WnCPaBVFDEFxD3/QKQnWDJHxYdIHjUVdVNVByTwc
14+HokO93HF9NQroSp2XHYdRD80uu5pLkaspNXGPBluoi7A4pet00q3zWlb7
2GnxltZ032ianFdK+3aEbY/HRSVq0v4+GjIUMsB41qs3LI/OtXcBe7Y9MoGt
tCMEWTBMUJysvLYS0kul8zbfNUDXbq5DSIMOTjrM7y7GUPGo5pQjBS1mrvfk
vXUwJOWXajdOOTBFDJfm4V0cNPdY6o1rec05DxbioAYStGMytCjJczPsBjFc
TS63AvXeOYegyrVe8u/z9L/11i8gFes7\
\>"]]}],
  SequenceForm[
  "There", " are 416 basis elements ", 
   "in the algebra for S1. The multiplication table looks like this: ", 
   Graphics[
    Raster[SparseArray[Automatic, {416, 416}, 1., {1, {CompressedData["
1:eJwV0mtM1lUcB/C/KVeJoVGzYoJESJuaChWZc441S0VhTK0XzxjDDfER0a05
Ly9ctcaUMduabrKl4cwuEluzXM90Ma+zAC0uFg6lyGcoJCqk8xKjPpztc16d
ne9+lxnlm0qqJwRBcGj8cqbwIgtYThGrKCXMJrZTQy0fU88BDtLAYb7kKE18
R4QfOc0ZznGBVi7xC+100EkXv9FND738QR9/cZ0o/dxkgEH+5hZD3OYOd0lW
39Okk00Os5hPHvksYCGLWMwyVlDMKuqop4kTXKCLbnropZ8RHjA63tMngmAi
sSQzladIZRrPkUY6mWQzkxxmMYe5zGM+ueTxCq/yGvmsYAO7OcjnNPIDP9PJ
MA8YI3FiEKQwlWdJ5wVeIpfXeYMC3qaQlRRTwhpClFJGORVUEqaKaurYx2d8
RSPHiXCSZlq4RAePiZukR6STwzwWUcASllJIESWs5l1ClLGWCtZRyXrCbKCK
jVTzLef5nQH+IzXGTMhgJrPJZSlFrCZEKWWsYyPvsYWt7OR9PuQjajhCKwPE
x6qPNLJ5k0LCbGEnH1BLHfuo5zBNHCfCac7SxkV+pZPLXOE6UW4wyC2GuMsw
98iIs18sZDGFFBOilHIqCFPFZvZzhGM000InV/mTKDcY5DYj3Och/zLGhPgg
mEQMscQRTwKJTCaJlaxlG7V8yjEiNHOeVtrpppcojxllbDwjwf8kkMIzpDGd
DDLJYg9NtDEy/jYxCJ4ni5fJp4AyKqlhN5+wlwM08DWNfE+EM7TRxWW66eEa
vfQRpZ9B7nGfhzxilLmT5bKL/XxBB1e5SVKSvaWAt1jOO4QIs4MadrGHvTTw
DSc4STOnOMdPXKSda/QxxB2G+YdHxDxpfsQRTyLJpJDKNNKYTgYzyCSLHDbT
Ql6yTP4HI3jdVQ==
        "], CompressedData["
1:eJztmweUVEUWhqtcs4g5I4goiIkgKmACM2YQxaxgRgVzwgwogmIAAwZgDRt0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        "]}, CompressedData["
1:eJztwTERACAMBLDHAB5qCQncMWMTWVXBlqT2XWckeTMAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAHzSPMICgQ==
       "]}], {{0, 0}, {416, 416}}, {0, 1}], Frame -> Automatic, 
    FrameLabel -> {None, None}, FrameTicks -> {{None, None}, {None, None}}, 
    GridLinesStyle -> Directive[
      GrayLevel[0.5, 0.4]], 
    Method -> {
     "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> Automatic}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894576291297*^9, 3.683894636939271*^9, 3.683896855963625*^9, 
   3.6838991777417603`*^9, 3.6838995563130627`*^9, {3.683903823955768*^9, 
   3.6839038446720753`*^9}, 3.683903990836575*^9, 3.683904600824422*^9, 
   3.683904673542452*^9, 3.683905474795196*^9, 3.683906239958479*^9, 
   3.683906674640527*^9, 3.6839067191536303`*^9, 3.683949293301263*^9, 
   3.683949855362233*^9, 3.683952376069016*^9, 3.683955123852866*^9, 
   3.683958902943614*^9, {3.68519145850126*^9, 3.685191480352109*^9}, 
   3.685191612181581*^9, 3.685191720422462*^9, 3.685191890702222*^9, 
   3.685191929102725*^9, 3.685192049265316*^9, 3.685192212772407*^9, 
   3.685192286439252*^9, 3.68519311765595*^9, 3.6851938427894278`*^9, 
   3.685249008374435*^9, 3.6852545068160353`*^9, 3.685258967957315*^9, 
   3.685706237906004*^9, 3.685711720394435*^9, 3.685714121898871*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There\"\>", 
   "\[InvisibleSpace]", "\<\" are 416 basis elements \"\>", 
   "\[InvisibleSpace]", "\<\"in the algebra for S2. The multiplication table \
looks like this: \"\>", "\[InvisibleSpace]", 
   GraphicsBox[
    RasterBox[SparseArray[Automatic, {416, 416}, 1., {1, {CompressedData["
1:eJwV1HtM1lUYB/CfoPhKSGoNiukkM2mKZJQBcsnRwAuKDhRIFxMl34Whqcyx
ucnFy8qGNhaMEWPqXCvqH9ty5sjVlu4dMzfTUXjZTN9Zowwsml1s68PZPmfn
n2d7nu/ZOU9t3lG2fUIQBMfHN2s2RWyhlTY6OcY5LhBlhL/4l4lq43iUx5hF
Gs+RSS75FLOMlaxmDeW8RjU11LKVMHVsY7zBbvo4zVkuMMAgP3CDW0S5yzAz
YszDArJYygoq2EA1NdQSpo563qKBRvayjyaaaaGV/RzgIIeIcJMRJsQGQTLp
ZJLNyxRRQg1h6mlgD400cZB3aeMonXTRTQ+9hCbKl2Le5DAd9PIxn9HPNW4T
TAqCWBJIJJkUnuYZMsgkj2JKWUMZ66mkio1Us4latrODXexmD31cIyZO/qSy
igo2c4j36edrznOZQaKMEUxWT4hEUpjHiywmmyUUUMgySqhkI2HeYBv17KaJ
Zlpo5QBvc5gjtNNJF918QA+9nGCA74kyykMmhfTHDJJ4kpmkMpc05rOQRbzA
S2SRTQ5LyCWPfApopoM++rlElGFGecB/xE4JgnimkUQ6GSwiixxyKWQ5payl
jHVUsIktbKWOvRzlJJ/zBeeIcJUh7jDKGH8TG+/KCBHPVKbzOMnMYg5pLCCd
DJ5nMdnkkEse+RSwlEKKWM4KSljFakpZSxnlrGM9FVRSxatsoJEm3uE92umk
h15OcJIP+Yg+IlzmOlF+4j5jPOAf4h4xM4kUU06YBlo4QjsddHGMTznFac7y
JV8R4SLfconvuMogQ9zgFj9ym7v8zDC/8Cv3+I0RRrnP70xO8NZ5hSqqeZ2d
7KeNTzjFGb5hgItcYYib3OEef/AnD4mZKgdCxJPANJJ4ghRmksoc5jKPZ2kf
Pyf6S4jwP4bZypo=
        "], CompressedData["
1:eJztmnecFdUVx8+AIoIUFcFKEREBsWHBLopiAXVXrFgRRVHAgiVYEVCKYqG5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        "]}, CompressedData["
1:eJztwTERACAMBLDHAB5qCQncMWMTWVXBlqT2XWckeTMAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAHzSPMICgQ==
       "]}], {{0, 0}, {416, 416}}, {0, 1}],
    Frame->Automatic,
    FrameLabel->{None, None},
    FrameTicks->{{None, None}, {None, None}},
    GridLinesStyle->Directive[
      GrayLevel[0.5, 0.4]],
    Method->{
     "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> Automatic},
    ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzlWEtPwzAMzvpYEQgGA8QNKgQ3jsCNh4aAE1eQdpsmpu2AQMD/L3HWOG3q
PBY6NIlJbfNwvjiJP9vL0+h7+vo2+p6NR/nj5+hjOht/5Q/vn7wp7jDGhvDk
DMoFL5avYcF/vBDDt5hMJvCwF/GutoLUM7w7ZVdS7QKEG/imAjWWbaIWFVKc
v6FRdvKf6IusuNfw7RK4m/DuhI2NyDYpbAe9JZYiwQTumufKBigX10fwugSf
1/gvXkHFEuy1K3ZHjKXwMqLNCJrjrrBudblYrq2BpVVUWeYzMsSW4/mTeiq8
bl32sdd5xDihKB1YIU89FVsj2qhF7VdnU2yHTelDpQfFC7PQLuodWXY5caAc
IopFaJ9Qv+sz8NnctYvWSfeLRWWEr8gcA8XB6c6wkAZnGShWFCkb7OrWI8su
jBi9bkKoMWhbg4alXsH3oAWnFWla4OHP6x5+8X9FAbOzTWp7WPM6rUEq67FD
th1icjw27Tx164faltvRGvE0nbXeDTeyiAoJrlfxNKsz1gPFZn7iIFKzMTln
OEGohABIUU914u2ELuW9qHSgFrD+IuLatyHD3sWV9d2Q7aUhB2UJK5+TUIlC
rLXNmbs4jjL2S/PAIxRaTlYiarpvKnyTi+DE4Hc5TfC0lPkbUo+S7n2czxCk
lOP1TfQpJSI85qAQRiTSWw6b2UMkFTC8xOll2q04ON+mBqpwsTTCaQPPHeIu
fi6IaaEzSVeouXijNk20U9Sz8EaFJhXq7qviDd70iCWfmZRfau4clP+WKDtQ
71Hsb0yjRyTc9IV8Q+0SgGA15e/8qevF9GDKrZCL8GK64QqyxOk7CBX8dz6Y
wtS1J/vNf3vNJ2jGGzVI3v7tgtOvEOKUaTZ1dTokwBs0PAB5dS3vtTs/W6db
yw==\
\>"]]}],
  SequenceForm[
  "There", " are 416 basis elements ", 
   "in the algebra for S2. The multiplication table looks like this: ", 
   Graphics[
    Raster[SparseArray[Automatic, {416, 416}, 1., {1, {CompressedData["
1:eJwV1HtM1lUYB/CfoPhKSGoNiukkM2mKZJQBcsnRwAuKDhRIFxMl34Whqcyx
ucnFy8qGNhaMEWPqXCvqH9ty5sjVlu4dMzfTUXjZTN9Zowwsml1s68PZPmfn
n2d7nu/ZOU9t3lG2fUIQBMfHN2s2RWyhlTY6OcY5LhBlhL/4l4lq43iUx5hF
Gs+RSS75FLOMlaxmDeW8RjU11LKVMHVsY7zBbvo4zVkuMMAgP3CDW0S5yzAz
YszDArJYygoq2EA1NdQSpo563qKBRvayjyaaaaGV/RzgIIeIcJMRJsQGQTLp
ZJLNyxRRQg1h6mlgD400cZB3aeMonXTRTQ+9hCbKl2Le5DAd9PIxn9HPNW4T
TAqCWBJIJJkUnuYZMsgkj2JKWUMZ66mkio1Us4latrODXexmD31cIyZO/qSy
igo2c4j36edrznOZQaKMEUxWT4hEUpjHiywmmyUUUMgySqhkI2HeYBv17KaJ
Zlpo5QBvc5gjtNNJF918QA+9nGCA74kyykMmhfTHDJJ4kpmkMpc05rOQRbzA
S2SRTQ5LyCWPfApopoM++rlElGFGecB/xE4JgnimkUQ6GSwiixxyKWQ5payl
jHVUsIktbKWOvRzlJJ/zBeeIcJUh7jDKGH8TG+/KCBHPVKbzOMnMYg5pLCCd
DJ5nMdnkkEse+RSwlEKKWM4KSljFakpZSxnlrGM9FVRSxatsoJEm3uE92umk
h15OcJIP+Yg+IlzmOlF+4j5jPOAf4h4xM4kUU06YBlo4QjsddHGMTznFac7y
JV8R4SLfconvuMogQ9zgFj9ym7v8zDC/8Cv3+I0RRrnP70xO8NZ5hSqqeZ2d
7KeNTzjFGb5hgItcYYib3OEef/AnD4mZKgdCxJPANJJ4ghRmksoc5jKPZ2kf
Pyf6S4jwP4bZypo=
        "], CompressedData["
1:eJztmnecFdUVx8+AIoIUFcFKEREBsWHBLopiAXVXrFgRRVHAgiVYEVCKYqG5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        "]}, CompressedData["
1:eJztwTERACAMBLDHAB5qCQncMWMTWVXBlqT2XWckeTMAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAHzSPMICgQ==
       "]}], {{0, 0}, {416, 416}}, {0, 1}], Frame -> Automatic, 
    FrameLabel -> {None, None}, FrameTicks -> {{None, None}, {None, None}}, 
    GridLinesStyle -> Directive[
      GrayLevel[0.5, 0.4]], 
    Method -> {
     "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> Automatic}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894576291297*^9, 3.683894636939271*^9, 3.683896855963625*^9, 
   3.6838991777417603`*^9, 3.6838995563130627`*^9, {3.683903823955768*^9, 
   3.6839038446720753`*^9}, 3.683903990836575*^9, 3.683904600824422*^9, 
   3.683904673542452*^9, 3.683905474795196*^9, 3.683906239958479*^9, 
   3.683906674640527*^9, 3.6839067191536303`*^9, 3.683949293301263*^9, 
   3.683949855362233*^9, 3.683952376069016*^9, 3.683955123852866*^9, 
   3.683958902943614*^9, {3.68519145850126*^9, 3.685191480352109*^9}, 
   3.685191612181581*^9, 3.685191720422462*^9, 3.685191890702222*^9, 
   3.685191929102725*^9, 3.685192049265316*^9, 3.685192212772407*^9, 
   3.685192286439252*^9, 3.68519311765595*^9, 3.6851938427894278`*^9, 
   3.685249008374435*^9, 3.6852545068160353`*^9, 3.685258967957315*^9, 
   3.685706237906004*^9, 3.685711720394435*^9, 3.685714152087469*^9}],

Cell[BoxData["\<\"Sanity check for the differential on S1 algebra: ok.\"\>"], \
"Print",
 CellChangeTimes->{
  3.683894576291297*^9, 3.683894636939271*^9, 3.683896855963625*^9, 
   3.6838991777417603`*^9, 3.6838995563130627`*^9, {3.683903823955768*^9, 
   3.6839038446720753`*^9}, 3.683903990836575*^9, 3.683904600824422*^9, 
   3.683904673542452*^9, 3.683905474795196*^9, 3.683906239958479*^9, 
   3.683906674640527*^9, 3.6839067191536303`*^9, 3.683949293301263*^9, 
   3.683949855362233*^9, 3.683952376069016*^9, 3.683955123852866*^9, 
   3.683958902943614*^9, {3.68519145850126*^9, 3.685191480352109*^9}, 
   3.685191612181581*^9, 3.685191720422462*^9, 3.685191890702222*^9, 
   3.685191929102725*^9, 3.685192049265316*^9, 3.685192212772407*^9, 
   3.685192286439252*^9, 3.68519311765595*^9, 3.6851938427894278`*^9, 
   3.685249008374435*^9, 3.6852545068160353`*^9, 3.685258967957315*^9, 
   3.685706237906004*^9, 3.685711720394435*^9, 3.6857141608351*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There\"\>", 
   "\[InvisibleSpace]", "\<\" are 299 basis elements \"\>", 
   "\[InvisibleSpace]", "\<\"in the algebra for S1 whose differential is \
non-vanishing.\"\>"}],
  SequenceForm[
  "There", " are 299 basis elements ", 
   "in the algebra for S1 whose differential is non-vanishing."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894576291297*^9, 3.683894636939271*^9, 3.683896855963625*^9, 
   3.6838991777417603`*^9, 3.6838995563130627`*^9, {3.683903823955768*^9, 
   3.6839038446720753`*^9}, 3.683903990836575*^9, 3.683904600824422*^9, 
   3.683904673542452*^9, 3.683905474795196*^9, 3.683906239958479*^9, 
   3.683906674640527*^9, 3.6839067191536303`*^9, 3.683949293301263*^9, 
   3.683949855362233*^9, 3.683952376069016*^9, 3.683955123852866*^9, 
   3.683958902943614*^9, {3.68519145850126*^9, 3.685191480352109*^9}, 
   3.685191612181581*^9, 3.685191720422462*^9, 3.685191890702222*^9, 
   3.685191929102725*^9, 3.685192049265316*^9, 3.685192212772407*^9, 
   3.685192286439252*^9, 3.68519311765595*^9, 3.6851938427894278`*^9, 
   3.685249008374435*^9, 3.6852545068160353`*^9, 3.685258967957315*^9, 
   3.685706237906004*^9, 3.685711720394435*^9, 3.6857141608419456`*^9}],

Cell[BoxData["\<\"Sanity check for the differential on S2 algebra: ok.\"\>"], \
"Print",
 CellChangeTimes->{
  3.683894576291297*^9, 3.683894636939271*^9, 3.683896855963625*^9, 
   3.6838991777417603`*^9, 3.6838995563130627`*^9, {3.683903823955768*^9, 
   3.6839038446720753`*^9}, 3.683903990836575*^9, 3.683904600824422*^9, 
   3.683904673542452*^9, 3.683905474795196*^9, 3.683906239958479*^9, 
   3.683906674640527*^9, 3.6839067191536303`*^9, 3.683949293301263*^9, 
   3.683949855362233*^9, 3.683952376069016*^9, 3.683955123852866*^9, 
   3.683958902943614*^9, {3.68519145850126*^9, 3.685191480352109*^9}, 
   3.685191612181581*^9, 3.685191720422462*^9, 3.685191890702222*^9, 
   3.685191929102725*^9, 3.685192049265316*^9, 3.685192212772407*^9, 
   3.685192286439252*^9, 3.68519311765595*^9, 3.6851938427894278`*^9, 
   3.685249008374435*^9, 3.6852545068160353`*^9, 3.685258967957315*^9, 
   3.685706237906004*^9, 3.685711720394435*^9, 3.6857141691063004`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There\"\>", 
   "\[InvisibleSpace]", "\<\" are 299 basis elements \"\>", 
   "\[InvisibleSpace]", "\<\"in the algebra for S2 whose differential is \
non-vanishing.\"\>"}],
  SequenceForm[
  "There", " are 299 basis elements ", 
   "in the algebra for S2 whose differential is non-vanishing."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894576291297*^9, 3.683894636939271*^9, 3.683896855963625*^9, 
   3.6838991777417603`*^9, 3.6838995563130627`*^9, {3.683903823955768*^9, 
   3.6839038446720753`*^9}, 3.683903990836575*^9, 3.683904600824422*^9, 
   3.683904673542452*^9, 3.683905474795196*^9, 3.683906239958479*^9, 
   3.683906674640527*^9, 3.6839067191536303`*^9, 3.683949293301263*^9, 
   3.683949855362233*^9, 3.683952376069016*^9, 3.683955123852866*^9, 
   3.683958902943614*^9, {3.68519145850126*^9, 3.685191480352109*^9}, 
   3.685191612181581*^9, 3.685191720422462*^9, 3.685191890702222*^9, 
   3.685191929102725*^9, 3.685192049265316*^9, 3.685192212772407*^9, 
   3.685192286439252*^9, 3.68519311765595*^9, 3.6851938427894278`*^9, 
   3.685249008374435*^9, 3.6852545068160353`*^9, 3.685258967957315*^9, 
   3.685706237906004*^9, 3.685711720394435*^9, 3.685714169112759*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Define", " ", "subalgebra", " ", "of", " ", "glueing", " ", "algebras"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"S1SubalgebraGensInput", "=", 
     RowBox[{"(", GridBox[{
        {"\"\<\!\(\*SubscriptBox[\(p\), \(2\)]\)\>\"", "\"\<p_2\>\"", "4", 
         RowBox[{"{", 
          RowBox[{"3", ",", "4"}], "}"}], "3"},
        {"\"\<\!\(\*SubscriptBox[\(q\), \(2\)]\)\>\"", "\"\<q_2\>\"", "3", 
         RowBox[{"{", 
          RowBox[{"2", ",", "3", ",", "4", ",", "5"}], "}"}], "4"},
        {"\"\<\!\(\*SubscriptBox[\(p\), \(3\)]\)\>\"", "\"\<p_3\>\"", "3", 
         RowBox[{"{", 
          RowBox[{"7", ",", "8"}], "}"}], "2"},
        {"\"\<\!\(\*SubscriptBox[\(q\), \(3\)]\)\>\"", "\"\<q_3\>\"", "2", 
         RowBox[{"{", 
          RowBox[{"6", ",", "7", ",", "8", ",", "9"}], "}"}], "3"},
        {"\"\<\!\(\*SubscriptBox[\(p\), \(4\)]\)\>\"", "\"\<p_4\>\"", "2", 
         RowBox[{"{", 
          RowBox[{"11", ",", "12"}], "}"}], "1"},
        {"\"\<\!\(\*SubscriptBox[\(q\), \(4\)]\)\>\"", "\"\<q_4\>\"", "1", 
         RowBox[{"{", 
          RowBox[{"10", ",", "11", ",", "12", ",", "13"}], "}"}], "2"}
       }], ")"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"S2SubalgebraGensInput", "=", 
     RowBox[{"(", GridBox[{
        {"\"\<\!\(\*SubscriptBox[\(p\), \(4\)]\)\>\"", "\"\<p_4\>\"", "2", 
         RowBox[{"{", 
          RowBox[{"3", ",", "4"}], "}"}], "1"},
        {"\"\<\!\(\*SubscriptBox[\(q\), \(4\)]\)\>\"", "\"\<q_4\>\"", "1", 
         RowBox[{"{", 
          RowBox[{"2", ",", "3", ",", "4", ",", "5"}], "}"}], "2"},
        {"\"\<\!\(\*SubscriptBox[\(p\), \(1\)]\)\>\"", "\"\<p_1\>\"", "1", 
         RowBox[{"{", 
          RowBox[{"7", ",", "8"}], "}"}], "4"},
        {"\"\<\!\(\*SubscriptBox[\(q\), \(1\)]\)\>\"", "\"\<q_1\>\"", "4", 
         RowBox[{"{", 
          RowBox[{"6", ",", "7", ",", "8", ",", "9"}], "}"}], "1"},
        {"\"\<\!\(\*SubscriptBox[\(p\), \(2\)]\)\>\"", "\"\<p_2\>\"", "4", 
         RowBox[{"{", 
          RowBox[{"11", ",", "12"}], "}"}], "3"},
        {"\"\<\!\(\*SubscriptBox[\(q\), \(2\)]\)\>\"", "\"\<q_2\>\"", "3", 
         RowBox[{"{", 
          RowBox[{"10", ",", "11", ",", "12", ",", "13"}], "}"}], "4"}
       }], ")"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Step1x3Algebra", ";"}]}]}]], "Input",
 CellChangeTimes->{{3.67541670490312*^9, 3.675416943706355*^9}, {
   3.6754170205791273`*^9, 3.675417160207923*^9}, {3.6754171988645773`*^9, 
   3.6754172047285013`*^9}, {3.67541726389194*^9, 3.675417411421652*^9}, {
   3.675417504592208*^9, 3.675417671756445*^9}, {3.675417702455329*^9, 
   3.6754177955677443`*^9}, {3.675417857795292*^9, 3.6754180486165743`*^9}, {
   3.6754181200985603`*^9, 3.675418156692951*^9}, {3.6754182097573767`*^9, 
   3.675418233939465*^9}, {3.675418578868428*^9, 3.675418585533842*^9}, {
   3.6754187853257713`*^9, 3.6754191790874443`*^9}, {3.6754196050117188`*^9, 
   3.6754196402749863`*^9}, {3.6754197357439947`*^9, 3.675419766438498*^9}, {
   3.675419986525477*^9, 3.675420009644898*^9}, {3.675420050158463*^9, 
   3.675420079462613*^9}, {3.6754201403113937`*^9, 3.6754201888257*^9}, {
   3.675420232067382*^9, 3.675420386424735*^9}, {3.675420417032227*^9, 
   3.675420509776697*^9}, {3.675420545939254*^9, 3.6754205864055357`*^9}, {
   3.675420722813902*^9, 3.675420723408658*^9}, {3.675421190651394*^9, 
   3.675421195333506*^9}, {3.675421884925761*^9, 3.675421885037178*^9}, {
   3.675422070693953*^9, 3.675422191917118*^9}, {3.675422236953292*^9, 
   3.675422449285512*^9}, {3.675422489267954*^9, 3.675422509463949*^9}, {
   3.675422635165626*^9, 3.675422640045535*^9}, {3.675422685645858*^9, 
   3.675422750348567*^9}, {3.675422785240765*^9, 3.67542280706288*^9}, {
   3.675422855020863*^9, 3.675422859344832*^9}, {3.675424215280971*^9, 
   3.675424221070169*^9}, {3.6754242919296637`*^9, 3.6754243212187567`*^9}, {
   3.67542602176145*^9, 3.67542602609664*^9}, {3.6754260603369637`*^9, 
   3.675426068589275*^9}, {3.675429232464768*^9, 3.675429323920988*^9}, {
   3.6754293690262938`*^9, 3.675429369521201*^9}, {3.6754294085392933`*^9, 
   3.675429435698406*^9}, {3.675489570048691*^9, 3.6754895887810993`*^9}, {
   3.6754896880190897`*^9, 3.6754896937036343`*^9}, {3.6754897259876423`*^9, 
   3.675489738120859*^9}, {3.675489801566051*^9, 3.675489826478066*^9}, {
   3.6754904308821793`*^9, 3.675490455156652*^9}, {3.675490489672057*^9, 
   3.675490502896306*^9}, {3.67549062825817*^9, 3.675490980950973*^9}, {
   3.675491047466683*^9, 3.675491089193486*^9}, {3.67549121466953*^9, 
   3.6754913164714518`*^9}, 3.675491391767598*^9, {3.6754914249514227`*^9, 
   3.675491472388465*^9}, {3.675491506053948*^9, 3.675491507522543*^9}, {
   3.675491616142733*^9, 3.6754916228800497`*^9}, {3.675491766836528*^9, 
   3.6754917910789957`*^9}, {3.675492000529435*^9, 3.6754920619598293`*^9}, 
   3.675493085052888*^9, {3.675496723655764*^9, 3.675496774348954*^9}, {
   3.6754968300053883`*^9, 3.675496890103347*^9}, {3.675496958064917*^9, 
   3.675496980749998*^9}, {3.675497027081711*^9, 3.675497072937887*^9}, {
   3.675500494000929*^9, 3.6755005190493*^9}, {3.675501434290371*^9, 
   3.6755014406626368`*^9}, {3.6755022859449368`*^9, 3.67550231374466*^9}, {
   3.675576639058669*^9, 3.6755766395736933`*^9}, {3.675576695541645*^9, 
   3.675576860809417*^9}, {3.67557704449465*^9, 3.675577357618638*^9}, {
   3.6755953877500257`*^9, 3.675595392298416*^9}, {3.6756818427121563`*^9, 
   3.6756818487330112`*^9}, {3.675927638493026*^9, 3.6759276689603777`*^9}, {
   3.6759586354724283`*^9, 3.675958645259203*^9}, {3.6759605315291443`*^9, 
   3.675960760207101*^9}, 3.6760053846449127`*^9, {3.676026462041202*^9, 
   3.6760265881084013`*^9}, {3.676026684200674*^9, 3.676026815068563*^9}, {
   3.6760269150023746`*^9, 3.676026993126997*^9}, {3.6761254946040907`*^9, 
   3.676125552395556*^9}, {3.676125606553938*^9, 3.676125711299168*^9}, {
   3.676125753429627*^9, 3.676125773481463*^9}, {3.676265137067075*^9, 
   3.676265220549065*^9}, {3.676288128022416*^9, 3.676288201806101*^9}, {
   3.677681981601057*^9, 3.677682107280738*^9}, {3.677682137522174*^9, 
   3.677682265999445*^9}, {3.677682307394906*^9, 3.6776823431857147`*^9}, {
   3.677682379758047*^9, 3.677682403763871*^9}, {3.677682492007575*^9, 
   3.6776826007343893`*^9}, {3.6787715125583973`*^9, 
   3.6787715614795017`*^9}, {3.678771609093541*^9, 3.6787717536203117`*^9}, {
   3.678771805742807*^9, 3.678771868759883*^9}, {3.678772027332717*^9, 
   3.678772034436185*^9}, {3.6787722605150347`*^9, 3.678772283682819*^9}, {
   3.678772373965992*^9, 3.678772449903233*^9}, {3.678772529785922*^9, 
   3.678772531905593*^9}, {3.678772824890971*^9, 3.678772827481413*^9}, {
   3.6787728690995407`*^9, 3.678772871578577*^9}, {3.678774431296946*^9, 
   3.678774434324017*^9}, {3.679373140304928*^9, 3.679373144800671*^9}, {
   3.6838946851494904`*^9, 3.683894703205244*^9}, {3.685190554574445*^9, 
   3.685190556892708*^9}, {3.685192961281529*^9, 3.685192987809022*^9}, {
   3.685207421645051*^9, 3.685207426225121*^9}, 3.685207467365735*^9, 
   3.685697492274362*^9, {3.6857140253997*^9, 3.6857140328964167`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"Note: If this step produces an error message, double-check \
'S1SubalgebraGensInput' and 'S2SubalgebraGensInput'.\\n If some of the \
entries of the lists below are empty, you have probably only mixed up the \
starting/ending idempotents.\"\>"], "Print",
 CellChangeTimes->{
  3.675577358840218*^9, 3.67557784106756*^9, 3.675581579650231*^9, 
   3.675595500289331*^9, 3.675613125973466*^9, 3.675656236601492*^9, 
   3.675681856180417*^9, 3.675682207840516*^9, 3.6756824475633097`*^9, 
   3.675852729718355*^9, 3.6758617463689203`*^9, {3.675927619547714*^9, 
   3.675927651329775*^9}, 3.675938927383788*^9, 3.67595865191124*^9, 
   3.675960603697714*^9, 3.6759606522289267`*^9, {3.675960729708458*^9, 
   3.675960760646541*^9}, 3.675961789029345*^9, 3.676004009504449*^9, {
   3.6760053876838408`*^9, 3.676005391390046*^9}, {3.6760267460268908`*^9, 
   3.67602677066754*^9}, 3.676026818467801*^9, {3.67602691981961*^9, 
   3.676026955021439*^9}, {3.676026993767375*^9, 3.6760270089952517`*^9}, {
   3.6761255821669617`*^9, 3.676125713077436*^9}, 3.676125774688211*^9, 
   3.676265293611487*^9, 3.676288224107232*^9, 3.6763477949276323`*^9, 
   3.676388666448176*^9, 3.676440141917055*^9, 3.67644206113505*^9, 
   3.6764734260760403`*^9, 3.677484677351678*^9, 3.67750386490447*^9, 
   3.677682252521587*^9, 3.677682344242956*^9, 3.677682405799204*^9, {
   3.677682559314039*^9, 3.677682601748749*^9}, 3.678771755603828*^9, 
   3.6787718704111567`*^9, 3.6787720354712553`*^9, {3.678772266822555*^9, 
   3.678772284607242*^9}, {3.678772375092311*^9, 3.678772409154812*^9}, {
   3.678772441192569*^9, 3.67877245072477*^9}, 3.678772532795595*^9, {
   3.678772817801484*^9, 3.678772828460821*^9}, 3.678772872535182*^9, 
   3.678774475451853*^9, 3.678775839601779*^9, 3.679373148388205*^9, 
   3.6838947043272953`*^9, 3.68389686364214*^9, 3.683899190547463*^9, 
   3.683899560122406*^9, 3.6839038492626743`*^9, 3.683903995232173*^9, 
   3.683904603740594*^9, 3.6839046780311937`*^9, 3.6839054787572117`*^9, 
   3.683906251985915*^9, 3.68390668065705*^9, 3.683906723095969*^9, 
   3.683949302957801*^9, 3.683949860524699*^9, 3.6839523804559183`*^9, 
   3.6839551294524803`*^9, 3.683958906704781*^9, {3.685192867733756*^9, 
   3.6851928832382393`*^9}, {3.6851929468598423`*^9, 3.6851929884163*^9}, 
   3.685193122696867*^9, 3.685193849822316*^9, 3.6852490140941887`*^9, 
   3.6852545093644657`*^9, 3.685258976314921*^9, 3.685706242225347*^9, 
   3.685711724459684*^9, 3.685714169939982*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"S1 algebra indices of the subalgebra generators = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "3", ",", "4", ",", "345", ",", "362", ",", "229", 
     ",", "268", ",", "97", ",", "164"}], "}"}]}],
  SequenceForm[
  "S1 algebra indices of the subalgebra generators = ", {1, 2, 3, 4, 345, 362,
    229, 268, 97, 164}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.675577358840218*^9, 3.67557784106756*^9, 3.675581579650231*^9, 
   3.675595500289331*^9, 3.675613125973466*^9, 3.675656236601492*^9, 
   3.675681856180417*^9, 3.675682207840516*^9, 3.6756824475633097`*^9, 
   3.675852729718355*^9, 3.6758617463689203`*^9, {3.675927619547714*^9, 
   3.675927651329775*^9}, 3.675938927383788*^9, 3.67595865191124*^9, 
   3.675960603697714*^9, 3.6759606522289267`*^9, {3.675960729708458*^9, 
   3.675960760646541*^9}, 3.675961789029345*^9, 3.676004009504449*^9, {
   3.6760053876838408`*^9, 3.676005391390046*^9}, {3.6760267460268908`*^9, 
   3.67602677066754*^9}, 3.676026818467801*^9, {3.67602691981961*^9, 
   3.676026955021439*^9}, {3.676026993767375*^9, 3.6760270089952517`*^9}, {
   3.6761255821669617`*^9, 3.676125713077436*^9}, 3.676125774688211*^9, 
   3.676265293611487*^9, 3.676288224107232*^9, 3.6763477949276323`*^9, 
   3.676388666448176*^9, 3.676440141917055*^9, 3.67644206113505*^9, 
   3.6764734260760403`*^9, 3.677484677351678*^9, 3.67750386490447*^9, 
   3.677682252521587*^9, 3.677682344242956*^9, 3.677682405799204*^9, {
   3.677682559314039*^9, 3.677682601748749*^9}, 3.678771755603828*^9, 
   3.6787718704111567`*^9, 3.6787720354712553`*^9, {3.678772266822555*^9, 
   3.678772284607242*^9}, {3.678772375092311*^9, 3.678772409154812*^9}, {
   3.678772441192569*^9, 3.67877245072477*^9}, 3.678772532795595*^9, {
   3.678772817801484*^9, 3.678772828460821*^9}, 3.678772872535182*^9, 
   3.678774475451853*^9, 3.678775839601779*^9, 3.679373148388205*^9, 
   3.6838947043272953`*^9, 3.68389686364214*^9, 3.683899190547463*^9, 
   3.683899560122406*^9, 3.6839038492626743`*^9, 3.683903995232173*^9, 
   3.683904603740594*^9, 3.6839046780311937`*^9, 3.6839054787572117`*^9, 
   3.683906251985915*^9, 3.68390668065705*^9, 3.683906723095969*^9, 
   3.683949302957801*^9, 3.683949860524699*^9, 3.6839523804559183`*^9, 
   3.6839551294524803`*^9, 3.683958906704781*^9, {3.685192867733756*^9, 
   3.6851928832382393`*^9}, {3.6851929468598423`*^9, 3.6851929884163*^9}, 
   3.685193122696867*^9, 3.685193849822316*^9, 3.6852490140941887`*^9, 
   3.6852545093644657`*^9, 3.685258976314921*^9, 3.685706242225347*^9, 
   3.685711724459684*^9, 3.685714170876113*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"S2 algebra indices of the subalgebra generators = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "3", ",", "4", ",", "81", ",", "106", ",", "338", ",",
      "93", ",", "311", ",", "378"}], "}"}]}],
  SequenceForm[
  "S2 algebra indices of the subalgebra generators = ", {1, 2, 3, 4, 81, 106, 
   338, 93, 311, 378}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.675577358840218*^9, 3.67557784106756*^9, 3.675581579650231*^9, 
   3.675595500289331*^9, 3.675613125973466*^9, 3.675656236601492*^9, 
   3.675681856180417*^9, 3.675682207840516*^9, 3.6756824475633097`*^9, 
   3.675852729718355*^9, 3.6758617463689203`*^9, {3.675927619547714*^9, 
   3.675927651329775*^9}, 3.675938927383788*^9, 3.67595865191124*^9, 
   3.675960603697714*^9, 3.6759606522289267`*^9, {3.675960729708458*^9, 
   3.675960760646541*^9}, 3.675961789029345*^9, 3.676004009504449*^9, {
   3.6760053876838408`*^9, 3.676005391390046*^9}, {3.6760267460268908`*^9, 
   3.67602677066754*^9}, 3.676026818467801*^9, {3.67602691981961*^9, 
   3.676026955021439*^9}, {3.676026993767375*^9, 3.6760270089952517`*^9}, {
   3.6761255821669617`*^9, 3.676125713077436*^9}, 3.676125774688211*^9, 
   3.676265293611487*^9, 3.676288224107232*^9, 3.6763477949276323`*^9, 
   3.676388666448176*^9, 3.676440141917055*^9, 3.67644206113505*^9, 
   3.6764734260760403`*^9, 3.677484677351678*^9, 3.67750386490447*^9, 
   3.677682252521587*^9, 3.677682344242956*^9, 3.677682405799204*^9, {
   3.677682559314039*^9, 3.677682601748749*^9}, 3.678771755603828*^9, 
   3.6787718704111567`*^9, 3.6787720354712553`*^9, {3.678772266822555*^9, 
   3.678772284607242*^9}, {3.678772375092311*^9, 3.678772409154812*^9}, {
   3.678772441192569*^9, 3.67877245072477*^9}, 3.678772532795595*^9, {
   3.678772817801484*^9, 3.678772828460821*^9}, 3.678772872535182*^9, 
   3.678774475451853*^9, 3.678775839601779*^9, 3.679373148388205*^9, 
   3.6838947043272953`*^9, 3.68389686364214*^9, 3.683899190547463*^9, 
   3.683899560122406*^9, 3.6839038492626743`*^9, 3.683903995232173*^9, 
   3.683904603740594*^9, 3.6839046780311937`*^9, 3.6839054787572117`*^9, 
   3.683906251985915*^9, 3.68390668065705*^9, 3.683906723095969*^9, 
   3.683949302957801*^9, 3.683949860524699*^9, 3.6839523804559183`*^9, 
   3.6839551294524803`*^9, 3.683958906704781*^9, {3.685192867733756*^9, 
   3.6851928832382393`*^9}, {3.6851929468598423`*^9, 3.6851929884163*^9}, 
   3.685193122696867*^9, 3.685193849822316*^9, 3.6852490140941887`*^9, 
   3.6852545093644657`*^9, 3.685258976314921*^9, 3.685706242225347*^9, 
   3.685711724459684*^9, 3.6857141718770437`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Step1x4Algebra", ";"}]], "Input",
 CellChangeTimes->{{3.6851905751101*^9, 3.6851905772932377`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"S1Subalgebra=\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1"},
            {
             SubscriptBox["\[Iota]", "1"]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"2"},
            {
             SubscriptBox["\[Iota]", "2"]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"3"},
            {
             SubscriptBox["\[Iota]", "3"]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"4"},
            {
             SubscriptBox["\[Iota]", "4"]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"5"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"27"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"53"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"59"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"63"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"79"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]]},
       {
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"87"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"95"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"97"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"98"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"102"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"104"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"110"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"114"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"120"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"122"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]]},
       {
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"124"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"125"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"133"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"137"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"139"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"145"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"147"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"149"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"151"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"152"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]]},
       {
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"160"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"164"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"165"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"173"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"181"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"195"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"199"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"203"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"207"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"210"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]]},
       {
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"216"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"218"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"224"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"226"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"229"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"230"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"238"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"240"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"242"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"250"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]]},
       {
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"251"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"253"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"256"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"257"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"259"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"260"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"263"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"265"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"268"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"270"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]]},
       {
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"277"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"286"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"297"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"299"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"309"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"320"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"321"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"335"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"341"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"345"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]]},
       {
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"346"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"347"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"349"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"351"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"356"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"362"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"366"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"379"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"406"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox["\<\"\"\>",
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["S1Subalgebra=", 
   MatrixForm[{{
      MatrixForm[{{1}, {
         Subscript[$CellContext`\[Iota], 1]}}], 
      MatrixForm[{{2}, {
         Subscript[$CellContext`\[Iota], 2]}}], 
      MatrixForm[{{3}, {
         Subscript[$CellContext`\[Iota], 3]}}], 
      MatrixForm[{{4}, {
         Subscript[$CellContext`\[Iota], 4]}}], 
      MatrixForm[{{5}, {
        "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\)]\)\
\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)"}}], 
      MatrixForm[{{27}, {
        "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\)]\)\
\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}], 
      MatrixForm[{{53}, {
        "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)"}}], 
      MatrixForm[{{59}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)\
\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \
\(3\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}], 
      MatrixForm[{{63}, {
        "\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)\
\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \
\(3\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}], 
      MatrixForm[{{79}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)\
\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(3\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}]}, {
      MatrixForm[{{87}, {
        "\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)\
\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}], 
      MatrixForm[{{95}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)\
\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}], 
      MatrixForm[{{97}, {"\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}], 
      MatrixForm[{{98}, {
        "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)\
\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \
\(3\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)"}}], 
      MatrixForm[{{102}, {
        "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \(3\)]\)\
\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)"}}], 
      MatrixForm[{{104}, {
        "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)\
\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)"}}], 
      MatrixForm[{{110}, {
        "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)\
\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}], 
      MatrixForm[{{114}, {
        "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)\
\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \
\(3\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)"}}], 
      MatrixForm[{{120}, {
        "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \(3\)]\)\
\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}], 
      MatrixForm[{{122}, {
        "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)\
\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}]}, {
      MatrixForm[{{124}, {
        "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)"}}], 
      MatrixForm[{{125}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)\
\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \
\(3\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}], 
      MatrixForm[{{133}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)\
\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \
\(3\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}], 
      MatrixForm[{{137}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)\
\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \
\(3\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}], 
      MatrixForm[{{139}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)\
\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(3\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}], 
      MatrixForm[{{145}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)\
\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \
\(3\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}], 
      MatrixForm[{{147}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)\
\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(3\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}], 
      MatrixForm[{{149}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)\
\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}], 
      MatrixForm[{{151}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)\
\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}], 
      MatrixForm[{{152}, {
        "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\)]\)\
\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)"}}]}, {
      MatrixForm[{{160}, {
        "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\)]\)\
\!\(\*SubscriptBox[\(p\), \(3\)]\)"}}], 
      MatrixForm[{{164}, {"\!\(\*SubscriptBox[\(q\), \(4\)]\)"}}], 
      MatrixForm[{{165}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)\
\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \
\(3\)]\)"}}], 
      MatrixForm[{{173}, {
        "\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)\
\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)"}}], 
      MatrixForm[{{181}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)\
\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)"}}], 
      MatrixForm[{{195}, {
        "\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(3\)]\)"}}], 
      MatrixForm[{{199}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)"}}], 
      MatrixForm[{{203}, {
        "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)\
\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \
\(3\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)"}}], 
      MatrixForm[{{207}, {
        "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)\
\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)"}}], 
      MatrixForm[{{210}, {
        "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \(3\)]\)\
\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)"}}]}, {
      MatrixForm[{{216}, {
        "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)\
\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \
\(3\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)"}}], 
      MatrixForm[{{218}, {
        "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)\
\!\(\*SubscriptBox[\(p\), \(3\)]\)"}}], 
      MatrixForm[{{224}, {
        "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)\
\!\(\*SubscriptBox[\(q\), \(4\)]\)"}}], 
      MatrixForm[{{226}, {
        "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \(3\)]\)\
\!\(\*SubscriptBox[\(p\), \(3\)]\)"}}], 
      MatrixForm[{{229}, {"\!\(\*SubscriptBox[\(p\), \(3\)]\)"}}], 
      MatrixForm[{{230}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)\
\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \
\(3\)]\)"}}], 
      MatrixForm[{{238}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)\
\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \
\(3\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)"}}], 
      MatrixForm[{{240}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)\
\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(3\)]\)"}}], 
      MatrixForm[{{242}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)\
\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \
\(3\)]\)"}}], 
      MatrixForm[{{250}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)\
\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)"}}]}, {
      MatrixForm[{{251}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)\
\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)"}}], 
      MatrixForm[{{253}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)\
\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)"}}], 
      MatrixForm[{{256}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \
\(3\)]\)"}}], 
      MatrixForm[{{257}, {
        "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\)]\)\
\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}], 
      MatrixForm[{{259}, {
        "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \
\(3\)]\)"}}], 
      MatrixForm[{{260}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)\
\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}], 
      MatrixForm[{{263}, {
        "\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)\
\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}], 
      MatrixForm[{{265}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)\
\!\(\*SubscriptBox[\(q\), \(3\)]\)"}}], 
      MatrixForm[{{268}, {"\!\(\*SubscriptBox[\(q\), \(3\)]\)"}}], 
      MatrixForm[{{270}, {
        "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)\
\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \
\(3\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)"}}]}, {
      MatrixForm[{{277}, {
        "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \(3\)]\)\
\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}], 
      MatrixForm[{{286}, {
        "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)\
\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\)]\)"}}], 
      MatrixForm[{{297}, {
        "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)"}}], 
      MatrixForm[{{299}, {
        "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(3\)]\)"}}], 
      MatrixForm[{{309}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)\
\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}], 
      MatrixForm[{{320}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)\
\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\)]\)"}}], 
      MatrixForm[{{321}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)\
\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}], 
      MatrixForm[{{335}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)\
\!\(\*SubscriptBox[\(q\), \(3\)]\)"}}], 
      MatrixForm[{{341}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)\
\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}], 
      MatrixForm[{{345}, {"\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}]}, {
      MatrixForm[{{346}, {
        "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\)]\)\
\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}], 
      MatrixForm[{{347}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)\
\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}], 
      MatrixForm[{{349}, {
        "\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)"}}], 
      MatrixForm[{{351}, {
        "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)\
\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \
\(3\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}], 
      MatrixForm[{{356}, {
        "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \(3\)]\)\
\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}], 
      MatrixForm[{{362}, {"\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}], 
      MatrixForm[{{366}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)\
\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)"}}], 
      MatrixForm[{{379}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\)]\)\
\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}], 
      MatrixForm[{{406}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)"}}], 
      MatrixForm[""]}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.683894720447112*^9, 3.6838968668468018`*^9, 
  3.683899198805331*^9, 3.683899562039463*^9, 3.683903850917775*^9, 
  3.683903999315219*^9, 3.683904605899776*^9, 3.683904680346571*^9, 
  3.6839054808932447`*^9, 3.683906254214137*^9, 3.683906688799885*^9, 
  3.6839067255501547`*^9, 3.683949307746722*^9, 3.6839498623762913`*^9, 
  3.6839523828028383`*^9, 3.683955131153241*^9, 3.683958910291017*^9, 
  3.6851931255300837`*^9, 3.6851938653373003`*^9, 3.685254511106864*^9, 
  3.685258992752664*^9, 3.685706244525*^9, 3.685711726494656*^9, 
  3.6857141781065598`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"S2Subalgebra=\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1"},
            {
             SubscriptBox["\[Iota]", "1"]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"2"},
            {
             SubscriptBox["\[Iota]", "2"]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"3"},
            {
             SubscriptBox["\[Iota]", "3"]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"4"},
            {
             SubscriptBox["\[Iota]", "4"]}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"6"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"13"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"22"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"33"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"35"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"45"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]]},
       {
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"56"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"57"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"71"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"77"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"81"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"82"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"84"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"85"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"88"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"90"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]]},
       {
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"93"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"95"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"100"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"106"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"110"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"123"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"150"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"161"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"162"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"164"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]]},
       {
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"165"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"169"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"171"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"177"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"181"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"187"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"189"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"191"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"192"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"200"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]]},
       {
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"204"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"206"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"212"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"214"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"216"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"218"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"219"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"241"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"267"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"273"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]]},
       {
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"277"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"293"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"301"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"309"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"311"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"312"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"316"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"319"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"325"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"327"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]]},
       {
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"333"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"335"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"338"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"339"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"347"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"349"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"351"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"359"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"360"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"362"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]]},
       {
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"365"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"366"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"374"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"378"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"379"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"387"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"395"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"409"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox[
         RowBox[{"(", "\[NoBreak]", GridBox[{
            {"413"},
            {"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.7]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]], 
        TagBox["\<\"\"\>",
         Function[BoxForm`e$, 
          MatrixForm[BoxForm`e$]]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["S2Subalgebra=", 
   MatrixForm[{{
      MatrixForm[{{1}, {
         Subscript[$CellContext`\[Iota], 1]}}], 
      MatrixForm[{{2}, {
         Subscript[$CellContext`\[Iota], 2]}}], 
      MatrixForm[{{3}, {
         Subscript[$CellContext`\[Iota], 3]}}], 
      MatrixForm[{{4}, {
         Subscript[$CellContext`\[Iota], 4]}}], 
      MatrixForm[{{6}, {
        "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)\
\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \
\(1\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)"}}], 
      MatrixForm[{{13}, {
        "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \(1\)]\)\
\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}], 
      MatrixForm[{{22}, {
        "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)\
\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\)]\)"}}], 
      MatrixForm[{{33}, {
        "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)"}}], 
      MatrixForm[{{35}, {
        "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(1\)]\)"}}], 
      MatrixForm[{{45}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)\
\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}]}, {
      MatrixForm[{{56}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)\
\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\)]\)"}}], 
      MatrixForm[{{57}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)\
\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}], 
      MatrixForm[{{71}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)\
\!\(\*SubscriptBox[\(q\), \(1\)]\)"}}], 
      MatrixForm[{{77}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)\
\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}], 
      MatrixForm[{{81}, {"\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}], 
      MatrixForm[{{82}, {
        "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\)]\)\
\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}], 
      MatrixForm[{{84}, {
        "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \
\(1\)]\)"}}], 
      MatrixForm[{{85}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)\
\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}], 
      MatrixForm[{{88}, {
        "\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)\
\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}], 
      MatrixForm[{{90}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)\
\!\(\*SubscriptBox[\(q\), \(1\)]\)"}}]}, {
      MatrixForm[{{93}, {"\!\(\*SubscriptBox[\(q\), \(1\)]\)"}}], 
      MatrixForm[{{95}, {
        "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)\
\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \
\(1\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)"}}], 
      MatrixForm[{{100}, {
        "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \(1\)]\)\
\!\(\*SubscriptBox[\(q\), \(4\)]\)"}}], 
      MatrixForm[{{106}, {"\!\(\*SubscriptBox[\(q\), \(4\)]\)"}}], 
      MatrixForm[{{110}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)\
\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)"}}], 
      MatrixForm[{{123}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)\
\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)"}}], 
      MatrixForm[{{150}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)"}}], 
      MatrixForm[{{161}, {
        "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\)]\)\
\!\(\*SubscriptBox[\(q\), \(4\)]\)"}}], 
      MatrixForm[{{162}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)\
\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)"}}], 
      MatrixForm[{{164}, {
        "\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)"}}]}, {
      MatrixForm[{{165}, {
        "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)\
\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \
\(1\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)"}}], 
      MatrixForm[{{169}, {
        "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \(1\)]\)\
\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)"}}], 
      MatrixForm[{{171}, {
        "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)\
\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)"}}], 
      MatrixForm[{{177}, {
        "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)\
\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}], 
      MatrixForm[{{181}, {
        "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)\
\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \
\(1\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)"}}], 
      MatrixForm[{{187}, {
        "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \(1\)]\)\
\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}], 
      MatrixForm[{{189}, {
        "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)\
\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}], 
      MatrixForm[{{191}, {
        "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)"}}], 
      MatrixForm[{{192}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)\
\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \
\(1\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}], 
      MatrixForm[{{200}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)\
\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \
\(1\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}]}, {
      MatrixForm[{{204}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)\
\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \
\(1\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}], 
      MatrixForm[{{206}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)\
\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(1\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}], 
      MatrixForm[{{212}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)\
\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \
\(1\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}], 
      MatrixForm[{{214}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)\
\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(1\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}], 
      MatrixForm[{{216}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)\
\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}], 
      MatrixForm[{{218}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)\
\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}], 
      MatrixForm[{{219}, {
        "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\)]\)\
\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)"}}], 
      MatrixForm[{{241}, {
        "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\)]\)\
\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}], 
      MatrixForm[{{267}, {
        "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)"}}], 
      MatrixForm[{{273}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)\
\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \
\(1\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}]}, {
      MatrixForm[{{277}, {
        "\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)\
\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \
\(1\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}], 
      MatrixForm[{{293}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)\
\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(1\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}], 
      MatrixForm[{{301}, {
        "\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)\
\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}], 
      MatrixForm[{{309}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)\
\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}], 
      MatrixForm[{{311}, {"\!\(\*SubscriptBox[\(p\), \(2\)]\)"}}], 
      MatrixForm[{{312}, {
        "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)\
\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \
\(1\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)"}}], 
      MatrixForm[{{316}, {
        "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)\
\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}], 
      MatrixForm[{{319}, {
        "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \(1\)]\)\
\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)"}}], 
      MatrixForm[{{325}, {
        "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)\
\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \
\(1\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)"}}], 
      MatrixForm[{{327}, {
        "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)\
\!\(\*SubscriptBox[\(p\), \(1\)]\)"}}]}, {
      MatrixForm[{{333}, {
        "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)\
\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}], 
      MatrixForm[{{335}, {
        "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \(1\)]\)\
\!\(\*SubscriptBox[\(p\), \(1\)]\)"}}], 
      MatrixForm[{{338}, {"\!\(\*SubscriptBox[\(p\), \(1\)]\)"}}], 
      MatrixForm[{{339}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)\
\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \
\(1\)]\)"}}], 
      MatrixForm[{{347}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)\
\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \
\(1\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)"}}], 
      MatrixForm[{{349}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)\
\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(1\)]\)"}}], 
      MatrixForm[{{351}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)\
\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \
\(1\)]\)"}}], 
      MatrixForm[{{359}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)\
\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}], 
      MatrixForm[{{360}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)\
\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)"}}], 
      MatrixForm[{{362}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)\
\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)"}}]}, {
      MatrixForm[{{365}, {
        "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \
\(1\)]\)"}}], 
      MatrixForm[{{366}, {
        "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\)]\)\
\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)"}}], 
      MatrixForm[{{374}, {
        "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\)]\)\
\!\(\*SubscriptBox[\(p\), \(1\)]\)"}}], 
      MatrixForm[{{378}, {"\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}], 
      MatrixForm[{{379}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)\
\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \
\(1\)]\)"}}], 
      MatrixForm[{{387}, {
        "\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)\
\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)"}}], 
      MatrixForm[{{395}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)\
\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \(1\)]\)"}}], 
      MatrixForm[{{409}, {
        "\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(1\)]\)"}}], 
      MatrixForm[{{413}, {
        "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)"}}], 
      MatrixForm[""]}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.683894720447112*^9, 3.6838968668468018`*^9, 
  3.683899198805331*^9, 3.683899562039463*^9, 3.683903850917775*^9, 
  3.683903999315219*^9, 3.683904605899776*^9, 3.683904680346571*^9, 
  3.6839054808932447`*^9, 3.683906254214137*^9, 3.683906688799885*^9, 
  3.6839067255501547`*^9, 3.683949307746722*^9, 3.6839498623762913`*^9, 
  3.6839523828028383`*^9, 3.683955131153241*^9, 3.683958910291017*^9, 
  3.6851931255300837`*^9, 3.6851938653373003`*^9, 3.685254511106864*^9, 
  3.685258992752664*^9, 3.685706244525*^9, 3.685711726494656*^9, 
  3.685714178171637*^9}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Step1x5Algebra", ";"}]], "Input",
 CellChangeTimes->{
  3.683894830461444*^9, {3.6851905801180687`*^9, 3.685190585509602*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculation of generators", "Section",
 CellChangeTimes->{{3.683902406280332*^9, 3.683902411992662*^9}, {
  3.6839024516165123`*^9, 3.683902475521956*^9}, {3.683902509419033*^9, 
  3.683902551851089*^9}, {3.683902843994619*^9, 3.6839028464994917`*^9}, {
  3.683903880670438*^9, 3.683903893160449*^9}, {3.6851906152290363`*^9, 
  3.6851906281173563`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Step2Generators", ";"}]], "Input",
 CellChangeTimes->{{3.683894537461843*^9, 3.6838945431879177`*^9}, 
   3.683896844267519*^9, {3.685190630579959*^9, 3.685190640942966*^9}, {
   3.685248875406439*^9, 3.6852488757824078`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Number of prefiltered (RelevantGeneratorGenerationQ) \
generators = \"\>", "\[InvisibleSpace]", "481236"}],
  SequenceForm[
  "Number of prefiltered (RelevantGeneratorGenerationQ) generators = ", 
   481236],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894543869298*^9, 3.683896846407238*^9, 3.683899171636959*^9, 
   3.683899550999612*^9, 3.68390341308134*^9, 3.683903487359417*^9, {
   3.683903575170375*^9, 3.683903580924982*^9}, {3.683903794785561*^9, 
   3.683903798387924*^9}, 3.6839038692686567`*^9, 3.6839040053230257`*^9, 
   3.683904191184215*^9, 3.6839042879017773`*^9, 3.683904612034918*^9, {
   3.6839046848598967`*^9, 3.683904691479237*^9}, 3.683905484692594*^9, 
   3.683906258270974*^9, 3.683906729250897*^9, 3.683949311284865*^9, 
   3.683949866022407*^9, 3.683952386424906*^9, 3.683955134941909*^9, 
   3.6839589138886127`*^9, 3.685193073719002*^9, 3.685193129928636*^9, 
   3.6851931966453743`*^9, 3.6851938896178083`*^9, {3.685249057025475*^9, 
   3.68524907850462*^9}, 3.685259002990913*^9, 3.685706249520693*^9, 
   3.685711735967304*^9, 3.68571424215281*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Final number of generators = \"\>", "\[InvisibleSpace]", 
   "269344", 
   "\[InvisibleSpace]", "\<\". The first (up to) 10 generators are = \"\>", 
   "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {
       TagBox[
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"15"},
            {"1"},
            {"3"},
            {"34"},
            {"30"},
            {"20"},
            {"51"},
            {"53"},
            {"46"},
            {"74"},
            {"79"},
            {"64"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}],
        Function[BoxForm`e$, 
         MatrixForm[BoxForm`e$]]], 
       TagBox[
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"15"},
            {"1"},
            {"3"},
            {"34"},
            {"29"},
            {"20"},
            {"51"},
            {"53"},
            {"46"},
            {"74"},
            {"79"},
            {"64"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}],
        Function[BoxForm`e$, 
         MatrixForm[BoxForm`e$]]], 
       TagBox[
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"15"},
            {"1"},
            {"3"},
            {"34"},
            {"30"},
            {"20"},
            {"51"},
            {"53"},
            {"47"},
            {"74"},
            {"79"},
            {"64"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}],
        Function[BoxForm`e$, 
         MatrixForm[BoxForm`e$]]], 
       TagBox[
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"15"},
            {"1"},
            {"3"},
            {"34"},
            {"29"},
            {"20"},
            {"51"},
            {"53"},
            {"47"},
            {"74"},
            {"79"},
            {"64"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}],
        Function[BoxForm`e$, 
         MatrixForm[BoxForm`e$]]], 
       TagBox[
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"15"},
            {"1"},
            {"3"},
            {"34"},
            {"30"},
            {"21"},
            {"51"},
            {"53"},
            {"46"},
            {"74"},
            {"79"},
            {"64"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}],
        Function[BoxForm`e$, 
         MatrixForm[BoxForm`e$]]], 
       TagBox[
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"15"},
            {"1"},
            {"3"},
            {"34"},
            {"29"},
            {"21"},
            {"51"},
            {"53"},
            {"46"},
            {"74"},
            {"79"},
            {"64"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}],
        Function[BoxForm`e$, 
         MatrixForm[BoxForm`e$]]], 
       TagBox[
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"15"},
            {"1"},
            {"3"},
            {"34"},
            {"30"},
            {"21"},
            {"51"},
            {"53"},
            {"47"},
            {"74"},
            {"79"},
            {"64"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}],
        Function[BoxForm`e$, 
         MatrixForm[BoxForm`e$]]], 
       TagBox[
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"15"},
            {"1"},
            {"3"},
            {"34"},
            {"29"},
            {"21"},
            {"51"},
            {"53"},
            {"47"},
            {"74"},
            {"79"},
            {"64"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}],
        Function[BoxForm`e$, 
         MatrixForm[BoxForm`e$]]], 
       TagBox[
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"15"},
            {"1"},
            {"3"},
            {"34"},
            {"30"},
            {"49"},
            {"51"},
            {"53"},
            {"18"},
            {"74"},
            {"79"},
            {"64"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}],
        Function[BoxForm`e$, 
         MatrixForm[BoxForm`e$]]], 
       TagBox[
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"15"},
            {"1"},
            {"3"},
            {"34"},
            {"29"},
            {"49"},
            {"51"},
            {"53"},
            {"18"},
            {"74"},
            {"79"},
            {"64"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}],
        Function[BoxForm`e$, 
         MatrixForm[BoxForm`e$]]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]]}],
  SequenceForm[
  "Final number of generators = ", 269344, 
   ". The first (up to) 10 generators are = ", 
   TableForm[{{
      MatrixForm[{15, 1, 3, 34, 30, 20, 51, 53, 46, 74, 79, 64}], 
      MatrixForm[{15, 1, 3, 34, 29, 20, 51, 53, 46, 74, 79, 64}], 
      MatrixForm[{15, 1, 3, 34, 30, 20, 51, 53, 47, 74, 79, 64}], 
      MatrixForm[{15, 1, 3, 34, 29, 20, 51, 53, 47, 74, 79, 64}], 
      MatrixForm[{15, 1, 3, 34, 30, 21, 51, 53, 46, 74, 79, 64}], 
      MatrixForm[{15, 1, 3, 34, 29, 21, 51, 53, 46, 74, 79, 64}], 
      MatrixForm[{15, 1, 3, 34, 30, 21, 51, 53, 47, 74, 79, 64}], 
      MatrixForm[{15, 1, 3, 34, 29, 21, 51, 53, 47, 74, 79, 64}], 
      MatrixForm[{15, 1, 3, 34, 30, 49, 51, 53, 18, 74, 79, 64}], 
      MatrixForm[{15, 1, 3, 34, 29, 49, 51, 53, 18, 74, 79, 64}]}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894543869298*^9, 3.683896846407238*^9, 3.683899171636959*^9, 
   3.683899550999612*^9, 3.68390341308134*^9, 3.683903487359417*^9, {
   3.683903575170375*^9, 3.683903580924982*^9}, {3.683903794785561*^9, 
   3.683903798387924*^9}, 3.6839038692686567`*^9, 3.6839040053230257`*^9, 
   3.683904191184215*^9, 3.6839042879017773`*^9, 3.683904612034918*^9, {
   3.6839046848598967`*^9, 3.683904691479237*^9}, 3.683905484692594*^9, 
   3.683906258270974*^9, 3.683906729250897*^9, 3.683949311284865*^9, 
   3.683949866022407*^9, 3.683952386424906*^9, 3.683955134941909*^9, 
   3.6839589138886127`*^9, 3.685193073719002*^9, 3.685193129928636*^9, 
   3.6851931966453743`*^9, 3.6851938896178083`*^9, {3.685249057025475*^9, 
   3.68524907850462*^9}, 3.685259002990913*^9, 3.685706249520693*^9, 
   3.685711735967304*^9, 3.685714310241729*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"After the initial cancellation (de-niceification), we expect \
to have \"\>", "\[InvisibleSpace]", "512", 
   "\[InvisibleSpace]", "\<\" generators left.\"\>"}],
  SequenceForm[
  "After the initial cancellation (de-niceification), we expect to have ", 
   512, " generators left."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894543869298*^9, 3.683896846407238*^9, 3.683899171636959*^9, 
   3.683899550999612*^9, 3.68390341308134*^9, 3.683903487359417*^9, {
   3.683903575170375*^9, 3.683903580924982*^9}, {3.683903794785561*^9, 
   3.683903798387924*^9}, 3.6839038692686567`*^9, 3.6839040053230257`*^9, 
   3.683904191184215*^9, 3.6839042879017773`*^9, 3.683904612034918*^9, {
   3.6839046848598967`*^9, 3.683904691479237*^9}, 3.683905484692594*^9, 
   3.683906258270974*^9, 3.683906729250897*^9, 3.683949311284865*^9, 
   3.683949866022407*^9, 3.683952386424906*^9, 3.683955134941909*^9, 
   3.6839589138886127`*^9, 3.685193073719002*^9, 3.685193129928636*^9, 
   3.6851931966453743`*^9, 3.6851938896178083`*^9, {3.685249057025475*^9, 
   3.68524907850462*^9}, 3.685259002990913*^9, 3.685706249520693*^9, 
   3.685711735967304*^9, 3.685714318105331*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"They will lie in the following idempotents:\\n\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"\<\"idempotents\"\>", "\<\"#{generators}\"\>"},
       {
        RowBox[{"{", 
         RowBox[{"\<\"c\"\>", ",", "\<\"d\"\>"}], "}"}], "8"},
       {
        RowBox[{"{", 
         RowBox[{"\<\"c\"\>", ",", "\<\"b\"\>"}], "}"}], "32"},
       {
        RowBox[{"{", 
         RowBox[{"\<\"c\"\>", ",", "\<\"a\"\>"}], "}"}], "24"},
       {
        RowBox[{"{", 
         RowBox[{"\<\"b\"\>", ",", "\<\"d\"\>"}], "}"}], "24"},
       {
        RowBox[{"{", 
         RowBox[{"\<\"b\"\>", ",", "\<\"b\"\>"}], "}"}], "96"},
       {
        RowBox[{"{", 
         RowBox[{"\<\"b\"\>", ",", "\<\"a\"\>"}], "}"}], "72"},
       {
        RowBox[{"{", 
         RowBox[{"\<\"a\"\>", ",", "\<\"d\"\>"}], "}"}], "32"},
       {
        RowBox[{"{", 
         RowBox[{"\<\"a\"\>", ",", "\<\"b\"\>"}], "}"}], "128"},
       {
        RowBox[{"{", 
         RowBox[{"\<\"a\"\>", ",", "\<\"a\"\>"}], "}"}], "96"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["They will lie in the following idempotents:\n", 
   MatrixForm[{{
     "idempotents", "#{generators}"}, {{"c", "d"}, 8}, {{"c", "b"}, 32}, {{
      "c", "a"}, 24}, {{"b", "d"}, 24}, {{"b", "b"}, 96}, {{"b", "a"}, 72}, {{
      "a", "d"}, 32}, {{"a", "b"}, 128}, {{"a", "a"}, 96}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.683894543869298*^9, 3.683896846407238*^9, 3.683899171636959*^9, 
   3.683899550999612*^9, 3.68390341308134*^9, 3.683903487359417*^9, {
   3.683903575170375*^9, 3.683903580924982*^9}, {3.683903794785561*^9, 
   3.683903798387924*^9}, 3.6839038692686567`*^9, 3.6839040053230257`*^9, 
   3.683904191184215*^9, 3.6839042879017773`*^9, 3.683904612034918*^9, {
   3.6839046848598967`*^9, 3.683904691479237*^9}, 3.683905484692594*^9, 
   3.683906258270974*^9, 3.683906729250897*^9, 3.683949311284865*^9, 
   3.683949866022407*^9, 3.683952386424906*^9, 3.683955134941909*^9, 
   3.6839589138886127`*^9, 3.685193073719002*^9, 3.685193129928636*^9, 
   3.6851931966453743`*^9, 3.6851938896178083`*^9, {3.685249057025475*^9, 
   3.68524907850462*^9}, 3.685259002990913*^9, 3.685706249520693*^9, 
   3.685711735967304*^9, 3.685714347787462*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculation of domains and structure maps", "Section",
 CellChangeTimes->{{3.683902406280332*^9, 3.683902411992662*^9}, {
  3.6839024516165123`*^9, 3.683902475521956*^9}, {3.683902509419033*^9, 
  3.6839025833159637`*^9}, {3.683902614317812*^9, 3.683902621444993*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Step3x1Domains", ";"}]], "Input",
 CellChangeTimes->{{3.6838947269387207`*^9, 3.6838947298832827`*^9}, 
   3.6838947755524597`*^9, {3.68519067320802*^9, 3.685190679928112*^9}, {
   3.685248878742404*^9, 3.685248878886519*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There are \"\>", "\[InvisibleSpace]", "210", 
   "\[InvisibleSpace]", "\<\" rectangles, bigons or boundary rectangles. Here \
is a random selection of up to 10 of these:\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"188", "158", "72", "70", "146", "83", "120", "93", "127", "135"},
       {
        RowBox[{"{", "52", "}"}], 
        RowBox[{"{", 
         RowBox[{"35", ",", "34"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"28", ",", "9"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"28", ",", "9", ",", "42"}], "}"}], 
        RowBox[{"{", "29", "}"}], 
        RowBox[{"{", 
         RowBox[{"11", ",", "10"}], "}"}], 
        RowBox[{"{", "19", "}"}], 
        RowBox[{"{", 
         RowBox[{"32", ",", "14", ",", "33", ",", "13"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"23", ",", "22"}], "}"}], 
        RowBox[{"{", "25", "}"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm[
  "There are ", 210, 
   " rectangles, bigons or boundary rectangles. Here is a random selection of \
up to 10 of these:", 
   MatrixForm[{{188, 158, 72, 70, 146, 83, 120, 93, 127, 
     135}, {{52}, {35, 34}, {28, 9}, {28, 9, 42}, {29}, {11, 10}, {19}, {32, 
      14, 33, 13}, {23, 22}, {25}}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.683894730955065*^9, 3.6838947783069363`*^9, 
  3.683894849892799*^9, 3.683896385425003*^9, 3.683896875241727*^9, 
  3.6838992152472486`*^9, 3.683899568257552*^9, 3.683904569129693*^9, 
  3.683904615298397*^9, 3.683904696135613*^9, 3.6839054921439457`*^9, 
  3.6839062640974073`*^9, 3.68390673333317*^9, 3.6839072142815037`*^9, 
  3.6839493213703203`*^9, 3.683949878004867*^9, 3.683952394631023*^9, 
  3.6839551403057747`*^9, 3.683958924101*^9, 3.685193337800858*^9, 
  3.6851938971431427`*^9, 3.685202311684525*^9, 3.685249082427041*^9, 
  3.6852590077462797`*^9, 3.685706253568079*^9, 3.685711740102295*^9, 
  3.685714366804544*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There are \"\>", "\[InvisibleSpace]", "3281", 
   "\[InvisibleSpace]", "\<\" domains with boundary on S1, \"\>", 
   "\[InvisibleSpace]", "3281", "\[InvisibleSpace]", "\<\" on S2 and \"\>", 
   "\[InvisibleSpace]", "158", 
   "\[InvisibleSpace]", "\<\" without any boundary.\"\>"}],
  SequenceForm[
  "There are ", 3281, " domains with boundary on S1, ", 3281, " on S2 and ", 
   158, " without any boundary."],
  Editable->False]], "Print",
 CellChangeTimes->{3.683894730955065*^9, 3.6838947783069363`*^9, 
  3.683894849892799*^9, 3.683896385425003*^9, 3.683896875241727*^9, 
  3.6838992152472486`*^9, 3.683899568257552*^9, 3.683904569129693*^9, 
  3.683904615298397*^9, 3.683904696135613*^9, 3.6839054921439457`*^9, 
  3.6839062640974073`*^9, 3.68390673333317*^9, 3.6839072142815037`*^9, 
  3.6839493213703203`*^9, 3.683949878004867*^9, 3.683952394631023*^9, 
  3.6839551403057747`*^9, 3.683958924101*^9, 3.685193337800858*^9, 
  3.6851938971431427`*^9, 3.685202311684525*^9, 3.685249082427041*^9, 
  3.6852590077462797`*^9, 3.685706253568079*^9, 3.685711740102295*^9, 
  3.685714412645885*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\" << backup saved at: \"\>", 
   "\[InvisibleSpace]", \
"\<\"/mhome/dpmms/c/cbz20/Documents/PhD/Research/thesis/BSFH/Backups/\
GlueingBSAAx4e_AfterDomains1.mx >>\"\>"}],
  SequenceForm[
  " << backup saved at: ", 
   "/mhome/dpmms/c/cbz20/Documents/PhD/Research/thesis/BSFH/Backups/\
GlueingBSAAx4e_AfterDomains1.mx >>"],
  Editable->False]], "Print",
 CellChangeTimes->{3.683894730955065*^9, 3.6838947783069363`*^9, 
  3.683894849892799*^9, 3.683896385425003*^9, 3.683896875241727*^9, 
  3.6838992152472486`*^9, 3.683899568257552*^9, 3.683904569129693*^9, 
  3.683904615298397*^9, 3.683904696135613*^9, 3.6839054921439457`*^9, 
  3.6839062640974073`*^9, 3.68390673333317*^9, 3.6839072142815037`*^9, 
  3.6839493213703203`*^9, 3.683949878004867*^9, 3.683952394631023*^9, 
  3.6839551403057747`*^9, 3.683958924101*^9, 3.685193337800858*^9, 
  3.6851938971431427`*^9, 3.685202311684525*^9, 3.685249082427041*^9, 
  3.6852590077462797`*^9, 3.685706253568079*^9, 3.685711740102295*^9, 
  3.685714417565749*^9}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"<<", 
  RowBox[{"(", 
   RowBox[{"BackupFilePath", "<>", "\"\<_AfterDomains1.mx\>\""}], 
   ")"}]}]], "Input",
 CellChangeTimes->{{3.67401554637004*^9, 3.674015550954636*^9}, 
   3.674027617098591*^9, {3.683907168603799*^9, 3.6839071704999237`*^9}}],

Cell["\<\
The next two steps can take quite a while for large diagrams, for 250 000 \
generators up to a week or more. Parallel processing is possible, so consider \
using a computer with multiple kernels to speed up.\
\>", "Text",
 CellChangeTimes->{{3.683904487701765*^9, 3.683904540055222*^9}, {
  3.6839067513604193`*^9, 3.6839067871764097`*^9}, {3.683907238892846*^9, 
  3.6839072757256117`*^9}, {3.6839073161515713`*^9, 3.683907319646093*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Step3x2Domains", ";"}]], "Input",
 CellChangeTimes->{{3.68389561766648*^9, 3.683895623768882*^9}, {
  3.685190703361431*^9, 3.685190705639604*^9}, {3.685248881614497*^9, 
  3.685248881790359*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"Computed indices for domains.\"\>"], "Print",
 CellChangeTimes->{3.6838956246100893`*^9, 3.683895684554982*^9, 
  3.683896099063699*^9, 3.6838961508419447`*^9, 3.68389639107202*^9, 
  3.683896615873249*^9, 3.6838968837250547`*^9, 3.6838992386609*^9, 
  3.683899573469658*^9, 3.683901250664845*^9, 3.683904706146625*^9, 
  3.6839056527730093`*^9, 3.6839062695679092`*^9, 3.683949330866878*^9, 
  3.6839498827606487`*^9, 3.683952400833411*^9, 3.68395892921129*^9, 
  3.6851937142246103`*^9, 3.685193906917478*^9, 3.685249092025691*^9, 
  3.685259023392149*^9, 3.685259056942852*^9, 3.685706258821162*^9, 
  3.6857117468757668`*^9, 3.685714431191799*^9}],

Cell[BoxData["\<\"Computed starting intersection points of domains.\"\>"], \
"Print",
 CellChangeTimes->{3.6838956246100893`*^9, 3.683895684554982*^9, 
  3.683896099063699*^9, 3.6838961508419447`*^9, 3.68389639107202*^9, 
  3.683896615873249*^9, 3.6838968837250547`*^9, 3.6838992386609*^9, 
  3.683899573469658*^9, 3.683901250664845*^9, 3.683904706146625*^9, 
  3.6839056527730093`*^9, 3.6839062695679092`*^9, 3.683949330866878*^9, 
  3.6839498827606487`*^9, 3.683952400833411*^9, 3.68395892921129*^9, 
  3.6851937142246103`*^9, 3.685193906917478*^9, 3.685249092025691*^9, 
  3.685259023392149*^9, 3.685259056942852*^9, 3.685706258821162*^9, 
  3.6857117468757668`*^9, 3.685714431787622*^9}],

Cell[BoxData[
 TemplateBox[{RowBox[{"\"Mon 17 Oct 2016 18:33:51\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", "1.`"}], FontColor -> 
      GrayLevel[0.5]]}],RowBox[{"DateObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"2016", ",", "10", ",", "17"}], "}"}], ",", 
       RowBox[{"TimeObject", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"18", ",", "33", ",", "51.770095`"}], "}"}], ",", 
           RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}], ",", 
       RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}]},
  "DateObject",
  Editable->False]], "Print",
 CellChangeTimes->{3.6838956246100893`*^9, 3.683895684554982*^9, 
  3.683896099063699*^9, 3.6838961508419447`*^9, 3.68389639107202*^9, 
  3.683896615873249*^9, 3.6838968837250547`*^9, 3.6838992386609*^9, 
  3.683899573469658*^9, 3.683901250664845*^9, 3.683904706146625*^9, 
  3.6839056527730093`*^9, 3.6839062695679092`*^9, 3.683949330866878*^9, 
  3.6839498827606487`*^9, 3.683952400833411*^9, 3.68395892921129*^9, 
  3.6851937142246103`*^9, 3.685193906917478*^9, 3.685249092025691*^9, 
  3.685259023392149*^9, 3.685259056942852*^9, 3.685706258821162*^9, 
  3.6857117468757668`*^9, 3.685714431799564*^9}],

Cell[BoxData["\<\"There are 6720 domains that I need to look at.\"\>"], \
"Print",
 CellChangeTimes->{3.6838956246100893`*^9, 3.683895684554982*^9, 
  3.683896099063699*^9, 3.6838961508419447`*^9, 3.68389639107202*^9, 
  3.683896615873249*^9, 3.6838968837250547`*^9, 3.6838992386609*^9, 
  3.683899573469658*^9, 3.683901250664845*^9, 3.683904706146625*^9, 
  3.6839056527730093`*^9, 3.6839062695679092`*^9, 3.683949330866878*^9, 
  3.6839498827606487`*^9, 3.683952400833411*^9, 3.68395892921129*^9, 
  3.6851937142246103`*^9, 3.685193906917478*^9, 3.685249092025691*^9, 
  3.685259023392149*^9, 3.685259056942852*^9, 3.685706258821162*^9, 
  3.6857117468757668`*^9, 3.68571443180308*^9}],

Cell[BoxData["\<\"Computed starting generators for all domains.\"\>"], "Print",
 CellChangeTimes->{3.6838956246100893`*^9, 3.683895684554982*^9, 
  3.683896099063699*^9, 3.6838961508419447`*^9, 3.68389639107202*^9, 
  3.683896615873249*^9, 3.6838968837250547`*^9, 3.6838992386609*^9, 
  3.683899573469658*^9, 3.683901250664845*^9, 3.683904706146625*^9, 
  3.6839056527730093`*^9, 3.6839062695679092`*^9, 3.683949330866878*^9, 
  3.6839498827606487`*^9, 3.683952400833411*^9, 3.68395892921129*^9, 
  3.6851937142246103`*^9, 3.685193906917478*^9, 3.685249092025691*^9, 
  3.685259023392149*^9, 3.685259056942852*^9, 3.685706258821162*^9, 
  3.6857117468757668`*^9, 3.6857159027727747`*^9}],

Cell[BoxData[
 TemplateBox[{RowBox[{"\"Mon 17 Oct 2016 18:58:22\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", "1.`"}], FontColor -> 
      GrayLevel[0.5]]}],RowBox[{"DateObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"2016", ",", "10", ",", "17"}], "}"}], ",", 
       RowBox[{"TimeObject", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"18", ",", "58", ",", "22.768743`"}], "}"}], ",", 
           RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}], ",", 
       RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}]},
  "DateObject",
  Editable->False]], "Print",
 CellChangeTimes->{3.6838956246100893`*^9, 3.683895684554982*^9, 
  3.683896099063699*^9, 3.6838961508419447`*^9, 3.68389639107202*^9, 
  3.683896615873249*^9, 3.6838968837250547`*^9, 3.6838992386609*^9, 
  3.683899573469658*^9, 3.683901250664845*^9, 3.683904706146625*^9, 
  3.6839056527730093`*^9, 3.6839062695679092`*^9, 3.683949330866878*^9, 
  3.6839498827606487`*^9, 3.683952400833411*^9, 3.68395892921129*^9, 
  3.6851937142246103`*^9, 3.685193906917478*^9, 3.685249092025691*^9, 
  3.685259023392149*^9, 3.685259056942852*^9, 3.685706258821162*^9, 
  3.6857117468757668`*^9, 3.685715902784301*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Step3x3Domains", ";"}]], "Input",
 CellChangeTimes->{{3.68389606856364*^9, 3.683896070573711*^9}, {
  3.685190710440928*^9, 3.685190712688836*^9}, {3.685249107324833*^9, 
  3.6852491074910917`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 TemplateBox[{RowBox[{"\"Mon 17 Oct 2016 18:58:43\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", "1.`"}], FontColor -> 
      GrayLevel[0.5]]}],RowBox[{"DateObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"2016", ",", "10", ",", "17"}], "}"}], ",", 
       RowBox[{"TimeObject", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"18", ",", "58", ",", "43.259373`"}], "}"}], ",", 
           RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}], ",", 
       RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}]},
  "DateObject",
  Editable->False]], "Print",
 CellChangeTimes->{3.685249109994158*^9, 3.685259025303008*^9, 
  3.6852590586172037`*^9, 3.6857062612414713`*^9, 3.685711748953321*^9, 
  3.685715923308544*^9}],

Cell[BoxData["\<\"Calculation of the structure map. There are 269344 \
generators.\"\>"], "Print",
 CellChangeTimes->{3.685249109994158*^9, 3.685259025303008*^9, 
  3.6852590586172037`*^9, 3.6857062612414713`*^9, 3.685711748953321*^9, 
  3.685715923318761*^9}],

Cell[BoxData["\<\"Good: There are no multiple labels in the structure!\"\>"], \
"Print",
 CellChangeTimes->{3.685249109994158*^9, 3.685259025303008*^9, 
  3.6852590586172037`*^9, 3.6857062612414713`*^9, 3.685711748953321*^9, 
  3.685831031822525*^9}],

Cell[BoxData[
 TemplateBox[{RowBox[{"\"Wed 19 Oct 2016 02:57:12\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", "1.`"}], FontColor -> 
      GrayLevel[0.5]]}],RowBox[{"DateObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"2016", ",", "10", ",", "19"}], "}"}], ",", 
       RowBox[{"TimeObject", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"2", ",", "57", ",", "12.817382`"}], "}"}], ",", 
           RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}], ",", 
       RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}]},
  "DateObject",
  Editable->False]], "Print",
 CellChangeTimes->{3.685249109994158*^9, 3.685259025303008*^9, 
  3.6852590586172037`*^9, 3.6857062612414713`*^9, 3.685711748953321*^9, 
  3.6858310328278093`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Step3x4Domains", ";"}]], "Input",
 CellChangeTimes->{{3.683896075892415*^9, 3.683896076077523*^9}, {
  3.68519071569775*^9, 3.685190717729068*^9}, {3.685248883862629*^9, 
  3.685248884014323*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There are \"\>", "\[InvisibleSpace]", "302", 
   "\[InvisibleSpace]", "\<\" domains that contribute to the structure \
maps.\"\>"}],
  SequenceForm[
  "There are ", 302, " domains that contribute to the structure maps."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.68571175160121*^9, 3.6858311005084877`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There are \"\>", "\[InvisibleSpace]", "142", 
   "\[InvisibleSpace]", "\<\" domains that contribute an honest differential \
to the structure maps, e.g. \\n\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"1"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}], 
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"2"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}], 
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"3"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}], 
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"4"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}], 
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"5"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}], 
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"6"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}], 
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"7"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}], 
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"8"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}], 
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"9"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}], 
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"10"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}], 
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"11"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}], 
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"12"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}], 
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"13"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}], 
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"14"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}], 
        RowBox[{"(", "\[NoBreak]", 
         TagBox[GridBox[{
            {"15"}
           },
           
           GridBoxAlignment->{
            "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
             "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
           GridBoxSpacings->{"Columns" -> {
               Offset[0.27999999999999997`], {
                Offset[0.5599999999999999]}, 
               Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
               Offset[0.2], {
                Offset[0.4]}, 
               Offset[0.2]}, "RowsIndexed" -> {}}],
          Column], "\[NoBreak]", ")"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm[
  "There are ", 142, 
   " domains that contribute an honest differential to the structure maps, \
e.g. \n", 
   MatrixForm[{{{1}, {2}, {3}, {4}, {5}, {6}, {7}, {8}, {9}, {10}, {11}, {
    12}, {13}, {14}, {15}}}]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.68571175160121*^9, 3.685831100517803*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There are \"\>", "\[InvisibleSpace]", "80", 
   "\[InvisibleSpace]", "\<\" domains that contribute an S1 algebra element \
to the structure maps, e.g. \\n\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"\<\"Regions\"\>", 
        RowBox[{"{", "20", "}"}], 
        RowBox[{"{", "48", "}"}], 
        RowBox[{"{", 
         RowBox[{"20", ",", "48"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"21", ",", "19", ",", "18"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"19", ",", "18", ",", "21", ",", "20"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"29", ",", "28", ",", "31", ",", "30"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"20", ",", "29", ",", "28", ",", "31", ",", "30"}], "}"}]},
       {"\<\"moving strands\"\>", 
        RowBox[{"{", 
         RowBox[{"11", ",", "12"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"7", ",", "8"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"7", ",", "8", ",", "11", ",", "12"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"10", ",", "11", ",", "12", ",", "13"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"10", ",", "11", ",", "11", ",", "13"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"2", ",", "4", ",", "4", ",", "5"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"2", ",", "4", ",", "4", ",", "5", ",", "11", ",", "12"}], 
         "}"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm[
  "There are ", 80, 
   " domains that contribute an S1 algebra element to the structure maps, \
e.g. \n", 
   MatrixForm[{{
     "Regions", {20}, {48}, {20, 48}, {21, 19, 18}, {19, 18, 21, 20}, {29, 28,
       31, 30}, {20, 29, 28, 31, 30}}, {
     "moving strands", {11, 12}, {7, 8}, {7, 8, 11, 12}, {10, 11, 12, 13}, {
      10, 11, 11, 13}, {2, 4, 4, 5}, {2, 4, 4, 5, 11, 12}}}]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.68571175160121*^9, 3.68583110052386*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There are \"\>", "\[InvisibleSpace]", "80", 
   "\[InvisibleSpace]", "\<\" domains that contribute an S2 algebra element \
to the structure maps, e.g. \\n\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"\<\"Regions\"\>", 
        RowBox[{"{", "25", "}"}], 
        RowBox[{"{", "55", "}"}], 
        RowBox[{"{", 
         RowBox[{"25", ",", "55"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"26", ",", "24", ",", "23"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"24", ",", "23", ",", "26", ",", "25"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"34", ",", "33", ",", "36", ",", "35"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"25", ",", "34", ",", "33", ",", "36", ",", "35"}], "}"}]},
       {"\<\"moving strands\"\>", 
        RowBox[{"{", 
         RowBox[{"3", ",", "4"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"7", ",", "8"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"3", ",", "4", ",", "7", ",", "8"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"2", ",", "3", ",", "4", ",", "5"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"2", ",", "4", ",", "4", ",", "5"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"10", ",", "11", ",", "11", ",", "13"}], "}"}], 
        RowBox[{"{", 
         RowBox[{"3", ",", "4", ",", "10", ",", "11", ",", "11", ",", "13"}], 
         "}"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm[
  "There are ", 80, 
   " domains that contribute an S2 algebra element to the structure maps, \
e.g. \n", 
   MatrixForm[{{
     "Regions", {25}, {55}, {25, 55}, {26, 24, 23}, {24, 23, 26, 25}, {34, 33,
       36, 35}, {25, 34, 33, 36, 35}}, {
     "moving strands", {3, 4}, {7, 8}, {3, 4, 7, 8}, {2, 3, 4, 5}, {2, 4, 4, 
      5}, {10, 11, 11, 13}, {3, 4, 10, 11, 11, 13}}}]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.68571175160121*^9, 3.685831100529849*^9}],

Cell[BoxData["\<\"Note: If this calculation gives an error message 'Part 1 of \
{} does not exist', there are some algebra elements generated by domains, \
that do not show up in the glueing algebra. This should not happen. If it \
does, check your algebra input data.\"\>"], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.68571175160121*^9, 3.685831108981894*^9}],

Cell[BoxData["\<\"OK. All domains for S1 can contribute.\"\>"], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.68571175160121*^9, 3.6858311305155487`*^9}],

Cell[BoxData["\<\"OK. All domains for S2 can contribute.\"\>"], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.68571175160121*^9, 3.685831150689321*^9}],

Cell[BoxData[
 TemplateBox[{RowBox[{"\"Wed 19 Oct 2016 02:59:10\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", "1.`"}], FontColor -> 
      GrayLevel[0.5]]}],RowBox[{"DateObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"2016", ",", "10", ",", "19"}], "}"}], ",", 
       RowBox[{"TimeObject", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"2", ",", "59", ",", "10.688711`"}], "}"}], ",", 
           RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}], ",", 
       RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}]},
  "DateObject",
  Editable->False]], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.68571175160121*^9, 3.6858311509592113`*^9}],

Cell[BoxData["\<\"Calculation of StructureMapsSparse.\"\>"], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.68571175160121*^9, 3.685831150962278*^9}],

Cell[BoxData[
 TemplateBox[{RowBox[{"\"Wed 19 Oct 2016 03:01:31\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", "1.`"}], FontColor -> 
      GrayLevel[0.5]]}],RowBox[{"DateObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"2016", ",", "10", ",", "19"}], "}"}], ",", 
       RowBox[{"TimeObject", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"3", ",", "1", ",", "31.221839`"}], "}"}], ",", 
           RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}], ",", 
       RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}]},
  "DateObject",
  Editable->False]], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.68571175160121*^9, 3.685831291232896*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"This is what the upper left corner of \
'StructureMapsWith1Action' looks like:\\n\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", \\\"2\\\", \\\"}\\\"}], \\\",\\\", \\\"3\\\"}], \\\
\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \
RowBox[{\\\"{\\\", \\\"3\\\", \\\"}\\\"}]}], \\\"}\\\"}]}], \
\\\"}\\\"}]\\)\"\>", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", \
RowBox[{\\\"2\\\", \\\",\\\", \\\"3\\\"}], \\\"}\\\"}], \\\"}\\\"}]\\)\"\>", \
"\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \
\\\",\\\", \\\"3\\\"}], \\\"}\\\"}], \\\"}\\\"}]\\)\"\>", "0", "0", "0", "0", 
        "0", "0", "0"},
       {"0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", \\\"2\\\", \\\"}\\\"}], \\\",\\\", \\\"3\\\"}], \\\
\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \
RowBox[{\\\"{\\\", \\\"3\\\", \\\"}\\\"}]}], \\\"}\\\"}]}], \
\\\"}\\\"}]\\)\"\>", 
        "0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", \
RowBox[{\\\"2\\\", \\\",\\\", \\\"3\\\"}], \\\"}\\\"}], \\\"}\\\"}]\\)\"\>", 
        "0", "0", "0", "0", "0", "0"},
       {"0", 
        "0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", \\\"2\\\", \\\"}\\\"}], \\\",\\\", \\\"3\\\"}], \\\
\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \
RowBox[{\\\"{\\\", \\\"3\\\", \\\"}\\\"}]}], \\\"}\\\"}]}], \
\\\"}\\\"}]\\)\"\>", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", \
RowBox[{\\\"2\\\", \\\",\\\", \\\"3\\\"}], \\\"}\\\"}], \\\"}\\\"}]\\)\"\>", 
        "0", "0", "0", "0", "0", "0"},
       {"0", "0", 
        "0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", \\\"2\\\", \\\"}\\\"}], \\\",\\\", \\\"3\\\"}], \\\
\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \
RowBox[{\\\"{\\\", \\\"3\\\", \\\"}\\\"}]}], \\\"}\\\"}]}], \
\\\"}\\\"}]\\)\"\>", "0", "0", "0", "0", "0", "0"},
       {"\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", \
RowBox[{\\\"2\\\", \\\",\\\", \\\"3\\\"}], \\\"}\\\"}], \\\"}\\\"}]\\)\"\>", 
        "0", "0", 
        "0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", \\\"2\\\", \\\"}\\\"}], \\\",\\\", \\\"3\\\"}], \\\
\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \
RowBox[{\\\"{\\\", \\\"3\\\", \\\"}\\\"}]}], \\\"}\\\"}]}], \
\\\"}\\\"}]\\)\"\>", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", \
RowBox[{\\\"2\\\", \\\",\\\", \\\"3\\\"}], \\\"}\\\"}], \\\"}\\\"}]\\)\"\>", \
"\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \
\\\",\\\", \\\"3\\\"}], \\\"}\\\"}], \\\"}\\\"}]\\)\"\>", "0", "0", "0"},
       {"0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", \
RowBox[{\\\"2\\\", \\\",\\\", \\\"3\\\"}], \\\"}\\\"}], \\\"}\\\"}]\\)\"\>", 
        "0", "0", 
        "0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", \\\"2\\\", \\\"}\\\"}], \\\",\\\", \\\"3\\\"}], \\\
\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \
RowBox[{\\\"{\\\", \\\"3\\\", \\\"}\\\"}]}], \\\"}\\\"}]}], \
\\\"}\\\"}]\\)\"\>", 
        "0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", \
RowBox[{\\\"2\\\", \\\",\\\", \\\"3\\\"}], \\\"}\\\"}], \\\"}\\\"}]\\)\"\>", 
        "0", "0"},
       {"0", 
        "0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", \
RowBox[{\\\"2\\\", \\\",\\\", \\\"3\\\"}], \\\"}\\\"}], \\\"}\\\"}]\\)\"\>", 
        "0", "0", 
        "0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", \\\"2\\\", \\\"}\\\"}], \\\",\\\", \\\"3\\\"}], \\\
\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \
RowBox[{\\\"{\\\", \\\"3\\\", \\\"}\\\"}]}], \\\"}\\\"}]}], \
\\\"}\\\"}]\\)\"\>", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", \
RowBox[{\\\"2\\\", \\\",\\\", \\\"3\\\"}], \\\"}\\\"}], \\\"}\\\"}]\\)\"\>", 
        "0", "0"},
       {"0", "0", 
        "0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", \
RowBox[{\\\"2\\\", \\\",\\\", \\\"3\\\"}], \\\"}\\\"}], \\\"}\\\"}]\\)\"\>", 
        "0", "0", 
        "0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", \\\"2\\\", \\\"}\\\"}], \\\",\\\", \\\"3\\\"}], \\\
\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \
RowBox[{\\\"{\\\", \\\"3\\\", \\\"}\\\"}]}], \\\"}\\\"}]}], \
\\\"}\\\"}]\\)\"\>", "0", "0"},
       {"0", 
        "0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", \
RowBox[{\\\"2\\\", \\\",\\\", \\\"3\\\"}], \\\"}\\\"}], \\\"}\\\"}]\\)\"\>", 
        "0", "0", "0", "0", 
        "0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", \\\"2\\\", \\\"}\\\"}], \\\",\\\", \\\"3\\\"}], \\\
\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \
RowBox[{\\\"{\\\", \\\"3\\\", \\\"}\\\"}]}], \\\"}\\\"}]}], \
\\\"}\\\"}]\\)\"\>", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", \
RowBox[{\\\"2\\\", \\\",\\\", \\\"3\\\"}], \\\"}\\\"}], \\\"}\\\"}]\\)\"\>"},
       {"0", "0", 
        "0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"{\\\", \
RowBox[{\\\"2\\\", \\\",\\\", \\\"3\\\"}], \\\"}\\\"}], \\\"}\\\"}]\\)\"\>", 
        "0", "0", "0", "0", 
        "0", "\<\"\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", \\\"2\\\", \\\"}\\\"}], \\\",\\\", \\\"3\\\"}], \\\
\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{\\\"2\\\", \\\",\\\", \
RowBox[{\\\"{\\\", \\\"3\\\", \\\"}\\\"}]}], \\\"}\\\"}]}], \
\\\"}\\\"}]\\)\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {10, 10}, 0, {
       1, {{0, 3, 5, 7, 8, 12, 15, 18, 20, 23, 25}, {{1}, {2}, {3}, {2}, {
         4}, {3}, {4}, {4}, {5}, {1}, {6}, {7}, {6}, {2}, {8}, {7}, {3}, {
         8}, {8}, {4}, {9}, {3}, {10}, {10}, {4}}}, {
        "\!\(\*RowBox[{\"{\", RowBox[{RowBox[{\"{\", RowBox[{RowBox[{\"{\", \
\"2\", \"}\"}], \",\", \"3\"}], \"}\"}], \",\", RowBox[{\"{\", RowBox[{\"2\", \
\",\", RowBox[{\"{\", \"3\", \"}\"}]}], \"}\"}]}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{RowBox[{\"{\", RowBox[{RowBox[{\"{\", \
\"2\", \"}\"}], \",\", \"3\"}], \"}\"}], \",\", RowBox[{\"{\", RowBox[{\"2\", \
\",\", RowBox[{\"{\", \"3\", \"}\"}]}], \"}\"}]}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{RowBox[{\"{\", RowBox[{RowBox[{\"{\", \
\"2\", \"}\"}], \",\", \"3\"}], \"}\"}], \",\", RowBox[{\"{\", RowBox[{\"2\", \
\",\", RowBox[{\"{\", \"3\", \"}\"}]}], \"}\"}]}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{RowBox[{\"{\", RowBox[{RowBox[{\"{\", \
\"2\", \"}\"}], \",\", \"3\"}], \"}\"}], \",\", RowBox[{\"{\", RowBox[{\"2\", \
\",\", RowBox[{\"{\", \"3\", \"}\"}]}], \"}\"}]}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{RowBox[{\"{\", RowBox[{RowBox[{\"{\", \
\"2\", \"}\"}], \",\", \"3\"}], \"}\"}], \",\", RowBox[{\"{\", RowBox[{\"2\", \
\",\", RowBox[{\"{\", \"3\", \"}\"}]}], \"}\"}]}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{RowBox[{\"{\", RowBox[{RowBox[{\"{\", \
\"2\", \"}\"}], \",\", \"3\"}], \"}\"}], \",\", RowBox[{\"{\", RowBox[{\"2\", \
\",\", RowBox[{\"{\", \"3\", \"}\"}]}], \"}\"}]}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{RowBox[{\"{\", RowBox[{RowBox[{\"{\", \
\"2\", \"}\"}], \",\", \"3\"}], \"}\"}], \",\", RowBox[{\"{\", RowBox[{\"2\", \
\",\", RowBox[{\"{\", \"3\", \"}\"}]}], \"}\"}]}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{RowBox[{\"{\", RowBox[{RowBox[{\"{\", \
\"2\", \"}\"}], \",\", \"3\"}], \"}\"}], \",\", RowBox[{\"{\", RowBox[{\"2\", \
\",\", RowBox[{\"{\", \"3\", \"}\"}]}], \"}\"}]}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{RowBox[{\"{\", RowBox[{RowBox[{\"{\", \
\"2\", \"}\"}], \",\", \"3\"}], \"}\"}], \",\", RowBox[{\"{\", RowBox[{\"2\", \
\",\", RowBox[{\"{\", \"3\", \"}\"}]}], \"}\"}]}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{RowBox[{\"{\", RowBox[{RowBox[{\"{\", \
\"2\", \"}\"}], \",\", \"3\"}], \"}\"}], \",\", RowBox[{\"{\", RowBox[{\"2\", \
\",\", RowBox[{\"{\", \"3\", \"}\"}]}], \"}\"}]}], \"}\"}]\)", 
         "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)"}}]]]]}],
  SequenceForm[
  "This is what the upper left corner of 'StructureMapsWith1Action' looks \
like:\n", 
   MatrixForm[
   SparseArray[
    Automatic, {10, 10}, 0, {
     1, {{0, 3, 5, 7, 8, 12, 15, 18, 20, 23, 25}, {{1}, {2}, {3}, {2}, {4}, {
       3}, {4}, {4}, {5}, {1}, {6}, {7}, {6}, {2}, {8}, {7}, {3}, {8}, {8}, {
       4}, {9}, {3}, {10}, {10}, {4}}}, {
      "\!\(\*RowBox[{\"{\", RowBox[{RowBox[{\"{\", RowBox[{RowBox[{\"{\", \"2\
\", \"}\"}], \",\", \"3\"}], \"}\"}], \",\", RowBox[{\"{\", RowBox[{\"2\", \
\",\", RowBox[{\"{\", \"3\", \"}\"}]}], \"}\"}]}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{RowBox[{\"{\", RowBox[{RowBox[{\"{\", \
\"2\", \"}\"}], \",\", \"3\"}], \"}\"}], \",\", RowBox[{\"{\", RowBox[{\"2\", \
\",\", RowBox[{\"{\", \"3\", \"}\"}]}], \"}\"}]}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{RowBox[{\"{\", RowBox[{RowBox[{\"{\", \
\"2\", \"}\"}], \",\", \"3\"}], \"}\"}], \",\", RowBox[{\"{\", RowBox[{\"2\", \
\",\", RowBox[{\"{\", \"3\", \"}\"}]}], \"}\"}]}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{RowBox[{\"{\", RowBox[{RowBox[{\"{\", \
\"2\", \"}\"}], \",\", \"3\"}], \"}\"}], \",\", RowBox[{\"{\", RowBox[{\"2\", \
\",\", RowBox[{\"{\", \"3\", \"}\"}]}], \"}\"}]}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{RowBox[{\"{\", RowBox[{RowBox[{\"{\", \
\"2\", \"}\"}], \",\", \"3\"}], \"}\"}], \",\", RowBox[{\"{\", RowBox[{\"2\", \
\",\", RowBox[{\"{\", \"3\", \"}\"}]}], \"}\"}]}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{RowBox[{\"{\", RowBox[{RowBox[{\"{\", \
\"2\", \"}\"}], \",\", \"3\"}], \"}\"}], \",\", RowBox[{\"{\", RowBox[{\"2\", \
\",\", RowBox[{\"{\", \"3\", \"}\"}]}], \"}\"}]}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{RowBox[{\"{\", RowBox[{RowBox[{\"{\", \
\"2\", \"}\"}], \",\", \"3\"}], \"}\"}], \",\", RowBox[{\"{\", RowBox[{\"2\", \
\",\", RowBox[{\"{\", \"3\", \"}\"}]}], \"}\"}]}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{RowBox[{\"{\", RowBox[{RowBox[{\"{\", \
\"2\", \"}\"}], \",\", \"3\"}], \"}\"}], \",\", RowBox[{\"{\", RowBox[{\"2\", \
\",\", RowBox[{\"{\", \"3\", \"}\"}]}], \"}\"}]}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{RowBox[{\"{\", RowBox[{RowBox[{\"{\", \
\"2\", \"}\"}], \",\", \"3\"}], \"}\"}], \",\", RowBox[{\"{\", RowBox[{\"2\", \
\",\", RowBox[{\"{\", \"3\", \"}\"}]}], \"}\"}]}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{RowBox[{\"{\", RowBox[{RowBox[{\"{\", \
\"2\", \"}\"}], \",\", \"3\"}], \"}\"}], \",\", RowBox[{\"{\", RowBox[{\"2\", \
\",\", RowBox[{\"{\", \"3\", \"}\"}]}], \"}\"}]}], \"}\"}]\)", 
       "\!\(\*RowBox[{\"{\", RowBox[{\"{\", RowBox[{\"2\", \",\", \"3\"}], \
\"}\"}], \"}\"}]\)"}}]]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.68571175160121*^9, 3.685831300210712*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\" << backup saved at: \"\>", 
   "\[InvisibleSpace]", \
"\<\"/mhome/dpmms/c/cbz20/Documents/PhD/Research/thesis/BSFH/Backups/\
GlueingBSAAx4e_BeforeCancellation.mx >>\"\>"}],
  SequenceForm[
  " << backup saved at: ", 
   "/mhome/dpmms/c/cbz20/Documents/PhD/Research/thesis/BSFH/Backups/\
GlueingBSAAx4e_BeforeCancellation.mx >>"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.6838960929023323`*^9, 3.683896103810855*^9}, {
   3.683896140584502*^9, 3.683896155318943*^9}, 3.6838962279757233`*^9, 
   3.683896264453897*^9, 3.6838962971043873`*^9, 3.683896720995179*^9, 
   3.683896802716756*^9, 3.683896890229953*^9, 3.683899246434545*^9, 
   3.6838995776783*^9, 3.683899809963675*^9, 3.683901021311666*^9, 
   3.6839010657291193`*^9, 3.6839012615721807`*^9, {3.683904716836667*^9, 
   3.6839047283278313`*^9}, 3.6839056592902937`*^9, 3.683906273569572*^9, 
   3.6839067401551332`*^9, 3.683906796114818*^9, 3.68394933516684*^9, 
   3.683949887483099*^9, 3.6839524051761713`*^9, 3.68395893334379*^9, 
   3.685193724405591*^9, 3.685193918204859*^9, 3.685249111820959*^9, 
   3.6852590270962973`*^9, 3.685259060183831*^9, 3.68570626279569*^9, 
   3.68571175160121*^9, 3.6858313569912558`*^9}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"<<", 
   RowBox[{"(", 
    RowBox[{"BackupFilePath", "<>", "\"\<_BeforeCancellation.mx\>\""}], 
    ")"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.676092257232688*^9, 3.676092257977479*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"SANITY", " ", "CHECK"}], ";", " ", 
    RowBox[{
    "you", " ", "might", " ", "want", " ", "to", " ", "check", " ", "if", " ",
      "you", " ", "can", " ", "find", " ", "some", " ", "differentials", " ", 
     "computed", " ", "here", " ", "in", " ", "your", " ", "nice", " ", 
     "Heegaard", " ", "diagram"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SparseNiceFindAllArrowsStartingAt", "[", "n_", "]"}], " ", 
     "lists", " ", "all", " ", "arrows", " ", "that", " ", "start", " ", "at",
      " ", "generator", " ", "of", " ", 
     RowBox[{"index", " ", "'"}], 
     RowBox[{"n", "'"}], " ", "in", " ", "the", " ", 
     RowBox[{"list", " ", "'"}], 
     RowBox[{"generators", "'"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SparseNiceFindAllArrowsStartingAt", "[", "n_", "]"}], " ", 
     "lists", " ", "all", " ", "arrows", " ", "that", " ", "end", " ", "at", 
     " ", "generator", " ", "of", " ", 
     RowBox[{"index", " ", "'"}], 
     RowBox[{"n", "'"}], " ", "in", " ", "the", " ", 
     RowBox[{"list", " ", "'"}], 
     RowBox[{"generators", "'"}]}], ";"}], "\[IndentingNewLine]", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"SparseNiceFindAllArrowsStartingAt", "[", "2", "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"SparseNiceFindAllArrowsEndingAt", "[", "3", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.674104304443412*^9, 3.674104307474148*^9}, 
   3.674104966443514*^9, {3.674105085853196*^9, 3.6741050869424877`*^9}, {
   3.674228773456483*^9, 3.6742287789948273`*^9}, {3.674268634047946*^9, 
   3.674268635627301*^9}, {3.674268790102474*^9, 3.6742688117888603`*^9}, {
   3.674269107233716*^9, 3.6742691076093807`*^9}, {3.6742765544263973`*^9, 
   3.67427655485629*^9}, 3.675245199212315*^9, {3.675245268803441*^9, 
   3.675245294940248*^9}, {3.675245613734436*^9, 3.675245614036627*^9}, {
   3.675935426998316*^9, 3.675935427252965*^9}, {3.676441741691539*^9, 
   3.67644175022666*^9}, {3.6838969940205708`*^9, 3.683896994204054*^9}, {
   3.6851939440098352`*^9, 3.685193977665649*^9}, {3.685194036684403*^9, 
   3.6851941015901117`*^9}, {3.685194137103114*^9, 3.685194258090046*^9}, {
   3.68519429023514*^9, 3.685194382196105*^9}, {3.685194417518076*^9, 
   3.685194417725258*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"From 2=(15|1|3|34|29|20|51|53|46|74|79|64)      {regions} = \
Relevant Domain Index (Old Index)\"\>", 
   "\[InvisibleSpace]", "\<\"\\n To  1=(15|1|3|34|30|20|51|53|46|74|79|64) \
via (72) = 42 (54), label =((2|3))\"\>", 
   "\[InvisibleSpace]", "\<\"\\n To  6=(15|1|3|34|29|21|51|53|46|74|79|64) \
via (39) = 26 (27), label =((2|3))\"\>", 
   "\[InvisibleSpace]", "\<\"\\n To  4402=(15|1|73|34|29|20|51|53|46|4|79|64) \
via (17|2) = 63 (75), label =((2|3))\"\>", 
   "\[InvisibleSpace]", "\<\"\\n To  \
133658=(15|1|3|34|75|20|51|53|46|28|79|64) via (74) = 44 (56), label =((2|3))\
\"\>"}],
  SequenceForm[
  "From 2=(15|1|3|34|29|20|51|53|46|74|79|64)      {regions} = Relevant \
Domain Index (Old Index)", 
   "\n To  1=(15|1|3|34|30|20|51|53|46|74|79|64) via (72) = 42 (54), label \
=((2|3))", 
   "\n To  6=(15|1|3|34|29|21|51|53|46|74|79|64) via (39) = 26 (27), label \
=((2|3))", 
   "\n To  4402=(15|1|73|34|29|20|51|53|46|4|79|64) via (17|2) = 63 (75), \
label =((2|3))", 
   "\n To  133658=(15|1|3|34|75|20|51|53|46|28|79|64) via (74) = 44 (56), \
label =((2|3))"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.674149533028758*^9, 3.674149613295639*^9, {3.67422875015836*^9, 
   3.6742287793379374`*^9}, 3.674268636201438*^9, {3.674268790888933*^9, 
   3.674268812213994*^9}, 3.674269108319046*^9, 3.674276555521348*^9, 
   3.674278431214143*^9, 3.674279561803392*^9, 3.675240304731463*^9, 
   3.67524055059062*^9, 3.675242328123254*^9, 3.67524519978808*^9, {
   3.675245270088979*^9, 3.6752452952635193`*^9}, {3.6752455965712852`*^9, 
   3.675245614489789*^9}, 3.675272485838872*^9, {3.675272601160602*^9, 
   3.67527271885688*^9}, 3.675272793273382*^9, 3.675272846678245*^9, 
   3.675503699806039*^9, {3.675507867971129*^9, 3.6755078958091373`*^9}, 
   3.67550935516679*^9, 3.675509425533766*^9, {3.6759354173925447`*^9, 
   3.67593542778658*^9}, 3.675935534043977*^9, {3.6759356389280024`*^9, 
   3.6759356598173847`*^9}, {3.675935749004092*^9, 3.6759357720758543`*^9}, 
   3.6759421296376123`*^9, 3.675958787663187*^9, 3.675962599266767*^9, 
   3.6760054406677027`*^9, 3.676389732279505*^9, {3.67644174352247*^9, 
   3.676441751092914*^9}, 3.676475067922023*^9, 3.677558347572921*^9, 
   3.6789371436314898`*^9, 3.6789382478871098`*^9, 3.683896779420425*^9, 
   3.683896904192246*^9, 3.6838969947649813`*^9, 3.6838992605164824`*^9, 
   3.683899622598269*^9, 3.683899819133437*^9, 3.683906280399602*^9, 
   3.6839068019023046`*^9, 3.683949355652266*^9, 3.6839498914696693`*^9, 
   3.683952408955373*^9, 3.683958936989856*^9, 3.6851944185927553`*^9, 
   3.685194582335441*^9, 3.6852590806499767`*^9, 3.685706267130395*^9, 
   3.685711755199422*^9, 3.6858313577825727`*^9, 3.6858517618219767`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"From 3=(15|1|3|34|30|20|51|53|47|74|79|64)      {regions} = \
Relevant Domain Index (Old Index)\"\>", 
   "\[InvisibleSpace]", "\<\"\\n From 4=(15|1|3|34|29|20|51|53|47|74|79|64) \
via (72) = 42 (54), label =((2|3))\"\>", 
   "\[InvisibleSpace]", "\<\"\\n From 27=(15|1|3|43|30|20|51|53|47|74|79|64) \
via (31|30|29) = 163 (1886), label =(((202)|3))\"\>", 
   "\[InvisibleSpace]", "\<\"\\n From 51=(15|1|3|81|30|20|51|53|47|74|36|64) \
via (10|9) = 56 (68), label =((2|3))\"\>", 
   "\[InvisibleSpace]", "\<\"\\n From 99=(15|1|6|34|30|20|51|53|47|74|79|64) \
via (60|59) = 93 (105), label =((2|3))\"\>", 
   "\[InvisibleSpace]", "\<\"\\n From \
133664=(15|1|3|34|78|20|51|53|47|74|31|64) via (75) = 45 (57), label =((2|3))\
\"\>"}],
  SequenceForm[
  "From 3=(15|1|3|34|30|20|51|53|47|74|79|64)      {regions} = Relevant \
Domain Index (Old Index)", 
   "\n From 4=(15|1|3|34|29|20|51|53|47|74|79|64) via (72) = 42 (54), label \
=((2|3))", 
   "\n From 27=(15|1|3|43|30|20|51|53|47|74|79|64) via (31|30|29) = 163 \
(1886), label =(((202)|3))", 
   "\n From 51=(15|1|3|81|30|20|51|53|47|74|36|64) via (10|9) = 56 (68), \
label =((2|3))", 
   "\n From 99=(15|1|6|34|30|20|51|53|47|74|79|64) via (60|59) = 93 (105), \
label =((2|3))", 
   "\n From 133664=(15|1|3|34|78|20|51|53|47|74|31|64) via (75) = 45 (57), \
label =((2|3))"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.674149533028758*^9, 3.674149613295639*^9, {3.67422875015836*^9, 
   3.6742287793379374`*^9}, 3.674268636201438*^9, {3.674268790888933*^9, 
   3.674268812213994*^9}, 3.674269108319046*^9, 3.674276555521348*^9, 
   3.674278431214143*^9, 3.674279561803392*^9, 3.675240304731463*^9, 
   3.67524055059062*^9, 3.675242328123254*^9, 3.67524519978808*^9, {
   3.675245270088979*^9, 3.6752452952635193`*^9}, {3.6752455965712852`*^9, 
   3.675245614489789*^9}, 3.675272485838872*^9, {3.675272601160602*^9, 
   3.67527271885688*^9}, 3.675272793273382*^9, 3.675272846678245*^9, 
   3.675503699806039*^9, {3.675507867971129*^9, 3.6755078958091373`*^9}, 
   3.67550935516679*^9, 3.675509425533766*^9, {3.6759354173925447`*^9, 
   3.67593542778658*^9}, 3.675935534043977*^9, {3.6759356389280024`*^9, 
   3.6759356598173847`*^9}, {3.675935749004092*^9, 3.6759357720758543`*^9}, 
   3.6759421296376123`*^9, 3.675958787663187*^9, 3.675962599266767*^9, 
   3.6760054406677027`*^9, 3.676389732279505*^9, {3.67644174352247*^9, 
   3.676441751092914*^9}, 3.676475067922023*^9, 3.677558347572921*^9, 
   3.6789371436314898`*^9, 3.6789382478871098`*^9, 3.683896779420425*^9, 
   3.683896904192246*^9, 3.6838969947649813`*^9, 3.6838992605164824`*^9, 
   3.683899622598269*^9, 3.683899819133437*^9, 3.683906280399602*^9, 
   3.6839068019023046`*^9, 3.683949355652266*^9, 3.6839498914696693`*^9, 
   3.683952408955373*^9, 3.683958936989856*^9, 3.6851944185927553`*^9, 
   3.685194582335441*^9, 3.6852590806499767`*^9, 3.685706267130395*^9, 
   3.685711755199422*^9, 3.6858313577825727`*^9, 3.685851761880087*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Initial cancellation (de-niceification)", "Section",
 CellChangeTimes->{{3.683902406280332*^9, 3.683902411992662*^9}, {
  3.6839024516165123`*^9, 3.683902475521956*^9}, {3.683902509419033*^9, 
  3.6839025833159637`*^9}, {3.683902614317812*^9, 3.683902621444993*^9}, {
  3.6839026606787653`*^9, 3.683902706656199*^9}, {3.683902768385414*^9, 
  3.6839028035945807`*^9}}],

Cell[BoxData[
 RowBox[{"Step4CancellationPreparation", ";"}]], "Input",
 CellChangeTimes->{{3.6838972567262897`*^9, 3.6838972613485126`*^9}, 
   3.685194519470417*^9, {3.68524888962287*^9, 3.685248890046817*^9}}],

Cell["\<\
The next step can take quite a while for large diagrams. Consider using a \
computer with a single fast kernel to speed up, as no parallel evaluation is \
possible.\
\>", "Text",
 CellChangeTimes->{{3.683904487701765*^9, 3.683904540055222*^9}, {
  3.683906443512352*^9, 3.6839064977306423`*^9}, {3.683907404281674*^9, 
  3.683907411497081*^9}, {3.683907443442786*^9, 3.683907445257428*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"BackToStart", "=", 
   RowBox[{"CancellationSparse", "[", 
    RowBox[{"StructureMapsSparse", ",", "generators"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MMit", "=", 
   RowBox[{"BackToStart", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"generatorsit", "=", 
    RowBox[{"BackToStart", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", "backup", " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{
    RowBox[{"BackupFilePath", "<>", "\"\<_AfterCancellation.mx\>\""}], ",", 
    "\"\<Global`\>\""}], "]"}], ";", 
  RowBox[{"Print", "[", 
   RowBox[{"\"\< << backup saved at: \>\"", " ", ",", 
    RowBox[{"BackupFilePath", "<>", "\"\<_AfterCancellation.mx >>\>\""}]}], 
   "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.675529652739524*^9, 3.675529692839591*^9}, {
   3.675533781109782*^9, 3.675533788559823*^9}, {3.6755339029195147`*^9, 
   3.6755339057155733`*^9}, {3.675534517304041*^9, 3.67553451981328*^9}, {
   3.6755354813960943`*^9, 3.6755354971737413`*^9}, {3.675535640875539*^9, 
   3.6755356519778547`*^9}, {3.6755359652661943`*^9, 3.675535976345201*^9}, {
   3.6755360643622417`*^9, 3.675536064611867*^9}, {3.6755361393965387`*^9, 
   3.6755361396533003`*^9}, {3.6755709179569883`*^9, 3.675570929236774*^9}, {
   3.675571665947143*^9, 3.675571678890936*^9}, 3.675571917736599*^9, {
   3.675571979826198*^9, 3.6755720109772253`*^9}, 3.675573257411477*^9, {
   3.675574565159875*^9, 3.6755745664054403`*^9}, {3.6755823477349453`*^9, 
   3.6755823483031054`*^9}, {3.6755900229971848`*^9, 3.675590024322789*^9}, {
   3.675595572936466*^9, 3.675595573174676*^9}, {3.675599437786158*^9, 
   3.6755994407980137`*^9}, {3.675682262423912*^9, 3.675682263327428*^9}, {
   3.675683187529191*^9, 3.675683212504593*^9}, {3.6756905066294813`*^9, 
   3.6756905090293922`*^9}, {3.675865338794071*^9, 3.6758653399670467`*^9}, {
   3.675867831309825*^9, 3.675867832071665*^9}, {3.675936856885241*^9, 
   3.675936857843165*^9}, 3.675942144804379*^9, {3.6851946075638866`*^9, 
   3.6851946736934967`*^9}, {3.6851958500589848`*^9, 3.685195851450302*^9}, {
   3.6856928016572037`*^9, 3.68569280207942*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 TemplateBox[{RowBox[{"\"08:42:50\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", "1.`"}], FontColor -> 
      GrayLevel[0.5]]}],RowBox[{"TimeObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"8", ",", "42", ",", "50.553656`"}], "}"}], ",", 
       RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}]},
  "TimeObject",
  Editable->False]], "Print",
 CellChangeTimes->{{3.675572006401083*^9, 3.6755720142676477`*^9}, {
   3.6755724810671797`*^9, 3.6755725163027477`*^9}, {3.6755726014468203`*^9, 
   3.6755726042007113`*^9}, 3.675572832423069*^9, {3.6755731727076263`*^9, 
   3.675573260843977*^9}, 3.675573532159712*^9, {3.675573721837899*^9, 
   3.675573752056282*^9}, {3.675573782652417*^9, 3.6755738066460943`*^9}, {
   3.675573898552917*^9, 3.6755739274110928`*^9}, {3.675574004200198*^9, 
   3.675574008538425*^9}, 3.675574053034545*^9, {3.675574280711363*^9, 
   3.675574297288308*^9}, 3.675574462790161*^9, 3.675574586089883*^9, 
   3.675574637476365*^9, 3.675574839226425*^9, {3.675574890495219*^9, 
   3.675574899961628*^9}, {3.6755750577441473`*^9, 3.6755750653479033`*^9}, {
   3.67557536517969*^9, 3.675575374622838*^9}, 3.67558241864917*^9, 
   3.675595561804577*^9, 3.675595598189539*^9, 3.675596941501546*^9, {
   3.6755969799136963`*^9, 3.675596981891532*^9}, {3.6755985390385427`*^9, 
   3.6755985603346*^9}, 3.675598655784644*^9, 3.675598710761747*^9, 
   3.675598772277358*^9, 3.675598982611813*^9, 3.6755990365712214`*^9, 
   3.675599124714926*^9, 3.675599190525057*^9, 3.6755992265054293`*^9, 
   3.6755993517965727`*^9, 3.675599384154059*^9, 3.675599441691959*^9, 
   3.6755995793084993`*^9, 3.675600493810341*^9, 3.675601419908771*^9, 
   3.6756020555122337`*^9, 3.6756023632210083`*^9, 3.675602807876725*^9, 
   3.675602897602737*^9, {3.6756033421530533`*^9, 3.675603380919065*^9}, 
   3.675613375417395*^9, 3.675613494839464*^9, 3.675656390071207*^9, 
   3.6756832342389383`*^9, 3.675683357975985*^9, 3.675857704474587*^9, 
   3.675862632474606*^9, 3.6758648822207727`*^9, 3.675865049216236*^9, 
   3.67586513788349*^9, {3.675865233131024*^9, 3.675865257251742*^9}, {
   3.6758653420784893`*^9, 3.675865356836982*^9}, 3.6758656228927298`*^9, 
   3.675865747362034*^9, {3.675865818783901*^9, 3.675865835891333*^9}, {
   3.6758658670111237`*^9, 3.675865896860029*^9}, 3.675865958760379*^9, 
   3.6758676158396473`*^9, {3.675867824560811*^9, 3.675867834230739*^9}, {
   3.675936848949038*^9, 3.675936860094269*^9}, 3.675942150157858*^9, 
   3.6759589153553867`*^9, 3.675959692249486*^9, 3.675959749337008*^9, 
   3.675959793505755*^9, {3.675962726520094*^9, 3.675962732940042*^9}, 
   3.6759631992326183`*^9, 3.676005076509894*^9, 3.6760054510397987`*^9, 
   3.6760922799521914`*^9, 3.676145031860186*^9, 3.67752770975972*^9, 
   3.6781944003152027`*^9, 3.678938324033092*^9, 3.678938762397016*^9, 
   3.678938841034732*^9, 3.678938888097413*^9, 3.679373237470869*^9, 
   3.679379242564719*^9, 3.679379516825293*^9, 3.679381106126199*^9, 
   3.679381156825899*^9, 3.6793821749785*^9, 3.6793823448314533`*^9, 
   3.679382425135206*^9, 3.683899292519908*^9, 3.683899851402754*^9, 
   3.6839027549793243`*^9, 3.683906415792178*^9, 3.683906819144183*^9, 
   3.683949372390581*^9, 3.6839498985827827`*^9, 3.6839524145676823`*^9, 
   3.683958943103503*^9, 3.6851945867973022`*^9, 3.685194616981819*^9, 
   3.68519478292586*^9, 3.685195855352476*^9, 3.685195900536501*^9, 
   3.685195987695903*^9, 3.685249178033299*^9, 3.685259097524781*^9, 
   3.685706272015841*^9, 3.685711817356892*^9, 3.685831358611857*^9, 
   3.685851770557208*^9}],

Cell[BoxData["\<\"Finished calculation after 134416 iterations.\"\>"], "Print",
 CellChangeTimes->{{3.675572006401083*^9, 3.6755720142676477`*^9}, {
   3.6755724810671797`*^9, 3.6755725163027477`*^9}, {3.6755726014468203`*^9, 
   3.6755726042007113`*^9}, 3.675572832423069*^9, {3.6755731727076263`*^9, 
   3.675573260843977*^9}, 3.675573532159712*^9, {3.675573721837899*^9, 
   3.675573752056282*^9}, {3.675573782652417*^9, 3.6755738066460943`*^9}, {
   3.675573898552917*^9, 3.6755739274110928`*^9}, {3.675574004200198*^9, 
   3.675574008538425*^9}, 3.675574053034545*^9, {3.675574280711363*^9, 
   3.675574297288308*^9}, 3.675574462790161*^9, 3.675574586089883*^9, 
   3.675574637476365*^9, 3.675574839226425*^9, {3.675574890495219*^9, 
   3.675574899961628*^9}, {3.6755750577441473`*^9, 3.6755750653479033`*^9}, {
   3.67557536517969*^9, 3.675575374622838*^9}, 3.67558241864917*^9, 
   3.675595561804577*^9, 3.675595598189539*^9, 3.675596941501546*^9, {
   3.6755969799136963`*^9, 3.675596981891532*^9}, {3.6755985390385427`*^9, 
   3.6755985603346*^9}, 3.675598655784644*^9, 3.675598710761747*^9, 
   3.675598772277358*^9, 3.675598982611813*^9, 3.6755990365712214`*^9, 
   3.675599124714926*^9, 3.675599190525057*^9, 3.6755992265054293`*^9, 
   3.6755993517965727`*^9, 3.675599384154059*^9, 3.675599441691959*^9, 
   3.6755995793084993`*^9, 3.675600493810341*^9, 3.675601419908771*^9, 
   3.6756020555122337`*^9, 3.6756023632210083`*^9, 3.675602807876725*^9, 
   3.675602897602737*^9, {3.6756033421530533`*^9, 3.675603380919065*^9}, 
   3.675613375417395*^9, 3.675613494839464*^9, 3.675656390071207*^9, 
   3.6756832342389383`*^9, 3.675683357975985*^9, 3.675857704474587*^9, 
   3.675862632474606*^9, 3.6758648822207727`*^9, 3.675865049216236*^9, 
   3.67586513788349*^9, {3.675865233131024*^9, 3.675865257251742*^9}, {
   3.6758653420784893`*^9, 3.675865356836982*^9}, 3.6758656228927298`*^9, 
   3.675865747362034*^9, {3.675865818783901*^9, 3.675865835891333*^9}, {
   3.6758658670111237`*^9, 3.675865896860029*^9}, 3.675865958760379*^9, 
   3.6758676158396473`*^9, {3.675867824560811*^9, 3.675867834230739*^9}, {
   3.675936848949038*^9, 3.675936860094269*^9}, 3.675942150157858*^9, 
   3.6759589153553867`*^9, 3.675959692249486*^9, 3.675959749337008*^9, 
   3.675959793505755*^9, {3.675962726520094*^9, 3.675962732940042*^9}, 
   3.6759631992326183`*^9, 3.676005076509894*^9, 3.6760054510397987`*^9, 
   3.6760922799521914`*^9, 3.676145031860186*^9, 3.67752770975972*^9, 
   3.6781944003152027`*^9, 3.678938324033092*^9, 3.678938762397016*^9, 
   3.678938841034732*^9, 3.678938888097413*^9, 3.679373237470869*^9, 
   3.679379242564719*^9, 3.679379516825293*^9, 3.679381106126199*^9, 
   3.679381156825899*^9, 3.6793821749785*^9, 3.6793823448314533`*^9, 
   3.679382425135206*^9, 3.683899292519908*^9, 3.683899851402754*^9, 
   3.6839027549793243`*^9, 3.683906415792178*^9, 3.683906819144183*^9, 
   3.683949372390581*^9, 3.6839498985827827`*^9, 3.6839524145676823`*^9, 
   3.683958943103503*^9, 3.6851945867973022`*^9, 3.685194616981819*^9, 
   3.68519478292586*^9, 3.685195855352476*^9, 3.685195900536501*^9, 
   3.685195987695903*^9, 3.685249178033299*^9, 3.685259097524781*^9, 
   3.685706272015841*^9, 3.685711817356892*^9, 3.685831358611857*^9, 
   3.686000414208127*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There are \"\>", "\[InvisibleSpace]", "512", 
   "\[InvisibleSpace]", "\<\" generators left.\"\>"}],
  SequenceForm["There are ", 512, " generators left."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.675572006401083*^9, 3.6755720142676477`*^9}, {
   3.6755724810671797`*^9, 3.6755725163027477`*^9}, {3.6755726014468203`*^9, 
   3.6755726042007113`*^9}, 3.675572832423069*^9, {3.6755731727076263`*^9, 
   3.675573260843977*^9}, 3.675573532159712*^9, {3.675573721837899*^9, 
   3.675573752056282*^9}, {3.675573782652417*^9, 3.6755738066460943`*^9}, {
   3.675573898552917*^9, 3.6755739274110928`*^9}, {3.675574004200198*^9, 
   3.675574008538425*^9}, 3.675574053034545*^9, {3.675574280711363*^9, 
   3.675574297288308*^9}, 3.675574462790161*^9, 3.675574586089883*^9, 
   3.675574637476365*^9, 3.675574839226425*^9, {3.675574890495219*^9, 
   3.675574899961628*^9}, {3.6755750577441473`*^9, 3.6755750653479033`*^9}, {
   3.67557536517969*^9, 3.675575374622838*^9}, 3.67558241864917*^9, 
   3.675595561804577*^9, 3.675595598189539*^9, 3.675596941501546*^9, {
   3.6755969799136963`*^9, 3.675596981891532*^9}, {3.6755985390385427`*^9, 
   3.6755985603346*^9}, 3.675598655784644*^9, 3.675598710761747*^9, 
   3.675598772277358*^9, 3.675598982611813*^9, 3.6755990365712214`*^9, 
   3.675599124714926*^9, 3.675599190525057*^9, 3.6755992265054293`*^9, 
   3.6755993517965727`*^9, 3.675599384154059*^9, 3.675599441691959*^9, 
   3.6755995793084993`*^9, 3.675600493810341*^9, 3.675601419908771*^9, 
   3.6756020555122337`*^9, 3.6756023632210083`*^9, 3.675602807876725*^9, 
   3.675602897602737*^9, {3.6756033421530533`*^9, 3.675603380919065*^9}, 
   3.675613375417395*^9, 3.675613494839464*^9, 3.675656390071207*^9, 
   3.6756832342389383`*^9, 3.675683357975985*^9, 3.675857704474587*^9, 
   3.675862632474606*^9, 3.6758648822207727`*^9, 3.675865049216236*^9, 
   3.67586513788349*^9, {3.675865233131024*^9, 3.675865257251742*^9}, {
   3.6758653420784893`*^9, 3.675865356836982*^9}, 3.6758656228927298`*^9, 
   3.675865747362034*^9, {3.675865818783901*^9, 3.675865835891333*^9}, {
   3.6758658670111237`*^9, 3.675865896860029*^9}, 3.675865958760379*^9, 
   3.6758676158396473`*^9, {3.675867824560811*^9, 3.675867834230739*^9}, {
   3.675936848949038*^9, 3.675936860094269*^9}, 3.675942150157858*^9, 
   3.6759589153553867`*^9, 3.675959692249486*^9, 3.675959749337008*^9, 
   3.675959793505755*^9, {3.675962726520094*^9, 3.675962732940042*^9}, 
   3.6759631992326183`*^9, 3.676005076509894*^9, 3.6760054510397987`*^9, 
   3.6760922799521914`*^9, 3.676145031860186*^9, 3.67752770975972*^9, 
   3.6781944003152027`*^9, 3.678938324033092*^9, 3.678938762397016*^9, 
   3.678938841034732*^9, 3.678938888097413*^9, 3.679373237470869*^9, 
   3.679379242564719*^9, 3.679379516825293*^9, 3.679381106126199*^9, 
   3.679381156825899*^9, 3.6793821749785*^9, 3.6793823448314533`*^9, 
   3.679382425135206*^9, 3.683899292519908*^9, 3.683899851402754*^9, 
   3.6839027549793243`*^9, 3.683906415792178*^9, 3.683906819144183*^9, 
   3.683949372390581*^9, 3.6839498985827827`*^9, 3.6839524145676823`*^9, 
   3.683958943103503*^9, 3.6851945867973022`*^9, 3.685194616981819*^9, 
   3.68519478292586*^9, 3.685195855352476*^9, 3.685195900536501*^9, 
   3.685195987695903*^9, 3.685249178033299*^9, 3.685259097524781*^9, 
   3.685706272015841*^9, 3.685711817356892*^9, 3.685831358611857*^9, 
   3.6860004142088842`*^9}],

Cell[BoxData[
 TemplateBox[{RowBox[{"\"02:00:14\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", "1.`"}], FontColor -> 
      GrayLevel[0.5]]}],RowBox[{"TimeObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"2", ",", "0", ",", "14.207575`"}], "}"}], ",", 
       RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}]},
  "TimeObject",
  Editable->False]], "Print",
 CellChangeTimes->{{3.675572006401083*^9, 3.6755720142676477`*^9}, {
   3.6755724810671797`*^9, 3.6755725163027477`*^9}, {3.6755726014468203`*^9, 
   3.6755726042007113`*^9}, 3.675572832423069*^9, {3.6755731727076263`*^9, 
   3.675573260843977*^9}, 3.675573532159712*^9, {3.675573721837899*^9, 
   3.675573752056282*^9}, {3.675573782652417*^9, 3.6755738066460943`*^9}, {
   3.675573898552917*^9, 3.6755739274110928`*^9}, {3.675574004200198*^9, 
   3.675574008538425*^9}, 3.675574053034545*^9, {3.675574280711363*^9, 
   3.675574297288308*^9}, 3.675574462790161*^9, 3.675574586089883*^9, 
   3.675574637476365*^9, 3.675574839226425*^9, {3.675574890495219*^9, 
   3.675574899961628*^9}, {3.6755750577441473`*^9, 3.6755750653479033`*^9}, {
   3.67557536517969*^9, 3.675575374622838*^9}, 3.67558241864917*^9, 
   3.675595561804577*^9, 3.675595598189539*^9, 3.675596941501546*^9, {
   3.6755969799136963`*^9, 3.675596981891532*^9}, {3.6755985390385427`*^9, 
   3.6755985603346*^9}, 3.675598655784644*^9, 3.675598710761747*^9, 
   3.675598772277358*^9, 3.675598982611813*^9, 3.6755990365712214`*^9, 
   3.675599124714926*^9, 3.675599190525057*^9, 3.6755992265054293`*^9, 
   3.6755993517965727`*^9, 3.675599384154059*^9, 3.675599441691959*^9, 
   3.6755995793084993`*^9, 3.675600493810341*^9, 3.675601419908771*^9, 
   3.6756020555122337`*^9, 3.6756023632210083`*^9, 3.675602807876725*^9, 
   3.675602897602737*^9, {3.6756033421530533`*^9, 3.675603380919065*^9}, 
   3.675613375417395*^9, 3.675613494839464*^9, 3.675656390071207*^9, 
   3.6756832342389383`*^9, 3.675683357975985*^9, 3.675857704474587*^9, 
   3.675862632474606*^9, 3.6758648822207727`*^9, 3.675865049216236*^9, 
   3.67586513788349*^9, {3.675865233131024*^9, 3.675865257251742*^9}, {
   3.6758653420784893`*^9, 3.675865356836982*^9}, 3.6758656228927298`*^9, 
   3.675865747362034*^9, {3.675865818783901*^9, 3.675865835891333*^9}, {
   3.6758658670111237`*^9, 3.675865896860029*^9}, 3.675865958760379*^9, 
   3.6758676158396473`*^9, {3.675867824560811*^9, 3.675867834230739*^9}, {
   3.675936848949038*^9, 3.675936860094269*^9}, 3.675942150157858*^9, 
   3.6759589153553867`*^9, 3.675959692249486*^9, 3.675959749337008*^9, 
   3.675959793505755*^9, {3.675962726520094*^9, 3.675962732940042*^9}, 
   3.6759631992326183`*^9, 3.676005076509894*^9, 3.6760054510397987`*^9, 
   3.6760922799521914`*^9, 3.676145031860186*^9, 3.67752770975972*^9, 
   3.6781944003152027`*^9, 3.678938324033092*^9, 3.678938762397016*^9, 
   3.678938841034732*^9, 3.678938888097413*^9, 3.679373237470869*^9, 
   3.679379242564719*^9, 3.679379516825293*^9, 3.679381106126199*^9, 
   3.679381156825899*^9, 3.6793821749785*^9, 3.6793823448314533`*^9, 
   3.679382425135206*^9, 3.683899292519908*^9, 3.683899851402754*^9, 
   3.6839027549793243`*^9, 3.683906415792178*^9, 3.683906819144183*^9, 
   3.683949372390581*^9, 3.6839498985827827`*^9, 3.6839524145676823`*^9, 
   3.683958943103503*^9, 3.6851945867973022`*^9, 3.685194616981819*^9, 
   3.68519478292586*^9, 3.685195855352476*^9, 3.685195900536501*^9, 
   3.685195987695903*^9, 3.685249178033299*^9, 3.685259097524781*^9, 
   3.685706272015841*^9, 3.685711817356892*^9, 3.685831358611857*^9, 
   3.686000414211768*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\" << backup saved at: \"\>", 
   "\[InvisibleSpace]", \
"\<\"/mhome/dpmms/c/cbz20/Documents/PhD/Research/thesis/BSFH/Backups/\
GlueingBSAAx4e_AfterCancellation.mx >>\"\>"}],
  SequenceForm[
  " << backup saved at: ", 
   "/mhome/dpmms/c/cbz20/Documents/PhD/Research/thesis/BSFH/Backups/\
GlueingBSAAx4e_AfterCancellation.mx >>"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.675572006401083*^9, 3.6755720142676477`*^9}, {
   3.6755724810671797`*^9, 3.6755725163027477`*^9}, {3.6755726014468203`*^9, 
   3.6755726042007113`*^9}, 3.675572832423069*^9, {3.6755731727076263`*^9, 
   3.675573260843977*^9}, 3.675573532159712*^9, {3.675573721837899*^9, 
   3.675573752056282*^9}, {3.675573782652417*^9, 3.6755738066460943`*^9}, {
   3.675573898552917*^9, 3.6755739274110928`*^9}, {3.675574004200198*^9, 
   3.675574008538425*^9}, 3.675574053034545*^9, {3.675574280711363*^9, 
   3.675574297288308*^9}, 3.675574462790161*^9, 3.675574586089883*^9, 
   3.675574637476365*^9, 3.675574839226425*^9, {3.675574890495219*^9, 
   3.675574899961628*^9}, {3.6755750577441473`*^9, 3.6755750653479033`*^9}, {
   3.67557536517969*^9, 3.675575374622838*^9}, 3.67558241864917*^9, 
   3.675595561804577*^9, 3.675595598189539*^9, 3.675596941501546*^9, {
   3.6755969799136963`*^9, 3.675596981891532*^9}, {3.6755985390385427`*^9, 
   3.6755985603346*^9}, 3.675598655784644*^9, 3.675598710761747*^9, 
   3.675598772277358*^9, 3.675598982611813*^9, 3.6755990365712214`*^9, 
   3.675599124714926*^9, 3.675599190525057*^9, 3.6755992265054293`*^9, 
   3.6755993517965727`*^9, 3.675599384154059*^9, 3.675599441691959*^9, 
   3.6755995793084993`*^9, 3.675600493810341*^9, 3.675601419908771*^9, 
   3.6756020555122337`*^9, 3.6756023632210083`*^9, 3.675602807876725*^9, 
   3.675602897602737*^9, {3.6756033421530533`*^9, 3.675603380919065*^9}, 
   3.675613375417395*^9, 3.675613494839464*^9, 3.675656390071207*^9, 
   3.6756832342389383`*^9, 3.675683357975985*^9, 3.675857704474587*^9, 
   3.675862632474606*^9, 3.6758648822207727`*^9, 3.675865049216236*^9, 
   3.67586513788349*^9, {3.675865233131024*^9, 3.675865257251742*^9}, {
   3.6758653420784893`*^9, 3.675865356836982*^9}, 3.6758656228927298`*^9, 
   3.675865747362034*^9, {3.675865818783901*^9, 3.675865835891333*^9}, {
   3.6758658670111237`*^9, 3.675865896860029*^9}, 3.675865958760379*^9, 
   3.6758676158396473`*^9, {3.675867824560811*^9, 3.675867834230739*^9}, {
   3.675936848949038*^9, 3.675936860094269*^9}, 3.675942150157858*^9, 
   3.6759589153553867`*^9, 3.675959692249486*^9, 3.675959749337008*^9, 
   3.675959793505755*^9, {3.675962726520094*^9, 3.675962732940042*^9}, 
   3.6759631992326183`*^9, 3.676005076509894*^9, 3.6760054510397987`*^9, 
   3.6760922799521914`*^9, 3.676145031860186*^9, 3.67752770975972*^9, 
   3.6781944003152027`*^9, 3.678938324033092*^9, 3.678938762397016*^9, 
   3.678938841034732*^9, 3.678938888097413*^9, 3.679373237470869*^9, 
   3.679379242564719*^9, 3.679379516825293*^9, 3.679381106126199*^9, 
   3.679381156825899*^9, 3.6793821749785*^9, 3.6793823448314533`*^9, 
   3.679382425135206*^9, 3.683899292519908*^9, 3.683899851402754*^9, 
   3.6839027549793243`*^9, 3.683906415792178*^9, 3.683906819144183*^9, 
   3.683949372390581*^9, 3.6839498985827827`*^9, 3.6839524145676823`*^9, 
   3.683958943103503*^9, 3.6851945867973022`*^9, 3.685194616981819*^9, 
   3.68519478292586*^9, 3.685195855352476*^9, 3.685195900536501*^9, 
   3.685195987695903*^9, 3.685249178033299*^9, 3.685259097524781*^9, 
   3.685706272015841*^9, 3.685711817356892*^9, 3.685831358611857*^9, 
   3.686000448241263*^9}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"<<", 
   RowBox[{"(", 
    RowBox[{"BackupFilePath", "<>", "\"\<_AfterCancellation.mx\>\""}], 
    ")"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.675682414716271*^9, 3.675682416691991*^9}, 
   3.675683195825262*^9, {3.675747922268229*^9, 3.675747929553258*^9}, {
   3.676175514307502*^9, 3.676175515721424*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Post-processing: Further cancellations and homotopies", "Section",
 CellChangeTimes->{{3.683902406280332*^9, 3.683902411992662*^9}, {
  3.6839024516165123`*^9, 3.683902475521956*^9}, {3.683902509419033*^9, 
  3.6839025833159637`*^9}, {3.683902614317812*^9, 3.683902621444993*^9}, {
  3.6839026606787653`*^9, 3.683902706656199*^9}, {3.683902768385414*^9, 
  3.6839028035945807`*^9}, {3.683906361254035*^9, 3.683906397535213*^9}}],

Cell[BoxData[
 RowBox[{"Step5PostProcessing", ";"}]], "Input",
 CellChangeTimes->{
  3.683897532395102*^9, {3.6839058148344393`*^9, 3.683905815122682*^9}, {
   3.683905991192045*^9, 3.6839059922611847`*^9}, {3.685194541520829*^9, 
   3.685194543848864*^9}, {3.685248894086935*^9, 3.6852488943255787`*^9}, {
   3.685693093120482*^9, 3.685693117431604*^9}, {3.685695524119947*^9, 
   3.685695530703979*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"PlotGraph", "[", "MMit", "]"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"GenTableWithIdems", "[", "gens_", "]"}], " ", "displays", " ", 
     "a", " ", "list", " ", "of", " ", "idempotents", " ", "and", " ", 
     "their", " ", "generators"}], ";"}], "\[IndentingNewLine]", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"GenTableWithIdems", "[", "generatorsit", "]"}]}], "Input",
 CellChangeTimes->{{3.6761773820432796`*^9, 3.676177384954527*^9}, 
   3.676177617306233*^9, 3.6761786321171417`*^9, {3.6839495373610287`*^9, 
   3.683949538281969*^9}, {3.685693132401354*^9, 3.6856931784270372`*^9}, {
   3.6856955535368137`*^9, 3.6856955843935833`*^9}, {3.685697559716579*^9, 
   3.685697559947776*^9}, 3.685706283228877*^9}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJzs3UFuI8u2HVDDHokBzYNtdT0EA27+57loMF8zqY76BQjGAzwEq64at0yC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   "], {{0, 0}, {512, 512}}, {0, 1}],
  Frame->Automatic,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
    Automatic}]], "Print",
 CellChangeTimes->{{3.685706277430007*^9, 3.685706283816469*^9}, 
   3.685711824375615*^9, 3.685712345087315*^9, 3.685712558558536*^9, 
   3.6860246020481863`*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"{", 
       RowBox[{"\<\"c\"\>", ",", "\<\"d\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "2", ",", "3", ",", "4", ",", "33", ",", "34", ",", "35", 
        ",", "36"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"c\"\>", ",", "\<\"b\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
       "5", ",", "6", ",", "7", ",", "8", ",", "9", ",", "10", ",", "11", ",",
         "12", ",", "17", ",", "18", ",", "21", ",", "22", ",", "25", ",", 
        "26", ",", "29", ",", "30", ",", "37", ",", "38", ",", "39", ",", 
        "40", ",", "41", ",", "42", ",", "43", ",", "44", ",", "49", ",", 
        "50", ",", "53", ",", "54", ",", "57", ",", "58", ",", "61", ",", 
        "62"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"c\"\>", ",", "\<\"a\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
       "13", ",", "14", ",", "15", ",", "16", ",", "19", ",", "20", ",", "23",
         ",", "24", ",", "27", ",", "28", ",", "31", ",", "32", ",", "45", 
        ",", "46", ",", "47", ",", "48", ",", "51", ",", "52", ",", "55", ",",
         "56", ",", "59", ",", "60", ",", "63", ",", "64"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"b\"\>", ",", "\<\"d\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
       "65", ",", "66", ",", "67", ",", "68", ",", "97", ",", "98", ",", "99",
         ",", "100", ",", "129", ",", "130", ",", "131", ",", "132", ",", 
        "161", ",", "162", ",", "163", ",", "164", ",", "193", ",", "194", 
        ",", "195", ",", "196", ",", "225", ",", "226", ",", "227", ",", 
        "228"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"b\"\>", ",", "\<\"b\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
       "69", ",", "70", ",", "71", ",", "72", ",", "73", ",", "74", ",", "75",
         ",", "76", ",", "81", ",", "82", ",", "85", ",", "86", ",", "89", 
        ",", "90", ",", "93", ",", "94", ",", "101", ",", "102", ",", "103", 
        ",", "104", ",", "105", ",", "106", ",", "107", ",", "108", ",", 
        "113", ",", "114", ",", "117", ",", "118", ",", "121", ",", "122", 
        ",", "125", ",", "126", ",", "133", ",", "134", ",", "135", ",", 
        "136", ",", "137", ",", "138", ",", "139", ",", "140", ",", "145", 
        ",", "146", ",", "149", ",", "150", ",", "153", ",", "154", ",", 
        "157", ",", "158", ",", "165", ",", "166", ",", "167", ",", "168", 
        ",", "169", ",", "170", ",", "171", ",", "172", ",", "177", ",", 
        "178", ",", "181", ",", "182", ",", "185", ",", "186", ",", "189", 
        ",", "190", ",", "197", ",", "198", ",", "199", ",", "200", ",", 
        "201", ",", "202", ",", "203", ",", "204", ",", "209", ",", "210", 
        ",", "213", ",", "214", ",", "217", ",", "218", ",", "221", ",", 
        "222", ",", "229", ",", "230", ",", "231", ",", "232", ",", "233", 
        ",", "234", ",", "235", ",", "236", ",", "241", ",", "242", ",", 
        "245", ",", "246", ",", "249", ",", "250", ",", "253", ",", "254"}], 
       "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"b\"\>", ",", "\<\"a\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
       "77", ",", "78", ",", "79", ",", "80", ",", "83", ",", "84", ",", "87",
         ",", "88", ",", "91", ",", "92", ",", "95", ",", "96", ",", "109", 
        ",", "110", ",", "111", ",", "112", ",", "115", ",", "116", ",", 
        "119", ",", "120", ",", "123", ",", "124", ",", "127", ",", "128", 
        ",", "141", ",", "142", ",", "143", ",", "144", ",", "147", ",", 
        "148", ",", "151", ",", "152", ",", "155", ",", "156", ",", "159", 
        ",", "160", ",", "173", ",", "174", ",", "175", ",", "176", ",", 
        "179", ",", "180", ",", "183", ",", "184", ",", "187", ",", "188", 
        ",", "191", ",", "192", ",", "205", ",", "206", ",", "207", ",", 
        "208", ",", "211", ",", "212", ",", "215", ",", "216", ",", "219", 
        ",", "220", ",", "223", ",", "224", ",", "237", ",", "238", ",", 
        "239", ",", "240", ",", "243", ",", "244", ",", "247", ",", "248", 
        ",", "251", ",", "252", ",", "255", ",", "256"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"a\"\>", ",", "\<\"d\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
       "257", ",", "258", ",", "259", ",", "260", ",", "289", ",", "290", ",",
         "291", ",", "292", ",", "321", ",", "322", ",", "323", ",", "324", 
        ",", "353", ",", "354", ",", "355", ",", "356", ",", "385", ",", 
        "386", ",", "387", ",", "388", ",", "417", ",", "418", ",", "419", 
        ",", "420", ",", "449", ",", "450", ",", "451", ",", "452", ",", 
        "481", ",", "482", ",", "483", ",", "484"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"a\"\>", ",", "\<\"b\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
       "261", ",", "262", ",", "263", ",", "264", ",", "265", ",", "266", ",",
         "267", ",", "268", ",", "273", ",", "274", ",", "277", ",", "278", 
        ",", "281", ",", "282", ",", "285", ",", "286", ",", "293", ",", 
        "294", ",", "295", ",", "296", ",", "297", ",", "298", ",", "299", 
        ",", "300", ",", "305", ",", "306", ",", "309", ",", "310", ",", 
        "313", ",", "314", ",", "317", ",", "318", ",", "325", ",", "326", 
        ",", "327", ",", "328", ",", "329", ",", "330", ",", "331", ",", 
        "332", ",", "337", ",", "338", ",", "341", ",", "342", ",", "345", 
        ",", "346", ",", "349", ",", "350", ",", "357", ",", "358", ",", 
        "359", ",", "360", ",", "361", ",", "362", ",", "363", ",", "364", 
        ",", "369", ",", "370", ",", "373", ",", "374", ",", "377", ",", 
        "378", ",", "381", ",", "382", ",", "389", ",", "390", ",", "391", 
        ",", "392", ",", "393", ",", "394", ",", "395", ",", "396", ",", 
        "401", ",", "402", ",", "405", ",", "406", ",", "409", ",", "410", 
        ",", "413", ",", "414", ",", "421", ",", "422", ",", "423", ",", 
        "424", ",", "425", ",", "426", ",", "427", ",", "428", ",", "433", 
        ",", "434", ",", "437", ",", "438", ",", "441", ",", "442", ",", 
        "445", ",", "446", ",", "453", ",", "454", ",", "455", ",", "456", 
        ",", "457", ",", "458", ",", "459", ",", "460", ",", "465", ",", 
        "466", ",", "469", ",", "470", ",", "473", ",", "474", ",", "477", 
        ",", "478", ",", "485", ",", "486", ",", "487", ",", "488", ",", 
        "489", ",", "490", ",", "491", ",", "492", ",", "497", ",", "498", 
        ",", "501", ",", "502", ",", "505", ",", "506", ",", "509", ",", 
        "510"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"a\"\>", ",", "\<\"a\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
       "269", ",", "270", ",", "271", ",", "272", ",", "275", ",", "276", ",",
         "279", ",", "280", ",", "283", ",", "284", ",", "287", ",", "288", 
        ",", "301", ",", "302", ",", "303", ",", "304", ",", "307", ",", 
        "308", ",", "311", ",", "312", ",", "315", ",", "316", ",", "319", 
        ",", "320", ",", "333", ",", "334", ",", "335", ",", "336", ",", 
        "339", ",", "340", ",", "343", ",", "344", ",", "347", ",", "348", 
        ",", "351", ",", "352", ",", "365", ",", "366", ",", "367", ",", 
        "368", ",", "371", ",", "372", ",", "375", ",", "376", ",", "379", 
        ",", "380", ",", "383", ",", "384", ",", "397", ",", "398", ",", 
        "399", ",", "400", ",", "403", ",", "404", ",", "407", ",", "408", 
        ",", "411", ",", "412", ",", "415", ",", "416", ",", "429", ",", 
        "430", ",", "431", ",", "432", ",", "435", ",", "436", ",", "439", 
        ",", "440", ",", "443", ",", "444", ",", "447", ",", "448", ",", 
        "461", ",", "462", ",", "463", ",", "464", ",", "467", ",", "468", 
        ",", "471", ",", "472", ",", "475", ",", "476", ",", "479", ",", 
        "480", ",", "493", ",", "494", ",", "495", ",", "496", ",", "499", 
        ",", "500", ",", "503", ",", "504", ",", "507", ",", "508", ",", 
        "511", ",", "512"}], "}"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.685706283820657*^9, 3.6857118243768883`*^9, 
  3.68571234512143*^9, 3.685712558590065*^9, 3.6860246020913363`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"CarefulCancel1", "=", 
   RowBox[{"CarefulCancellation", "[", 
    RowBox[{"MMit", ",", "generatorsit"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MM1", "=", 
   RowBox[{"CarefulCancel1", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GG1", "=", 
   RowBox[{"CarefulCancel1", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.6761752543259783`*^9, 3.676175337459744*^9}, {
   3.676175408702016*^9, 3.6761754091734247`*^9}, {3.6761754586476603`*^9, 
   3.676175483863119*^9}, {3.6761756365504932`*^9, 3.6761756366932783`*^9}, {
   3.676181697923071*^9, 3.67618170080893*^9}, {3.676181786491774*^9, 
   3.676181803043103*^9}, {3.676181845699214*^9, 3.676181850899927*^9}, {
   3.6761819942660027`*^9, 3.676182005800435*^9}, {3.676182125581752*^9, 
   3.676182180341146*^9}, {3.678365601919386*^9, 3.678365642786083*^9}, {
   3.679100821763163*^9, 3.67910105888132*^9}, 3.679101231862932*^9, {
   3.6793734417653027`*^9, 3.679373463948657*^9}, {3.6793812277833776`*^9, 
   3.679381285144319*^9}, {3.679381341196933*^9, 3.679381343026075*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 TemplateBox[{RowBox[{"\"08:43:38\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", "1.`"}], FontColor -> 
      GrayLevel[0.5]]}],RowBox[{"TimeObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"8", ",", "43", ",", "38.332621`"}], "}"}], ",", 
       RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}]},
  "TimeObject",
  Editable->False]], "Print",
 CellChangeTimes->{{3.676175630167898*^9, 3.6761756432051477`*^9}, 
   3.676177633238863*^9, 3.676181718282309*^9, 3.676181805218286*^9, 
   3.676181851823415*^9, 3.676182006495245*^9, 3.676182181420231*^9, 
   3.676221922288815*^9, 3.6762219998584948`*^9, 3.676259911566552*^9, 
   3.676347690195682*^9, 3.676365991397257*^9, 3.6763879252666597`*^9, 
   3.676392629800563*^9, 3.676440169293993*^9, 3.676473474391552*^9, 
   3.677558391444075*^9, 3.67755939315864*^9, 3.677561474804204*^9, {
   3.678365630463592*^9, 3.678365643154956*^9}, 3.678438841809287*^9, 
   3.67910106886849*^9, 3.679101233304977*^9, {3.679228828213192*^9, 
   3.679228845187958*^9}, 3.6792292430359297`*^9, 3.679235213978156*^9, 
   3.679373465879586*^9, 3.679379276205572*^9, 3.679379653711396*^9, 
   3.679381175254533*^9, 3.679381220446678*^9, {3.679381278310419*^9, 
   3.679381286237536*^9}, 3.679381363721024*^9, 3.679382113895825*^9, 
   3.6793821789474087`*^9, {3.679382351073333*^9, 3.6793823563180857`*^9}, 
   3.679382428774447*^9, 3.6839008031636467`*^9, 3.683906842872005*^9, {
   3.683907938656304*^9, 3.683907945517867*^9}, 3.6839496031815987`*^9, 
   3.683949916694581*^9, 3.683952428309697*^9, 3.6839589662501383`*^9, 
   3.684043336180006*^9, 3.684043390906584*^9, 3.685196556483519*^9, 
   3.685257710349473*^9, 3.6852591238576803`*^9, 3.685706310640483*^9, 
   3.685711829094784*^9, 3.6857123501278343`*^9, 3.685712563375325*^9, 
   3.686024618347172*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {"\<\"Finished calculation\"\>"},
      {"\<\"after 236 iterations.\"\>"},
      {
       GraphicsBox[RasterBox[CompressedData["
1:eJztnEFKBEEMRQc8iTtv0XcQvIDg2qVn0avoVXQnIiJ4BGkVxJ5JQ8ak83/q
FwwlbzGdStWvVCXtnF5en1+d7Ha7s5/P/Pff9jHtIXHxFf70OLf3admj2Wlx
Fvsf7uf2Ni17NDvFa7l3Pd/dzu11WvZV9kfxKl1Lp5icZZ9n4ZY/o/ycPV+j
6ZR9/XeNU9k8W4/S6ZicfT9B49n+RNNp1X4SxVnstLji6XGcfd6jdOp9Lrvf
xLfh3nXS9XzYdVzi4p3ignQqjqwX9ntlFGfXKYufR+NV9dao/AmaLtDs8XLp
FJNH6SVbv1HjzebsOrU4+7xYnH1cUesN7fyczbvq1MvZ5xGNV/kzW79V5+fs
+il7vQ9Nv2j2eLniwnfL1rvqp9twdv9Ij8fxi6/2PC17y59V53/29Skurn1v
HM6+X3VdV9nxyxtPrXul9VxvXPZ+v9XffLWXvT57vqI4ux7Ft+FV91NxcUbO
ku8djWtfEkdYV9LpOh9Np1HvEVVx7z0Ozf7sfO//+G/rmjce7f0Z8ViOFk+1
Pmu54mmt/d54auVRo/K3h+3F+z23qjiYnT+P8pv4Nhwt36t1JS6+z9HOveLi
CBwtH+s990Y918sVZ9e5/NObo517xcUZuTf/ZuUTLD1G5ZEOj6POb105+z7J
bn8Vz46nXeel67jEMXlVHknvM2xjj3gPnh1Pvd/PUo+WHsU76TTbTjS9oNkj
3oOz10+lC3GEdcVePx3t/SXLHvb9MIp76xRo9ldxlnMviz3iY/LR6qfe8Uqn
XJwlz2Dxqv93YK+fsswvGtc5nIurflrL0fSieyImZ6+fosVrln0DbX8QX+cs
eST2ew1LHljxlIt/AnfzMrw=
         "], {{0, 0}, {40, 40}}, {0, 1}],
        Frame->Automatic,
        FrameLabel->{None, None},
        FrameTicks->{{None, None}, {None, None}},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
          Automatic}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{{3.676175630167898*^9, 3.6761756432051477`*^9}, 
   3.676177633238863*^9, 3.676181718282309*^9, 3.676181805218286*^9, 
   3.676181851823415*^9, 3.676182006495245*^9, 3.676182181420231*^9, 
   3.676221922288815*^9, 3.6762219998584948`*^9, 3.676259911566552*^9, 
   3.676347690195682*^9, 3.676365991397257*^9, 3.6763879252666597`*^9, 
   3.676392629800563*^9, 3.676440169293993*^9, 3.676473474391552*^9, 
   3.677558391444075*^9, 3.67755939315864*^9, 3.677561474804204*^9, {
   3.678365630463592*^9, 3.678365643154956*^9}, 3.678438841809287*^9, 
   3.67910106886849*^9, 3.679101233304977*^9, {3.679228828213192*^9, 
   3.679228845187958*^9}, 3.6792292430359297`*^9, 3.679235213978156*^9, 
   3.679373465879586*^9, 3.679379276205572*^9, 3.679379653711396*^9, 
   3.679381175254533*^9, 3.679381220446678*^9, {3.679381278310419*^9, 
   3.679381286237536*^9}, 3.679381363721024*^9, 3.679382113895825*^9, 
   3.6793821789474087`*^9, {3.679382351073333*^9, 3.6793823563180857`*^9}, 
   3.679382428774447*^9, 3.6839008031636467`*^9, 3.683906842872005*^9, {
   3.683907938656304*^9, 3.683907945517867*^9}, 3.6839496031815987`*^9, 
   3.683949916694581*^9, 3.683952428309697*^9, 3.6839589662501383`*^9, 
   3.684043336180006*^9, 3.684043390906584*^9, 3.685196556483519*^9, 
   3.685257710349473*^9, 3.6852591238576803`*^9, 3.685706310640483*^9, 
   3.685711829094784*^9, 3.6857123501278343`*^9, 3.685712563375325*^9, 
   3.686024746984269*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There are \"\>", "\[InvisibleSpace]", "40", 
   "\[InvisibleSpace]", "\<\" generators left.\"\>"}],
  SequenceForm["There are ", 40, " generators left."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.676175630167898*^9, 3.6761756432051477`*^9}, 
   3.676177633238863*^9, 3.676181718282309*^9, 3.676181805218286*^9, 
   3.676181851823415*^9, 3.676182006495245*^9, 3.676182181420231*^9, 
   3.676221922288815*^9, 3.6762219998584948`*^9, 3.676259911566552*^9, 
   3.676347690195682*^9, 3.676365991397257*^9, 3.6763879252666597`*^9, 
   3.676392629800563*^9, 3.676440169293993*^9, 3.676473474391552*^9, 
   3.677558391444075*^9, 3.67755939315864*^9, 3.677561474804204*^9, {
   3.678365630463592*^9, 3.678365643154956*^9}, 3.678438841809287*^9, 
   3.67910106886849*^9, 3.679101233304977*^9, {3.679228828213192*^9, 
   3.679228845187958*^9}, 3.6792292430359297`*^9, 3.679235213978156*^9, 
   3.679373465879586*^9, 3.679379276205572*^9, 3.679379653711396*^9, 
   3.679381175254533*^9, 3.679381220446678*^9, {3.679381278310419*^9, 
   3.679381286237536*^9}, 3.679381363721024*^9, 3.679382113895825*^9, 
   3.6793821789474087`*^9, {3.679382351073333*^9, 3.6793823563180857`*^9}, 
   3.679382428774447*^9, 3.6839008031636467`*^9, 3.683906842872005*^9, {
   3.683907938656304*^9, 3.683907945517867*^9}, 3.6839496031815987`*^9, 
   3.683949916694581*^9, 3.683952428309697*^9, 3.6839589662501383`*^9, 
   3.684043336180006*^9, 3.684043390906584*^9, 3.685196556483519*^9, 
   3.685257710349473*^9, 3.6852591238576803`*^9, 3.685706310640483*^9, 
   3.685711829094784*^9, 3.6857123501278343`*^9, 3.685712563375325*^9, 
   3.686024746985485*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The cancelled generators were \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"\<\"(25)\"\>", "\<\"(24)\"\>", "\<\"(25)\"\>", "\<\"(24)\"\>", \
"\<\"(21)\"\>", "\<\"(20)\"\>", "\<\"(19)\"\>", "\<\"(18)\"\>", \
"\<\"(5)\"\>", "\<\"(5)\"\>", "\<\"(5)\"\>", "\<\"(5)\"\>", "\<\"(33)\"\>", "\
\<\"(32)\"\>", "\<\"(33)\"\>", "\<\"(32)\"\>", "\<\"(29)\"\>", \
"\<\"(28)\"\>", "\<\"(27)\"\>", "\<\"(26)\"\>", "\<\"(13)\"\>", \
"\<\"(13)\"\>", "\<\"(13)\"\>", "\<\"(13)\"\>", "\<\"(41)\"\>", \
"\<\"(40)\"\>", "\<\"(41)\"\>", "\<\"(40)\"\>", "\<\"(37)\"\>", \
"\<\"(36)\"\>", "\<\"(35)\"\>", "\<\"(34)\"\>", "\<\"(21)\"\>", \
"\<\"(21)\"\>", "\<\"(21)\"\>", "\<\"(21)\"\>", "\<\"(49)\"\>", \
"\<\"(48)\"\>", "\<\"(49)\"\>", "\<\"(48)\"\>", "\<\"(45)\"\>", \
"\<\"(44)\"\>", "\<\"(43)\"\>", "\<\"(42)\"\>", "\<\"(29)\"\>", \
"\<\"(29)\"\>", "\<\"(29)\"\>", "\<\"(29)\"\>", "\<\"(57)\"\>", \
"\<\"(56)\"\>", "\<\"(57)\"\>", "\<\"(56)\"\>", "\<\"(53)\"\>", \
"\<\"(52)\"\>", "\<\"(51)\"\>", "\<\"(50)\"\>", "\<\"(37)\"\>", \
"\<\"(37)\"\>", "\<\"(75)\"\>", "\<\"(70)\"\>", "\<\"(37)\"\>", \
"\<\"(37)\"\>", "\<\"(63)\"\>", "\<\"(62)\"\>", "\<\"(62)\"\>", \
"\<\"(61)\"\>", "\<\"(59)\"\>", "\<\"(58)\"\>", "\<\"(43)\"\>", \
"\<\"(43)\"\>", "\<\"(43)\"\>", "\<\"(43)\"\>", "\<\"(17)\"\>", \
"\<\"(17)\"\>", "\<\"(17)\"\>", "\<\"(17)\"\>", "\<\"(65)\"\>", \
"\<\"(64)\"\>", "\<\"(65)\"\>", "\<\"(64)\"\>", "\<\"(61)\"\>", \
"\<\"(60)\"\>", "\<\"(59)\"\>", "\<\"(58)\"\>", "\<\"(45)\"\>", \
"\<\"(45)\"\>", "\<\"(17)\"\>", "\<\"(17)\"\>", "\<\"(43)\"\>", \
"\<\"(43)\"\>", "\<\"(17)\"\>", "\<\"(17)\"\>", "\<\"(17)\"\>", \
"\<\"(17)\"\>", "\<\"(17)\"\>", "\<\"(17)\"\>", "\<\"(57)\"\>", \
"\<\"(56)\"\>", "\<\"(57)\"\>", "\<\"(56)\"\>", "\<\"(53)\"\>", \
"\<\"(31)\"\>", "\<\"(51)\"\>", "\<\"(31)\"\>", "\<\"(35)\"\>", \
"\<\"(35)\"\>", "\<\"(17)\"\>", "\<\"(17)\"\>", "\<\"(33)\"\>", \
"\<\"(33)\"\>", "\<\"(17)\"\>", "\<\"(17)\"\>", "\<\"(57)\"\>", \
"\<\"(56)\"\>", "\<\"(57)\"\>", "\<\"(56)\"\>", "\<\"(53)\"\>", \
"\<\"(52)\"\>", "\<\"(51)\"\>", "\<\"(50)\"\>", "\<\"(37)\"\>", \
"\<\"(37)\"\>", "\<\"(37)\"\>", "\<\"(37)\"\>", "\<\"(65)\"\>", \
"\<\"(64)\"\>", "\<\"(65)\"\>", "\<\"(64)\"\>", "\<\"(61)\"\>", \
"\<\"(60)\"\>", "\<\"(59)\"\>", "\<\"(58)\"\>", "\<\"(45)\"\>", \
"\<\"(45)\"\>", "\<\"(45)\"\>", "\<\"(45)\"\>", "\<\"(73)\"\>", \
"\<\"(72)\"\>", "\<\"(73)\"\>", "\<\"(72)\"\>", "\<\"(69)\"\>", \
"\<\"(68)\"\>", "\<\"(67)\"\>", "\<\"(66)\"\>", "\<\"(53)\"\>", \
"\<\"(53)\"\>", "\<\"(91)\"\>", "\<\"(86)\"\>", "\<\"(53)\"\>", \
"\<\"(53)\"\>", "\<\"(79)\"\>", "\<\"(78)\"\>", "\<\"(78)\"\>", \
"\<\"(77)\"\>", "\<\"(75)\"\>", "\<\"(74)\"\>", "\<\"(59)\"\>", \
"\<\"(59)\"\>", "\<\"(59)\"\>", "\<\"(59)\"\>", "\<\"(33)\"\>", \
"\<\"(33)\"\>", "\<\"(33)\"\>", "\<\"(33)\"\>", "\<\"(81)\"\>", \
"\<\"(80)\"\>", "\<\"(81)\"\>", "\<\"(80)\"\>", "\<\"(77)\"\>", \
"\<\"(76)\"\>", "\<\"(75)\"\>", "\<\"(74)\"\>", "\<\"(61)\"\>", \
"\<\"(61)\"\>", "\<\"(33)\"\>", "\<\"(33)\"\>", "\<\"(59)\"\>", \
"\<\"(59)\"\>", "\<\"(33)\"\>", "\<\"(33)\"\>", "\<\"(33)\"\>", \
"\<\"(33)\"\>", "\<\"(33)\"\>", "\<\"(33)\"\>", "\<\"(73)\"\>", \
"\<\"(72)\"\>", "\<\"(73)\"\>", "\<\"(72)\"\>", "\<\"(69)\"\>", \
"\<\"(47)\"\>", "\<\"(67)\"\>", "\<\"(47)\"\>", "\<\"(51)\"\>", \
"\<\"(51)\"\>", "\<\"(33)\"\>", "\<\"(33)\"\>", "\<\"(49)\"\>", \
"\<\"(49)\"\>", "\<\"(33)\"\>", "\<\"(33)\"\>", "\<\"(33)\"\>", \
"\<\"(33)\"\>", "\<\"(33)\"\>", "\<\"(33)\"\>", "\<\"(65)\"\>", \
"\<\"(64)\"\>", "\<\"(65)\"\>", "\<\"(64)\"\>", "\<\"(61)\"\>", \
"\<\"(60)\"\>", "\<\"(59)\"\>", "\<\"(58)\"\>", "\<\"(45)\"\>", \
"\<\"(45)\"\>", "\<\"(45)\"\>", "\<\"(45)\"\>", "\<\"(35)\"\>", \
"\<\"(35)\"\>", "\<\"(35)\"\>", "\<\"(35)\"\>", "\<\"(65)\"\>", \
"\<\"(64)\"\>", "\<\"(65)\"\>", "\<\"(64)\"\>", "\<\"(39)\"\>", \
"\<\"(60)\"\>", "\<\"(39)\"\>", "\<\"(58)\"\>", "\<\"(43)\"\>", \
"\<\"(43)\"\>", "\<\"(35)\"\>", "\<\"(35)\"\>", "\<\"(41)\"\>", \
"\<\"(41)\"\>", "\<\"(35)\"\>", "\<\"(35)\"\>"},
       {"\<\"25\"\>", "\<\"26\"\>", "\<\"29\"\>", "\<\"30\"\>", "\<\"27\"\>", \
"\<\"28\"\>", "\<\"31\"\>", "\<\"32\"\>", "\<\"5\"\>", "\<\"6\"\>", \
"\<\"7\"\>", "\<\"8\"\>", "\<\"57\"\>", "\<\"58\"\>", "\<\"61\"\>", "\<\"62\"\
\>", "\<\"59\"\>", "\<\"60\"\>", "\<\"63\"\>", "\<\"64\"\>", "\<\"37\"\>", \
"\<\"38\"\>", "\<\"39\"\>", "\<\"40\"\>", "\<\"89\"\>", "\<\"90\"\>", "\<\"93\
\"\>", "\<\"94\"\>", "\<\"91\"\>", "\<\"92\"\>", "\<\"95\"\>", "\<\"96\"\>", \
"\<\"69\"\>", "\<\"70\"\>", "\<\"71\"\>", "\<\"72\"\>", "\<\"121\"\>", \
"\<\"122\"\>", "\<\"125\"\>", "\<\"126\"\>", "\<\"123\"\>", "\<\"124\"\>", \
"\<\"127\"\>", "\<\"128\"\>", "\<\"101\"\>", "\<\"102\"\>", "\<\"103\"\>", \
"\<\"104\"\>", "\<\"153\"\>", "\<\"154\"\>", "\<\"157\"\>", "\<\"158\"\>", \
"\<\"155\"\>", "\<\"156\"\>", "\<\"159\"\>", "\<\"160\"\>", "\<\"133\"\>", \
"\<\"134\"\>", "\<\"191\"\>", "\<\"187\"\>", "\<\"135\"\>", "\<\"136\"\>", \
"\<\"185\"\>", "\<\"186\"\>", "\<\"189\"\>", "\<\"190\"\>", "\<\"188\"\>", \
"\<\"192\"\>", "\<\"165\"\>", "\<\"166\"\>", "\<\"167\"\>", "\<\"168\"\>", \
"\<\"65\"\>", "\<\"66\"\>", "\<\"67\"\>", "\<\"68\"\>", "\<\"217\"\>", \
"\<\"218\"\>", "\<\"221\"\>", "\<\"222\"\>", "\<\"219\"\>", "\<\"220\"\>", \
"\<\"223\"\>", "\<\"224\"\>", "\<\"197\"\>", "\<\"198\"\>", "\<\"83\"\>", "\<\
\"84\"\>", "\<\"199\"\>", "\<\"200\"\>", "\<\"87\"\>", "\<\"88\"\>", \
"\<\"97\"\>", "\<\"98\"\>", "\<\"99\"\>", "\<\"100\"\>", "\<\"249\"\>", \
"\<\"250\"\>", "\<\"253\"\>", "\<\"254\"\>", "\<\"251\"\>", "\<\"173\"\>", \
"\<\"255\"\>", "\<\"175\"\>", "\<\"229\"\>", "\<\"230\"\>", "\<\"115\"\>", \
"\<\"116\"\>", "\<\"231\"\>", "\<\"232\"\>", "\<\"119\"\>", "\<\"120\"\>", \
"\<\"281\"\>", "\<\"282\"\>", "\<\"285\"\>", "\<\"286\"\>", "\<\"283\"\>", \
"\<\"284\"\>", "\<\"287\"\>", "\<\"288\"\>", "\<\"261\"\>", "\<\"262\"\>", \
"\<\"263\"\>", "\<\"264\"\>", "\<\"313\"\>", "\<\"314\"\>", "\<\"317\"\>", \
"\<\"318\"\>", "\<\"315\"\>", "\<\"316\"\>", "\<\"319\"\>", "\<\"320\"\>", \
"\<\"293\"\>", "\<\"294\"\>", "\<\"295\"\>", "\<\"296\"\>", "\<\"345\"\>", \
"\<\"346\"\>", "\<\"349\"\>", "\<\"350\"\>", "\<\"347\"\>", "\<\"348\"\>", \
"\<\"351\"\>", "\<\"352\"\>", "\<\"325\"\>", "\<\"326\"\>", "\<\"383\"\>", \
"\<\"379\"\>", "\<\"327\"\>", "\<\"328\"\>", "\<\"377\"\>", "\<\"378\"\>", \
"\<\"381\"\>", "\<\"382\"\>", "\<\"380\"\>", "\<\"384\"\>", "\<\"357\"\>", \
"\<\"358\"\>", "\<\"359\"\>", "\<\"360\"\>", "\<\"257\"\>", "\<\"258\"\>", \
"\<\"259\"\>", "\<\"260\"\>", "\<\"409\"\>", "\<\"410\"\>", "\<\"413\"\>", \
"\<\"414\"\>", "\<\"411\"\>", "\<\"412\"\>", "\<\"415\"\>", "\<\"416\"\>", \
"\<\"389\"\>", "\<\"390\"\>", "\<\"275\"\>", "\<\"276\"\>", "\<\"391\"\>", \
"\<\"392\"\>", "\<\"279\"\>", "\<\"280\"\>", "\<\"289\"\>", "\<\"290\"\>", \
"\<\"291\"\>", "\<\"292\"\>", "\<\"441\"\>", "\<\"442\"\>", "\<\"445\"\>", \
"\<\"446\"\>", "\<\"443\"\>", "\<\"365\"\>", "\<\"447\"\>", "\<\"367\"\>", \
"\<\"421\"\>", "\<\"422\"\>", "\<\"307\"\>", "\<\"308\"\>", "\<\"423\"\>", \
"\<\"424\"\>", "\<\"311\"\>", "\<\"312\"\>", "\<\"321\"\>", "\<\"322\"\>", \
"\<\"323\"\>", "\<\"324\"\>", "\<\"473\"\>", "\<\"474\"\>", "\<\"477\"\>", \
"\<\"478\"\>", "\<\"475\"\>", "\<\"476\"\>", "\<\"479\"\>", "\<\"480\"\>", \
"\<\"453\"\>", "\<\"454\"\>", "\<\"455\"\>", "\<\"456\"\>", "\<\"353\"\>", \
"\<\"354\"\>", "\<\"355\"\>", "\<\"356\"\>", "\<\"505\"\>", "\<\"506\"\>", \
"\<\"509\"\>", "\<\"510\"\>", "\<\"444\"\>", "\<\"508\"\>", "\<\"448\"\>", \
"\<\"512\"\>", "\<\"485\"\>", "\<\"486\"\>", "\<\"371\"\>", "\<\"372\"\>", \
"\<\"487\"\>", "\<\"488\"\>", "\<\"375\"\>", "\<\"376\"\>"},
       {"\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", \
"\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\
\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>"},
       {"\<\"9\"\>", "\<\"10\"\>", "\<\"11\"\>", "\<\"12\"\>", "\<\"13\"\>", \
"\<\"14\"\>", "\<\"15\"\>", "\<\"16\"\>", "\<\"17\"\>", "\<\"18\"\>", "\<\"21\
\"\>", "\<\"22\"\>", "\<\"41\"\>", "\<\"42\"\>", "\<\"43\"\>", "\<\"44\"\>", \
"\<\"45\"\>", "\<\"46\"\>", "\<\"47\"\>", "\<\"48\"\>", "\<\"49\"\>", "\<\"50\
\"\>", "\<\"53\"\>", "\<\"54\"\>", "\<\"73\"\>", "\<\"74\"\>", "\<\"75\"\>", \
"\<\"76\"\>", "\<\"77\"\>", "\<\"78\"\>", "\<\"79\"\>", "\<\"80\"\>", "\<\"81\
\"\>", "\<\"82\"\>", "\<\"85\"\>", "\<\"86\"\>", "\<\"105\"\>", \
"\<\"106\"\>", "\<\"107\"\>", "\<\"108\"\>", "\<\"109\"\>", "\<\"110\"\>", \
"\<\"111\"\>", "\<\"112\"\>", "\<\"113\"\>", "\<\"114\"\>", "\<\"117\"\>", \
"\<\"118\"\>", "\<\"137\"\>", "\<\"138\"\>", "\<\"139\"\>", "\<\"140\"\>", \
"\<\"141\"\>", "\<\"142\"\>", "\<\"143\"\>", "\<\"144\"\>", "\<\"145\"\>", \
"\<\"146\"\>", "\<\"147\"\>", "\<\"148\"\>", "\<\"149\"\>", "\<\"150\"\>", \
"\<\"169\"\>", "\<\"170\"\>", "\<\"171\"\>", "\<\"172\"\>", "\<\"174\"\>", \
"\<\"176\"\>", "\<\"177\"\>", "\<\"178\"\>", "\<\"181\"\>", "\<\"182\"\>", \
"\<\"193\"\>", "\<\"194\"\>", "\<\"195\"\>", "\<\"196\"\>", "\<\"201\"\>", \
"\<\"202\"\>", "\<\"203\"\>", "\<\"204\"\>", "\<\"205\"\>", "\<\"206\"\>", \
"\<\"207\"\>", "\<\"208\"\>", "\<\"209\"\>", "\<\"210\"\>", "\<\"211\"\>", \
"\<\"212\"\>", "\<\"213\"\>", "\<\"214\"\>", "\<\"215\"\>", "\<\"216\"\>", \
"\<\"225\"\>", "\<\"226\"\>", "\<\"227\"\>", "\<\"228\"\>", "\<\"233\"\>", \
"\<\"234\"\>", "\<\"235\"\>", "\<\"236\"\>", "\<\"237\"\>", "\<\"238\"\>", \
"\<\"239\"\>", "\<\"240\"\>", "\<\"241\"\>", "\<\"242\"\>", "\<\"243\"\>", \
"\<\"244\"\>", "\<\"245\"\>", "\<\"246\"\>", "\<\"247\"\>", "\<\"248\"\>", \
"\<\"265\"\>", "\<\"266\"\>", "\<\"267\"\>", "\<\"268\"\>", "\<\"269\"\>", \
"\<\"270\"\>", "\<\"271\"\>", "\<\"272\"\>", "\<\"273\"\>", "\<\"274\"\>", \
"\<\"277\"\>", "\<\"278\"\>", "\<\"297\"\>", "\<\"298\"\>", "\<\"299\"\>", \
"\<\"300\"\>", "\<\"301\"\>", "\<\"302\"\>", "\<\"303\"\>", "\<\"304\"\>", \
"\<\"305\"\>", "\<\"306\"\>", "\<\"309\"\>", "\<\"310\"\>", "\<\"329\"\>", \
"\<\"330\"\>", "\<\"331\"\>", "\<\"332\"\>", "\<\"333\"\>", "\<\"334\"\>", \
"\<\"335\"\>", "\<\"336\"\>", "\<\"337\"\>", "\<\"338\"\>", "\<\"339\"\>", \
"\<\"340\"\>", "\<\"341\"\>", "\<\"342\"\>", "\<\"361\"\>", "\<\"362\"\>", \
"\<\"363\"\>", "\<\"364\"\>", "\<\"366\"\>", "\<\"368\"\>", "\<\"369\"\>", \
"\<\"370\"\>", "\<\"373\"\>", "\<\"374\"\>", "\<\"385\"\>", "\<\"386\"\>", \
"\<\"387\"\>", "\<\"388\"\>", "\<\"393\"\>", "\<\"394\"\>", "\<\"395\"\>", \
"\<\"396\"\>", "\<\"397\"\>", "\<\"398\"\>", "\<\"399\"\>", "\<\"400\"\>", \
"\<\"401\"\>", "\<\"402\"\>", "\<\"403\"\>", "\<\"404\"\>", "\<\"405\"\>", \
"\<\"406\"\>", "\<\"407\"\>", "\<\"408\"\>", "\<\"417\"\>", "\<\"418\"\>", \
"\<\"419\"\>", "\<\"420\"\>", "\<\"425\"\>", "\<\"426\"\>", "\<\"427\"\>", \
"\<\"428\"\>", "\<\"429\"\>", "\<\"430\"\>", "\<\"431\"\>", "\<\"432\"\>", \
"\<\"433\"\>", "\<\"434\"\>", "\<\"435\"\>", "\<\"436\"\>", "\<\"437\"\>", \
"\<\"438\"\>", "\<\"439\"\>", "\<\"440\"\>", "\<\"449\"\>", "\<\"450\"\>", \
"\<\"451\"\>", "\<\"452\"\>", "\<\"457\"\>", "\<\"458\"\>", "\<\"459\"\>", \
"\<\"460\"\>", "\<\"461\"\>", "\<\"462\"\>", "\<\"463\"\>", "\<\"464\"\>", \
"\<\"465\"\>", "\<\"466\"\>", "\<\"469\"\>", "\<\"470\"\>", "\<\"481\"\>", \
"\<\"482\"\>", "\<\"483\"\>", "\<\"484\"\>", "\<\"489\"\>", "\<\"490\"\>", \
"\<\"491\"\>", "\<\"492\"\>", "\<\"493\"\>", "\<\"494\"\>", "\<\"495\"\>", \
"\<\"496\"\>", "\<\"497\"\>", "\<\"498\"\>", "\<\"499\"\>", "\<\"500\"\>", \
"\<\"501\"\>", "\<\"502\"\>", "\<\"503\"\>", "\<\"504\"\>"},
       {"\<\"(9)\"\>", "\<\"(9)\"\>", "\<\"(9)\"\>", "\<\"(9)\"\>", \
"\<\"(9)\"\>", "\<\"(9)\"\>", "\<\"(9)\"\>", "\<\"(9)\"\>", "\<\"(9)\"\>", \
"\<\"(8)\"\>", "\<\"(9)\"\>", "\<\"(8)\"\>", "\<\"(17)\"\>", "\<\"(17)\"\>", \
"\<\"(17)\"\>", "\<\"(17)\"\>", "\<\"(17)\"\>", "\<\"(17)\"\>", \
"\<\"(17)\"\>", "\<\"(17)\"\>", "\<\"(17)\"\>", "\<\"(16)\"\>", \
"\<\"(17)\"\>", "\<\"(16)\"\>", "\<\"(25)\"\>", "\<\"(25)\"\>", \
"\<\"(25)\"\>", "\<\"(25)\"\>", "\<\"(25)\"\>", "\<\"(25)\"\>", \
"\<\"(25)\"\>", "\<\"(25)\"\>", "\<\"(25)\"\>", "\<\"(24)\"\>", \
"\<\"(25)\"\>", "\<\"(24)\"\>", "\<\"(33)\"\>", "\<\"(33)\"\>", \
"\<\"(33)\"\>", "\<\"(33)\"\>", "\<\"(33)\"\>", "\<\"(33)\"\>", \
"\<\"(33)\"\>", "\<\"(33)\"\>", "\<\"(33)\"\>", "\<\"(32)\"\>", \
"\<\"(33)\"\>", "\<\"(32)\"\>", "\<\"(41)\"\>", "\<\"(41)\"\>", \
"\<\"(41)\"\>", "\<\"(41)\"\>", "\<\"(41)\"\>", "\<\"(41)\"\>", \
"\<\"(41)\"\>", "\<\"(41)\"\>", "\<\"(41)\"\>", "\<\"(40)\"\>", \
"\<\"(39)\"\>", "\<\"(39)\"\>", "\<\"(39)\"\>", "\<\"(38)\"\>", \
"\<\"(47)\"\>", "\<\"(47)\"\>", "\<\"(47)\"\>", "\<\"(47)\"\>", \
"\<\"(48)\"\>", "\<\"(49)\"\>", "\<\"(49)\"\>", "\<\"(48)\"\>", \
"\<\"(49)\"\>", "\<\"(48)\"\>", "\<\"(49)\"\>", "\<\"(48)\"\>", \
"\<\"(47)\"\>", "\<\"(46)\"\>", "\<\"(49)\"\>", "\<\"(49)\"\>", \
"\<\"(49)\"\>", "\<\"(49)\"\>", "\<\"(49)\"\>", "\<\"(49)\"\>", \
"\<\"(49)\"\>", "\<\"(49)\"\>", "\<\"(49)\"\>", "\<\"(48)\"\>", \
"\<\"(47)\"\>", "\<\"(46)\"\>", "\<\"(45)\"\>", "\<\"(44)\"\>", \
"\<\"(43)\"\>", "\<\"(42)\"\>", "\<\"(41)\"\>", "\<\"(40)\"\>", \
"\<\"(39)\"\>", "\<\"(38)\"\>", "\<\"(41)\"\>", "\<\"(41)\"\>", \
"\<\"(41)\"\>", "\<\"(41)\"\>", "\<\"(41)\"\>", "\<\"(41)\"\>", \
"\<\"(40)\"\>", "\<\"(40)\"\>", "\<\"(39)\"\>", "\<\"(38)\"\>", \
"\<\"(37)\"\>", "\<\"(36)\"\>", "\<\"(35)\"\>", "\<\"(34)\"\>", \
"\<\"(33)\"\>", "\<\"(32)\"\>", "\<\"(41)\"\>", "\<\"(41)\"\>", \
"\<\"(41)\"\>", "\<\"(41)\"\>", "\<\"(41)\"\>", "\<\"(41)\"\>", \
"\<\"(41)\"\>", "\<\"(41)\"\>", "\<\"(41)\"\>", "\<\"(40)\"\>", \
"\<\"(41)\"\>", "\<\"(40)\"\>", "\<\"(49)\"\>", "\<\"(49)\"\>", \
"\<\"(49)\"\>", "\<\"(49)\"\>", "\<\"(49)\"\>", "\<\"(49)\"\>", \
"\<\"(49)\"\>", "\<\"(49)\"\>", "\<\"(49)\"\>", "\<\"(48)\"\>", \
"\<\"(49)\"\>", "\<\"(48)\"\>", "\<\"(57)\"\>", "\<\"(57)\"\>", \
"\<\"(57)\"\>", "\<\"(57)\"\>", "\<\"(57)\"\>", "\<\"(57)\"\>", \
"\<\"(57)\"\>", "\<\"(57)\"\>", "\<\"(57)\"\>", "\<\"(56)\"\>", \
"\<\"(55)\"\>", "\<\"(55)\"\>", "\<\"(55)\"\>", "\<\"(54)\"\>", \
"\<\"(63)\"\>", "\<\"(63)\"\>", "\<\"(63)\"\>", "\<\"(63)\"\>", \
"\<\"(64)\"\>", "\<\"(65)\"\>", "\<\"(65)\"\>", "\<\"(64)\"\>", \
"\<\"(65)\"\>", "\<\"(64)\"\>", "\<\"(65)\"\>", "\<\"(64)\"\>", \
"\<\"(63)\"\>", "\<\"(62)\"\>", "\<\"(65)\"\>", "\<\"(65)\"\>", \
"\<\"(65)\"\>", "\<\"(65)\"\>", "\<\"(65)\"\>", "\<\"(65)\"\>", \
"\<\"(65)\"\>", "\<\"(65)\"\>", "\<\"(65)\"\>", "\<\"(64)\"\>", \
"\<\"(63)\"\>", "\<\"(62)\"\>", "\<\"(61)\"\>", "\<\"(60)\"\>", \
"\<\"(59)\"\>", "\<\"(58)\"\>", "\<\"(57)\"\>", "\<\"(56)\"\>", \
"\<\"(55)\"\>", "\<\"(54)\"\>", "\<\"(57)\"\>", "\<\"(57)\"\>", \
"\<\"(57)\"\>", "\<\"(57)\"\>", "\<\"(57)\"\>", "\<\"(57)\"\>", \
"\<\"(56)\"\>", "\<\"(56)\"\>", "\<\"(55)\"\>", "\<\"(54)\"\>", \
"\<\"(53)\"\>", "\<\"(52)\"\>", "\<\"(51)\"\>", "\<\"(50)\"\>", \
"\<\"(49)\"\>", "\<\"(48)\"\>", "\<\"(49)\"\>", "\<\"(48)\"\>", \
"\<\"(47)\"\>", "\<\"(46)\"\>", "\<\"(49)\"\>", "\<\"(49)\"\>", \
"\<\"(49)\"\>", "\<\"(49)\"\>", "\<\"(49)\"\>", "\<\"(49)\"\>", \
"\<\"(49)\"\>", "\<\"(49)\"\>", "\<\"(49)\"\>", "\<\"(48)\"\>", \
"\<\"(49)\"\>", "\<\"(48)\"\>", "\<\"(49)\"\>", "\<\"(48)\"\>", \
"\<\"(47)\"\>", "\<\"(46)\"\>", "\<\"(49)\"\>", "\<\"(49)\"\>", \
"\<\"(49)\"\>", "\<\"(49)\"\>", "\<\"(49)\"\>", "\<\"(48)\"\>", \
"\<\"(48)\"\>", "\<\"(47)\"\>", "\<\"(47)\"\>", "\<\"(46)\"\>", \
"\<\"(45)\"\>", "\<\"(44)\"\>", "\<\"(43)\"\>", "\<\"(42)\"\>", \
"\<\"(41)\"\>", "\<\"(40)\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["The cancelled generators were ", 
   MatrixForm[{{
     "(25)", "(24)", "(25)", "(24)", "(21)", "(20)", "(19)", "(18)", "(5)", 
      "(5)", "(5)", "(5)", "(33)", "(32)", "(33)", "(32)", "(29)", "(28)", 
      "(27)", "(26)", "(13)", "(13)", "(13)", "(13)", "(41)", "(40)", "(41)", 
      "(40)", "(37)", "(36)", "(35)", "(34)", "(21)", "(21)", "(21)", "(21)", 
      "(49)", "(48)", "(49)", "(48)", "(45)", "(44)", "(43)", "(42)", "(29)", 
      "(29)", "(29)", "(29)", "(57)", "(56)", "(57)", "(56)", "(53)", "(52)", 
      "(51)", "(50)", "(37)", "(37)", "(75)", "(70)", "(37)", "(37)", "(63)", 
      "(62)", "(62)", "(61)", "(59)", "(58)", "(43)", "(43)", "(43)", "(43)", 
      "(17)", "(17)", "(17)", "(17)", "(65)", "(64)", "(65)", "(64)", "(61)", 
      "(60)", "(59)", "(58)", "(45)", "(45)", "(17)", "(17)", "(43)", "(43)", 
      "(17)", "(17)", "(17)", "(17)", "(17)", "(17)", "(57)", "(56)", "(57)", 
      "(56)", "(53)", "(31)", "(51)", "(31)", "(35)", "(35)", "(17)", "(17)", 
      "(33)", "(33)", "(17)", "(17)", "(57)", "(56)", "(57)", "(56)", "(53)", 
      "(52)", "(51)", "(50)", "(37)", "(37)", "(37)", "(37)", "(65)", "(64)", 
      "(65)", "(64)", "(61)", "(60)", "(59)", "(58)", "(45)", "(45)", "(45)", 
      "(45)", "(73)", "(72)", "(73)", "(72)", "(69)", "(68)", "(67)", "(66)", 
      "(53)", "(53)", "(91)", "(86)", "(53)", "(53)", "(79)", "(78)", "(78)", 
      "(77)", "(75)", "(74)", "(59)", "(59)", "(59)", "(59)", "(33)", "(33)", 
      "(33)", "(33)", "(81)", "(80)", "(81)", "(80)", "(77)", "(76)", "(75)", 
      "(74)", "(61)", "(61)", "(33)", "(33)", "(59)", "(59)", "(33)", "(33)", 
      "(33)", "(33)", "(33)", "(33)", "(73)", "(72)", "(73)", "(72)", "(69)", 
      "(47)", "(67)", "(47)", "(51)", "(51)", "(33)", "(33)", "(49)", "(49)", 
      "(33)", "(33)", "(33)", "(33)", "(33)", "(33)", "(65)", "(64)", "(65)", 
      "(64)", "(61)", "(60)", "(59)", "(58)", "(45)", "(45)", "(45)", "(45)", 
      "(35)", "(35)", "(35)", "(35)", "(65)", "(64)", "(65)", "(64)", "(39)", 
      "(60)", "(39)", "(58)", "(43)", "(43)", "(35)", "(35)", "(41)", "(41)", 
      "(35)", "(35)"}, {
     "25", "26", "29", "30", "27", "28", "31", "32", "5", "6", "7", "8", "57",
       "58", "61", "62", "59", "60", "63", "64", "37", "38", "39", "40", "89",
       "90", "93", "94", "91", "92", "95", "96", "69", "70", "71", "72", 
      "121", "122", "125", "126", "123", "124", "127", "128", "101", "102", 
      "103", "104", "153", "154", "157", "158", "155", "156", "159", "160", 
      "133", "134", "191", "187", "135", "136", "185", "186", "189", "190", 
      "188", "192", "165", "166", "167", "168", "65", "66", "67", "68", "217",
       "218", "221", "222", "219", "220", "223", "224", "197", "198", "83", 
      "84", "199", "200", "87", "88", "97", "98", "99", "100", "249", "250", 
      "253", "254", "251", "173", "255", "175", "229", "230", "115", "116", 
      "231", "232", "119", "120", "281", "282", "285", "286", "283", "284", 
      "287", "288", "261", "262", "263", "264", "313", "314", "317", "318", 
      "315", "316", "319", "320", "293", "294", "295", "296", "345", "346", 
      "349", "350", "347", "348", "351", "352", "325", "326", "383", "379", 
      "327", "328", "377", "378", "381", "382", "380", "384", "357", "358", 
      "359", "360", "257", "258", "259", "260", "409", "410", "413", "414", 
      "411", "412", "415", "416", "389", "390", "275", "276", "391", "392", 
      "279", "280", "289", "290", "291", "292", "441", "442", "445", "446", 
      "443", "365", "447", "367", "421", "422", "307", "308", "423", "424", 
      "311", "312", "321", "322", "323", "324", "473", "474", "477", "478", 
      "475", "476", "479", "480", "453", "454", "455", "456", "353", "354", 
      "355", "356", "505", "506", "509", "510", "444", "508", "448", "512", 
      "485", "486", "371", "372", "487", "488", "375", "376"}, {
     "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", 
      "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]"}, {
     "9", "10", "11", "12", "13", "14", "15", "16", "17", "18", "21", "22", 
      "41", "42", "43", "44", "45", "46", "47", "48", "49", "50", "53", "54", 
      "73", "74", "75", "76", "77", "78", "79", "80", "81", "82", "85", "86", 
      "105", "106", "107", "108", "109", "110", "111", "112", "113", "114", 
      "117", "118", "137", "138", "139", "140", "141", "142", "143", "144", 
      "145", "146", "147", "148", "149", "150", "169", "170", "171", "172", 
      "174", "176", "177", "178", "181", "182", "193", "194", "195", "196", 
      "201", "202", "203", "204", "205", "206", "207", "208", "209", "210", 
      "211", "212", "213", "214", "215", "216", "225", "226", "227", "228", 
      "233", "234", "235", "236", "237", "238", "239", "240", "241", "242", 
      "243", "244", "245", "246", "247", "248", "265", "266", "267", "268", 
      "269", "270", "271", "272", "273", "274", "277", "278", "297", "298", 
      "299", "300", "301", "302", "303", "304", "305", "306", "309", "310", 
      "329", "330", "331", "332", "333", "334", "335", "336", "337", "338", 
      "339", "340", "341", "342", "361", "362", "363", "364", "366", "368", 
      "369", "370", "373", "374", "385", "386", "387", "388", "393", "394", 
      "395", "396", "397", "398", "399", "400", "401", "402", "403", "404", 
      "405", "406", "407", "408", "417", "418", "419", "420", "425", "426", 
      "427", "428", "429", "430", "431", "432", "433", "434", "435", "436", 
      "437", "438", "439", "440", "449", "450", "451", "452", "457", "458", 
      "459", "460", "461", "462", "463", "464", "465", "466", "469", "470", 
      "481", "482", "483", "484", "489", "490", "491", "492", "493", "494", 
      "495", "496", "497", "498", "499", "500", "501", "502", "503", "504"}, {
     "(9)", "(9)", "(9)", "(9)", "(9)", "(9)", "(9)", "(9)", "(9)", "(8)", 
      "(9)", "(8)", "(17)", "(17)", "(17)", "(17)", "(17)", "(17)", "(17)", 
      "(17)", "(17)", "(16)", "(17)", "(16)", "(25)", "(25)", "(25)", "(25)", 
      "(25)", "(25)", "(25)", "(25)", "(25)", "(24)", "(25)", "(24)", "(33)", 
      "(33)", "(33)", "(33)", "(33)", "(33)", "(33)", "(33)", "(33)", "(32)", 
      "(33)", "(32)", "(41)", "(41)", "(41)", "(41)", "(41)", "(41)", "(41)", 
      "(41)", "(41)", "(40)", "(39)", "(39)", "(39)", "(38)", "(47)", "(47)", 
      "(47)", "(47)", "(48)", "(49)", "(49)", "(48)", "(49)", "(48)", "(49)", 
      "(48)", "(47)", "(46)", "(49)", "(49)", "(49)", "(49)", "(49)", "(49)", 
      "(49)", "(49)", "(49)", "(48)", "(47)", "(46)", "(45)", "(44)", "(43)", 
      "(42)", "(41)", "(40)", "(39)", "(38)", "(41)", "(41)", "(41)", "(41)", 
      "(41)", "(41)", "(40)", "(40)", "(39)", "(38)", "(37)", "(36)", "(35)", 
      "(34)", "(33)", "(32)", "(41)", "(41)", "(41)", "(41)", "(41)", "(41)", 
      "(41)", "(41)", "(41)", "(40)", "(41)", "(40)", "(49)", "(49)", "(49)", 
      "(49)", "(49)", "(49)", "(49)", "(49)", "(49)", "(48)", "(49)", "(48)", 
      "(57)", "(57)", "(57)", "(57)", "(57)", "(57)", "(57)", "(57)", "(57)", 
      "(56)", "(55)", "(55)", "(55)", "(54)", "(63)", "(63)", "(63)", "(63)", 
      "(64)", "(65)", "(65)", "(64)", "(65)", "(64)", "(65)", "(64)", "(63)", 
      "(62)", "(65)", "(65)", "(65)", "(65)", "(65)", "(65)", "(65)", "(65)", 
      "(65)", "(64)", "(63)", "(62)", "(61)", "(60)", "(59)", "(58)", "(57)", 
      "(56)", "(55)", "(54)", "(57)", "(57)", "(57)", "(57)", "(57)", "(57)", 
      "(56)", "(56)", "(55)", "(54)", "(53)", "(52)", "(51)", "(50)", "(49)", 
      "(48)", "(49)", "(48)", "(47)", "(46)", "(49)", "(49)", "(49)", "(49)", 
      "(49)", "(49)", "(49)", "(49)", "(49)", "(48)", "(49)", "(48)", "(49)", 
      "(48)", "(47)", "(46)", "(49)", "(49)", "(49)", "(49)", "(49)", "(48)", 
      "(48)", "(47)", "(47)", "(46)", "(45)", "(44)", "(43)", "(42)", "(41)", 
      "(40)"}}]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.676175630167898*^9, 3.6761756432051477`*^9}, 
   3.676177633238863*^9, 3.676181718282309*^9, 3.676181805218286*^9, 
   3.676181851823415*^9, 3.676182006495245*^9, 3.676182181420231*^9, 
   3.676221922288815*^9, 3.6762219998584948`*^9, 3.676259911566552*^9, 
   3.676347690195682*^9, 3.676365991397257*^9, 3.6763879252666597`*^9, 
   3.676392629800563*^9, 3.676440169293993*^9, 3.676473474391552*^9, 
   3.677558391444075*^9, 3.67755939315864*^9, 3.677561474804204*^9, {
   3.678365630463592*^9, 3.678365643154956*^9}, 3.678438841809287*^9, 
   3.67910106886849*^9, 3.679101233304977*^9, {3.679228828213192*^9, 
   3.679228845187958*^9}, 3.6792292430359297`*^9, 3.679235213978156*^9, 
   3.679373465879586*^9, 3.679379276205572*^9, 3.679379653711396*^9, 
   3.679381175254533*^9, 3.679381220446678*^9, {3.679381278310419*^9, 
   3.679381286237536*^9}, 3.679381363721024*^9, 3.679382113895825*^9, 
   3.6793821789474087`*^9, {3.679382351073333*^9, 3.6793823563180857`*^9}, 
   3.679382428774447*^9, 3.6839008031636467`*^9, 3.683906842872005*^9, {
   3.683907938656304*^9, 3.683907945517867*^9}, 3.6839496031815987`*^9, 
   3.683949916694581*^9, 3.683952428309697*^9, 3.6839589662501383`*^9, 
   3.684043336180006*^9, 3.684043390906584*^9, 3.685196556483519*^9, 
   3.685257710349473*^9, 3.6852591238576803`*^9, 3.685706310640483*^9, 
   3.685711829094784*^9, 3.6857123501278343`*^9, 3.685712563375325*^9, 
   3.686024747038598*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"PlotGraph", "[", "MM1", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"GenTableWithIdems", "[", "GG1", "]"}]}], "Input",
 CellChangeTimes->{{3.6761773820432796`*^9, 3.676177384954527*^9}, 
   3.676177617306233*^9, 3.6761786321171417`*^9, {3.6839495373610287`*^9, 
   3.683949538281969*^9}, {3.6844681249806423`*^9, 3.6844681295966263`*^9}}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJztnEFKBEEMRQc8iTtv0XcQvIDg2qVn0avoVXQnIiJ4BGkVxJ5JQ8ak83/q
FwwlbzGdStWvVCXtnF5en1+d7Ha7s5/P/Pff9jHtIXHxFf70OLf3admj2Wlx
Fvsf7uf2Ni17NDvFa7l3Pd/dzu11WvZV9kfxKl1Lp5icZZ9n4ZY/o/ycPV+j
6ZR9/XeNU9k8W4/S6ZicfT9B49n+RNNp1X4SxVnstLji6XGcfd6jdOp9Lrvf
xLfh3nXS9XzYdVzi4p3ignQqjqwX9ntlFGfXKYufR+NV9dao/AmaLtDs8XLp
FJNH6SVbv1HjzebsOrU4+7xYnH1cUesN7fyczbvq1MvZ5xGNV/kzW79V5+fs
+il7vQ9Nv2j2eLniwnfL1rvqp9twdv9Ij8fxi6/2PC17y59V53/29Skurn1v
HM6+X3VdV9nxyxtPrXul9VxvXPZ+v9XffLWXvT57vqI4ux7Ft+FV91NxcUbO
ku8djWtfEkdYV9LpOh9Np1HvEVVx7z0Ozf7sfO//+G/rmjce7f0Z8ViOFk+1
Pmu54mmt/d54auVRo/K3h+3F+z23qjiYnT+P8pv4Nhwt36t1JS6+z9HOveLi
CBwtH+s990Y918sVZ9e5/NObo517xcUZuTf/ZuUTLD1G5ZEOj6POb105+z7J
bn8Vz46nXeel67jEMXlVHknvM2xjj3gPnh1Pvd/PUo+WHsU76TTbTjS9oNkj
3oOz10+lC3GEdcVePx3t/SXLHvb9MIp76xRo9ldxlnMviz3iY/LR6qfe8Uqn
XJwlz2Dxqv93YK+fsswvGtc5nIurflrL0fSieyImZ6+fosVrln0DbX8QX+cs
eST2ew1LHljxlIt/AnfzMrw=
   "], {{0, 0}, {40, 40}}, {0, 1}],
  Frame->Automatic,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
    Automatic}]], "Print",
 CellChangeTimes->{
  3.686024754651967*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztnb1u4kAUhY2ilezSdFChpKRMStLBbpU2ZVYo4q9YgbIptqVMu2UegVdA
+waIN0D7BrwCOx7b547H3s0EaYNtDlLQtT33OyMxP9d3xs7d8Hk6+jZ8nj0O
O1+ehovp7PF75/P8SZ26aHheY6r+Jh0vsg+eh6+LQ/QZj8fRn6et2PSMS+rj
6YNR9NWo5fVP0fdWlfP8w36/v4V1E1u73c6nN70N71/wCWJrs9kMIiuIzl3G
luboq4QRdhRsCdgissLICgFro72GhBFWFljPHlpVD5gAFkKgjb7QIpbYk2Pn
QCwg0Ma5FmABBJzGcGKJrSK2C1gvRmR6WQ9zQpDteX4sQDbZ5WbnAnXFGaCz
XLt0ESKIcEouKMceHc/H8RXjUZCdkiXPFBgwh9GKRBKPJ76A6GMelfskGee6
WbZ4UIACFHhbYAmYJWAFrANiiS0RNpdSS5O91jTUQ8e4d558yCa7zmzJv10W
EHOWYjdhSU5O92T3iI6iFKVo+UVzGczM0BLgnI8qybDUj8tRgAKVF2ihuAhM
YsfVapWsT0lUSwEKUOAYgS3mrCWLf2Bxv+CH7eNcLrpIf2y9eSUpog/TECMJ
NtbrtXuwwTqwDqwD6/DG0nZ6P6N9nAY3OtbDMbf+IWkwZT3gqtMuB8IIc13B
VoivaKrHbaEgggj1keVaeVxLT4jXMVsmzj12TSiSdSsl+Y4A55w2iVOe8pQ/
gfwr5iJBOMU8dKyHY4joIyhoeklzVLdDSQyT3jZJIzSfvcy0v9Boz+ntlW9c
YL1YL9aL9apnvV4MbEqU3cY/iThTxBKtasvi5S2eyyErx7bx66sRpYsi70zj
kE32qdlzY8ZMxy+njkHHejjqxtVEUBTagZLy+oEm9c7HNcgmu87sB2MQtoZo
ZQ1gOSVgCCPsL7B7TPtXcCzK+RJGWGlgdwU9QNa+k76gRuQbYJ3um4kl9r9i
+zZCOV6hY1g9gUQSK0eUx5jl5bxO94p0LJWjrFMUpYSagMnb6sztAbvsI0jp
cglFKUrR6ot2jSki9ZYs8W8iiDgWkbwfRbXEJlqxZNN0e24hGAkQpSSr8enq
OVWoch4q1juCzekgM+pP0DWdEizEEltFrOynkiyjBEHy+F4yU6leRiyxp8dK
bjG3pJPJN1o7762lH9nd75SroShFKVoF0X8laGUJwhp4yCb7nNn6YFTO69Gx
tpL/26kvzLSb5zX+AFPVv48=\
\>"]],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"{", 
       RowBox[{"\<\"c\"\>", ",", "\<\"d\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "2", ",", "3", ",", "4", ",", "9", ",", "10", ",", "11", ",",
         "12"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"c\"\>", ",", "\<\"a\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
       "5", ",", "6", ",", "7", ",", "8", ",", "13", ",", "14", ",", "15", 
        ",", "16"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"b\"\>", ",", "\<\"d\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
       "17", ",", "18", ",", "19", ",", "20", ",", "23", ",", "24", ",", "25",
         ",", "26"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"b\"\>", ",", "\<\"a\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
       "21", ",", "22", ",", "27", ",", "28", ",", "29", ",", "30", ",", "31",
         ",", "32"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"a\"\>", ",", "\<\"a\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
       "33", ",", "34", ",", "35", ",", "36", ",", "37", ",", "38", ",", "39",
         ",", "40"}], "}"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.686024754688843*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"AutoCleanPosns1", "=", 
   RowBox[{"AutoCleanPosns", "[", 
    RowBox[{"MM1", ",", "GG1", ",", 
     RowBox[{"Tuples", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", "40", "]"}], ",", 
        RowBox[{"Range", "[", "40", "]"}]}], "}"}], "]"}], ",", "500"}], 
    "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MM2", "=", 
   RowBox[{"AutoCleanPosns1", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.682250039879294*^9, 3.682250091659306*^9}, {
   3.682252329155525*^9, 3.68225233261656*^9}, {3.682252461204122*^9, 
   3.682252470417461*^9}, {3.6822525099974813`*^9, 3.682252510323305*^9}, {
   3.682255524595436*^9, 3.6822555533050537`*^9}, {3.682255620829262*^9, 
   3.682255626844368*^9}, {3.684468172438231*^9, 3.684468187862464*^9}, {
   3.684468231355555*^9, 3.6844682341273203`*^9}, 3.686024700352448*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 TemplateBox[{RowBox[{"\"Fri 21 Oct 2016 09:22:18\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", "1.`"}], FontColor -> 
      GrayLevel[0.5]]}],RowBox[{"DateObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"2016", ",", "10", ",", "21"}], "}"}], ",", 
       RowBox[{"TimeObject", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"9", ",", "22", ",", "18.115548`"}], "}"}], ",", 
           RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}], ",", 
       RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}]},
  "DateObject",
  Editable->False]], "Print",
 CellChangeTimes->{3.686024764301235*^9, 3.686026938138084*^9}],

Cell[BoxData["\<\"Aborted after iteration 267\"\>"], "Print",
 CellChangeTimes->{3.686024764301235*^9, 3.686027678739304*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"I increased complexity \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\" times.\"\>"}],
  SequenceForm["I increased complexity ", 0, " times."],
  Editable->False]], "Print",
 CellChangeTimes->{3.686024764301235*^9, 3.6860276787977324`*^9}],

Cell[BoxData[
 TemplateBox[{RowBox[{"\"Fri 21 Oct 2016 09:34:38\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", "1.`"}], FontColor -> 
      GrayLevel[0.5]]}],RowBox[{"DateObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"2016", ",", "10", ",", "21"}], "}"}], ",", 
       RowBox[{"TimeObject", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{"9", ",", "34", ",", "38.795308`"}], "}"}], ",", 
           RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}], ",", 
       RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}]},
  "DateObject",
  Editable->False]], "Print",
 CellChangeTimes->{3.686024764301235*^9, 3.686027678800138*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "list", " ", "of", " ", "homotopies", " ", "from", " ", "previous", " ", 
    "step"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"AutoCleanPosns1", "[", 
     RowBox[{"[", "2", "]"}], "]"}], "}"}], "//", "MatrixForm"}]}]], "Input",
 CellChangeTimes->{{3.686024847313023*^9, 3.6860248691688843`*^9}, {
  3.6860249789877377`*^9, 3.6860249868198767`*^9}, {3.686025581289081*^9, 
  3.686025763473337*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "82"}], "}"}]}], "}"}], ",", "29", ",", "24"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "345", "}"}], ",", "4"}], "}"}], ",", "35", ",", 
        "29"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "224", "}"}], ",", "4"}], "}"}], ",", "31", ",", "5"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "253", ",", "373"}], "}"}]}], "}"}], ",", "16",
         ",", "13"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", "88", "}"}]}], "}"}], ",", "29", ",", "18"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", "88", "}"}]}], "}"}], ",", "14", ",", "10"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "224", "}"}], ",", "1"}], "}"}], ",", "17", ",", "1"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "224", "}"}], ",", "1"}], "}"}], ",", "19", ",", "3"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", "88", "}"}]}], "}"}], ",", "27", ",", "24"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", "33", "}"}]}], "}"}], ",", "25", ",", "23"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "345", "}"}], ",", "4"}], "}"}], ",", "37", ",", 
        "21"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "82"}], "}"}]}], "}"}], ",", "21", ",", "18"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"397", ",", "93"}], "}"}]}], "}"}], ",", "29", ",", "18"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "224", "}"}], ",", "1"}], "}"}], ",", "23", ",", "2"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "349", "}"}], ",", "4"}], "}"}], ",", "14", ",", 
        "39"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "250", "}"}], ",", "4"}], "}"}], ",", "34", ",", "7"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "250", "}"}], ",", "4"}], "}"}], ",", "39", ",", "5"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "345", "}"}], ",", "4"}], "}"}], ",", "35", ",", 
        "32"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", "88", "}"}]}], "}"}], ",", "16", ",", "9"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"362", ",", "250"}], "}"}], ",", "1"}], "}"}], ",", "25", 
        ",", "3"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", "1"}], "}"}], ",", "11", ",", "1"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "224", "}"}], ",", "4"}], "}"}], ",", "22", ",", "7"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", "33", "}"}]}], "}"}], ",", "20", ",", "18"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "224", "}"}], ",", 
          RowBox[{"{", "33", "}"}]}], "}"}], ",", "25", ",", "2"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"403", ",", "256"}], "}"}], ",", "4"}], "}"}], ",", "34", 
        ",", "7"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", "33", "}"}]}], "}"}], ",", "4", ",", "2"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "249", ",", "84"}], "}"}]}], "}"}], ",", "21", 
        ",", "18"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "199", "}"}], ",", "1"}], "}"}], ",", "11", ",", "3"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"4", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "378"}], "}"}]}], "}"}], ",", "37", ",", 
        "40"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "199", "}"}], ",", "4"}], "}"}], ",", "13", ",", "5"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "224", "}"}], ",", 
          RowBox[{"{", "33", "}"}]}], "}"}], ",", "25", ",", "2"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", "33", "}"}]}], "}"}], ",", "11", ",", "9"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "256", "}"}], ",", "4"}], "}"}], ",", "37", ",", "7"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"397", ",", "93"}], "}"}]}], "}"}], ",", "14", ",", "10"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "256", "}"}], ",", "4"}], "}"}], ",", "35", ",", "5"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", "33", "}"}]}], "}"}], ",", "12", ",", "10"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "82"}], "}"}]}], "}"}], ",", "32", ",", "24"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "199", "}"}], ",", "4"}], "}"}], ",", "16", ",", "8"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"362", ",", "250"}], "}"}], ",", 
          RowBox[{"{", "33", "}"}]}], "}"}], ",", "25", ",", "1"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"4", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "378"}], "}"}]}], "}"}], ",", "38", ",", 
        "39"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "224", "}"}], ",", "1"}], "}"}], ",", "25", ",", "4"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "199", "}"}], ",", "1"}], "}"}], ",", "12", ",", "4"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "199", "}"}], ",", "1"}], "}"}], ",", "10", ",", "2"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "199", "}"}], ",", "4"}], "}"}], ",", "14", ",", "6"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"294", ",", "229"}], "}"}], ",", "1"}], "}"}], ",", "19", 
        ",", "3"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"329", ",", "229"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "378"}], "}"}]}], "}"}], ",", "38", ",", "5"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "345", "}"}], ",", "4"}], "}"}], ",", "38", ",", 
        "22"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", "33", "}"}]}], "}"}], ",", "3", ",", "1"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"300", ",", "84"}], "}"}]}], "}"}], ",", "32", ",", "24"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"349", ",", "410"}], "}"}], ",", "4"}], "}"}], ",", "14", 
        ",", "40"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "82"}], "}"}]}], "}"}], ",", "16", ",", "10"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"362", ",", "329", ",", "229"}], "}"}], ",", "1"}], "}"}], 
        ",", "25", ",", "3"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"357", ",", "395", ",", "345"}], "}"}], ",", "1"}], "}"}], 
        ",", "23", ",", "18"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"362", ",", "403", ",", "256"}], "}"}], ",", "1"}], "}"}], 
        ",", "25", ",", "3"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "199", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"397", ",", "93"}], "}"}]}], "}"}], ",", "14", ",", "2"}], 
       "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"300", ",", "378"}], "}"}]}], "}"}], ",", "32", ",", 
        "28"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"397", ",", "93"}], "}"}]}], "}"}], ",", "27", ",", "24"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "349", "}"}], ",", "4"}], "}"}], ",", "16", ",", 
        "34"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "345", "}"}], ",", "4"}], "}"}], ",", "36", ",", 
        "30"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", "327", "}"}]}], "}"}], ",", "12", ",", "13"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "199", "}"}], ",", 
          RowBox[{"{", "88", "}"}]}], "}"}], ",", "14", ",", "2"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", "88", "}"}]}], "}"}], ",", "6", ",", "2"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "362", "}"}], ",", "4"}], "}"}], ",", "32", ",", 
        "33"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"191", ",", "82"}], "}"}]}], "}"}], ",", "19", ",", "18"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", "33", "}"}]}], "}"}], ",", "19", ",", "17"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "249", ",", "84"}], "}"}]}], "}"}], ",", "16", 
        ",", "10"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"329", ",", "229"}], "}"}], ",", "4"}], "}"}], ",", "34", 
        ",", "7"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", "327", "}"}]}], "}"}], ",", "11", ",", "15"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "345", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "82"}], "}"}]}], "}"}], ",", "35", ",", "24"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "249", ",", "84"}], "}"}]}], "}"}], ",", "29", 
        ",", "24"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"347", ",", "345"}], "}"}], ",", "4"}], "}"}], ",", "16", 
        ",", "21"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "265", "}"}], ",", "4"}], "}"}], ",", "16", ",", 
        "29"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "368", ",", "93"}], "}"}]}], "}"}], ",", "16", 
        ",", "10"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "249", ",", "84"}], "}"}]}], "}"}], ",", "32", 
        ",", "24"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", "4"}], "}"}], ",", "29", ",", "32"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"329", ",", "229"}], "}"}], ",", "4"}], "}"}], ",", "39", 
        ",", "5"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"294", ",", "229"}], "}"}], ",", 
          RowBox[{"{", "33", "}"}]}], "}"}], ",", "19", ",", "1"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "362", "}"}], ",", "4"}], "}"}], ",", "28", ",", 
        "39"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"294", ",", "229"}], "}"}], ",", "1"}], "}"}], ",", "23", 
        ",", "2"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"268", ",", "294"}], "}"}], ",", "4"}], "}"}], ",", "16", 
        ",", "29"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "368", ",", "93"}], "}"}]}], "}"}], ",", "32", 
        ",", "24"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "265", "}"}], ",", "1"}], "}"}], ",", "12", ",", 
        "26"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"294", ",", "229"}], "}"}], ",", "4"}], "}"}], ",", "31", 
        ",", "5"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "256", "}"}], ",", "4"}], "}"}], ",", "38", ",", 
        "15"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"268", ",", "294"}], "}"}], ",", "1"}], "}"}], ",", "11", 
        ",", "20"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"191", ",", "368", ",", "93"}], "}"}]}], "}"}], ",", "19", 
        ",", "18"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "362", "}"}], ",", "4"}], "}"}], ",", "27", ",", 
        "40"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "265", "}"}], ",", "1"}], "}"}], ",", "10", ",", 
        "24"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"357", ",", "395", ",", "345"}], "}"}], ",", "1"}], "}"}], 
        ",", "25", ",", "20"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"177", ",", "378"}], "}"}]}], "}"}], ",", "19", ",", 
        "30"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "199", "}"}], ",", "4"}], "}"}], ",", "15", ",", "7"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"268", ",", "357"}], "}"}], ",", "4"}], "}"}], ",", "14", 
        ",", "40"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "368", ",", "93"}], "}"}]}], "}"}], ",", "21", 
        ",", "18"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"345", ",", "362"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"300", ",", "378"}], "}"}]}], "}"}], ",", "35", ",", 
        "39"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"347", ",", "345"}], "}"}], ",", "4"}], "}"}], ",", "14", 
        ",", "29"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "199", "}"}], ",", 
          RowBox[{"{", "327", "}"}]}], "}"}], ",", "11", ",", "7"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"345", ",", "294", ",", "229"}], "}"}], ",", "4"}], "}"}], 
        ",", "38", ",", "7"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "265", "}"}], ",", "1"}], "}"}], ",", "9", ",", "18"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"268", ",", "294"}], "}"}], ",", "4"}], "}"}], ",", "16", 
        ",", "32"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"403", ",", "256"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "378"}], "}"}]}], "}"}], ",", "38", ",", "5"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "265", "}"}], ",", "1"}], "}"}], ",", "11", ",", 
        "20"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "345", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"300", ",", "84"}], "}"}]}], "}"}], ",", "35", ",", "24"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"199", ",", "349"}], "}"}], ",", "4"}], "}"}], ",", "14", 
        ",", "40"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"349", ",", "403", ",", "256"}], "}"}], ",", "4"}], "}"}], 
        ",", "16", ",", "7"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"177", ",", "84"}], "}"}]}], "}"}], ",", "25", ",", "24"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"177", ",", "378"}], "}"}]}], "}"}], ",", "25", ",", 
        "28"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"191", ",", "249", ",", "378"}], "}"}]}], "}"}], ",", "19",
         ",", "30"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"151", ",", "164"}], "}"}], ",", "4"}], "}"}], ",", "38", 
        ",", "7"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "199", "}"}], ",", "1"}], "}"}], ",", "9", ",", "1"}], 
       "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"191", ",", "368", ",", "93"}], "}"}]}], "}"}], ",", "25", 
        ",", "24"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", "4"}], "}"}], ",", "30", ",", "31"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"177", ",", "84"}], "}"}]}], "}"}], ",", "19", ",", "18"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "345", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"300", ",", "378"}], "}"}]}], "}"}], ",", "35", ",", 
        "28"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "348", "}"}], ",", "4"}], "}"}], ",", "14", ",", 
        "40"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "265", "}"}], ",", 
          RowBox[{"{", "33", "}"}]}], "}"}], ",", "12", ",", "24"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"397", ",", "93"}], "}"}]}], "}"}], ",", "6", ",", "2"}], 
       "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "199", "}"}], ",", 
          RowBox[{"{", "33", "}"}]}], "}"}], ",", "11", ",", "1"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"268", ",", "294"}], "}"}], ",", "1"}], "}"}], ",", "9", 
        ",", "18"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "265", "}"}], ",", "4"}], "}"}], ",", "14", ",", 
        "27"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"362", ",", "403", ",", "256"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"177", ",", "378"}], "}"}]}], "}"}], ",", "25", ",", "5"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "265", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "368", ",", "93"}], "}"}]}], "}"}], ",", "16", 
        ",", "24"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"338", ",", "287", ",", "84"}], "}"}]}], "}"}], ",", "25", 
        ",", "24"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"349", ",", "329", ",", "229"}], "}"}], ",", "4"}], "}"}], 
        ",", "16", ",", "7"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "199", "}"}], ",", 
          RowBox[{"{", "88", "}"}]}], "}"}], ",", "16", ",", "1"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"294", ",", "229"}], "}"}], ",", "1"}], "}"}], ",", "25", 
        ",", "4"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"268", ",", "294"}], "}"}], ",", "4"}], "}"}], ",", "14", 
        ",", "27"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"349", ",", "329", ",", "229"}], "}"}], ",", "4"}], "}"}], 
        ",", "14", ",", "5"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", "33", "}"}]}], "}"}], ",", "26", ",", "24"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"256", ",", "199"}], "}"}], ",", "4"}], "}"}], ",", "38", 
        ",", "7"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "265", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"397", ",", "93"}], "}"}]}], "}"}], ",", "16", ",", "18"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", "327", "}"}]}], "}"}], ",", "25", ",", "31"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"347", ",", "345"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "368", ",", "93"}], "}"}]}], "}"}], ",", "16", 
        ",", "18"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"177", ",", "378"}], "}"}]}], "}"}], ",", "19", ",", 
        "31"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"349", ",", "250"}], "}"}], ",", "4"}], "}"}], ",", "14", 
        ",", "5"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "345", "}"}], ",", "4"}], "}"}], ",", "36", ",", 
        "31"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"268", ",", "294"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"397", ",", "93"}], "}"}]}], "}"}], ",", "16", ",", "18"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "256", "}"}], ",", "4"}], "}"}], ",", "36", ",", 
        "13"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", "327", "}"}]}], "}"}], ",", "3", ",", "7"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"347", ",", "256"}], "}"}], ",", "4"}], "}"}], ",", "14", 
        ",", "5"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "362", "}"}], ",", 
          RowBox[{"{", "327", "}"}]}], "}"}], ",", "25", ",", "34"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "199", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "253", ",", "373"}], "}"}]}], "}"}], ",", "16",
         ",", "5"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"347", ",", "256"}], "}"}], ",", "4"}], "}"}], ",", "16", 
        ",", "7"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"347", ",", "345"}], "}"}], ",", "1"}], "}"}], ",", "12", 
        ",", "20"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"349", ",", "403", ",", "345"}], "}"}], ",", "4"}], "}"}], 
        ",", "14", ",", "29"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"338", ",", "397"}], "}"}]}], "}"}], ",", "3", ",", "7"}], 
       "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"177", ",", "378"}], "}"}]}], "}"}], ",", "3", ",", "5"}], 
       "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", "1"}], "}"}], ",", "12", ",", "2"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"362", ",", "329", ",", "229"}], "}"}], ",", "1"}], "}"}], 
        ",", "23", ",", "1"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"347", ",", "345"}], "}"}], ",", "1"}], "}"}], ",", "10", 
        ",", "18"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"191", ",", "249", ",", "378"}], "}"}]}], "}"}], ",", "19",
         ",", "31"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"191", ",", "82"}], "}"}]}], "}"}], ",", "25", ",", "24"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", "88", "}"}]}], "}"}], ",", "8", ",", "1"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "347", "}"}], ",", "4"}], "}"}], ",", "16", ",", 
        "37"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"362", ",", "250"}], "}"}], ",", "1"}], "}"}], ",", "23", 
        ",", "1"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "349", "}"}], ",", "4"}], "}"}], ",", "8", ",", "33"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"403", ",", "256"}], "}"}], ",", "4"}], "}"}], ",", "39", 
        ",", "5"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"268", ",", "354", ",", "345"}], "}"}], ",", "1"}], "}"}], 
        ",", "12", ",", "20"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", "327", "}"}]}], "}"}], ",", "19", ",", "22"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"268", ",", "294"}], "}"}], ",", "1"}], "}"}], ",", "12", 
        ",", "26"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"97", ",", "346"}], "}"}], ",", "4"}], "}"}], ",", "16", 
        ",", "33"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"151", ",", "164"}], "}"}], ",", "4"}], "}"}], ",", "36", 
        ",", "5"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"268", ",", "354", ",", "345"}], "}"}], ",", "4"}], "}"}], 
        ",", "16", ",", "21"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"349", ",", "403", ",", "345"}], "}"}], ",", "1"}], "}"}], 
        ",", "10", ",", "18"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "362", "}"}], ",", "4"}], "}"}], ",", "31", ",", 
        "34"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "253", ",", "373"}], "}"}]}], "}"}], ",", "8", 
        ",", "5"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"268", ",", "354", ",", "345"}], "}"}], ",", "1"}], "}"}], 
        ",", "10", ",", "18"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "362", "}"}], ",", "4"}], "}"}], ",", "29", ",", 
        "33"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"338", ",", "397"}], "}"}]}], "}"}], ",", "11", ",", 
        "15"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"268", ",", "354", ",", "256"}], "}"}], ",", "4"}], "}"}], 
        ",", "14", ",", "5"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"268", ",", "354", ",", "345"}], "}"}], ",", "4"}], "}"}], 
        ",", "14", ",", "29"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"362", ",", "403", ",", "256"}], "}"}], ",", "4"}], "}"}], 
        ",", "28", ",", "5"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"349", ",", "403", ",", "345"}], "}"}], ",", "1"}], "}"}], 
        ",", "12", ",", "20"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"338", ",", "397"}], "}"}]}], "}"}], ",", "12", ",", 
        "13"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"191", ",", "249", ",", "378"}], "}"}]}], "}"}], ",", "3", 
        ",", "5"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"338", ",", "287", ",", "84"}], "}"}]}], "}"}], ",", "19", 
        ",", "18"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"349", ",", "403", ",", "345", ",", "362"}], "}"}], ",", 
          "4"}], "}"}], ",", "14", ",", "33"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "349", "}"}], ",", "4"}], "}"}], ",", "6", ",", "40"}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"362", ",", "403", ",", "256"}], "}"}], ",", "1"}], "}"}], 
        ",", "23", ",", "1"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"338", ",", "287", ",", "378"}], "}"}]}], "}"}], ",", "3", 
        ",", "5"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"349", ",", "403", ",", "345"}], "}"}], ",", "4"}], "}"}], 
        ",", "16", ",", "21"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"294", ",", "229"}], "}"}], ",", "4"}], "}"}], ",", "22", 
        ",", "7"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"338", ",", "287", ",", "378"}], "}"}]}], "}"}], ",", "25",
         ",", "28"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"191", ",", "249", ",", "378"}], "}"}]}], "}"}], ",", "25",
         ",", "28"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"338", ",", "287", ",", "378"}], "}"}]}], "}"}], ",", "19",
         ",", "30"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"347", ",", "345", ",", "362"}], "}"}], ",", "4"}], "}"}], 
        ",", "14", ",", "33"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"338", ",", "397"}], "}"}]}], "}"}], ",", "19", ",", 
        "22"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"268", ",", "294"}], "}"}], ",", "1"}], "}"}], ",", "10", 
        ",", "24"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"397", ",", "93"}], "}"}]}], "}"}], ",", "8", ",", "1"}], 
       "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", 
          RowBox[{"{", 
           RowBox[{"338", ",", "397"}], "}"}]}], "}"}], ",", "25", ",", 
        "31"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"294", ",", "229"}], "}"}], ",", 
          RowBox[{"{", "327", "}"}]}], "}"}], ",", "19", ",", "7"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"268", ",", "354", ",", "256"}], "}"}], ",", "4"}], "}"}], 
        ",", "16", ",", "7"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"294", ",", "229"}], "}"}], ",", "1"}], "}"}], ",", "17", 
        ",", "1"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"397", ",", "93"}], "}"}]}], "}"}], ",", "16", ",", "9"}], 
       "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"177", ",", "378"}], "}"}]}], "}"}], ",", "11", ",", 
        "13"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"191", ",", "249", ",", "378"}], "}"}]}], "}"}], ",", "11",
         ",", "13"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"338", ",", "287", ",", "378"}], "}"}]}], "}"}], ",", "11",
         ",", "13"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"268", ",", "354"}], "}"}], ",", "4"}], "}"}], ",", "16", 
        ",", "37"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", "327", "}"}]}], "}"}], ",", "4", ",", "5"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"338", ",", "397"}], "}"}]}], "}"}], ",", "4", ",", "5"}], 
       "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"349", ",", "403"}], "}"}], ",", "4"}], "}"}], ",", "16", 
        ",", "37"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "82"}], "}"}]}], "}"}], ",", "8", ",", "2"}], 
       "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "249", ",", "84"}], "}"}]}], "}"}], ",", "8", 
        ",", "2"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "368", ",", "93"}], "}"}]}], "}"}], ",", "8", 
        ",", "2"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", 
            RowBox[{"{", "387", "}"}]}], "}"}], ",", "6", ",", "5"}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", 
            RowBox[{"{", "388", "}"}]}], "}"}], ",", "6", ",", "5"}], "}"}]}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"397", ",", "409"}], "}"}]}], "}"}], ",", "6", ",", "5"}], 
       "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"409", ",", "397"}], "}"}]}], "}"}], ",", "6", ",", "5"}], 
       "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", 
            RowBox[{"{", "387", "}"}]}], "}"}], ",", "8", ",", "7"}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", 
            RowBox[{"{", "388", "}"}]}], "}"}], ",", "8", ",", "7"}], "}"}]}],
        "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"397", ",", "409"}], "}"}]}], "}"}], ",", "8", ",", "7"}], 
       "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"409", ",", "397"}], "}"}]}], "}"}], ",", "8", ",", "7"}], 
       "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", 
            RowBox[{"{", "387", "}"}]}], "}"}], ",", "14", ",", "13"}], "}"}],
         ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", 
            RowBox[{"{", "388", "}"}]}], "}"}], ",", "14", ",", "13"}], 
         "}"}]}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"397", ",", "409"}], "}"}]}], "}"}], ",", "14", ",", 
        "13"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"409", ",", "397"}], "}"}]}], "}"}], ",", "14", ",", 
        "13"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", 
            RowBox[{"{", "387", "}"}]}], "}"}], ",", "16", ",", "15"}], "}"}],
         ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", 
            RowBox[{"{", "388", "}"}]}], "}"}], ",", "16", ",", "15"}], 
         "}"}]}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"397", ",", "409"}], "}"}]}], "}"}], ",", "16", ",", 
        "15"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"409", ",", "397"}], "}"}]}], "}"}], ",", "16", ",", 
        "15"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "283", "}"}], ",", "1"}], "}"}], ",", "17", ",", 
          "18"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "286", "}"}], ",", "1"}], "}"}], ",", "17", ",", 
          "18"}], "}"}]}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"294", ",", "299"}], "}"}], ",", "1"}], "}"}], ",", "17", 
        ",", "18"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"299", ",", "294"}], "}"}], ",", "1"}], "}"}], ",", "17", 
        ",", "18"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "283", "}"}], ",", "1"}], "}"}], ",", "19", ",", 
          "20"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "286", "}"}], ",", "1"}], "}"}], ",", "19", ",", 
          "20"}], "}"}]}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"294", ",", "299"}], "}"}], ",", "1"}], "}"}], ",", "19", 
        ",", "20"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"299", ",", "294"}], "}"}], ",", "1"}], "}"}], ",", "19", 
        ",", "20"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "283", "}"}], ",", "1"}], "}"}], ",", "23", ",", 
          "24"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "286", "}"}], ",", "1"}], "}"}], ",", "23", ",", 
          "24"}], "}"}]}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"299", ",", "294"}], "}"}], ",", "1"}], "}"}], ",", "23", 
        ",", "24"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"294", ",", "299"}], "}"}], ",", "1"}], "}"}], ",", "23", 
        ",", "24"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "283", "}"}], ",", "1"}], "}"}], ",", "25", ",", 
          "26"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", "286", "}"}], ",", "1"}], "}"}], ",", "25", ",", 
          "26"}], "}"}]}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"294", ",", "299"}], "}"}], ",", "1"}], "}"}], ",", "25", 
        ",", "26"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"299", ",", "294"}], "}"}], ",", "1"}], "}"}], ",", "25", 
        ",", "26"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", 
            RowBox[{"{", 
             RowBox[{"277", ",", "378"}], "}"}]}], "}"}], ",", "8", ",", 
          "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", 
            RowBox[{"{", 
             RowBox[{"278", ",", "378"}], "}"}]}], "}"}], ",", "8", ",", 
          "5"}], "}"}]}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"397", ",", "301", ",", "378"}], "}"}]}], "}"}], ",", "8", 
        ",", "5"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"301", ",", "249", ",", "378"}], "}"}]}], "}"}], ",", "8", 
        ",", "5"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"287", ",", "264", ",", "378"}], "}"}]}], "}"}], ",", "8", 
        ",", "5"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"409", ",", "287", ",", "378"}], "}"}]}], "}"}], ",", "8", 
        ",", "5"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", 
            RowBox[{"{", 
             RowBox[{"311", ",", "368", ",", "409"}], "}"}]}], "}"}], ",", 
          "8", ",", "5"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", 
            RowBox[{"{", 
             RowBox[{"311", ",", "366"}], "}"}]}], "}"}], ",", "8", ",", 
          "5"}], "}"}]}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "367"}], "}"}]}], "}"}], ",", "8", ",", "5"}], 
       "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "264", ",", "368"}], "}"}]}], "}"}], ",", "8", 
        ",", "5"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "249", ",", "374"}], "}"}]}], "}"}], ",", "8", 
        ",", "5"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "374", ",", "397"}], "}"}]}], "}"}], ",", "8", 
        ",", "5"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", 
            RowBox[{"{", 
             RowBox[{"277", ",", "378"}], "}"}]}], "}"}], ",", "16", ",", 
          "13"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", 
            RowBox[{"{", 
             RowBox[{"278", ",", "378"}], "}"}]}], "}"}], ",", "16", ",", 
          "13"}], "}"}]}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"287", ",", "264", ",", "378"}], "}"}]}], "}"}], ",", "16",
         ",", "13"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"409", ",", "287", ",", "378"}], "}"}]}], "}"}], ",", "16",
         ",", "13"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"397", ",", "301", ",", "378"}], "}"}]}], "}"}], ",", "16",
         ",", "13"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"301", ",", "249", ",", "378"}], "}"}]}], "}"}], ",", "16",
         ",", "13"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", 
            RowBox[{"{", 
             RowBox[{"311", ",", "368", ",", "409"}], "}"}]}], "}"}], ",", 
          "16", ",", "13"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"2", ",", 
            RowBox[{"{", 
             RowBox[{"311", ",", "366"}], "}"}]}], "}"}], ",", "16", ",", 
          "13"}], "}"}]}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "264", ",", "368"}], "}"}]}], "}"}], ",", "16",
         ",", "13"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "367"}], "}"}]}], "}"}], ",", "16", ",", 
        "13"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "249", ",", "374"}], "}"}]}], "}"}], ",", "16",
         ",", "13"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", 
          RowBox[{"{", 
           RowBox[{"311", ",", "374", ",", "397"}], "}"}]}], "}"}], ",", "16",
         ",", "13"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"362", ",", "317"}], "}"}], ",", "1"}], "}"}], ",", "23",
           ",", "18"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"362", ",", "320"}], "}"}], ",", "1"}], "}"}], ",", "23",
           ",", "18"}], "}"}]}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"362", ",", "329", ",", "299"}], "}"}], ",", "1"}], "}"}], 
        ",", "23", ",", "18"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"362", ",", "409", ",", "329"}], "}"}], ",", "1"}], "}"}], 
        ",", "23", ",", "18"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"362", ",", "335", ",", "294"}], "}"}], ",", "1"}], "}"}], 
        ",", "23", ",", "18"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"362", ",", "403", ",", "335"}], "}"}], ",", "1"}], "}"}], 
        ",", "23", ",", "18"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"351", ",", "345"}], "}"}], ",", "1"}], "}"}], ",", "23",
           ",", "18"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"350", ",", "345"}], "}"}], ",", "1"}], "}"}], ",", "23",
           ",", "18"}], "}"}]}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"294", ",", "356", ",", "345"}], "}"}], ",", "1"}], "}"}], 
        ",", "23", ",", "18"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"299", ",", "354", ",", "345"}], "}"}], ",", "1"}], "}"}], 
        ",", "23", ",", "18"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"354", ",", "409", ",", "345"}], "}"}], ",", "1"}], "}"}], 
        ",", "23", ",", "18"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"356", ",", "403", ",", "345"}], "}"}], ",", "1"}], "}"}], 
        ",", "23", ",", "18"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"362", ",", "317"}], "}"}], ",", "1"}], "}"}], ",", "25",
           ",", "20"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"362", ",", "320"}], "}"}], ",", "1"}], "}"}], ",", "25",
           ",", "20"}], "}"}]}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"362", ",", "329", ",", "299"}], "}"}], ",", "1"}], "}"}], 
        ",", "25", ",", "20"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"362", ",", "335", ",", "294"}], "}"}], ",", "1"}], "}"}], 
        ",", "25", ",", "20"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"362", ",", "409", ",", "329"}], "}"}], ",", "1"}], "}"}], 
        ",", "25", ",", "20"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"362", ",", "403", ",", "335"}], "}"}], ",", "1"}], "}"}], 
        ",", "25", ",", "20"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"351", ",", "345"}], "}"}], ",", "1"}], "}"}], ",", "25",
           ",", "20"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"350", ",", "345"}], "}"}], ",", "1"}], "}"}], ",", "25",
           ",", "20"}], "}"}]}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"354", ",", "409", ",", "345"}], "}"}], ",", "1"}], "}"}], 
        ",", "25", ",", "20"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"294", ",", "356", ",", "345"}], "}"}], ",", "1"}], "}"}], 
        ",", "25", ",", "20"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"356", ",", "403", ",", "345"}], "}"}], ",", "1"}], "}"}], 
        ",", "25", ",", "20"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"299", ",", "354", ",", "345"}], "}"}], ",", "1"}], "}"}], 
        ",", "25", ",", "20"}], "}"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.686025570257675*^9, 3.686025667932056*^9}, {
   3.686025699692822*^9, 3.686025765384577*^9}, 3.6860276790740223`*^9, 
   3.686030287154888*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"SANITY", " ", "CHECK"}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"AInftyQ", "[", "mat_", "]"}], " ", "checks", " ", "that", " ", 
      "the", " ", "structure", " ", 
      RowBox[{"map", " ", "'"}], 
      RowBox[{"mat", "'"}], " ", "satisfy", " ", 
      RowBox[{"\"\<D^2=0\>\"", ".", " ", "If"}], " ", "it", " ", "does", " ", 
      "not", " ", 
      RowBox[{"return", " ", "'"}], 
      RowBox[{"True", "'"}]}]}], ",", " ", 
    RowBox[{
     RowBox[{"something", " ", "went", " ", "wrong"}], ";"}]}], 
   "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"AInftyQ", "[", "MM2", "]"}]}]], "Input",
 CellChangeTimes->{{3.6844689552965307`*^9, 3.684468955736527*^9}, {
  3.686024936273921*^9, 3.686024937042727*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.686025776993335*^9, 3.6860276807808647`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Cancel1", "=", 
   RowBox[{"Cancellation", "[", 
    RowBox[{"MM2", ",", "GG1", ",", "1"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MM3", "=", 
   RowBox[{"Cancel1", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GG2", "=", 
   RowBox[{"Cancel1", "[", 
    RowBox[{"[", "2", "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.680357212295043*^9, 3.680357259830065*^9}, {
  3.684468596743967*^9, 3.684468612728283*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 TemplateBox[{RowBox[{"\"09:34:40\"", 
     StyleBox[
      RowBox[{"\"GMT+\"", "\[InvisibleSpace]", "1.`"}], FontColor -> 
      GrayLevel[0.5]]}],RowBox[{"TimeObject", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{"9", ",", "34", ",", "40.99468`"}], "}"}], ",", 
       RowBox[{"TimeZone", "\[Rule]", "1.`"}]}], "]"}]},
  "TimeObject",
  Editable->False]], "Print",
 CellChangeTimes->{3.686025783049211*^9, 3.68602768101538*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", 
   TagBox[GridBox[{
      {"\<\"Finished calculation\"\>"},
      {"\<\"after 4 iterations.\"\>"},
      {
       GraphicsBox[RasterBox[CompressedData["
1:eJztmdFNBDEMRFeiEa6S64ESkPimZUqgBIQEH4ibuyRrxzPJjIRA7+MY27Pe
EC6v7y9vT8dxPP98ff/8V5/Xf4iKf1xvf6/y08vV/SOuVhcSm8/VuEpOen2y
1oXE0md1HpWTqryx5XbUDxJLThBX3zMquVXv2yOx5Hk3zparKF79fCGtNhcV
n4ir+4/iKvs8e17qeVD3X81bVdVnz9c8kyOx+dzleak+x6rzs+q978q+H/B8
zXs4kveG+Qhnu/9/JJa+9fJVn0f1uqr/b4XE0p9s7vPVbX9q/ns1q66s36s2
F/M5HIlln1T56eXq+zDqnqG63rOKrrf183/FMt9sP+Y5HGn2vnWuzDM5EptP
cw1efX8YdZ5h75sKX7UuVo7kuZjP4LP+/m3V6Oew9LOKR73HvWfOcSSVcxd7
bs05OBJ7TtjyxubHvE2z97lKTlR8mreJZb4q51U2P+ZtYvPpXGlw1vd4r1T6
ibT7eyeKq9WLxL4/2fyYj3Hfn9/nbH7UeXbeqvc/Evu5y/t8jO/aNyT2PqvP
i80/m59ojjR7n7O9L1blu/YZiaXe6nPdLnlj85PHvwBuN7aT
         "], {{0, 0}, {32, 32}}, {0, 1}],
        Frame->Automatic,
        FrameLabel->{None, None},
        FrameTicks->{{None, None}, {None, None}},
        GridLinesStyle->Directive[
          GrayLevel[0.5, 0.4]],
        Method->{
         "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> Automatic},
        ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztm71uwjAQgINoGJIlSxjK4iUMZWGBoV3oQDtVYmlnIlQEQ9WKoq70kVqJ
Pp9rG3JHLNM4amhJOCTCxfZ9h/xzd3aUu3g5e3yKl/NJzG4X8ctsPnllN88L
UVSvOY6zFt8v5kiZC3F7WXPxEUJd/vLpdCq/zqe67pbKVh/yWjtU1dlulfxE
XPzHBl+tVihdgMSk5PJEkSg5KSNdQ0gulJ1vJKGoyghVFGoIaqqxn0Z5OjSp
VQPqE/6E8a39U2+PIRc0ULcBJgMyeUomcXZ2DMY98GGaSYL+NRTHF8N7z+Ay
mtCOeGXiBdCuDdJgEzBUCiFuCVU86h1WY5S9BsvYGB1PpEcIIfWlFGxiReKb
/OxeI2hJoG/ghzT86aqNoOtMMRl3zLYbQEJZoaL0GJnzWKHYt3TcxDsuntqq
erIdg0nD0jE5gJmjbn0gW+xTCP9/+DHo4mbUwtFWWQ27OJRSMx2d3XQa6kGP
E7QS0AdD5oF7ki4BbAAjWHn31WxsOvwJwCuju8mVRhG0JNDhTsBN1CwmTZXV
OuCGMS9RlMt0x/p5xo14R8O7MoQElHD1WORXhLJH9WA1hqBmeqxIqEJRXRhB
PKUzjSWDWoukiKAlgXYM6zcEZ9ki1GFQEaxfPLWyyDyqrKY9KMDEFeczOjwf
oovVEwkil5vcMqw8DHLj7MlFAM5NGXKYHpmBvGXZ40Eoe1TwY9jGo6YBlFkk
bQQtCdQHqClRxwCZ89SeoEVDtyOduFctlml5tiq7NtSSoaoY2vUCmLC0DbyA
bJANo43fvkQk77fvKiUvMtW+AawstNk=\
\>"]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.5599999999999999]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Column], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Print",
 CellChangeTimes->{3.686025783049211*^9, 3.6860276811917477`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"There are \"\>", "\[InvisibleSpace]", "32", 
   "\[InvisibleSpace]", "\<\" generators left.\"\>"}],
  SequenceForm["There are ", 32, " generators left."],
  Editable->False]], "Print",
 CellChangeTimes->{3.686025783049211*^9, 3.686027681192946*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The cancelled generators were \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"\<\"(40)\"\>", "\<\"(38)\"\>", "\<\"(33)\"\>", "\<\"(33)\"\>"},
       {"\<\"40\"\>", "\<\"39\"\>", "\<\"33\"\>", "\<\"34\"\>"},
       {"\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>", \
"\<\"\[DownArrow]\"\>", "\<\"\[DownArrow]\"\>"},
       {"\<\"35\"\>", "\<\"36\"\>", "\<\"37\"\>", "\<\"38\"\>"},
       {"\<\"(35)\"\>", "\<\"(35)\"\>", "\<\"(35)\"\>", "\<\"(34)\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["The cancelled generators were ", 
   MatrixForm[{{"(40)", "(38)", "(33)", "(33)"}, {"40", "39", "33", "34"}, {
     "\[DownArrow]", "\[DownArrow]", "\[DownArrow]", "\[DownArrow]"}, {
     "35", "36", "37", "38"}, {"(35)", "(35)", "(35)", "(34)"}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.686025783049211*^9, 3.686027681194594*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"PlotGraph", "[", "MM3", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"GenTableWithIdems", "[", "GG2", "]"}]}], "Input",
 CellChangeTimes->{{3.6761773820432796`*^9, 3.676177384954527*^9}, 
   3.676177617306233*^9, 3.6761786321171417`*^9, {3.6839495373610287`*^9, 
   3.683949538281969*^9}, {3.6844681249806423`*^9, 3.6844681295966263`*^9}, {
   3.684469058092749*^9, 3.684469061244432*^9}}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJztmdFNBDEMRFeiEa6S64ESkPimZUqgBIQEH4ibuyRrxzPJjIRA7+MY27Pe
EC6v7y9vT8dxPP98ff/8V5/Xf4iKf1xvf6/y08vV/SOuVhcSm8/VuEpOen2y
1oXE0md1HpWTqryx5XbUDxJLThBX3zMquVXv2yOx5Hk3zparKF79fCGtNhcV
n4ir+4/iKvs8e17qeVD3X81bVdVnz9c8kyOx+dzleak+x6rzs+q978q+H/B8
zXs4kveG+Qhnu/9/JJa+9fJVn0f1uqr/b4XE0p9s7vPVbX9q/ns1q66s36s2
F/M5HIlln1T56eXq+zDqnqG63rOKrrf183/FMt9sP+Y5HGn2vnWuzDM5EptP
cw1efX8YdZ5h75sKX7UuVo7kuZjP4LP+/m3V6Oew9LOKR73HvWfOcSSVcxd7
bs05OBJ7TtjyxubHvE2z97lKTlR8mreJZb4q51U2P+ZtYvPpXGlw1vd4r1T6
ibT7eyeKq9WLxL4/2fyYj3Hfn9/nbH7UeXbeqvc/Evu5y/t8jO/aNyT2PqvP
i80/m59ojjR7n7O9L1blu/YZiaXe6nPdLnlj85PHvwBuN7aT
   "], {{0, 0}, {32, 32}}, {0, 1}],
  Frame->Automatic,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
    Automatic}]], "Print",
 CellChangeTimes->{3.686025789116209*^9, 
  3.686027681476019*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztncFO20AQhjdFlSpzts97rs9wTi/twe0RzolQ0kS0akURV8OZp+BMX4L3
6TukO2t3NjZGWVetMPEXKdF41//3S2hn7B0n4tP8crX4Or9cn83th4v599X6
7Id9/+3CDR1MjJms3PuzNRJvjNGPg428lsulvI2PqtBsTbmX8QcL+Zjs5fxr
+SzceeZwU5ZliE40eidRIn+4N3DgjIhzp5qpRolGx1XkpH4MGLC9g92q8FCi
VCM/ljaxydasw6UYYIDBWAyOmgY+6hoLVo+qUhhzFhZTTDHF9GWZhjp72oHN
qurqpFlzFixYsM+NDdUhNA7O2xXDSfPKwI1BhDhuou0gXkuUCccfAgMGLA4m
z2zMK83DIuayhQaNfIY7oLAQwzbHl3lbbWTK+iYpjVmSYMGC/d/YX5rrLQOE
CHc/8etu6DtBa4MMDBiwvt8eedQidtIvEkXd00OECLEf0aszOXPajFLdVFvF
tvxsTJpjgAEG+2DwoOpWdxshwh1Ls6y/D5xLlEtkde9e78X+TGS6NMGCBfvc
2J9yUlJdNBrXCx/NQIB42Yg7vazdc/pYTz+t1lG53dqyVaFs3O/0bHKBBQtW
sbealAEblZ4IEf6d0K9Qf0Mc+iCec9Vc4lm/3IAIEWI08UrTNzx0D4l8olEB
DNhews4VlqswNOB7NlSBARs3bKawkJFdWTrVaAYWLNghYOvuQgPra4J/hHEM
DBiweFihWVqo8B4hwp3CJzu8oaB77NtqoqwbvpG/34ANG/bQ2EdaLIJB2Hw9
xJQNECCGi8jlzFbj2t9bJXp4I4fTmGwBBmzcMKsZ2bXztxpda1TEZClYsGAV
myo2V2HaRLSuhWDBgh0ENvzwMlSCruoQxm46xrDCCius/q1V9xOGjxJ1dZlw
wQUXXCJc/MFimPNy7KP63435ibWXGTP5Dd4XjRg=\
\>"]],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"{", 
       RowBox[{"\<\"c\"\>", ",", "\<\"d\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "2", ",", "3", ",", "4", ",", "9", ",", "10", ",", "11", ",",
         "12"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"c\"\>", ",", "\<\"a\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
       "5", ",", "6", ",", "7", ",", "8", ",", "13", ",", "14", ",", "15", 
        ",", "16"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"b\"\>", ",", "\<\"d\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
       "17", ",", "18", ",", "19", ",", "20", ",", "23", ",", "24", ",", "25",
         ",", "26"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"b\"\>", ",", "\<\"a\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
       "21", ",", "22", ",", "27", ",", "28", ",", "29", ",", "30", ",", "31",
         ",", "32"}], "}"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.686025789147352*^9, 3.686027681499382*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Reordering1", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "14", ",", "13", ",", "23", ",", "24", ",", "31", ",", "28", ",", "12",
         ",", "10"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
       "6", ",", "5", ",", "25", ",", "26", ",", "29", ",", "27", ",", "4", 
        ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
       "16", ",", "15", ",", "17", ",", "18", ",", "22", ",", "30", ",", "11",
         ",", "9"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
       "8", ",", "7", ",", "19", ",", "20", ",", "21", ",", "32", ",", "3", 
        ",", "1"}], "}"}]}], "\[IndentingNewLine]", "}"}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"GG3", "=", 
   RowBox[{"GG2", "[", 
    RowBox[{"[", "Reordering1", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"MM4", "=", 
   RowBox[{"MM3", "[", 
    RowBox[{"[", 
     RowBox[{"Reordering1", ",", "Reordering1"}], "]"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.6804176615438843`*^9, 3.680417685489192*^9}, {
  3.6844691013897552`*^9, 3.68446912864489*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"PlotGraph", "[", "MM4", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"GenTableWithIdems", "[", "GG3", "]"}]}], "Input",
 CellChangeTimes->{{3.686025814410742*^9, 3.6860258165935307`*^9}}],

Cell[BoxData[
 GraphicsBox[RasterBox[CompressedData["
1:eJztmVFOAzEMRFfiInCS3oEjIPHNlTkCR0CofEDo0PVuHI/tGalq9T6yE8eN
E+/Ty9vz68O2bY/fn6/fv/Vx+YNu8vfL7W/rOFFc/uc+1+rH2/+98ZFY1teb
Z89/b+6dz6vij8QS5yjOlv9sfqw82j8SS3zE/+fR+cNeL5Cyxw3xqPqY5Xzr
zaPPJ6O6xd+bKz4cHInNp/JtDR81K25s+7l1fGtdnlXHxdfwKuuCxOZT68XF
2c636p/X5mz/XzY/91RtvmzvE72fy8aj3zchscw3O+82XyuP6p9bfc7iVfJh
lHe/Inudmu1/r1j7J2d9Wp/LNo74OY7E5rN7/nSb71Fu1erzldZR3JMjsfns
ztnO4eqfx3LVhbk8uh+o/dzGs+d/N/+r+jAs8anK1c+5Kmo/V/yvqlKvWXj0
+QTJ6z4ifowrzuc4EptP8TV8lHd9j3ofah2f9f0p2/45KqrPln1djnIkNp/V
ePb8YbuPqH8e66cbZ40/UrX5svnpxqP7V0gs8xUX/6mj+YOUxX8XP+L7+F6x
3tP3+kTjsN2buvHoeCKxxAfx6LiJc3KrzuZb9P7Pxkdl6Z/P8hPNkdh8VuPV
84qXfwKvSraT
   "], {{0, 0}, {32, 32}}, {0, 1}],
  Frame->Automatic,
  FrameLabel->{None, None},
  FrameTicks->{{None, None}, {None, None}},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultPlotStyle" -> 
    Automatic}]], "Print",
 CellChangeTimes->{3.686025817019312*^9, 
  3.686027681914384*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\
eJztnb2O00AURidaIaGkdmpTu17XqaAwlKQmWiUk2kWgZQWlHwBq+lDzUjxJ
mLk2dzyOpdiWA5v1iRTr2jPf+aTV/N5xtG9WD9v1h9XD7mYVv7pffdrubj7H
Lz/e20dXE2MmW/t9HxsXH4zRy9XBfTabjfsaiYrQVIrsx8jN2l0mT7L8mbtG
tp6ZHfI8zxqixEWRi2b6LNZo6v6izzHAAIMRGNxq9S9VYRkdYS1ESsGCBdsD
m7po2tCNBRYBAwbsFOxXA8L3zanC5BYiRIhnIC4aZsPaYjQLq0RqUHPGCius
sBrGyq819mp1jRDhSWGik+TXIgomRN8057pUTdwzsGDB/m/s0QrXVsva9HqE
CPsJfYP9rgi/WImryxZjlhAhQhye6Jd7PreYakf2xI5rR2DALgQm6kQ1dw0d
KzjFMibBAAMMxmdwtPlqYltpChYs2MeFjVTo8yVzHTHEZa5EKY2KIcIXmDLt
PlcFpphiiunFmebV852s10gKAsTQiNrcH+kpxt81e/nOdqvcFjBg44aVhzO2
cE/1sVb3rSfR1uP3U3G1bRnzVm8z2LBhXyZ7Ec4YzQeFVvoOLFiwPbHCed1A
9Dv7ffgMIkSIZyW+KCJTZtV8ZiwLBwGJ/HlgjBVWWGE1nNUirC6vZE+LyD77
0W2UAwbs4mC3RXVb+JvqY61eG12jSmQLJErcs+uwbc1UJg0xdhFWWGGF1VBW
uS4Fg21n5+QPatRnVx8lLPPybGBZYPPyvQtgwJ4mLNWR3sNSOHBGzvGdLDje
qv6+peVODRiwMcOiOsdUf2fSsW8CAwasSCHLnr22U5+GVhJ906hVghkDDDD4
VwZCzHrNqAgRdhdWE75LnY58OiHWAmDAgJ08WPlZIPLW2QU0I9fIzfpxlrt7
icr/VyYFO5EZM/kDlJSf2w==\
\>"]],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"{", 
       RowBox[{"\<\"c\"\>", ",", "\<\"a\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
       "1", ",", "2", ",", "9", ",", "10", ",", "17", ",", "18", ",", "25", 
        ",", "26"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"b\"\>", ",", "\<\"d\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
       "3", ",", "4", ",", "11", ",", "12", ",", "19", ",", "20", ",", "27", 
        ",", "28"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"b\"\>", ",", "\<\"a\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
       "5", ",", "6", ",", "13", ",", "14", ",", "21", ",", "22", ",", "29", 
        ",", "30"}], "}"}]},
     {
      RowBox[{"{", 
       RowBox[{"\<\"c\"\>", ",", "\<\"d\"\>"}], "}"}], 
      RowBox[{"{", 
       RowBox[{
       "7", ",", "8", ",", "15", ",", "16", ",", "23", ",", "24", ",", "31", 
        ",", "32"}], "}"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.6860258170473948`*^9, 3.686027681918881*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Manual", " ", "homotopies", " ", 
    RowBox[{"s", ".", "t", ".", " ", "all"}], " ", "four", " ", "blocks", " ",
     "of", " ", "8", " ", "generators", " ", "are", " ", "identical"}], " ", 
   "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"MM5", "=", 
     RowBox[{"Homotopy", "[", 
      RowBox[{"MM4", ",", "GG3", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}], ",", "16", ",", "7"}], "]"}]}], ";"}],
    "\n", 
   RowBox[{
    RowBox[{"MM6", "=", 
     RowBox[{"Homotopy", "[", 
      RowBox[{"MM5", ",", "GG3", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}], ",", "22", ",", "5"}], "]"}]}], ";"}],
    "\n", 
   RowBox[{
    RowBox[{"MM7", "=", 
     RowBox[{"Homotopy", "[", 
      RowBox[{"MM6", ",", "GG3", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}], ",", "32", ",", "23"}], "]"}]}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{"MM8", "=", 
     RowBox[{"Homotopy", "[", 
      RowBox[{"MM7", ",", "GG3", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}], ",", "30", ",", "13"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MM9", "=", 
     RowBox[{"Homotopy", "[", 
      RowBox[{"MM8", ",", "GG3", ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "4"}], "}"}], ",", "13", ",", "30"}], "]"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.68446942657996*^9, 3.6844694794293633`*^9}, {
   3.686025254857567*^9, 3.686025278571439*^9}, 3.686026026362998*^9, {
   3.686026225558466*^9, 3.6860262468699703`*^9}, {3.686026400683053*^9, 
   3.686026401898144*^9}, {3.6860290224472*^9, 3.686029025030369*^9}, {
   3.686029085728496*^9, 3.686029096334753*^9}, {3.6860305302074537`*^9, 
   3.686030532301062*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"coordinates", " ", "for", " ", "8", " ", "generators"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"mycoords", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2"}], ",", 
        RowBox[{"-", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", 
        RowBox[{"-", "1"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", 
        RowBox[{"-", "2"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"-", "2"}]}], "}"}]}], "}"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.680342040462161*^9, 3.680342043866082*^9}, {
  3.680414706458083*^9, 3.680414808761121*^9}, {3.6804152285274963`*^9, 
  3.680415230320108*^9}, {3.686025182560987*^9, 3.6860252154658403`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ShowSubGraph", "[", 
  RowBox[{"MM9", ",", "GG3", ",", 
   RowBox[{"Range", "[", 
    RowBox[{"1", ",", "8"}], "]"}], ",", "mycoords"}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8}, {
       SparseArray[
       Automatic, {8, 8}, 0, {
        1, {{0, 5, 5, 10, 10, 13, 16, 19, 22}, {{2}, {5}, {6}, {7}, {8}, {
          4}, {5}, {6}, {7}, {8}, {2}, {4}, {6}, {2}, {4}, {5}, {2}, {4}, {
          8}, {2}, {4}, {7}}}, Pattern}], Null}, {
      EdgeLabels -> {DirectedEdge[3, 6] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)", "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, 
         DirectedEdge[
          6, 2] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, 
         DirectedEdge[1, 6] -> {{{"\!\(\*SubscriptBox[\(q\), \(3\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[3, 4] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)"}}, {{
            "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          8, 4] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[8, 2] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)"}}}, DirectedEdge[7, 8] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, 
         DirectedEdge[3, 8] -> {{{"\!\(\*SubscriptBox[\(p\), \(3\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[1, 8] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)", "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, DirectedEdge[5, 6] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, DirectedEdge[7, 2] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)"}}}, DirectedEdge[6, 4] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)"}}}, 
         DirectedEdge[
          3, 7] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)", "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[3, 5] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)"}}}, 
         DirectedEdge[7, 4] -> {{{"\!\(\*SubscriptBox[\(q\), \(3\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          1, 5] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)", "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[5, 4] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)"}}}, DirectedEdge[1, 7] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)"}}}, 
         DirectedEdge[
          1, 2] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}, {
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)"}}}, 
         DirectedEdge[
          8, 7] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          6, 5] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, 
         DirectedEdge[5, 2] -> {{{"\!\(\*SubscriptBox[\(p\), \(3\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}}, 
       VertexLabels -> {
        6 -> Placed["6:(ba)", Above], 3 -> Placed["3:(bd)", Above], 5 -> 
         Placed["5:(ba)", Above], 8 -> Placed["8:(cd)", Above], 7 -> 
         Placed["7:(cd)", Above], 4 -> Placed["4:(bd)", Above], 2 -> 
         Placed["2:(ca)", Above], 1 -> Placed["1:(ca)", Above]}, 
       VertexCoordinates -> {{-2, 1}, {2, 1}, {-2, -1}, {2, -1}, {-1, 2}, {1, 
        2}, {-1, -2}, {1, -2}}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
        Medium], {ArrowBox[{{-2., 1.}, {2., 1.}}, 0.03700564971751412], 
         InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "4"]},
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0., 1.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., 1.}, {-1., 2.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-1.5, 1.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., 1.}, {1., 2.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>", 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-0.5, 1.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., 1.}, {-1., -2.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>", "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-1.5, -0.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., 1.}, {1., -2.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-0.5, -0.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., -1.}, {2., -1.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}], "}"}]},
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0., -1.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., -1.}, {-1., 2.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>", "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-1.5, 0.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., -1.}, {1., 2.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-0.5, 0.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., -1.}, {-1., -2.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-1.5, -1.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., -1.}, {1., -2.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>", 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-0.5, -1.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-1., 2.}, {2., 1.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>", 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0.5, 1.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-1., 2.}, {2., -1.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0.5, 0.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{-1., 2.}, {1.288057039570842*^-16, 
          2.3288814943657057`}, {1., 2.}}], 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {5.551115123125783*^-17, 2.14},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1., 2.}, {2., 1.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.5, 1.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1., 2.}, {2., -1.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>", "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.5, 0.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{1., 2.}, {8.58704693047239*^-17, 
          1.671118505634294}, {-1., 2.}}], 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.942890293094024*^-16, 1.8599999999999999`},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-1., -2.}, {2., 1.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0.5, -0.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-1., -2.}, {2., -1.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>", 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0.5, -1.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[
          BezierCurveBox[{{-1., -2.}, {-8.58704693047239*^-17, \
-1.671118505634294}, {1., -2.}}], 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-1.942890293094024*^-16, -1.8599999999999999`},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1., -2.}, {2., 1.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>", "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.5, -0.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1., -2.}, {2., -1.}}, 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.5, -1.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{
          1., -2.}, {-1.288057039570842*^-16, -2.3288814943657057`}, {-1., \
-2.}}], 0.03700564971751412], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-5.551115123125783*^-17, -2.14},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {DiskBox[{-2., 1.}, 0.03700564971751412], 
         InsetBox["\<\"1:(ca)\"\>", 
          Offset[{0, 2}, {-2., 1.0370056497175142`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{2., 1.}, 0.03700564971751412], 
         InsetBox["\<\"2:(ca)\"\>", Offset[{0, 2}, {2., 1.0370056497175142`}],
           ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{-2., -1.}, 0.03700564971751412], 
         InsetBox["\<\"3:(bd)\"\>", 
          Offset[{0, 2}, {-2., -0.9629943502824859}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{2., -1.}, 0.03700564971751412], 
         InsetBox["\<\"4:(bd)\"\>", Offset[{0, 2}, {2., -0.9629943502824859}],
           ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{-1., 2.}, 0.03700564971751412], 
         InsetBox["\<\"5:(ba)\"\>", Offset[{0, 2}, {-1., 2.037005649717514}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{1., 2.}, 0.03700564971751412], 
         InsetBox["\<\"6:(ba)\"\>", Offset[{0, 2}, {1., 2.037005649717514}], 
          ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{-1., -2.}, 0.03700564971751412], 
         InsetBox["\<\"7:(cd)\"\>", 
          Offset[{0, 2}, {-1., -1.9629943502824858`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{1., -2.}, 0.03700564971751412], 
         InsetBox["\<\"8:(cd)\"\>", 
          Offset[{0, 2}, {1., -1.9629943502824858`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None,
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{314., Automatic}]], "Output",
 CellChangeTimes->{3.686029847793881*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Test", " ", "if", " ", "submatrices", " ", "of", " ", "the", " ", 
    "structure", " ", "map", " ", "are", " ", "identical", " ", 
    RowBox[{"(", 
     RowBox[{"up", " ", "to", " ", "reordering", " ", "labels"}], ")"}]}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"MatrixEqualQ", "[", 
      RowBox[{"mat1_", ",", "mat2_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"Map", "[", 
       RowBox[{"Sort", ",", "mat1", ",", 
        RowBox[{"{", "2", "}"}]}], "]"}], "===", 
      RowBox[{"Map", "[", 
       RowBox[{"Sort", ",", "mat2", ",", 
        RowBox[{"{", "2", "}"}]}], "]"}]}]}], ";"}], "\n", 
   RowBox[{"MatrixEqualQ", "[", 
    RowBox[{
     RowBox[{"MM9", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"1", ";;", "8"}], ",", 
        RowBox[{"1", ";;", "8"}]}], "]"}], "]"}], ",", 
     RowBox[{"MM9", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"9", ";;", "16"}], ",", 
        RowBox[{"9", ";;", "16"}]}], "]"}], "]"}]}], "]"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"(", "1", ")"}], "=", 
     RowBox[{"(", "2", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"MatrixEqualQ", "[", 
    RowBox[{
     RowBox[{"MM9", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"1", ";;", "8"}], ",", 
        RowBox[{"1", ";;", "8"}]}], "]"}], "]"}], ",", 
     RowBox[{"MM9", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"17", ";;", "24"}], ",", 
        RowBox[{"17", ";;", "24"}]}], "]"}], "]"}]}], "]"}], 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"(", "1", ")"}], "=", 
     RowBox[{"(", "3", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"MatrixEqualQ", "[", 
    RowBox[{
     RowBox[{"MM9", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"1", ";;", "8"}], ",", 
        RowBox[{"1", ";;", "8"}]}], "]"}], "]"}], ",", 
     RowBox[{"MM9", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"25", ";;", "32"}], ",", 
        RowBox[{"25", ";;", "32"}]}], "]"}], "]"}]}], "]"}], 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"(", "1", ")"}], "=", 
     RowBox[{"(", "4", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"MatrixEqualQ", "[", 
    RowBox[{
     RowBox[{"MM9", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"9", ";;", "16"}], ",", 
        RowBox[{"1", ";;", "8"}]}], "]"}], "]"}], ",", 
     RowBox[{"MM9", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"25", ";;", "32"}], ",", 
        RowBox[{"17", ";;", "24"}]}], "]"}], "]"}]}], "]"}], 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "\[Rule]", "2"}], ")"}], "=", 
     RowBox[{"(", 
      RowBox[{"3", "\[Rule]", "4"}], ")"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"MatrixEqualQ", "[", 
    RowBox[{
     RowBox[{"MM9", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"1", ";;", "8"}], ",", 
        RowBox[{"9", ";;", "16"}]}], "]"}], "]"}], ",", 
     RowBox[{"MM9", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"17", ";;", "24"}], ",", 
        RowBox[{"25", ";;", "32"}]}], "]"}], "]"}]}], "]"}], 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "\[Rule]", "1"}], ")"}], "=", 
     RowBox[{"(", 
      RowBox[{"4", "\[Rule]", "3"}], ")"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"MatrixEqualQ", "[", 
    RowBox[{
     RowBox[{"MM9", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"1", ";;", "8"}], ",", 
        RowBox[{"17", ";;", "24"}]}], "]"}], "]"}], ",", 
     RowBox[{"MM9", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"9", ";;", "16"}], ",", 
        RowBox[{"25", ";;", "32"}]}], "]"}], "]"}]}], "]"}], 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"3", "\[Rule]", "1"}], ")"}], "=", 
     RowBox[{"(", 
      RowBox[{"4", "\[Rule]", "2"}], ")"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"MatrixEqualQ", "[", 
    RowBox[{
     RowBox[{"MM9", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"17", ";;", "24"}], ",", 
        RowBox[{"1", ";;", "8"}]}], "]"}], "]"}], ",", 
     RowBox[{"MM9", "[", 
      RowBox[{"[", 
       RowBox[{
        RowBox[{"25", ";;", "32"}], ",", 
        RowBox[{"9", ";;", "16"}]}], "]"}], "]"}]}], "]"}], 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "\[Rule]", "3"}], ")"}], "=", 
     RowBox[{"(", 
      RowBox[{"2", "\[Rule]", "4"}], ")"}]}], " ", "*)"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.6860296809009237`*^9, 3.686029824738964*^9}, {
  3.686029861970147*^9, 3.686029951637455*^9}, {3.686029983346274*^9, 
  3.686030101057246*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.686025865927541*^9, 3.686026255557424*^9, 3.6860264084554663`*^9, {
   3.6860291689196987`*^9, 3.686029183642748*^9}, 3.68602976444388*^9, 
   3.686029881105782*^9, 3.686029917643487*^9, 3.686030103952696*^9, 
   3.686030309488215*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.686025865927541*^9, 3.686026255557424*^9, 3.6860264084554663`*^9, {
   3.6860291689196987`*^9, 3.686029183642748*^9}, 3.68602976444388*^9, 
   3.686029881105782*^9, 3.686029917643487*^9, 3.686030103952696*^9, 
   3.686030309489616*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.686025865927541*^9, 3.686026255557424*^9, 3.6860264084554663`*^9, {
   3.6860291689196987`*^9, 3.686029183642748*^9}, 3.68602976444388*^9, 
   3.686029881105782*^9, 3.686029917643487*^9, 3.686030103952696*^9, 
   3.686030309490844*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.686025865927541*^9, 3.686026255557424*^9, 3.6860264084554663`*^9, {
   3.6860291689196987`*^9, 3.686029183642748*^9}, 3.68602976444388*^9, 
   3.686029881105782*^9, 3.686029917643487*^9, 3.686030103952696*^9, 
   3.6860303094920588`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.686025865927541*^9, 3.686026255557424*^9, 3.6860264084554663`*^9, {
   3.6860291689196987`*^9, 3.686029183642748*^9}, 3.68602976444388*^9, 
   3.686029881105782*^9, 3.686029917643487*^9, 3.686030103952696*^9, 
   3.686030309493862*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.686025865927541*^9, 3.686026255557424*^9, 3.6860264084554663`*^9, {
   3.6860291689196987`*^9, 3.686029183642748*^9}, 3.68602976444388*^9, 
   3.686029881105782*^9, 3.686029917643487*^9, 3.686030103952696*^9, 
   3.686030309495091*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.686025865927541*^9, 3.686026255557424*^9, 3.6860264084554663`*^9, {
   3.6860291689196987`*^9, 3.686029183642748*^9}, 3.68602976444388*^9, 
   3.686029881105782*^9, 3.686029917643487*^9, 3.686030103952696*^9, 
   3.6860303094963303`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ShowGraph", "[", 
  RowBox[{"MM9", ",", "GG3", ",", 
   RowBox[{"Range", "[", 
    RowBox[{"1", ",", "32"}], "]"}], ",", 
   RowBox[{"Join", "[", 
    RowBox[{"mycoords", ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "0.5"}], ",", 
          RowBox[{"-", "10.5"}]}], "}"}], "+", "#"}], "&"}], "/@", 
      "mycoords"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"10.5", ",", "0.5"}], "}"}], "+", "#"}], "&"}], "/@", 
      "mycoords"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"10", ",", 
          RowBox[{"-", "10"}]}], "}"}], "+", "#"}], "&"}], "/@", 
      "mycoords"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.686025895005067*^9, 3.68602596515091*^9}, {
  3.6860262663194427`*^9, 3.686026266541181*^9}, {3.686030130204896*^9, 
  3.68603013062742*^9}, {3.686030367483205*^9, 3.6860303815135527`*^9}, {
  3.68603154031456*^9, 3.686031620862632*^9}, {3.6860316924231052`*^9, 
  3.686031695581032*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19,
       20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32}, {
       SparseArray[
       Automatic, {32, 32}, 0, {
        1, {{0, 11, 12, 23, 24, 31, 36, 43, 48, 55, 55, 68, 70, 76, 81, 86, 
          92, 105, 107, 114, 114, 119, 125, 131, 136, 147, 148, 159, 160, 165,
           172, 177, 184}, {{2}, {5}, {6}, {7}, {8}, {9}, {10}, {13}, {14}, {
          22}, {30}, {10}, {4}, {5}, {6}, {7}, {8}, {16}, {19}, {20}, {23}, {
          24}, {32}, {20}, {2}, {4}, {6}, {10}, {18}, {21}, {26}, {2}, {4}, {
          5}, {10}, {22}, {2}, {4}, {8}, {12}, {15}, {20}, {28}, {2}, {4}, {
          7}, {16}, {20}, {7}, {10}, {13}, {14}, {15}, {16}, {30}, {3}, {4}, {
          5}, {6}, {12}, {13}, {14}, {15}, {16}, {27}, {28}, {31}, {32}, {
          4}, {28}, {4}, {10}, {12}, {14}, {26}, {29}, {4}, {10}, {12}, {
          13}, {30}, {7}, {10}, {12}, {16}, {28}, {2}, {8}, {10}, {12}, {
          15}, {28}, {1}, {2}, {7}, {8}, {18}, {21}, {22}, {23}, {24}, {25}, {
          26}, {29}, {30}, {2}, {26}, {5}, {20}, {21}, {22}, {23}, {24}, {
          32}, {5}, {18}, {20}, {22}, {26}, {4}, {6}, {18}, {20}, {21}, {
          26}, {2}, {18}, {20}, {24}, {28}, {31}, {2}, {18}, {20}, {23}, {
          32}, {7}, {9}, {10}, {15}, {16}, {23}, {26}, {29}, {30}, {31}, {
          32}, {10}, {5}, {13}, {19}, {20}, {21}, {22}, {28}, {29}, {30}, {
          31}, {32}, {20}, {13}, {20}, {26}, {28}, {30}, {4}, {12}, {14}, {
          20}, {26}, {28}, {29}, {10}, {23}, {26}, {28}, {32}, {2}, {10}, {
          18}, {24}, {26}, {28}, {31}}}, Pattern}], Null}, {
      EdgeLabels -> {
        DirectedEdge[21, 18] -> {{{"\!\(\*SubscriptBox[\(p\), \(3\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[5, 6] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, DirectedEdge[16, 8] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, 
         DirectedEdge[
          14, 10] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, 
         DirectedEdge[
          17, 26] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}, {{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, 
         DirectedEdge[
          1, 9] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, 
         DirectedEdge[
          13, 26] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, 
         DirectedEdge[5, 2] -> {{{"\!\(\*SubscriptBox[\(p\), \(3\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[22, 6] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, DirectedEdge[3, 4] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)"}}, {{
            "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          24, 32] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[3, 6] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)", "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, DirectedEdge[32, 18] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)"}}}, DirectedEdge[11, 13] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)"}}}, 
         DirectedEdge[
          24, 20] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          5, 26] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, 
         DirectedEdge[23, 20] -> {{{"\!\(\*SubscriptBox[\(q\), \(3\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[7, 2] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)"}}}, 
         DirectedEdge[
          8, 16] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[11, 4] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)"}}, {
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, 
         DirectedEdge[11, 16] -> {{{"\!\(\*SubscriptBox[\(p\), \(3\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[19, 22] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)", "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, DirectedEdge[29, 30] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, 
         DirectedEdge[
          9, 13] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)", "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, 
         DirectedEdge[
          1, 14] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[17, 23] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)"}}}, 
         DirectedEdge[
          8, 20] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          5, 21] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[17, 7] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)"}}}, DirectedEdge[11, 12] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)"}}, {{
            "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[15, 7] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, DirectedEdge[18, 2] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, 
         DirectedEdge[
          3, 23] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          6, 5] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[25, 15] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)"}}}, 
         DirectedEdge[
          14, 13] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, 
         DirectedEdge[
          18, 26] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[17, 24] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)", "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, 
         DirectedEdge[
          1, 2] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}, {
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)"}}}, 
         DirectedEdge[
          7, 15] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          11, 15] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)", "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          4, 20] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[1, 6] -> {{{"\!\(\*SubscriptBox[\(q\), \(3\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, 
         DirectedEdge[27, 32] -> {{{"\!\(\*SubscriptBox[\(p\), \(3\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[22, 4] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)"}}}, 
         DirectedEdge[
          7, 12] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          9, 10] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}, {
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)"}}}, 
         DirectedEdge[
          1, 10] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}, {{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, 
         DirectedEdge[
          30, 26] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[27, 29] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)"}}}, DirectedEdge[27, 21] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)"}}}, DirectedEdge[16, 10] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)"}}}, 
         DirectedEdge[
          22, 21] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, 
         DirectedEdge[
          25, 29] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)", "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, 
         DirectedEdge[
          11, 28] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}, {{
            "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[31, 23] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, 
         DirectedEdge[
          16, 28] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          19, 32] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)", "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          30, 29] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, 
         DirectedEdge[
          3, 20] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}, {{
            "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[22, 20] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)"}}}, DirectedEdge[28, 20] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, DirectedEdge[1, 8] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)", "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, 
         DirectedEdge[
          11, 32] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[25, 23] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)", "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, DirectedEdge[29, 13] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, 
         DirectedEdge[23, 18] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)"}}}, 
         DirectedEdge[
          1, 30] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, 
         DirectedEdge[
          19, 23] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)", "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          3, 32] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          14, 30] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[30, 4] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, DirectedEdge[3, 5] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)"}}}, DirectedEdge[1, 7] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)"}}}, 
         DirectedEdge[
          17, 18] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}, {
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)"}}}, DirectedEdge[13, 12] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)"}}}, DirectedEdge[15, 10] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)"}}}, 
         DirectedEdge[
          3, 19] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[25, 7] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, 
         DirectedEdge[21, 20] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)"}}}, DirectedEdge[12, 4] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, 
         DirectedEdge[27, 22] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, 
         DirectedEdge[
          8, 4] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          3, 16] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)", "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[19, 21] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)"}}}, DirectedEdge[7, 8] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, 
         DirectedEdge[
          17, 29] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, 
         DirectedEdge[
          13, 29] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, 
         DirectedEdge[
          12, 28] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[3, 8] -> {{{"\!\(\*SubscriptBox[\(p\), \(3\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[9, 7] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)", "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, 
         DirectedEdge[
          6, 2] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[11, 14] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)", "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, 
         DirectedEdge[
          1, 5] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)", "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[23, 2] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, 
         DirectedEdge[30, 12] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)"}}}, DirectedEdge[29, 28] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)"}}}, 
         DirectedEdge[
          5, 18] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[25, 32] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)", "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, 
         DirectedEdge[
          15, 28] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)", "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[32, 24] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, DirectedEdge[17, 8] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, DirectedEdge[9, 16] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)", "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, DirectedEdge[15, 16] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, 
         DirectedEdge[27, 30] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)", "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, DirectedEdge[32, 2] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, DirectedEdge[21, 5] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, 
         DirectedEdge[
          3, 7] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)", "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          23, 31] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          1, 22] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)", "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[5, 4] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)"}}}, DirectedEdge[11, 5] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)"}}}, 
         DirectedEdge[
          17, 30] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, 
         DirectedEdge[
          23, 28] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          21, 26] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)", "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[31, 26] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)"}}}, DirectedEdge[25, 30] -> {{{"\!\(\*SubscriptBox[\(q\), \(3\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[23, 24] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, 
         DirectedEdge[
          11, 31] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[27, 28] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)"}}, {{
            "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[27, 13] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)", "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, 
         DirectedEdge[
          8, 7] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[31, 10] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, 
         DirectedEdge[31, 32] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, DirectedEdge[24, 2] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)", "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, DirectedEdge[30, 14] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, 
         DirectedEdge[
          7, 20] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)", "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[29, 26] -> {{{"\!\(\*SubscriptBox[\(p\), \(3\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[29, 20] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, 
         DirectedEdge[
          3, 24] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[13, 4] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, 
         DirectedEdge[31, 28] -> {{{"\!\(\*SubscriptBox[\(q\), \(3\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[32, 10] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)", "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, 
         DirectedEdge[
          16, 15] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[19, 5] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)", "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, DirectedEdge[32, 26] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)"}}}, 
         DirectedEdge[
          24, 23] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[17, 1] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, 
         DirectedEdge[25, 31] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)"}}}, 
         DirectedEdge[
          9, 30] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)", "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[27, 20] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}, {
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)"}}}, 
         DirectedEdge[
          22, 18] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[16, 2] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)"}}}, DirectedEdge[9, 15] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)"}}}, 
         DirectedEdge[
          5, 10] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)", "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[6, 4] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)"}}}, DirectedEdge[30, 20] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)", "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, 
         DirectedEdge[9, 14] -> {{{"\!\(\*SubscriptBox[\(q\), \(3\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[13, 14] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, DirectedEdge[8, 2] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)"}}}, 
         DirectedEdge[15, 12] -> {{{"\!\(\*SubscriptBox[\(q\), \(3\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          7, 28] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          22, 26] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, 
         DirectedEdge[
          25, 26] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}, {
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)"}}}, DirectedEdge[17, 2] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}, {
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)"}}}, DirectedEdge[21, 22] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, 
         DirectedEdge[
          17, 21] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(3\)]\)\!\(\*SubscriptBox[\(q\), \
\(2\)]\)", "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, 
         DirectedEdge[
          32, 31] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          16, 12] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          17, 25] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[26, 10] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, 
         DirectedEdge[17, 22] -> {{{"\!\(\*SubscriptBox[\(q\), \(3\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, 
         DirectedEdge[
          6, 22] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[11, 6] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, 
         DirectedEdge[24, 18] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)"}}}, 
         DirectedEdge[
          6, 10] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)\!\(\*SubscriptBox[\(p\), \(3\
\)]\)\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[27, 19] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, DirectedEdge[11, 3] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, 
         DirectedEdge[30, 28] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)"}}}, DirectedEdge[25, 10] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}, {
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)"}}}, DirectedEdge[25, 16] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}, 
         DirectedEdge[13, 10] -> {{{"\!\(\*SubscriptBox[\(p\), \(3\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, DirectedEdge[14, 12] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)"}}}, 
         DirectedEdge[
          32, 28] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[7, 4] -> {{{"\!\(\*SubscriptBox[\(q\), \(3\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          2, 10] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, 
         DirectedEdge[
          27, 31] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)", "\!\(\*SubscriptBox[\(q\), \(4\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[27, 5] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(q\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(4\)]\)\!\(\*SubscriptBox[\(p\), \(1\
\)]\)\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, DirectedEdge[25, 9] -> {{
            Subscript[$CellContext`\[Iota], 2], {
            "\!\(\*SubscriptBox[\(p\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)"}}}, 
         DirectedEdge[
          11, 27] -> {{{
            "\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, 
         DirectedEdge[
          1, 13] -> {{{
            "\!\(\*SubscriptBox[\(p\), \(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)\!\(\*SubscriptBox[\(q\), \(2\)]\)", 
             "\!\(\*SubscriptBox[\(p\), \(2\)]\)"}, 
            Subscript[$CellContext`\[Iota], 4]}}, 
         DirectedEdge[19, 24] -> {{{"\!\(\*SubscriptBox[\(p\), \(3\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[19, 20] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(p\), \(1\)]\)\!\(\*SubscriptBox[\(p\), \
\(2\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(2\)]\)\!\(\*SubscriptBox[\(q\), \(1\
\)]\)"}}, {{
            "\!\(\*SubscriptBox[\(p\), \(3\)]\)\!\(\*SubscriptBox[\(p\), \
\(4\)]\)", 
             "\!\(\*SubscriptBox[\(q\), \(4\)]\)\!\(\*SubscriptBox[\(q\), \(3\
\)]\)"}, 
            Subscript[$CellContext`\[Iota], 1]}}, DirectedEdge[14, 4] -> {{
            Subscript[$CellContext`\[Iota], 3], {
            "\!\(\*SubscriptBox[\(q\), \(1\)]\)\!\(\*SubscriptBox[\(q\), \
\(4\)]\)", "\!\(\*SubscriptBox[\(p\), \(4\)]\)"}}}}, 
       VertexLabels -> {
        4 -> Placed["4:(bd)", Above], 11 -> Placed["11:(bd)", Above], 26 -> 
         Placed["26:(ca)", Above], 32 -> Placed["32:(cd)", Above], 17 -> 
         Placed["17:(ca)", Above], 18 -> Placed["18:(ca)", Above], 5 -> 
         Placed["5:(ba)", Above], 27 -> Placed["27:(bd)", Above], 24 -> 
         Placed["24:(cd)", Above], 3 -> Placed["3:(bd)", Above], 20 -> 
         Placed["20:(bd)", Above], 19 -> Placed["19:(bd)", Above], 9 -> 
         Placed["9:(ca)", Above], 30 -> Placed["30:(ba)", Above], 1 -> 
         Placed["1:(ca)", Above], 2 -> Placed["2:(ca)", Above], 16 -> 
         Placed["16:(cd)", Above], 12 -> Placed["12:(bd)", Above], 21 -> 
         Placed["21:(ba)", Above], 13 -> Placed["13:(ba)", Above], 28 -> 
         Placed["28:(bd)", Above], 23 -> Placed["23:(cd)", Above], 6 -> 
         Placed["6:(ba)", Above], 14 -> Placed["14:(ba)", Above], 29 -> 
         Placed["29:(ba)", Above], 10 -> Placed["10:(ca)", Above], 22 -> 
         Placed["22:(ba)", Above], 7 -> Placed["7:(cd)", Above], 31 -> 
         Placed["31:(cd)", Above], 25 -> Placed["25:(ca)", Above], 15 -> 
         Placed["15:(cd)", Above], 8 -> Placed["8:(cd)", Above]}, 
       VertexCoordinates -> {{-2, 1}, {2, 1}, {-2, -1}, {2, -1}, {-1, 2}, {1, 
         2}, {-1, -2}, {1, -2}, {-2.5, -9.5}, {1.5, -9.5}, {-2.5, -11.5}, {
         1.5, -11.5}, {-1.5, -8.5}, {0.5, -8.5}, {-1.5, -12.5}, {
         0.5, -12.5}, {8.5, 1.5}, {12.5, 1.5}, {8.5, -0.5}, {12.5, -0.5}, {
         9.5, 2.5}, {11.5, 2.5}, {9.5, -1.5}, {11.5, -1.5}, {8, -9}, {
         12, -9}, {8, -11}, {12, -11}, {9, -8}, {11, -8}, {9, -12}, {
         11, -12}}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
        0.013385598141695702`], {
         ArrowBox[{{-2., 1.}, {2., 1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "4"]},
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0., 1.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., 1.}, {-1., 2.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-1.5, 1.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., 1.}, {1., 2.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>", 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-0.5, 1.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., 1.}, {-1., -2.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>", "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-1.5, -0.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., 1.}, {1., -2.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-0.5, -0.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., 1.}, {-2.5, -9.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-2.25, -4.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., 1.}, {1.5, -9.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]},
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-0.25, -4.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., 1.}, {-1.5, -8.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-1.75, -3.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., 1.}, {0.5, -8.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-0.75, -3.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., 1.}, {11.5, 2.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {4.75, 1.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., 1.}, {11., -8.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {4.5, -3.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{2., 1.}, {1.5, -9.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.75, -4.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., -1.}, {2., -1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}], "}"}]},
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0., -1.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., -1.}, {-1., 2.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>", "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-1.5, 0.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., -1.}, {1., 2.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-0.5, 0.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., -1.}, {-1., -2.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-1.5, -1.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., -1.}, {1., -2.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>", 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-0.5, -1.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., -1.}, {0.5, -12.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-0.75, -6.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., -1.}, {8.5, -0.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {3.25, -0.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., -1.}, {12.5, -0.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]},
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {5.25, -0.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., -1.}, {9.5, -1.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {3.75, -1.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., -1.}, {11.5, -1.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {4.75, -1.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2., -1.}, {11., -12.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {4.5, -6.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{2., -1.}, {12.5, -0.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {7.25, -0.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-1., 2.}, {2., 1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>", 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0.5, 1.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-1., 2.}, {2., -1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0.5, 0.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{-1., 2.}, {1.288057039570842*^-16, 
          2.3288814943657057`}, {1., 2.}}], 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {5.551115123125783*^-17, 2.14},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-1., 2.}, {1.5, -9.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0.25, -3.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-1., 2.}, {12.5, 1.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {5.75, 1.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{-1., 2.}, {4.167779626408458, 
          3.976627845422477}, {9.5, 2.5}}], 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {4.214999999999999, 2.985000000000001},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-1., 2.}, {12., -9.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {5.5, -3.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1., 2.}, {2., 1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.5, 1.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1., 2.}, {2., -1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>", "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.5, 0.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{1., 2.}, {8.58704693047239*^-17, 
          1.671118505634294}, {-1., 2.}}], 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.942890293094024*^-16, 1.8599999999999999`},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1., 2.}, {1.5, -9.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.25, -3.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{1., 2.}, {6.16777962640845, 
          3.976627845422924}, {11.5, 2.5}}], 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {6.214999999999999, 2.9850000000000017`},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-1., -2.}, {2., 1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0.5, -0.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-1., -2.}, {2., -1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>", 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0.5, -1.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[
          BezierCurveBox[{{-1., -2.}, {-8.58704693047239*^-17, \
-1.671118505634294}, {1., -2.}}], 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-1.942890293094024*^-16, -1.8599999999999999`},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-1., -2.}, {1.5, -11.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
          {0.25, -6.75}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{-1., -2.}, {
          0.47662784542270614`, -7.332220373591639}, {-1.5, -12.5}}], 
          0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-0.5149999999999987, -7.284999999999999},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-1., -2.}, {12.5, -0.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {5.75, -1.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-1., -2.}, {12., -11.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {5.5, -6.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1., -2.}, {2., 1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>", "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.5, -0.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1., -2.}, {2., -1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.5, -1.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{
          1., -2.}, {-1.288057039570842*^-16, -2.3288814943657057`}, {-1., \
-2.}}], 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-5.551115123125783*^-17, -2.14},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{1., -2.}, {
          2.476627845422706, -7.332220373591502}, {0.5, -12.5}}], 
          0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.4850000000000014`, -7.284999999999999},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1., -2.}, {12.5, -0.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {6.75, -1.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2.5, -9.5}, {-1., -2.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-1.75, -5.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2.5, -9.5}, {1.5, -9.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "4"]},
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-0.5, -9.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2.5, -9.5}, {-1.5, -8.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-2., -9.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2.5, -9.5}, {0.5, -8.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>", 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-1., -9.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2.5, -9.5}, {-1.5, -12.5}}, 0.08031358885017421], 
         InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>", "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-2., -11.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2.5, -9.5}, {0.5, -12.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-1., -11.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2.5, -9.5}, {11., -8.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {4.25, -8.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2.5, -11.5}, {-2., -1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-2.25, -6.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2.5, -11.5}, {2., -1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}], "}"}]},
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-0.25, -6.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2.5, -11.5}, {-1., 2.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-1.75, -4.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2.5, -11.5}, {1., 2.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-0.75, -4.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2.5, -11.5}, {1.5, -11.5}}, 0.08031358885017421], 
         InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}], "}"}]},
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
          {-0.5, -11.5}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2.5, -11.5}, {-1.5, -8.5}}, 0.08031358885017421], 
         InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>", "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-2., -10.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2.5, -11.5}, {0.5, -8.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-1., -10.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2.5, -11.5}, {-1.5, -12.5}}, 0.08031358885017421], 
         InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-2., -12.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2.5, -11.5}, {0.5, -12.5}}, 0.08031358885017421], 
         InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>", 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-1., -12.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2.5, -11.5}, {8., -11.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {2.75, -11.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2.5, -11.5}, {12., -11.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]},
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {4.75, -11.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2.5, -11.5}, {9., -12.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {3.25, -11.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-2.5, -11.5}, {11., -12.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {4.25, -11.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.5, -11.5}, {2., -1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.75, -6.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.5, -11.5}, {12., -11.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {6.75, -11.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-1.5, -8.5}, {2., -1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0.25, -4.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-1.5, -8.5}, {1.5, -9.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>", 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0., -9.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-1.5, -8.5}, {1.5, -11.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0., -10.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[
          BezierCurveBox[{{-1.5, -8.5}, {-0.4999999999999626, \
-8.171118505621664}, {0.5, -8.5}}], 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-0.4999999999999997, -8.36},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-1.5, -8.5}, {12., -9.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {5.25, -8.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{-1.5, -8.5}, {
          3.6677796264084797`, -6.523372154577187}, {9., -8.}}], 
          0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {3.7150000000000003`, -7.515000000000001},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.5, -8.5}, {2., -1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.25, -4.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.5, -8.5}, {1.5, -9.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1., -9.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.5, -8.5}, {1.5, -11.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>", "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1., -10.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{
          
          0.5, -8.5}, {-0.4999999999999998, -8.828881494365662}, {-1.5, \
-8.5}}], 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-0.4999999999999998, -8.64},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{0.5, -8.5}, {
          5.66777962640847, -6.52337215457811}, {11., -8.}}], 
          0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
          {5.714999999999999, -7.515000000000001}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[
          BezierCurveBox[{{-1.5, -12.5}, {-2.976627845422716, \
-7.167779626408217}, {-1., -2.}}], 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-1.9850000000000012`, -7.214999999999998},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-1.5, -12.5}, {1.5, -9.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0., -11.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-1.5, -12.5}, {1.5, -11.5}}, 0.08031358885017421], 
         InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>", 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0., -12.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[
          BezierCurveBox[{{-1.5, -12.5}, {-0.4999999999999626, \
-12.171118505623394`}, {0.5, -12.5}}], 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-0.4999999999999997, -12.36},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{-1.5, -12.5}, {12., -11.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {5.25, -11.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.5, -12.5}, {2., 1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1.25, -5.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{
          0.5, -12.5}, {-0.9766278454227154, -7.167779626408532}, {1., -2.}}],
           0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {0.014999999999998744`, -7.214999999999998},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.5, -12.5}, {1.5, -9.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>", "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1., -11.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.5, -12.5}, {1.5, -11.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {1., -12.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{
          0.5, -12.5}, {-0.5000000000000373, -12.828881494376086`}, {-1.5, \
-12.5}}], 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {-0.5000000000000002, -12.64},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.5, -12.5}, {12., -11.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {6.25, -11.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8.5, 1.5}, {-2., 1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {3.25, 1.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8.5, 1.5}, {2., 1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]},
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {5.25, 1.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8.5, 1.5}, {-1., -2.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {3.75, -0.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8.5, 1.5}, {1., -2.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {4.75, -0.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8.5, 1.5}, {12.5, 1.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "4"]},
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10.5, 1.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8.5, 1.5}, {9.5, 2.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {9., 2.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8.5, 1.5}, {11.5, 2.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>", 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10., 2.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8.5, 1.5}, {9.5, -1.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>", "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {9., 0.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8.5, 1.5}, {11.5, -1.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10., 0.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8.5, 1.5}, {8., -9.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {8.25, -3.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8.5, 1.5}, {12., -9.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]},
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10.25, -3.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8.5, 1.5}, {9., -8.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {8.75, -3.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8.5, 1.5}, {11., -8.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {9.75, -3.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{12.5, 1.5}, {2., 1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {7.25, 1.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{12.5, 1.5}, {12., -9.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {12.25, -3.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8.5, -0.5}, {-1., 2.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {3.75, 0.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8.5, -0.5}, {12.5, -0.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}], "}"}]},
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10.5, -0.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8.5, -0.5}, {9.5, 2.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>", "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {9., 1.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8.5, -0.5}, {11.5, 2.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10., 1.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8.5, -0.5}, {9.5, -1.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {9., -1.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8.5, -0.5}, {11.5, -1.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>", 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10., -1.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8.5, -0.5}, {11., -12.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {9.75, -6.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{9.5, 2.5}, {4.332220373591539, 
          0.5233721545772432}, {-1., 2.}}], 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {4.284999999999998, 1.5149999999999992`},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{9.5, 2.5}, {12.5, 1.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>", 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {11., 2.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{9.5, 2.5}, {12.5, -0.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {11., 1.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{9.5, 2.5}, {10.500000000000002`, 
          2.828881494352457}, {11.5, 2.5}}], 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10.5, 2.6400000000000006`},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{9.5, 2.5}, {12., -9.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10.75, -3.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{11.5, 2.5}, {2., -1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {6.75, 0.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{11.5, 2.5}, {6.332220373591541, 
          0.523372154577076}, {1., 2.}}], 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {6.284999999999999, 1.5149999999999992`},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{11.5, 2.5}, {12.5, 1.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {12., 2.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{11.5, 2.5}, {12.5, -0.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>", "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {12., 1.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{11.5, 2.5}, {10.500000000000002`, 
          2.171118505631461}, {9.5, 2.5}}], 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10.5, 2.3600000000000003`},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{11.5, 2.5}, {12., -9.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {11.75, -3.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{9.5, -1.5}, {2., 1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {5.75, -0.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{9.5, -1.5}, {12.5, 1.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {11., 0.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{9.5, -1.5}, {12.5, -0.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>", 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {11., -1.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{9.5, -1.5}, {
          10.500000000000002`, -1.171118505633032}, {11.5, -1.5}}], 
          0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10.5, -1.3599999999999999`},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{9.5, -1.5}, {12., -11.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10.75, -6.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{9.5, -1.5}, {
          10.976627845422719`, -6.832220373590131}, {9., -12.}}], 
          0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {9.985000000000003, -6.784999999999999},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{11.5, -1.5}, {2., 1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {6.75, -0.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{11.5, -1.5}, {12.5, 1.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>", "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {12., 0.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{11.5, -1.5}, {12.5, -0.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {12., -1.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{11.5, -1.5}, {
          10.5, -1.8288814943616074`}, {9.5, -1.5}}], 0.08031358885017421], 
         InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10.5, -1.6400000000000001`},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{11.5, -1.5}, {
          12.976627845422698`, -6.832220373590131}, {11., -12.}}], 
          0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
          {11.985000000000003`, -6.785000000000001}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8., -9.}, {-1., -2.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {3.5, -5.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8., -9.}, {-2.5, -9.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {2.75, -9.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8., -9.}, {1.5, -9.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]},
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {4.75, -9.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8., -9.}, {-1.5, -12.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {3.25, -10.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8., -9.}, {0.5, -12.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {4.25, -10.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8., -9.}, {9.5, -1.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {8.75, -5.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8., -9.}, {12., -9.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "4"]},
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10., -9.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8., -9.}, {9., -8.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {8.5, -8.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8., -9.}, {11., -8.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>", 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {9.5, -8.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8., -9.}, {9., -12.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>", "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {8.5, -10.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8., -9.}, {11., -12.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {9.5, -10.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{12., -9.}, {1.5, -9.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {6.75, -9.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8., -11.}, {-1., 2.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {3.5, -4.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8., -11.}, {-1.5, -8.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {3.25, -9.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8., -11.}, {8.5, -0.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {8.25, -5.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8., -11.}, {12.5, -0.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]},
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10.25, -5.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8., -11.}, {9.5, 2.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {8.75, -4.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8., -11.}, {11.5, 2.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {9.75, -4.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8., -11.}, {12., -11.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}], "}"}]},
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10., -11.},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8., -11.}, {9., -8.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>", "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {8.5, -9.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8., -11.}, {11., -8.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {9.5, -9.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8., -11.}, {9., -12.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {8.5, -11.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{8., -11.}, {11., -12.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>", 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {9.5, -11.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{12., -11.}, {12.5, -0.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {12.25, -5.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{9., -8.}, {
          3.832220373591554, -9.97662784542299}, {-1.5, -8.5}}], 
          0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {3.7849999999999984`, -8.985000000000003},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{9., -8.}, {12.5, -0.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10.75, -4.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{9., -8.}, {12., -9.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>", 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10.5, -8.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{9., -8.}, {12., -11.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10.5, -9.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{9., -8.}, {10., -7.671118505719925}, {
          11., -8.}}], 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10., -7.859999999999999},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{11., -8.}, {2., -1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {6.5, -4.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{11., -8.}, {1.5, -11.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {6.25, -9.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{11., -8.}, {
          5.83222037359154, -9.97662784542347}, {0.5, -8.5}}], 
          0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {5.784999999999998, -8.985000000000001},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{11., -8.}, {12.5, -0.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {11.75, -4.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{11., -8.}, {12., -9.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {11.5, -8.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{11., -8.}, {12., -11.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "3"], 
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>", "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {11.5, -9.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{11., -8.}, {
          10.000000000000002`, -8.32888149433822}, {9., -8.}}], 
          0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "4"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10., -8.14},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{9., -12.}, {1.5, -9.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {5.25, -10.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{9., -12.}, {
          7.523372154577284, -6.667779626409138}, {9.5, -1.5}}], 
          0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {8.515, -6.715000000000001},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{9., -12.}, {12., -9.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10.5, -10.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{9., -12.}, {12., -11.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>", 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10.5, -11.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{9., -12.}, {
          10.000000000000037`, -11.671118505633954`}, {11., -12.}}], 
          0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10., -11.86},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{11., -12.}, {2., 1.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {6.5, -5.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{11., -12.}, {1.5, -9.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {6.25, -10.75},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{11., -12.}, {12.5, 1.5}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}], "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {11.75, -5.25},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{11., -12.}, {
          9.52337215457728, -6.6677796264080404`}, {11.5, -1.5}}], 
          0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
               "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10.515, -6.715},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{11., -12.}, {12., -9.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              SubscriptBox["\[Iota]", "2"], 
              RowBox[{
              "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>", "}"}]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {11.5, -10.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{11., -12.}, {12., -11.}}, 0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}], "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {11.5, -11.5},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[BezierCurveBox[{{11., -12.}, {
          9.999999999999964, -12.32888149427758}, {9., -12.}}], 
          0.08031358885017421], InsetBox[
          RowBox[{"(", "\[NoBreak]", GridBox[{
             {
              RowBox[{"{", 
               
               RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
                ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], 
               "}"}], 
              SubscriptBox["\[Iota]", "1"]}
            },
            
            GridBoxAlignment->{
             "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
            GridBoxSpacings->{"Columns" -> {
                Offset[0.27999999999999997`], {
                 Offset[0.7]}, 
                Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
                Offset[0.2], {
                 Offset[0.4]}, 
                Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], {10., -12.14},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {DiskBox[{-2., 1.}, 0.08031358885017421], 
         InsetBox["\<\"1:(ca)\"\>", 
          Offset[{0, 2}, {-2., 1.0803135888501743`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{2., 1.}, 0.08031358885017421], 
         InsetBox["\<\"2:(ca)\"\>", Offset[{0, 2}, {2., 1.0803135888501743`}],
           ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{-2., -1.}, 0.08031358885017421], 
         InsetBox["\<\"3:(bd)\"\>", 
          Offset[{0, 2}, {-2., -0.9196864111498257}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{2., -1.}, 0.08031358885017421], 
         InsetBox["\<\"4:(bd)\"\>", Offset[{0, 2}, {2., -0.9196864111498257}],
           ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{-1., 2.}, 0.08031358885017421], 
         InsetBox["\<\"5:(ba)\"\>", 
          Offset[{0, 2}, {-1., 2.0803135888501743`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{1., 2.}, 0.08031358885017421], 
         InsetBox["\<\"6:(ba)\"\>", Offset[{0, 2}, {1., 2.0803135888501743`}],
           ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{-1., -2.}, 0.08031358885017421], 
         InsetBox["\<\"7:(cd)\"\>", 
          Offset[{0, 2}, {-1., -1.9196864111498257`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{1., -2.}, 0.08031358885017421], 
         InsetBox["\<\"8:(cd)\"\>", 
          Offset[{0, 2}, {1., -1.9196864111498257`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{-2.5, -9.5}, 0.08031358885017421], 
         InsetBox["\<\"9:(ca)\"\>", 
          Offset[{0, 2}, {-2.5, -9.419686411149826}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{1.5, -9.5}, 0.08031358885017421],
          InsetBox["\<\"10:(ca)\"\>", 
          Offset[{0, 2}, {1.5, -9.419686411149826}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{-2.5, -11.5}, 0.08031358885017421], 
         InsetBox["\<\"11:(bd)\"\>", 
          Offset[{0, 2}, {-2.5, -11.419686411149826`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.5, -11.5}, 0.08031358885017421], 
         InsetBox["\<\"12:(bd)\"\>", 
          Offset[{0, 2}, {1.5, -11.419686411149826`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{-1.5, -8.5}, 0.08031358885017421], 
         InsetBox["\<\"13:(ba)\"\>", 
          Offset[{0, 2}, {-1.5, -8.419686411149826}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{0.5, -8.5}, 0.08031358885017421],
          InsetBox["\<\"14:(ba)\"\>", 
          Offset[{0, 2}, {0.5, -8.419686411149826}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{-1.5, -12.5}, 0.08031358885017421], 
         InsetBox["\<\"15:(cd)\"\>", 
          Offset[{0, 2}, {-1.5, -12.419686411149826`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.5, -12.5}, 0.08031358885017421], 
         InsetBox["\<\"16:(cd)\"\>", 
          Offset[{0, 2}, {0.5, -12.419686411149826`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{8.5, 1.5}, 0.08031358885017421], 
         InsetBox["\<\"17:(ca)\"\>", 
          Offset[{0, 2}, {8.5, 1.5803135888501743`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{12.5, 1.5}, 0.08031358885017421],
          InsetBox["\<\"18:(ca)\"\>", 
          Offset[{0, 2}, {12.5, 1.5803135888501743`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{8.5, -0.5}, 0.08031358885017421],
          InsetBox["\<\"19:(bd)\"\>", 
          Offset[{0, 2}, {8.5, -0.4196864111498258}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{12.5, -0.5}, 0.08031358885017421], 
         InsetBox["\<\"20:(bd)\"\>", 
          Offset[{0, 2}, {12.5, -0.4196864111498258}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{9.5, 2.5}, 0.08031358885017421], 
         InsetBox["\<\"21:(ba)\"\>", 
          Offset[{0, 2}, {9.5, 2.5803135888501743`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{11.5, 2.5}, 0.08031358885017421],
          InsetBox["\<\"22:(ba)\"\>", 
          Offset[{0, 2}, {11.5, 2.5803135888501743`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{9.5, -1.5}, 0.08031358885017421],
          InsetBox["\<\"23:(cd)\"\>", 
          Offset[{0, 2}, {9.5, -1.4196864111498257`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{11.5, -1.5}, 0.08031358885017421], 
         InsetBox["\<\"24:(cd)\"\>", 
          Offset[{0, 2}, {11.5, -1.4196864111498257`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{8., -9.}, 0.08031358885017421], 
         InsetBox["\<\"25:(ca)\"\>", Offset[{0, 2}, {8., -8.919686411149826}],
           ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{12., -9.}, 0.08031358885017421], 
         InsetBox["\<\"26:(ca)\"\>", 
          Offset[{0, 2}, {12., -8.919686411149826}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{8., -11.}, 0.08031358885017421], 
         InsetBox["\<\"27:(bd)\"\>", 
          Offset[{0, 2}, {8., -10.919686411149826`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{12., -11.}, 0.08031358885017421],
          InsetBox["\<\"28:(bd)\"\>", 
          Offset[{0, 2}, {12., -10.919686411149826`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{9., -8.}, 0.08031358885017421], 
         InsetBox["\<\"29:(ba)\"\>", Offset[{0, 2}, {9., -7.919686411149826}],
           ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{11., -8.}, 0.08031358885017421], 
         InsetBox["\<\"30:(ba)\"\>", 
          Offset[{0, 2}, {11., -7.919686411149826}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{9., -12.}, 0.08031358885017421], 
         InsetBox["\<\"31:(cd)\"\>", 
          Offset[{0, 2}, {9., -11.919686411149826`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{11., -12.}, 0.08031358885017421],
          InsetBox["\<\"32:(cd)\"\>", 
          Offset[{0, 2}, {11., -11.919686411149826`}], ImageScaled[{0.5, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None,
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->{Automatic, 949.5812425870422}]], "Output",
 CellChangeTimes->{
  3.686030136397827*^9, 3.686030392561842*^9, {3.686031551779182*^9, 
   3.686031593298246*^9}, 3.6860316233282967`*^9, 
   3.686031696491111*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ListOfAllLabels", "[", "mat_", "]"}], " ", "returns", " ", "a", 
     " ", "list", " ", "of", " ", "all", " ", "labels", " ", "appearing", " ",
      "in", " ", "mat"}], ";"}], "\[IndentingNewLine]", " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"ListOfAllLabels", "[", "MM9", "]"}]}]], "Input",
 CellChangeTimes->{{3.679237666887838*^9, 3.679237667346768*^9}, {
  3.679239191225569*^9, 3.679239191450878*^9}, {3.6792394544071093`*^9, 
  3.679239454672257*^9}, {3.6792399684612503`*^9, 3.6792399688802633`*^9}, {
  3.6793800792981243`*^9, 3.679380100506167*^9}, {3.679380264670209*^9, 
  3.679380267101907*^9}, {3.679381410516021*^9, 3.6793814106679087`*^9}, {
  3.685196601266109*^9, 3.685196606857038*^9}, {3.6852577371148367`*^9, 
  3.685257764209899*^9}, {3.686030180532508*^9, 3.686030181140396*^9}, {
  3.686030602591702*^9, 3.686030603230916*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      SubscriptBox["\[Iota]", "2"], 
      RowBox[{"{", 
       SubscriptBox["\[Iota]", "1"], "}"}], "\<\"\[LeftRightArrow]\"\>", "2", 
      RowBox[{"{", "1", "}"}]},
     {
      SubscriptBox["\[Iota]", "2"], 
      RowBox[{"{", 
       SubscriptBox["\[Iota]", "4"], "}"}], "\<\"\[LeftRightArrow]\"\>", "2", 
      RowBox[{"{", "4", "}"}]},
     {
      SubscriptBox["\[Iota]", "2"], 
      RowBox[{
      "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>", 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "2", 
      RowBox[{"{", "93", "}"}]},
     {
      SubscriptBox["\[Iota]", "2"], 
      RowBox[{
      "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>", 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "2", 
      RowBox[{"{", "338", "}"}]},
     {
      SubscriptBox["\[Iota]", "2"], 
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "2", 
      RowBox[{"{", 
       RowBox[{"106", ",", "81"}], "}"}]},
     {
      SubscriptBox["\[Iota]", "2"], 
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}], 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "2", 
      RowBox[{"{", 
       RowBox[{"106", ",", "365"}], "}"}]},
     {
      SubscriptBox["\[Iota]", "2"], 
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "2", 
      RowBox[{"{", 
       RowBox[{"164", ",", "81"}], "}"}]},
     {
      SubscriptBox["\[Iota]", "2"], 
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}], 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "2", 
      RowBox[{"{", 
       RowBox[{"164", ",", "365"}], "}"}]},
     {
      SubscriptBox["\[Iota]", "2"], 
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "2", 
      RowBox[{"{", 
       RowBox[{"191", ",", "378"}], "}"}]},
     {
      SubscriptBox["\[Iota]", "2"], 
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}], 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "2", 
      RowBox[{"{", 
       RowBox[{"311", ",", "84"}], "}"}]},
     {
      SubscriptBox["\[Iota]", "2"], 
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "2", 
      RowBox[{"{", 
       RowBox[{"311", ",", "378"}], "}"}]},
     {
      SubscriptBox["\[Iota]", "2"], 
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "2", 
      RowBox[{"{", 
       RowBox[{"106", ",", "218", ",", "378"}], "}"}]},
     {
      SubscriptBox["\[Iota]", "2"], 
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "2", 
      RowBox[{"{", 
       RowBox[{"164", ",", "218", ",", "378"}], "}"}]},
     {
      SubscriptBox["\[Iota]", "2"], 
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "2", 
      RowBox[{"{", 
       RowBox[{"311", ",", "161", ",", "81"}], "}"}]},
     {
      SubscriptBox["\[Iota]", "2"], 
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}], 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "2", 
      RowBox[{"{", 
       RowBox[{"311", ",", "161", ",", "365"}], "}"}]},
     {
      SubscriptBox["\[Iota]", "3"], 
      RowBox[{"{", 
       SubscriptBox["\[Iota]", "1"], "}"}], "\<\"\[LeftRightArrow]\"\>", "3", 
      RowBox[{"{", "1", "}"}]},
     {
      SubscriptBox["\[Iota]", "3"], 
      RowBox[{"{", 
       SubscriptBox["\[Iota]", "4"], "}"}], "\<\"\[LeftRightArrow]\"\>", "3", 
      RowBox[{"{", "4", "}"}]},
     {
      SubscriptBox["\[Iota]", "3"], 
      RowBox[{
      "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>", 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "3", 
      RowBox[{"{", "93", "}"}]},
     {
      SubscriptBox["\[Iota]", "3"], 
      RowBox[{
      "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>", 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "3", 
      RowBox[{"{", "338", "}"}]},
     {
      SubscriptBox["\[Iota]", "3"], 
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "3", 
      RowBox[{"{", 
       RowBox[{"106", ",", "81"}], "}"}]},
     {
      SubscriptBox["\[Iota]", "3"], 
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(1\\)]\\)\"\>"}], 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "3", 
      RowBox[{"{", 
       RowBox[{"106", ",", "365"}], "}"}]},
     {
      SubscriptBox["\[Iota]", "3"], 
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "3", 
      RowBox[{"{", 
       RowBox[{"164", ",", "81"}], "}"}]},
     {
      SubscriptBox["\[Iota]", "3"], 
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}], 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "3", 
      RowBox[{"{", 
       RowBox[{"191", ",", "84"}], "}"}]},
     {
      SubscriptBox["\[Iota]", "3"], 
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "3", 
      RowBox[{"{", 
       RowBox[{"191", ",", "378"}], "}"}]},
     {
      SubscriptBox["\[Iota]", "3"], 
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}], 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "3", 
      RowBox[{"{", 
       RowBox[{"311", ",", "84"}], "}"}]},
     {
      SubscriptBox["\[Iota]", "3"], 
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "3", 
      RowBox[{"{", 
       RowBox[{"311", ",", "378"}], "}"}]},
     {
      SubscriptBox["\[Iota]", "3"], 
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(1\\)]\\)\"\>"}], 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "3", 
      RowBox[{"{", 
       RowBox[{"106", ",", "218", ",", "84"}], "}"}]},
     {
      SubscriptBox["\[Iota]", "3"], 
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>"}], 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "3", 
      RowBox[{"{", 
       RowBox[{"106", ",", "218", ",", "378"}], "}"}]},
     {
      SubscriptBox["\[Iota]", "3"], 
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "3", 
      RowBox[{"{", 
       RowBox[{"191", ",", "161", ",", "81"}], "}"}]},
     {
      SubscriptBox["\[Iota]", "3"], 
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(1\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>"}], 
       "}"}], "\<\"\[LeftRightArrow]\"\>", "3", 
      RowBox[{"{", 
       RowBox[{"311", ",", "161", ",", "81"}], "}"}]},
     {
      RowBox[{"{", 
       SubscriptBox["\[Iota]", "2"], "}"}], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", "2", "}"}], "1"},
     {
      RowBox[{"{", 
       SubscriptBox["\[Iota]", "2"], "}"}], 
      SubscriptBox["\[Iota]", "4"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", "2", "}"}], "4"},
     {
      RowBox[{"{", 
       SubscriptBox["\[Iota]", "3"], "}"}], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", "3", "}"}], "1"},
     {
      RowBox[{"{", 
       SubscriptBox["\[Iota]", "3"], "}"}], 
      SubscriptBox["\[Iota]", "4"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", "3", "}"}], "4"},
     {
      RowBox[{
      "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>", "}"}], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", "229", "}"}], "1"},
     {
      RowBox[{
      "{", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>", "}"}], 
      SubscriptBox["\[Iota]", "4"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", "229", "}"}], "4"},
     {
      RowBox[{
      "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>", "}"}], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", "268", "}"}], "1"},
     {
      RowBox[{
      "{", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>", "}"}], 
      SubscriptBox["\[Iota]", "4"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", "268", "}"}], "4"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"97", ",", "164"}], "}"}], "1"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "4"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"97", ",", "164"}], "}"}], "4"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"97", ",", "259"}], "}"}], "1"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "4"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"97", ",", "259"}], "}"}], "4"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"124", ",", "164"}], "}"}], "1"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "4"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"124", ",", "164"}], "}"}], "4"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"124", ",", "259"}], "}"}], "1"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "4"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"349", ",", "256"}], "}"}], "4"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"349", ",", "345"}], "}"}], "1"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "4"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"349", ",", "345"}], "}"}], "4"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"362", ",", "256"}], "}"}], "1"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "4"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"362", ",", "256"}], "}"}], "4"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"362", ",", "345"}], "}"}], "1"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "4"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"362", ",", "345"}], "}"}], "4"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(3\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "4"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"97", ",", "346", ",", "256"}], "}"}], "4"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"97", ",", "346", ",", "345"}], "}"}], "1"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "4"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"97", ",", "346", ",", "345"}], "}"}], "4"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \\(2\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"124", ",", "346", ",", "345"}], "}"}], "1"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "4"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"349", ",", "151", ",", "164"}], "}"}], "4"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"362", ",", "151", ",", "164"}], "}"}], "1"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(4\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "4"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"362", ",", "151", ",", "164"}], "}"}], "4"},
     {
      RowBox[{"{", 
       RowBox[{"\<\"\\!\\(\\*SubscriptBox[\\(q\\), \\(2\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(p\\), \
\\(2\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \
\\(3\\)]\\)\\!\\(\\*SubscriptBox[\\(p\\), \\(4\\)]\\)\"\>", 
        ",", "\<\"\\!\\(\\*SubscriptBox[\\(q\\), \
\\(4\\)]\\)\\!\\(\\*SubscriptBox[\\(q\\), \\(3\\)]\\)\"\>"}], "}"}], 
      SubscriptBox["\[Iota]", "1"], "\<\"\[LeftRightArrow]\"\>", 
      RowBox[{"{", 
       RowBox[{"362", ",", "151", ",", "259"}], "}"}], "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.679238299497143*^9, 3.679239205140809*^9, {3.679239585409433*^9, 
   3.679239608398715*^9}, 3.679239970015602*^9, 3.679241783079337*^9, 
   3.6792425566861753`*^9, {3.679380073444624*^9, 3.679380091254319*^9}, 
   3.679380268153495*^9, 3.679380444312344*^9, {3.679381408476821*^9, 
   3.679381411370544*^9}, 3.679382230400732*^9, 3.679382626632945*^9, 
   3.6839008168762827`*^9, 3.683901513492984*^9, 3.6839068558028727`*^9, 
   3.683907956029022*^9, 3.683949626834029*^9, 3.683949930836933*^9, 
   3.683952438601931*^9, 3.683958978077808*^9, 3.684043403578092*^9, 
   3.685196584455429*^9, 3.6852577320115843`*^9, 3.6852591337127*^9, 
   3.685706334950254*^9, 3.6857118404975977`*^9, {3.685712448133966*^9, 
   3.685712455531282*^9}, 3.685712585741621*^9, 3.686030181940481*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1080, 1894},
WindowMargins->{{Automatic, -2}, {0, Automatic}},
FrontEndVersion->"10.3 for Linux x86 (64-bit) (December 10, 2015)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[422, 15, 275, 4, 93, "Title"],
Cell[700, 21, 417, 8, 71, "Text"],
Cell[CellGroupData[{
Cell[1142, 33, 349, 5, 65, "Section"],
Cell[CellGroupData[{
Cell[1516, 42, 366, 6, 32, "Input"],
Cell[1885, 50, 3902, 60, 537, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5836, 116, 173, 2, 65, "Section"],
Cell[CellGroupData[{
Cell[6034, 122, 25558, 556, 2820, "Input"],
Cell[CellGroupData[{
Cell[31617, 682, 1776, 25, 23, "Print"],
Cell[33396, 709, 1860, 29, 23, "Print"],
Cell[35259, 740, 1884, 29, 23, "Print"],
Cell[37146, 771, 2053, 33, 23, "Print"],
Cell[39202, 806, 2400, 38, 43, "Print"],
Cell[41605, 846, 2402, 38, 43, "Print"],
Cell[44010, 886, 1987, 32, 23, "Print"],
Cell[46000, 920, 1987, 32, 23, "Print"],
Cell[47990, 954, 2412, 38, 43, "Print"],
Cell[50405, 994, 1766, 25, 23, "Print"],
Cell[52174, 1021, 2672, 43, 43, "Print"],
Cell[54849, 1066, 1784, 26, 23, "Print"],
Cell[56636, 1094, 1783, 26, 23, "Print"],
Cell[58422, 1122, 1800, 26, 23, "Print"],
Cell[60225, 1150, 1799, 26, 23, "Print"],
Cell[62027, 1178, 1884, 29, 23, "Print"],
Cell[63914, 1209, 1882, 29, 23, "Print"],
Cell[65799, 1240, 1884, 29, 23, "Print"],
Cell[67686, 1271, 1884, 29, 23, "Print"],
Cell[69573, 1302, 2134, 35, 23, "Print"],
Cell[71710, 1339, 2132, 35, 23, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[73903, 1381, 469, 6, 65, "Section"],
Cell[CellGroupData[{
Cell[74397, 1391, 1619, 39, 121, "Input"],
Cell[76019, 1432, 387, 5, 65, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[76455, 1443, 348, 4, 65, "Section"],
Cell[CellGroupData[{
Cell[76828, 1451, 250, 4, 32, "Input"],
Cell[CellGroupData[{
Cell[77103, 1459, 2246, 49, 58, "Print"],
Cell[79352, 1510, 2280, 49, 58, "Print"]
}, Open  ]]
}, Open  ]],
Cell[81659, 1563, 1577, 33, 77, "Input"],
Cell[CellGroupData[{
Cell[83261, 1600, 3138, 66, 187, "Input"],
Cell[86402, 1668, 48516, 1421, 600, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[134955, 3094, 194, 3, 32, "Input"],
Cell[CellGroupData[{
Cell[135174, 3101, 2403, 52, 58, "Print"],
Cell[137580, 3155, 2437, 52, 58, "Print"],
Cell[140020, 3209, 1907, 40, 69, "Print"],
Cell[141930, 3251, 1907, 40, 69, "Print"],
Cell[143840, 3293, 1189, 19, 23, "Print"],
Cell[145032, 3314, 11213, 197, 100, "Print"],
Cell[156248, 3513, 11190, 198, 100, "Print"],
Cell[167441, 3713, 959, 14, 23, "Print"],
Cell[168403, 3729, 1247, 22, 23, "Print"],
Cell[169653, 3753, 963, 14, 23, "Print"],
Cell[170619, 3769, 1245, 22, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[171913, 3797, 7181, 116, 329, "Input"],
Cell[CellGroupData[{
Cell[179119, 3917, 2498, 35, 62, "Print"],
Cell[181620, 3954, 2664, 43, 23, "Print"],
Cell[184287, 3999, 2664, 43, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[187000, 4048, 123, 2, 32, "Input"],
Cell[CellGroupData[{
Cell[187148, 4054, 84252, 1979, 277, "Print"],
Cell[271403, 6035, 84246, 1980, 277, "Print"]
}, Open  ]]
}, Open  ]],
Cell[355676, 8019, 150, 3, 32, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[355863, 8027, 360, 5, 65, "Section"],
Cell[CellGroupData[{
Cell[356248, 8036, 250, 4, 32, "Input"],
Cell[CellGroupData[{
Cell[356523, 8044, 1143, 20, 23, "Print"],
Cell[357669, 8066, 11722, 348, 228, "Print"],
Cell[369394, 8416, 1219, 21, 23, "Print"],
Cell[370616, 8439, 2784, 65, 206, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[373461, 8511, 274, 3, 65, "Section"],
Cell[CellGroupData[{
Cell[373760, 8518, 250, 4, 32, "Input"],
Cell[CellGroupData[{
Cell[374035, 8526, 2456, 55, 58, "Print"],
Cell[376494, 8583, 1145, 20, 23, "Print"],
Cell[377642, 8605, 1054, 20, 43, "Print"]
}, Open  ]]
}, Open  ]],
Cell[378723, 8629, 273, 6, 32, "Input"],
Cell[378999, 8637, 449, 7, 51, "Text"],
Cell[CellGroupData[{
Cell[379473, 8648, 220, 4, 32, "Input"],
Cell[CellGroupData[{
Cell[379718, 8656, 669, 9, 23, "Print"],
Cell[380390, 8667, 691, 10, 23, "Print"],
Cell[381084, 8679, 1227, 24, 33, "Print"],
Cell[382314, 8705, 687, 10, 23, "Print"],
Cell[383004, 8717, 687, 9, 23, "Print"],
Cell[383694, 8728, 1227, 24, 33, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[384970, 8758, 222, 4, 32, "Input"],
Cell[CellGroupData[{
Cell[385217, 8766, 783, 18, 33, "Print"],
Cell[386003, 8786, 260, 4, 23, "Print"],
Cell[386266, 8792, 250, 4, 23, "Print"],
Cell[386519, 8798, 784, 18, 33, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[387352, 8822, 220, 4, 32, "Input"],
Cell[CellGroupData[{
Cell[387597, 8830, 1134, 19, 23, "Print"],
Cell[388734, 8851, 11366, 279, 44, "Print"],
Cell[400103, 9132, 3195, 70, 78, "Print"],
Cell[403301, 9204, 3184, 70, 59, "Print"],
Cell[406488, 9276, 1116, 15, 62, "Print"],
Cell[407607, 9293, 906, 12, 23, "Print"],
Cell[408516, 9307, 904, 12, 23, "Print"],
Cell[409423, 9321, 1454, 27, 33, "Print"],
Cell[410880, 9350, 901, 12, 23, "Print"],
Cell[411784, 9364, 1451, 27, 33, "Print"],
Cell[413238, 9393, 15257, 257, 206, "Print"],
Cell[428498, 9652, 1243, 22, 43, "Print"]
}, Open  ]]
}, Open  ]],
Cell[429768, 9678, 226, 6, 32, "Input"],
Cell[CellGroupData[{
Cell[430019, 9688, 2326, 43, 209, "Input"],
Cell[CellGroupData[{
Cell[432370, 9735, 2766, 47, 100, "Print"],
Cell[435139, 9784, 3016, 51, 119, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[438216, 9842, 374, 5, 65, "Section"],
Cell[438593, 9849, 212, 3, 32, "Input"],
Cell[438808, 9854, 400, 7, 51, "Text"],
Cell[CellGroupData[{
Cell[439233, 9865, 2303, 43, 143, "Input"],
Cell[CellGroupData[{
Cell[441561, 9912, 3599, 55, 33, "Print"],
Cell[445163, 9969, 3284, 45, 23, "Print"],
Cell[448450, 10016, 3442, 50, 23, "Print"],
Cell[451895, 10068, 3598, 55, 33, "Print"],
Cell[455496, 10125, 3612, 55, 43, "Print"]
}, Open  ]]
}, Open  ]],
Cell[459135, 10184, 347, 8, 32, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[459519, 10197, 434, 5, 65, "Section"],
Cell[459956, 10204, 405, 7, 32, "Input"],
Cell[CellGroupData[{
Cell[460386, 10215, 846, 16, 121, "Input"],
Cell[461235, 10233, 34585, 572, 367, "Print"],
Cell[495823, 10807, 8684, 158, 188, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[504544, 10970, 1181, 23, 77, "Input"],
Cell[CellGroupData[{
Cell[505750, 10997, 1846, 31, 33, "Print"],
Cell[507599, 11030, 3398, 66, 222, "Print"],
Cell[511000, 11098, 1685, 26, 23, "Print"],
Cell[512688, 11126, 34895, 491, 85, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[547632, 11623, 377, 6, 55, "Input"],
Cell[548012, 11631, 2565, 49, 367, 1219, 25, "CachedBoxData", "BoxData", \
"Print"],
Cell[550580, 11682, 1724, 51, 116, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[552341, 11738, 923, 20, 55, "Input"],
Cell[CellGroupData[{
Cell[553289, 11762, 684, 16, 33, "Print"],
Cell[553976, 11780, 125, 1, 23, "Print"],
Cell[554104, 11783, 303, 6, 23, "Print"],
Cell[554410, 11791, 684, 16, 33, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[555143, 11813, 498, 12, 55, "Input"],
Cell[555644, 11827, 58713, 1932, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[614394, 13764, 836, 20, 121, "Input"],
Cell[615233, 13786, 97, 1, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[615367, 13792, 532, 15, 77, "Input"],
Cell[CellGroupData[{
Cell[615924, 13811, 456, 11, 33, "Print"],
Cell[616383, 13824, 2609, 56, 222, "Print"],
Cell[618995, 13882, 297, 6, 23, "Print"],
Cell[619295, 13890, 1409, 29, 85, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[620753, 13925, 427, 7, 55, "Input"],
Cell[621183, 13934, 2017, 39, 367, 938, 20, "CachedBoxData", "BoxData", \
"Print"],
Cell[623203, 13975, 1518, 44, 98, "Output"]
}, Open  ]],
Cell[624736, 14022, 1249, 34, 187, "Input"],
Cell[CellGroupData[{
Cell[626010, 14060, 225, 4, 55, "Input"],
Cell[626238, 14066, 2026, 40, 367, 963, 21, "CachedBoxData", "BoxData", \
"Print"],
Cell[628267, 14108, 1520, 44, 98, "Output"]
}, Open  ]],
Cell[629802, 14155, 1784, 48, 143, "Input"],
Cell[631589, 14205, 1177, 35, 55, "Input"],
Cell[CellGroupData[{
Cell[632791, 14244, 177, 4, 32, "Input"],
Cell[632971, 14250, 30466, 659, 349, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[663474, 14914, 4756, 147, 231, "Input"],
Cell[668233, 15063, 291, 5, 32, "Output"],
Cell[668527, 15070, 291, 5, 32, "Output"],
Cell[668821, 15077, 291, 5, 32, "Output"],
Cell[669115, 15084, 293, 5, 32, "Output"],
Cell[669411, 15091, 291, 5, 32, "Output"],
Cell[669705, 15098, 291, 5, 32, "Output"],
Cell[669999, 15105, 293, 5, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[670329, 15115, 1103, 32, 55, "Input"],
Cell[671435, 15149, 805812, 14555, 965, 257089, 5558, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1477284, 29709, 966, 17, 99, "Input"],
Cell[1478253, 29728, 22236, 521, 1106, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

